<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'מסננים';
$labels['managefilters'] = 'ניהול מסננים לדואר נכנס';
$labels['filtername'] = 'שם המסנן';
$labels['newfilter'] = 'מסנן חדש';
$labels['filteradd'] = 'הוספת מסנן';
$labels['filterdel'] = 'מחיקת מסנן';
$labels['rules'] = 'כללים';
$labels['actions'] = 'פעולות';
$labels['scope'] = 'היקף';
$labels['moveup'] = 'הזזה מעלה';
$labels['movedown'] = 'הזזה מטה';
$labels['filterallof'] = 'תאימות לכל הכללים שלהלן';
$labels['filteranyof'] = 'תאימות לחלק מהכללים שלהלן';
$labels['filterany'] = 'כל ההודעות';
$labels['filtercontains'] = 'מכיל';
$labels['filternotcontains'] = 'לא מכיל';
$labels['filteris'] = 'שווה ערך ל-';
$labels['filterisnot'] = 'אינו שווה ערך ל-';
$labels['filterexists'] = 'קיים';
$labels['filternotexists'] = 'לא קיים';
$labels['filtermatches'] = 'תואם ביטוי';
$labels['filternotmatches'] = 'לא תואם ביטוי';
$labels['filterregex'] = 'תואם ביטוי מורכב';
$labels['filternotregex'] = 'לא תואם ביטוי מורכב';
$labels['filterunder'] = 'תחת';
$labels['filterover'] = 'מעל';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'MIME Part:';
$labels['mime-message'] = 'הודעה';
$labels['mime-anychild'] = 'הכל';
$labels['mime-type'] = 'סוג';
$labels['mime-subtype'] = 'תת סוג';
$labels['mime-contenttype'] = 'סוג תוכן';
$labels['mime-param'] = 'פרמטר';
$labels['addrule'] = 'הוספת כלל';
$labels['delrule'] = 'מחיקת כלל';
$labels['messagemoveto'] = 'העברת הודעה אל';
$labels['messageredirect'] = 'השמה חדשה של ההודעה אל';
$labels['messagecopyto'] = 'העתקת ההודעה אל';
$labels['messagesendcopy'] = 'משלוח העתק מההודעה אל';
$labels['messagereply'] = 'מענה עם הודעה';
$labels['messagedelete'] = 'מחיקת הודעה';
$labels['messagediscard'] = 'ביטול ההודעה';
$labels['messagekeep'] = 'שמירת הודעה בדואר נכנס';
$labels['messagesrules'] = 'עבור דואר נכנס:';
$labels['messagesactions'] = '...מבצע הפעולות הבאות:';
$labels['add'] = 'הוספה';
$labels['del'] = 'מחיקה';
$labels['sender'] = 'השולח';
$labels['recipient'] = 'הנמען';
$labels['vacationaddr'] = 'כתובות הדוא"ל שלי:';
$labels['vacationdays'] = 'באיזו תדירות ( בימים ) לשלוח הודעות:';
$labels['vacationinterval'] = 'באיזו תדירות לשלוח ההודעה';
$labels['vacationreason'] = 'גוף ההודעה (סיבת החופשה):';
$labels['vacationfrom'] = 'כתובת שולח התשובה:';
$labels['vacationsubject'] = 'נושא ההודעה:';
$labels['days'] = 'ימים';
$labels['seconds'] = 'שניות';
$labels['rulestop'] = 'עצירה של בחינת הכללים';
$labels['enable'] = 'אפשור/ניטרול';
$labels['filterset'] = 'ערכת מסננים';
$labels['filtersets'] = 'קבוצות מסננים';
$labels['filtersetadd'] = 'הוספה של ערכת מסננים';
$labels['filtersetdel'] = 'מחיקת של ערכת מסננים';
$labels['filtersetact'] = 'הפעלה של ערכת המסננים הנוכחית';
$labels['filtersetdeact'] = 'השבתה של ערכת מסננים נוכחית';
$labels['filterseteditraw'] = 'עריכת סינון';
$labels['filtersetswitch'] = 'הפעלה/השבתה ערכת מסננים';
$labels['filterdef'] = 'הגדרת מסנן';
$labels['filtersetname'] = 'שם של ערכת מסננים';
$labels['newfilterset'] = 'ערכת מסננים חדשה';
$labels['active'] = 'פעיל';
$labels['none'] = 'אף אחד מאלה';
$labels['fromset'] = 'מקבוצה';
$labels['fromfile'] = 'מקובץ';
$labels['filterdisabled'] = 'מסנן מושבת';
$labels['filterenabled'] = 'מופעל מסנן';
$labels['countisgreaterthan'] = 'המספר גדול מ-';
$labels['countisgreaterthanequal'] = 'המספר גדול או שווה ל-';
$labels['countislessthan'] = 'המספר קטן מ-';
$labels['countislessthanequal'] = 'המספר קטן או שווה ל-';
$labels['countequals'] = 'המספר שווה ל-';
$labels['countnotequals'] = 'המספר אינו שווה ל ';
$labels['valueisgreaterthan'] = 'הערך גדול מ-';
$labels['valueisgreaterthanequal'] = 'הערך גדול או שווה ל-';
$labels['valueislessthan'] = 'הערך קטן מ-';
$labels['valueislessthanequal'] = 'הערך קטן או שווה ל-';
$labels['valueequals'] = 'הערך שווה ל-';
$labels['valuenotequals'] = 'הערך אינו שוה ל ';
$labels['setflags'] = 'סימון דגלים להודעה';
$labels['addflags'] = 'הוספת דגלים להודעה';
$labels['removeflags'] = 'הסרת דגלים מההודעה';
$labels['flagread'] = 'נקרא';
$labels['flagdeleted'] = 'נמחק';
$labels['flaganswered'] = 'נענה';
$labels['flagflagged'] = 'סומן בדגל';
$labels['flagdraft'] = 'טיוטה';
$labels['addheader'] = 'הוספת כותרת להודעה';
$labels['deleteheader'] = 'הסרת כותרת מההודעה';
$labels['headername'] = 'שם הכותרת';
$labels['headervalue'] = 'תוכן הכותרת';
$labels['headerpos'] = 'מיקום הכותרת';
$labels['headeratstart'] = 'בהתחלה';
$labels['headeratend'] = 'בסוף';
$labels['headeroccurrence'] = 'מופע הכותרת/מיקומה';
$labels['headerfromstart'] = 'מההתחלה';
$labels['headerfromend'] = 'מהסוף';
$labels['headerpatterns'] = 'תבנית תוכנה של הכותרת';
$labels['headermatchtype'] = 'סוג ההתאמה:';
$labels['setvariable'] = 'הגדרת משתנה';
$labels['setvarname'] = 'שם המשתנה:';
$labels['setvarvalue'] = 'ערך המשתנה:';
$labels['setvarmodifiers'] = 'גורם משנה:';
$labels['varlower'] = 'אותיות קטנות';
$labels['varupper'] = 'אותיות גדולות';
$labels['varlowerfirst'] = 'התו הראשון אות קטנה';
$labels['varupperfirst'] = 'התו הראשון אות גדולה';
$labels['varquotewildcard'] = 'תו מיוחד יש לשים בין מרכאות';
$labels['varlength'] = 'אורך';
$labels['notify'] = 'משלוח התראה';
$labels['notifytarget'] = 'יעד התראה:';
$labels['notifymessage'] = 'הודעת התראה (רשות):';
$labels['notifyoptions'] = 'אפשרויות התראה (רשות):';
$labels['notifyfrom'] = 'שולח התראה (רשות):';
$labels['notifyimportance'] = 'חשיובת:';
$labels['notifyimportancelow'] = 'נמוכה';
$labels['notifyimportancenormal'] = 'רגילה';
$labels['notifyimportancehigh'] = 'גבוהה';
$labels['notifymethodmailto'] = 'דוא״ל';
$labels['notifymethodtel'] = 'טלפון';
$labels['notifymethodsms'] = 'מסרון';
$labels['filtercreate'] = 'יצירת מסנן';
$labels['usedata'] = 'שימוש במידע שלהלן ליצירת המסנן:';
$labels['nextstep'] = 'הצעד הבא';
$labels['...'] = '...';
$labels['string'] = 'מחרוזת';
$labels['currdate'] = 'תאריך נוכחי';
$labels['datetest'] = 'תאריך';
$labels['dateheader'] = 'כותרת:';
$labels['year'] = 'שנה';
$labels['month'] = 'חודש';
$labels['day'] = 'יום';
$labels['date'] = 'תאריך (שנה-חודש-יום)';
$labels['julian'] = 'תאריך (יוליאני)';
$labels['hour'] = 'שעה';
$labels['minute'] = 'דקה';
$labels['second'] = 'שניה';
$labels['time'] = 'זמן (שעה:דקה:שניה)';
$labels['iso8601'] = 'תאריך (ISO8601)';
$labels['std11'] = 'תאריך (RFC2822)';
$labels['zone'] = 'איזור זמן';
$labels['weekday'] = 'יום בשבוע (0-6)';
$labels['advancedopts'] = 'אפשרויות מתקדמות';
$labels['body'] = 'גוף ההודעה';
$labels['address'] = 'כתובת';
$labels['envelope'] = 'מעטפה';
$labels['modifier'] = 'גורם שינוי:';
$labels['text'] = 'תמליל';
$labels['undecoded'] = 'לא מקודד ( גולמי )';
$labels['contenttype'] = 'סוג התוכן';
$labels['modtype'] = 'סוג:';
$labels['allparts'] = 'הכל';
$labels['domain'] = 'מתחם';
$labels['localpart'] = 'חלק מקומי';
$labels['user'] = 'משתמש';
$labels['detail'] = 'פרטים';
$labels['comparator'] = 'משווה:';
$labels['default'] = 'ברירת מחדל';
$labels['octet'] = 'strict (octet)';
$labels['asciicasemap'] = 'case insensitive (ascii-casemap)';
$labels['asciinumeric'] = 'numeric (ascii-numeric)';
$labels['index'] = 'אינדקס:';
$labels['indexlast'] = 'בחזרה';
$labels['spamtest'] = 'דרגת הספאם';
$labels['spamtestisgreaterthan'] = 'גדול מ-';
$labels['spamtestisgreaterthanequal'] = 'גדול או שווה ל-';
$labels['spamtestislessthan'] = 'קטן מ-';
$labels['spamtestislessthanequal'] = 'קטן או שווה ל-';
$labels['spamtestequals'] = 'שווה ל-';
$labels['spamtestnotequals'] = 'אינו שווה ל-';
$labels['spamtestisunknown'] = 'לא ידוע';
$labels['vacation'] = 'מחוץ למשרד';
$labels['vacation.reply'] = 'הודעת תשובה';
$labels['vacation.advanced'] = 'הגדרות מתקדמות';
$labels['vacation.from'] = 'כתובת שולח התשובה';
$labels['vacation.subject'] = 'נושא';
$labels['vacation.body'] = 'גוף ההודעה';
$labels['vacation.start'] = 'מועד התחלה';
$labels['vacation.end'] = 'מועד סיום';
$labels['vacation.status'] = 'מצב';
$labels['vacation.on'] = 'מופעל';
$labels['vacation.off'] = 'כבוי';
$labels['vacation.addresses'] = 'כתובות הדוא"ל שלי';
$labels['vacation.interval'] = 'מרווח בין תשובות';
$labels['vacation.after'] = 'הצגת הודעה בדבר היעדרות מהמשרד אחרי ';
$labels['vacation.saving'] = 'שמירת מידע...';
$labels['vacation.action'] = 'פעולה על הודעה נכנסת';
$labels['vacation.keep'] = 'להשאיר';
$labels['vacation.discard'] = 'להפטר';
$labels['vacation.redirect'] = 'הפניה אל';
$labels['vacation.copy'] = 'שליחת העתק אל';
$labels['forward'] = 'העברה';
$labels['forward.redirect'] = 'הפניה אל';
$labels['forward.copy'] = 'שליחת העתק אל';
$labels['forward.on'] = 'מופעל';
$labels['forward.off'] = 'כבוי';
$labels['forward.status'] = 'סטטוס';
$labels['forward.action'] = 'יש לבצע הפעולה הבאה על דואר נכנס:';
$labels['forward.saving'] = 'שמירת מידע...';
$labels['filladdresses'] = 'שימוש בכל כתובת הדוא"ל שלי';
$labels['arialabelfiltersetactions'] = 'פעולות על קבוצה של חוקי סינון';
$labels['arialabelfilteractions'] = 'פעולות מסנן';
$labels['arialabelfilterform'] = 'מאפייני מסנן';
$labels['ariasummaryfilterslist'] = 'רשימה של מסננים';
$labels['ariasummaryfiltersetslist'] = 'רשימת קבוצות של חוקי סינון';
$labels['filterstitle'] = 'ערוך מסנני דואר נכנס';
$labels['vacationtitle'] = 'ערוך כלל מחוץ-אל-משרדי';
$labels['forwardtitle'] = 'עריכה של כלל להעברה';
$labels['message'] = 'הודעה';
$labels['duplicate'] = 'מוכפל';
$labels['notduplicate'] = 'לא מוכפל';
$labels['duplicate.handle'] = 'כינוי';
$labels['duplicate.header'] = 'כותרת';
$labels['duplicate.uniqueid'] = 'מזהה';
$labels['duplicate.seconds'] = 'תם הזמן שהוקצה (שניות):';
$labels['duplicate.last'] = 'יחסית לזמן הביצוע האחרון';
$messages['filterunknownerror'] = 'שגיאת שרת בלתי מוכרת.';
$messages['filterconnerror'] = 'לא ניתן להתחבר לשרת.';
$messages['filterdeleteerror'] = 'לא ניתן למחוק סינון. שגיאת שרת.';
$messages['filterdeleted'] = 'המסנן נמחק בהצלחה.';
$messages['filtersaved'] = 'המסנן נשמר בהצלחה.';
$messages['filtersaveerror'] = 'לא ניתן לשמור סינון. שגיאת שרת.';
$messages['filterformerror'] = 'טופס הסינון מכיל שגיאות';
$messages['filterdeleteconfirm'] = 'האם אכן ברצונך למחוק את המסנן הנבחר?';
$messages['ruledeleteconfirm'] = 'האם אכן ברצונך למחוק את הכלל הנבחר?';
$messages['actiondeleteconfirm'] = 'האם אכן ברצונך למחוק את הפעולה הנבחרת?';
$messages['forbiddenchars'] = 'תווים אסורים בשדה.';
$messages['cannotbeempty'] = 'השדה לא יכול להישאר ריק.';
$messages['ruleexist'] = 'כבר קיים מסנן בשם כזה.';
$messages['setactivateerror'] = 'לא ניתן להפעיל את ערכת המסננים שנבחרה. אירעה שגיאה בצד השרת.';
$messages['setdeactivateerror'] = 'לא ניתן להשבית את ערכת המסננים שנבחרה. אירעה שגיאה בצד השרת.';
$messages['setdeleteerror'] = 'לא ניתן למחוק את ערכת המסננים הנבחרת. אירעה שגיאה בצד השרת.';
$messages['setactivated'] = 'ערכת המסננים הופעלה בהצלחה.';
$messages['setdeactivated'] = 'ערכת המסננים הושבתה בהצלחה.';
$messages['setdeleted'] = 'ערכת המסננים נמחקה בהצלחה.';
$messages['setupdated'] = 'ערכת המסננים עודכנה בהצלחה.';
$messages['setdeleteconfirm'] = 'האם אכן ברצונך למחוק את ערכת המסננים שנבחרה?';
$messages['setcreateerror'] = 'לא ניתן ליצור ערכת מסננים. אירעה שגיאה בצד השרת.';
$messages['setcreated'] = 'ערכת המסננים נוצרה בהצלחה.';
$messages['activateerror'] = 'לא ניתן להפעיל את המסננים הנבחרים. אירעה שגיאה בצד השרת.';
$messages['deactivateerror'] = 'לא ניתן לנטרל את המסננים הנבחרים. אירעה שגיאה בצד השרת.';
$messages['deactivated'] = 'המסננים הופעלו בהצלחה.';
$messages['activated'] = 'המסננים נוטרלו בהצלחה.';
$messages['moved'] = 'המסנן הועבר בהצלחה.';
$messages['moveerror'] = 'לא ניתן להעביר את המסנן הנבחר. אירעה שגיאה בצד השרת.';
$messages['nametoolong'] = 'השם ארוך מדי.';
$messages['namereserved'] = 'השם הזה שמור.';
$messages['setexist'] = 'הערכה כבר קיימת.';
$messages['nodata'] = 'חובה לבחור במיקום אחד לפחות!';
$messages['invaliddateformat'] = 'תאריך לא חוקי אן פורמט לא תקין';
$messages['saveerror'] = 'לא ניתן לשמור המידע בשל שגיאה של השרת';
$messages['vacationsaved'] = 'הגדרת המועד להפעלת ההודעה על היעדרות מהמשרד נשמרה';
$messages['forwardsaved'] = 'מידע להעברה נשמר בהצלחה';
$messages['emptyvacationbody'] = 'גוף של הודעת חופשה נדרש!';
$messages['duplicate.conflict.err'] = 'לא ניתן להוסיף כותרת עם מזהה יחודי';
$messages['disabledaction'] = 'פעולה אסורה';
$messages['lastindexempty'] = 'נחוץ מצביע כאשר סופרים מהסוף';
$messages['noflagset'] = 'יש לסמן לפחות דגל אחד';
