<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail MarkdownEditor plugin      |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['editor_icon_alt'] = 'Éditeur Markdown';
$labels['editor_button_title'] = 'Rédiger le courriel en Markdown et l’envoyer au format HTML.';
$labels['toolbar_button_quit'] = 'Revenir à l’éditeur de texte brut';
$labels['toolbar_button_help'] = 'Ouvrir un guide syntaxique Markdown dans une nouvelle fenêtre';
$labels['toolbar_button_preview'] = 'Aperçu HTML tel qu’il serait envoyé';
$labels['toolbar_button_bold'] = 'Gras';
$labels['toolbar_button_italic'] = 'italique';
$labels['toolbar_button_strike'] = 'Barré';
$labels['toolbar_button_h1'] = '1er niveau de titre';
$labels['toolbar_button_h2'] = '2e niveau de titre';
$labels['toolbar_button_h3'] = '3e niveau de titre';
$labels['toolbar_button_h4'] = '4e niveau de titre';
$labels['toolbar_button_h5'] = '5e niveau de titre';
$labels['toolbar_button_h6'] = '6e niveau de titre';
$labels['toolbar_button_blockquote'] = 'Citation';
$labels['toolbar_button_unordered_list'] = 'Liste à puces';
$labels['toolbar_button_ordered_list'] = 'Liste numérotée';
$labels['toolbar_button_link'] = 'Lien';
$labels['toolbar_button_image'] = 'Image';
$labels['toolbar_button_undo'] = 'Annuler';
$labels['toolbar_button_redo'] = 'Refaire';
