<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Архива ';
$labels['buttontitle'] = 'Архивирај ја оваа порака ';
$labels['archived'] = 'Успешно архивирана ';
$labels['archivedreload'] = 'Успешно архивирано. Вчитај ја страната повторно за да ги видиш новите архивирани папки.';
$labels['archiveerror'] = 'Некои пораки не може да бидат архивирани ';
$labels['archivefolder'] = 'Архива ';
$labels['settingstitle'] = 'Архива ';
$labels['archivetype'] = 'Подели архива по ';
$labels['archivetypeyear'] = 'Година (пр. Архива/2012/06)';
$labels['archivetypemonth'] = 'Месец (пр. Архива/2012/06)';
$labels['archivetypefolder'] = 'Оригинална папка ';
$labels['archivetypesender'] = 'Електронска пошта на испраќач';
$labels['unkownsender'] = 'Непознато ';
$labels['readonarchive'] = 'Обележи ја пораката како прочитана на архивата ';
