<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Geymsla';
$labels['buttontitle'] = 'Setja þessi skilaboð í safngeymslu';
$labels['archived'] = 'Tókst að setja í geymslu';
$labels['archivedreload'] = 'Tókst að setja í geymslu. Endurlestu síðuna til að sjá nýju geymslumöppurnar.';
$labels['archiveerror'] = 'Ekki var hægt að setja öll skilaboð í safngeymslu';
$labels['archivefolder'] = 'Geymsla';
$labels['settingstitle'] = 'Geymsla';
$labels['archivetype'] = 'Skipta geymslu upp eftir';
$labels['archivetypeyear'] = 'ári (t.d. Geymsla/2012)';
$labels['archivetypemonth'] = 'mánuði (t.d. Geymsla/2012/06)';
$labels['archivetypetbmonth'] = 'mánuði - samhæft við Thunderbird (t.d. Geymsla/2012/2012-06)';
$labels['archivetypefolder'] = 'Upprunaleg mappa';
$labels['archivetypefolderyear'] = 'Ár og upprunaleg mappa (t.d. Geymsla/2012/...)';
$labels['archivetypefoldermonth'] = 'Ár, mánuður og upprunaleg mappa (t.d. Geymsla/2012/06/...)';
$labels['archivetypesender'] = 'Tölvupóstfang sendanda';
$labels['unkownsender'] = 'óþekkt';
$labels['readonarchive'] = 'Merkja skilaboð sem lesin þegar þau eru lesin í safni';
