<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Deelen';
$labels['myrights'] = 'Zougrëffsrechter';
$labels['username'] = 'Benotzer:';
$labels['advanced'] = 'Avancéierte Modus';
$labels['add'] = 'Dobäisetzen';
$labels['newuser'] = 'Element dobäisetzen';
$labels['editperms'] = 'Zougrëffsrechter beaarbechten';
$labels['actions'] = 'Optioune fir d\'Zougrëffsrechter';
$labels['anyone'] = 'All d\'Benotzer (jiddwereen)';
$labels['anonymous'] = 'Gaascht (anonym)';
$labels['identifier'] = 'Identifiant';
$labels['acll'] = 'Noschloen';
$labels['aclr'] = 'Messagë liesen';
$labels['acls'] = 'Lies-Status behalen';
$labels['aclp'] = 'Schécken';
$labels['aclc'] = 'Ënnerdossieren erstellen';
$labels['aclk'] = 'Ënnerdossieren erstellen';
$labels['acld'] = 'Messagë läschen';
$labels['aclt'] = 'Messagë läschen';
$labels['acle'] = 'Ausläschen';
$labels['aclx'] = 'Dossier läschen';
$labels['acla'] = 'Administréieren';
$labels['aclfull'] = 'Voll Kontroll';
$labels['aclother'] = 'Aner';
$labels['aclread'] = 'Liesen';
$labels['aclwrite'] = 'Schreiwen';
$labels['acldelete'] = 'Läschen';
$labels['shortacll'] = 'Noschloen';
$labels['shortaclr'] = 'Liesen';
$labels['shortacls'] = 'Halen';
$labels['shortaclw'] = 'Schreiwen';
$labels['shortacli'] = 'Drasetze';
$labels['shortaclp'] = 'Schécken';
$labels['shortaclc'] = 'Erstellen';
$labels['shortaclk'] = 'Erstellen';
$labels['shortacld'] = 'Läschen';
$labels['shortaclt'] = 'Läschen';
$labels['shortacle'] = 'Ausläschen';
$labels['shortaclx'] = 'Dossier läschen';
$labels['shortacla'] = 'Administréieren';
$labels['shortacln'] = 'Kommentéieren';
$labels['shortaclother'] = 'Aner';
$labels['shortaclread'] = 'Liesen';
$labels['shortaclwrite'] = 'Schreiwen';
$labels['shortacldelete'] = 'Läschen';
$labels['longacldelete'] = 'Messagë kënne geläscht ginn';
$labels['longaclother'] = 'Aner Zougrëffsrechter';
$labels['ariasummaryacltable'] = 'Lëscht vun Zougrëffsrechter';
$messages['deleting'] = 'Zougrëffsrechter gi geläscht...';
$messages['saving'] = 'Zougrëffsrechter gi gespäichert...';
$messages['updatesuccess'] = 'Rechter erfollegräich geännert';
$messages['deletesuccess'] = 'Rechter erfollegräich geläscht';
$messages['createsuccess'] = 'Rechter erfollegräich dobäigesat';
$messages['updateerror'] = 'D\'Zougrëffsrechter kënnen net aktualiséiert ginn';
$messages['deleteerror'] = 'Rechter kënnen net geläscht ginn';
$messages['createerror'] = 'Zougrëffsrechter kënnen net dobäigesat ginn';
$messages['deleteconfirm'] = 'Bass du dir sécher, dass du d\'Zougrëffsrechter fir déi ausgewielte Benotzer wëlls ewechhuelen?';
$messages['norights'] = 'Et goufe keng Rechter uginn! ';
$messages['nouser'] = 'Et gouf kee Benotzernumm uginn!';
