<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Arquivo';
$labels['buttontitle'] = 'Arquivar esta mensagem';
$labels['archived'] = 'Arquivada com sucesso';
$labels['archivedreload'] = 'Arquivado com sucesso. Recarregue a página para ver as novas pastas de arquivo.';
$labels['archiveerror'] = 'Algumas mensagens não puderam ser arquivadas';
$labels['archivefolder'] = 'Arquivo';
$labels['settingstitle'] = 'Arquivo';
$labels['archivetype'] = 'Dividir arquivo por';
$labels['archivetypeyear'] = 'Ano (ex. Arquivo/2012)';
$labels['archivetypemonth'] = 'Mês (ex. Arquivo/2012/06)';
$labels['archivetypetbmonth'] = 'Mês - Compatível com Thunderbird (ex. Arquivo/2012/2012-06)';
$labels['archivetypefolder'] = 'Pasta original';
$labels['archivetypefolderyear'] = 'Ano e pasta original (ex. Arquivo/2012/...)';
$labels['archivetypefoldermonth'] = 'Ano, mês e pasta original (ex. Arquivo/2012/06/...)';
$labels['archivetypesender'] = 'Email do remetente';
$labels['unkownsender'] = 'desconhecido';
$labels['readonarchive'] = 'Marcar a mensagem como lida ao arquivar';
