<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Filtri';
$labels['managefilters'] = 'Gestione dei filtri per la posta in arrivo';
$labels['filtername'] = 'Nome del filtro';
$labels['newfilter'] = 'Nuovo filtro';
$labels['filteradd'] = 'Aggiungi filtro';
$labels['filterdel'] = 'Elimina filtro';
$labels['rules'] = 'Regole';
$labels['actions'] = 'Azioni';
$labels['scope'] = 'Contesto';
$labels['moveup'] = 'Sposta sopra';
$labels['movedown'] = 'Sposta sotto';
$labels['filterallof'] = 'che soddisfa tutte le regole seguenti';
$labels['filteranyof'] = 'che soddisfa una qualsiasi delle regole seguenti';
$labels['filterany'] = 'tutti i messaggi';
$labels['filtercontains'] = 'contiene';
$labels['filternotcontains'] = 'non contiene';
$labels['filteris'] = 'è uguale a';
$labels['filterisnot'] = 'è diverso da';
$labels['filterexists'] = 'esiste';
$labels['filternotexists'] = 'non esiste';
$labels['filtermatches'] = 'corrisponde all\'espressione';
$labels['filternotmatches'] = 'non corrisponde all\'espressione';
$labels['filterregex'] = 'corrisponde all\'espressione regolare';
$labels['filternotregex'] = 'non corrisponde all\'espressione regolare';
$labels['filterunder'] = 'sotto';
$labels['filterover'] = 'sopra';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'Parte MIME:';
$labels['mime-message'] = 'messaggio';
$labels['mime-anychild'] = 'qualsiasi';
$labels['mime-type'] = 'tipo';
$labels['mime-subtype'] = 'sottotipo';
$labels['mime-contenttype'] = 'tipo contenuto';
$labels['mime-param'] = 'parametro';
$labels['addrule'] = 'Aggiungi regola';
$labels['delrule'] = 'Elimina regola';
$labels['messagemoveto'] = 'Sposta il messaggio in';
$labels['messageredirect'] = 'Inoltra il messaggio a';
$labels['messagecopyto'] = 'Copia messaggio in';
$labels['messagesendcopy'] = 'Invia copia a';
$labels['messagereply'] = 'Rispondi con messaggio';
$labels['messagedelete'] = 'Elimina il messaggio';
$labels['messagediscard'] = 'Rifiuta con messaggio';
$labels['messagekeep'] = 'Mantieni messaggio nella posta in arrivo';
$labels['messagesrules'] = 'Per la posta in arrivo';
$labels['messagesactions'] = '...esegui le seguenti azioni:';
$labels['add'] = 'Aggiungi';
$labels['del'] = 'Elimina';
$labels['sender'] = 'Mittente';
$labels['recipient'] = 'Destinatario';
$labels['vacationaddr'] = 'I miei indirizzi di posta:';
$labels['vacationdays'] = 'Ogni quanti giorni ribadire il messaggio allo stesso mittente';
$labels['vacationinterval'] = 'Ogni quanto tempo inviare i messaggi:';
$labels['vacationreason'] = 'Corpo del messaggio (dettagli relativi all\'assenza):';
$labels['vacationfrom'] = 'Indirizzo di risposta del mittente:';
$labels['vacationsubject'] = 'Oggetto del messaggio';
$labels['days'] = 'giorni';
$labels['seconds'] = 'secondi';
$labels['rulestop'] = 'Non valutare le regole successive';
$labels['enable'] = 'Abilita/disabilita';
$labels['filterset'] = 'Gruppo di filtri';
$labels['filtersets'] = 'Gruppi di filtri';
$labels['filtersetadd'] = 'Aggiungi gruppo di filtri';
$labels['filtersetdel'] = 'Elimina gruppo di filtri';
$labels['filtersetact'] = 'Attiva il gruppo di filtri corrente';
$labels['filtersetdeact'] = 'Disattiva il gruppo di filtri corrente';
$labels['filterseteditraw'] = 'Modifica gruppo di filtri';
$labels['filtersetswitch'] = 'Abilita/disabilita gruppo di filtri';
$labels['filterdef'] = 'Definizione del filtro';
$labels['filtersetname'] = 'Nome del gruppo di filtri';
$labels['newfilterset'] = 'Nuovo gruppo di filtri';
$labels['active'] = 'attivo';
$labels['none'] = 'nessuno';
$labels['fromset'] = 'dal gruppo';
$labels['fromfile'] = 'dal file';
$labels['filterdisabled'] = 'Filtro disabilitato';
$labels['filterenabled'] = 'Filtro abilitato';
$labels['countisgreaterthan'] = 'somma maggiore di';
$labels['countisgreaterthanequal'] = 'somma maggiore uguale  a';
$labels['countislessthan'] = 'somma minore di';
$labels['countislessthanequal'] = 'somma minore o uguale a';
$labels['countequals'] = 'somma uguale a';
$labels['countnotequals'] = 'il conteggio non è uguale a';
$labels['valueisgreaterthan'] = 'valore maggiore di';
$labels['valueisgreaterthanequal'] = 'valore maggiore uguale a';
$labels['valueislessthan'] = 'valore minore di';
$labels['valueislessthanequal'] = 'valore minore uguale di';
$labels['valueequals'] = 'valore uguale a';
$labels['valuenotequals'] = 'il valore non è uguale a';
$labels['setflags'] = 'Contrassegna il messaggio';
$labels['addflags'] = 'Aggiungi contrassegni al messaggio';
$labels['removeflags'] = 'Rimuovi contrassegni dal messaggio';
$labels['flagread'] = 'Letto';
$labels['flagdeleted'] = 'Eliminato';
$labels['flaganswered'] = 'Risposto';
$labels['flagflagged'] = 'Contrassegnato';
$labels['flagdraft'] = 'Bozza';
$labels['addheader'] = 'Aggiungi intestazioni al messaggio';
$labels['deleteheader'] = 'Rimuovi intestazioni al messaggio';
$labels['headername'] = 'Nome dell\'intestazione';
$labels['headervalue'] = 'Valore dell\'intestazione';
$labels['headerpos'] = 'Posizione dell\'intestazione';
$labels['headeratstart'] = 'all\'inizio';
$labels['headeratend'] = 'alla fine';
$labels['headeroccurrence'] = 'Intestazione occorrenza/posizione';
$labels['headerfromstart'] = 'dall\'inizio';
$labels['headerfromend'] = 'dalla fine';
$labels['headerpatterns'] = 'Modelli di valore dell\'intestazione';
$labels['headermatchtype'] = 'tipo di corrispondenza:';
$labels['setvariable'] = 'Imposta variabile';
$labels['setvarname'] = 'Nome variabile:';
$labels['setvarvalue'] = 'Valore variabile:';
$labels['setvarmodifiers'] = 'Modificatori:';
$labels['varlower'] = 'minuscole';
$labels['varupper'] = 'maiuscole';
$labels['varlowerfirst'] = 'primo carattere minuscolo';
$labels['varupperfirst'] = 'primo carattere maiuscolo';
$labels['varquotewildcard'] = 'caratteri speciali di quoting';
$labels['varlength'] = 'lunghezza';
$labels['notify'] = 'Invia notifica';
$labels['notifytarget'] = 'Destinatario della notifica:';
$labels['notifymessage'] = 'Messaggio di notifica (opzionale):';
$labels['notifyoptions'] = 'Opzioni di notifica (opzionale):';
$labels['notifyfrom'] = 'Mittente della notifica (opzionale):';
$labels['notifyimportance'] = 'Importanza:';
$labels['notifyimportancelow'] = 'bassa';
$labels['notifyimportancenormal'] = 'normale';
$labels['notifyimportancehigh'] = 'alta';
$labels['notifymethodmailto'] = 'Email';
$labels['notifymethodtel'] = 'Telefono';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Crea filtro';
$labels['usedata'] = 'Utilizza i seguenti dati nel filtro';
$labels['nextstep'] = 'Passo successivo';
$labels['...'] = '...';
$labels['string'] = 'Stringa';
$labels['currdate'] = 'Data attuale';
$labels['datetest'] = 'Data';
$labels['dateheader'] = 'intestazione:';
$labels['year'] = 'anno';
$labels['month'] = 'mese';
$labels['day'] = 'giorno';
$labels['date'] = 'data (aaaa-mm-gg)';
$labels['julian'] = 'data (giuliana)';
$labels['hour'] = 'ora';
$labels['minute'] = 'minuto';
$labels['second'] = 'secondo';
$labels['time'] = 'ora (hh:mm:ss)';
$labels['iso8601'] = 'data (ISO8601)';
$labels['std11'] = 'data (RFC2822)';
$labels['zone'] = 'fuso orario';
$labels['weekday'] = 'giorno della settimana (0-6)';
$labels['advancedopts'] = 'Opzioni avanzate';
$labels['body'] = 'Corpo';
$labels['address'] = 'indirizzo';
$labels['envelope'] = 'busta';
$labels['modifier'] = 'modificatore:';
$labels['text'] = 'testo';
$labels['undecoded'] = 'non decodificato (raw)';
$labels['contenttype'] = 'tipo di contenuto';
$labels['modtype'] = 'tipo:';
$labels['allparts'] = 'tutto';
$labels['domain'] = 'dominio';
$labels['localpart'] = 'parte locale';
$labels['user'] = 'user';
$labels['detail'] = 'dettaglio';
$labels['comparator'] = 'comparatore:';
$labels['default'] = 'predefinito';
$labels['octet'] = 'esatto (octet)';
$labels['asciicasemap'] = 'non differenziare maiuscole/minuscole (ascii-casemap)';
$labels['asciinumeric'] = 'numerico (ascii-numeric)';
$labels['index'] = 'indice:';
$labels['indexlast'] = 'indietro';
$labels['spamtest'] = 'Livello spam';
$labels['spamtestisgreaterthan'] = 'è più grande di';
$labels['spamtestisgreaterthanequal'] = 'è maggiore o uguale a';
$labels['spamtestislessthan'] = 'è meno di';
$labels['spamtestislessthanequal'] = 'è minore o uguale a';
$labels['spamtestequals'] = 'è uguale a';
$labels['spamtestnotequals'] = 'è diverso da';
$labels['spamtestisunknown'] = 'è sconosciuto';
$labels['vacation'] = 'Fuori ufficio';
$labels['vacation.reply'] = 'Messaggio di risposta';
$labels['vacation.advanced'] = 'Impostazioni avanzate';
$labels['vacation.from'] = 'Indirizzo di risposta del mittente:';
$labels['vacation.subject'] = 'Oggetto';
$labels['vacation.body'] = 'Testo';
$labels['vacation.start'] = 'Data di inizio';
$labels['vacation.end'] = 'Data di fine';
$labels['vacation.status'] = 'Stato';
$labels['vacation.on'] = 'Attivato';
$labels['vacation.off'] = 'Disattivato';
$labels['vacation.addresses'] = 'I miei indirizzi di posta';
$labels['vacation.interval'] = 'Intervallo di risposta';
$labels['vacation.after'] = 'Inserisci la regola di vacanza dopo';
$labels['vacation.saving'] = 'Salvataggio...';
$labels['vacation.action'] = 'Azione messaggio in arrivo';
$labels['vacation.keep'] = 'Mantieni';
$labels['vacation.discard'] = 'Scarta';
$labels['vacation.redirect'] = 'Ridireziona a';
$labels['vacation.copy'] = 'Invia copia a';
$labels['forward'] = 'Inoltro';
$labels['forward.redirect'] = 'Ridireziona a';
$labels['forward.copy'] = 'Invia copia a';
$labels['forward.on'] = 'Attivato';
$labels['forward.off'] = 'Disattivato';
$labels['forward.status'] = 'Stato:';
$labels['forward.action'] = 'Esegui le seguenti azioni all\'arrivo di messaggi di posta:';
$labels['forward.saving'] = 'Salvataggio...';
$labels['filladdresses'] = 'Riempire con tutti i miei indirizzi';
$labels['arialabelfiltersetactions'] = 'Azione gruppi di filtri ';
$labels['arialabelfilteractions'] = 'Azione filtri';
$labels['arialabelfilterform'] = 'Proprietà filtri';
$labels['ariasummaryfilterslist'] = 'Lista dei filtri';
$labels['ariasummaryfiltersetslist'] = 'Lista di grippi di filtri';
$labels['filterstitle'] = 'Modifica filtri dei messaggio in arrivo';
$labels['vacationtitle'] = 'Modifica le regole del Risponditore automatico';
$labels['forwardtitle'] = 'Modifica le regole di inoltro della posta';
$labels['message'] = 'Messaggio';
$labels['duplicate'] = 'è duplicato';
$labels['notduplicate'] = 'non è duplicato';
$labels['duplicate.handle'] = 'gestore:';
$labels['duplicate.header'] = 'intestazione:';
$labels['duplicate.uniqueid'] = 'identificatore:';
$labels['duplicate.seconds'] = 'timeout (secondi):';
$labels['duplicate.last'] = 'rispetto all\'ultima esecuzione';
$messages['filterunknownerror'] = 'Errore sconosciuto del server.';
$messages['filterconnerror'] = 'Collegamento non riuscito al server.';
$messages['filterdeleteerror'] = 'Eliminazione del filtro non riuscita. Si è verificato un errore nel server.';
$messages['filterdeleted'] = 'Filtro eliminato correttamente.';
$messages['filtersaved'] = 'Filtro salvato correttamente.';
$messages['filtersaveerror'] = 'Salvataggio del filtro non riuscito. Si è verificato un errore nel server.';
$messages['filterformerror'] = 'Il modulo del filtro contiene errori.';
$messages['filterdeleteconfirm'] = 'Vuoi veramente eliminare il filtro selezionato?';
$messages['ruledeleteconfirm'] = 'Sei sicuro di voler eliminare la regola selezionata?';
$messages['actiondeleteconfirm'] = 'Sei sicuro di voler eliminare l\'azione selezionata?';
$messages['forbiddenchars'] = 'Caratteri non consentiti nel campo.';
$messages['cannotbeempty'] = 'Il campo non può essere vuoto.';
$messages['ruleexist'] = 'Esiste già un filtro con questo nome.';
$messages['setactivateerror'] = 'Impossibile attivare il gruppo di filtri selezionato. Errore del server.';
$messages['setdeactivateerror'] = 'Impossibile disattivare il gruppo di filtri selezionato. Errore del server.';
$messages['setdeleteerror'] = 'Impossibile eliminare il gruppo di filtri selezionato. Errore del server.';
$messages['setactivated'] = 'Gruppo di filtri attivato correttamente.';
$messages['setdeactivated'] = 'Gruppo di filtri disattivato correttamente.';
$messages['setdeleted'] = 'Gruppo di filtri eliminato correttamente.';
$messages['setupdated'] = 'Gruppo di filtri aggiornato correttamente.';
$messages['setdeleteconfirm'] = 'Sei sicuro di voler eliminare il gruppo di filtri selezionato?';
$messages['setcreateerror'] = 'Impossibile creare il gruppo di filtri. Errore del server.';
$messages['setcreated'] = 'Gruppo di filtri creato correttamente.';
$messages['activateerror'] = 'Impossibile abilitare i filtri selezionati. Errore del server.';
$messages['deactivateerror'] = 'Impossibile disabilitare i filtri selezionati. Errore del server.';
$messages['deactivated'] = 'Filtro/i disabilitato/i correttamente.';
$messages['activated'] = 'Filtro/i abilitato/i correttamente.';
$messages['moved'] = 'Filtro/i spostato/i correttamente.';
$messages['moveerror'] = 'Impossibile spostare il filtro selezionato. Errore del server.';
$messages['nametoolong'] = 'Nome troppo lungo.';
$messages['namereserved'] = 'Nome riservato.';
$messages['setexist'] = 'Il gruppo esiste già.';
$messages['nodata'] = 'Selezionare almeno una posizione.';
$messages['invaliddateformat'] = 'Formato della data non valido';
$messages['saveerror'] = 'Impossibile salvare i dati. Errore del server.';
$messages['vacationsaved'] = 'Dati di vacanza salvati correttamente.';
$messages['forwardsaved'] = 'Dati di inoltro salvati correttamente.';
$messages['emptyvacationbody'] = 'Il testo del messaggio non può essere vuoto!';
$messages['duplicate.conflict.err'] = 'Sia l\'intestazione che l\'identificatore univoco non sono consentiti.';
$messages['disabledaction'] = 'Azione non permessa.';
$messages['lastindexempty'] = 'L\'indice è richiesto quando si conta dalla fine';
$messages['noflagset'] = 'Deve essere selezionato almeno un flag.';
