<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'តម្រង';
$labels['managefilters'] = 'គ្រប់គ្រង​តម្រប​សំបុត្រ​ចូល';
$labels['filtername'] = 'ឈ្មោះ​តម្រង';
$labels['newfilter'] = 'តម្រង​ថ្មី';
$labels['filteradd'] = 'បន្ថែម​តម្រង';
$labels['filterdel'] = 'លុប​តម្រង';
$labels['moveup'] = 'រុញ​ទៅ​លើ';
$labels['movedown'] = 'រុញ​ចុះ​ក្រោម';
$labels['filterallof'] = 'ត្រូវ​គ្នា​ទៅ​នឹង​លក្ខខណ្ឌ​ទាំង​នេះ';
$labels['filteranyof'] = 'ត្រូវ​គ្នា​ទៅ​នឹង​លក្ខខណ្ឌ​ណាមួយ';
$labels['filterany'] = 'សារ​ទាំង​អស់';
$labels['filtercontains'] = 'មាន​ផ្ទុក';
$labels['filternotcontains'] = 'មិន​មាន';
$labels['filteris'] = 'ស្មើ​នឹង';
$labels['filterisnot'] = 'មិន​ស្មើ​នឹង';
$labels['filterexists'] = 'មាន';
$labels['filternotexists'] = 'មិន​មាន';
$labels['filtermatches'] = 'សញ្ញាណ​ដែល​ត្រូវ';
$labels['filterunder'] = 'ក្រោម';
$labels['filterover'] = 'លើ';
$labels['addrule'] = 'បន្ថែម​លក្ខខណ្ឌ';
$labels['delrule'] = 'លុប​លក្ខខណ្ឌ';
$labels['messagemoveto'] = 'ផ្លាស់​ទី​សារ​ទៅ';
$labels['messageredirect'] = 'ប្ដូរ​ទិសដៅ​សារ​ទៅ';
$labels['messagecopyto'] = 'ចម្លង​សារ​ទៅ';
$labels['messagesendcopy'] = 'ផ្ញើ​ការ​ចម្លង​សារ​ទៅ';
$labels['messagereply'] = 'ឆ្លើយ​តប​ជាមួយ​សារ';
$labels['messagedelete'] = 'លុប​សារ';
$labels['messagediscard'] = 'បោះបង់​ជាមួយ​នឹង​សារ';
$labels['messagesrules'] = 'សម្រាប់​សំបុត្រ​ចូល៖';
$labels['messagesactions'] = '...ប្រតិបត្តិ​សកម្មភាព​ទាំង​នេះ៖';
$labels['add'] = 'បន្ថែម';
$labels['del'] = 'លុប';
$labels['sender'] = 'អ្នក​ផ្ញើ';
$labels['recipient'] = 'អ្នក​ទទួល';
$labels['vacationdays'] = 'តើ​ផ្ញើ​សារ​ញឹកញាប់​ប៉ុណ្ណា (ក្នុង​មួយ​ថ្ងៃ)៖';
$labels['vacationreason'] = 'តួ​សារ (ហេតុផល​វិស្សមកាល)៖';
$labels['vacationsubject'] = 'ប្រធានបទ​សារ៖';
$labels['days'] = 'ថ្ងៃ';
$labels['seconds'] = 'វិនាទី';
$labels['rulestop'] = 'ឈប់​គិត​ទៅ​លើ​លក្ខខណ្ឌ';
$labels['enable'] = 'បើក/បិទ';
$labels['filterdef'] = 'អត្ថន័យ​តម្រង';
$labels['active'] = 'សកម្ម';
$labels['none'] = 'គ្មាន';
$labels['fromfile'] = 'ពី​ឯកសារ';
$labels['filterdisabled'] = 'បាន​បិទ​តម្រង';
$labels['valuenotequals'] = 'តម្លៃ​មិន​ស្មើ​នឹង';
$labels['flagread'] = 'បាន​អាន';
$labels['flagdeleted'] = 'បាន​លុប';
$labels['flaganswered'] = 'បាន​ឆ្លើយ';
$labels['flagflagged'] = 'បាន​ដាក់​ទង់';
$labels['flagdraft'] = 'ការ​ព្រាង';
$labels['setvariable'] = 'កំណត់​អថេរ';
$labels['setvarname'] = 'ឈ្មោះ​អថេរ៖';
$labels['setvarvalue'] = 'តម្លៃ​អថេរ៖';
$labels['varlower'] = 'អក្សរ​តូច';
$labels['varupper'] = 'អក្សរ​ធំ';
$labels['varlength'] = 'ប្រវែង';
$labels['notify'] = 'ផ្ញើ​ការ​ជូន​ដំណឹង';
$labels['notifyimportance'] = 'សំខាន់៖';
$labels['notifyimportancelow'] = 'ទាប';
$labels['notifyimportancenormal'] = 'ធម្មតា';
$labels['notifyimportancehigh'] = 'ខ្ពស់';
$labels['notifymethodmailto'] = 'អ៊ីមែល';
$labels['notifymethodtel'] = 'ទូរស័ព្ទ';
$labels['filtercreate'] = 'បង្កើត​តម្រង';
$labels['usedata'] = 'ប្រើ​ទិន្នន័យ​ទាំង​នេះ​ក្នុង​តម្រង៖';
$labels['nextstep'] = 'ជំហាន​បន្ទាប់';
$labels['...'] = '...';
$labels['currdate'] = 'កាលបរិច្ឆេទ​បច្ចុប្បន្ន';
$labels['datetest'] = 'កាលបរិច្ឆេទ';
$labels['dateheader'] = 'ក្បាល៖';
$labels['year'] = 'ឆ្នាំ';
$labels['month'] = 'ខែ';
$labels['day'] = 'ថ្ងៃ';
$labels['date'] = 'កាល​បរិច្ឆេទ (yyyy-mm-dd)';
$labels['julian'] = 'កាល​បរិច្ឆេទ (julian)';
$labels['hour'] = 'ម៉ោង';
$labels['minute'] = 'នាទី';
$labels['second'] = 'វិនាទី';
$labels['time'] = 'ម៉ោង (hh:mm:ss)';
$labels['iso8601'] = 'កាល​បរិច្ឆេទ (ISO8601)';
$labels['std11'] = 'កាល​បរិច្ឆេទ (RFC2822)';
$labels['zone'] = 'តំបន់​ម៉ោង';
$labels['weekday'] = 'ថ្ងៃ​សប្ដាហ៍ (0-6)';
$labels['advancedopts'] = 'ជម្រើស​កម្រិត​ខ្ពស់';
$labels['body'] = 'តួ';
$labels['address'] = 'អាសយដ្ឋាន';
$labels['envelope'] = 'ស្រោម​សំបុត្រ';
$labels['text'] = 'អត្ថបទ';
$labels['contenttype'] = 'ប្រភេទ​មាតិកា';
$labels['modtype'] = 'ប្រភេទ៖';
$labels['allparts'] = 'ទាំងអស់';
$labels['domain'] = 'ដូមេន';
$labels['localpart'] = 'ផ្នែក​មូលដ្ឋាន';
$labels['user'] = 'អ្នកប្រើ';
$labels['detail'] = 'លម្អិត';
$labels['index'] = 'លិបិក្រម៖';
$labels['indexlast'] = 'បកក្រោយ';
$labels['spamtestequals'] = 'ស្មើ​នឹង';
$labels['spamtestnotequals'] = 'មិន​ស្មើ​នឹង';
$labels['vacation.subject'] = 'ចំណងជើង';
$labels['vacation.body'] = 'តួ';
$labels['vacation.keep'] = 'រក្សា';
$labels['duplicate.header'] = 'ក្បាល៖';
