<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Архів';
$labels['buttontitle'] = 'Архівувати це повідомлення';
$labels['archived'] = 'Перенесено в архів';
$labels['archivedreload'] = 'Успішно заархівовано. Перезавантажте сторінку, щоб побачити нові теки з архівами.';
$labels['archiveerror'] = 'Деякі повідомлення не вдалося заархівувати';
$labels['archivefolder'] = 'Архів';
$labels['settingstitle'] = 'Архів';
$labels['archivetype'] = 'Розділити архів по';
$labels['archivetypeyear'] = 'Рік (наприклад Архів/2012)';
$labels['archivetypemonth'] = 'Місяць (наприклад Архів/2012/06)';
$labels['archivetypetbmonth'] = 'Місяць - Thunderbird сумісний (наприклад Архів/2012/2012-06)';
$labels['archivetypefolder'] = 'Оригінальна тека';
$labels['archivetypefolderyear'] = 'Рік і оригінальна тека (наприклад Архів/2012/...)';
$labels['archivetypefoldermonth'] = 'Рік, місяць і оригінальна тека (наприклад Архів/2012/06/...)';
$labels['archivetypesender'] = 'Відправник email';
$labels['unkownsender'] = 'невідомо';
$labels['readonarchive'] = 'Позначити повідомлення як прочитане по архіву';
