<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Hidlyddion';
$labels['managefilters'] = 'Rheoli hidlyddion ebost i fewn';
$labels['filtername'] = 'Enw hidlydd';
$labels['newfilter'] = 'Hidlydd newydd';
$labels['filteradd'] = 'Ychwanegu hidlydd';
$labels['filterdel'] = 'Dileu hidlydd';
$labels['rules'] = 'Rheolau';
$labels['actions'] = 'Gweithredoedd';
$labels['scope'] = 'Amrediad';
$labels['moveup'] = 'Symud i fyny';
$labels['movedown'] = 'Symud i lawr';
$labels['filterallof'] = 'sy\'n cyfateb i\'r holl reolau canlynol';
$labels['filteranyof'] = 'sy\'n cyfateb i unrhyw un i\'r rheolau canlynol';
$labels['filterany'] = 'pob neges';
$labels['filtercontains'] = 'yn cynnwys';
$labels['filternotcontains'] = 'ddim yn cynnwys';
$labels['filteris'] = 'yn hafal i';
$labels['filterisnot'] = 'ddim yn hafal i';
$labels['filterexists'] = 'yn bodoli';
$labels['filternotexists'] = 'ddim yn bodoli';
$labels['filtermatches'] = 'yn cyfateb i\'r mynegiant';
$labels['filternotmatches'] = 'ddim yn cyfateb i\'r mynegiant';
$labels['filterregex'] = 'yn cyfateb i\'r mynegiant rheolaidd';
$labels['filternotregex'] = 'ddim yn cyfateb i\'r mynegiant rheolaidd';
$labels['filterunder'] = 'o dan';
$labels['filterover'] = 'dros';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'Rhan MIME:';
$labels['mime-message'] = 'neges';
$labels['mime-anychild'] = 'unrhywun';
$labels['mime-type'] = 'math';
$labels['mime-subtype'] = 'is-fath';
$labels['mime-contenttype'] = 'content-type';
$labels['mime-param'] = 'parameter';
$labels['addrule'] = 'Ychwanegu rheol';
$labels['delrule'] = 'Dileu rheol';
$labels['messagemoveto'] = 'Symud neges i';
$labels['messageredirect'] = 'Ail-gyfeirio neges i';
$labels['messagecopyto'] = 'Copio neges i';
$labels['messagesendcopy'] = 'Danfon copi o\'r neges i';
$labels['messagereply'] = 'Ymateb gyda\'r neges';
$labels['messagedelete'] = 'Dileu neges';
$labels['messagediscard'] = 'Gwaredu gyda neges';
$labels['messagekeep'] = 'Cadw\'r neges yn y Mewnflwch';
$labels['messagesrules'] = 'Ar gyfer ebost i fewn:';
$labels['messagesactions'] = '...rhedeg y gweithredoedd canlynol:';
$labels['add'] = 'Ychwanegu';
$labels['del'] = 'Dileu';
$labels['sender'] = 'Anfonwr';
$labels['recipient'] = 'Derbynnwr';
$labels['vacationaddr'] = 'Fy nghyfeiriadau ebost:';
$labels['vacationdays'] = 'Pa mor aml i ddanfon negeseuon (mewn dyddiau):';
$labels['vacationinterval'] = 'Pa mor aml i ddanfon negeseuon:';
$labels['vacationreason'] = 'Corff neges (rheswm ar wyliau):';
$labels['vacationfrom'] = 'Cyfeiriad ymateb anfonwr:';
$labels['vacationsubject'] = 'Pwnc neges:';
$labels['days'] = 'dyddiau';
$labels['seconds'] = 'eiliadau';
$labels['rulestop'] = 'Stopio gwerthuso rheolau';
$labels['enable'] = 'Galluogi/Analluogi';
$labels['filterset'] = 'Set hidlo';
$labels['filtersets'] = 'Setiau hidlyddion';
$labels['filtersetadd'] = 'Ychwanegu set hidlo';
$labels['filtersetdel'] = 'Dileu set hidlo';
$labels['filtersetact'] = 'Gweithredu set hidlo presennol';
$labels['filtersetdeact'] = 'Dadweithredu set hidlo presennol';
$labels['filterseteditraw'] = 'Golygu set hidlo';
$labels['filtersetswitch'] = 'Galluogi/analluogi set hidlo';
$labels['filterdef'] = 'Diffiniad hidlydd';
$labels['filtersetname'] = 'Enw set hidlo';
$labels['newfilterset'] = 'Set hidlo newydd';
$labels['active'] = 'gweithredol';
$labels['none'] = 'dim';
$labels['fromset'] = 'o set';
$labels['fromfile'] = 'o ffeil';
$labels['filterdisabled'] = 'Analluogwyd hidlydd';
$labels['filterenabled'] = 'Galluogwyd yr hidlydd';
$labels['countisgreaterthan'] = 'rhif yn fwy na';
$labels['countisgreaterthanequal'] = 'rhif yn fwy na neu hafal i';
$labels['countislessthan'] = 'rhif yn llai na';
$labels['countislessthanequal'] = 'rhif yn llai na neu hafal i';
$labels['countequals'] = 'rhif yn hafal i';
$labels['countnotequals'] = 'rhif ddim yn hafal i';
$labels['valueisgreaterthan'] = 'gwerth yn fwy na';
$labels['valueisgreaterthanequal'] = 'gwerth yn fwy na neu hafal i';
$labels['valueislessthan'] = 'gwerth yn llai na';
$labels['valueislessthanequal'] = 'gwerth yn llai neu hafal i';
$labels['valueequals'] = 'gwerth yn hafal i';
$labels['valuenotequals'] = 'gwerth ddim yn hafal i';
$labels['setflags'] = 'Rhoi fflag ar y neges';
$labels['addflags'] = 'Ychwanegu fflag i\'r neges';
$labels['removeflags'] = 'Dileu fflag o\'r neges';
$labels['flagread'] = 'Darllen';
$labels['flagdeleted'] = 'Dilewyd';
$labels['flaganswered'] = 'Atebwyd';
$labels['flagflagged'] = 'Nodwyd';
$labels['flagdraft'] = 'Drafft';
$labels['addheader'] = 'Ychwanegu pennawd i\'r neges';
$labels['deleteheader'] = 'Tynnu pennawd o\'r neges';
$labels['headername'] = 'Enw pennawd';
$labels['headervalue'] = 'Gwerth y pennawd';
$labels['headerpos'] = 'Safle\'r pennawd';
$labels['headeratstart'] = 'ar y dechrau';
$labels['headeratend'] = 'ar y diwedd';
$labels['headeroccurrence'] = 'Safle\'r pennawd';
$labels['headerfromstart'] = 'o\'r dechrau';
$labels['headerfromend'] = 'o\'r diwedd';
$labels['headerpatterns'] = 'Patrwm gwerth pennawd';
$labels['headermatchtype'] = 'cymharu math:';
$labels['setvariable'] = 'Gosod newidyn';
$labels['setvarname'] = 'Enw newidyn:';
$labels['setvarvalue'] = 'Gwerth newidyn:';
$labels['setvarmodifiers'] = 'Addasydd:';
$labels['varlower'] = 'llythrennau bychain';
$labels['varupper'] = 'priflythrennau';
$labels['varlowerfirst'] = 'llythyren gyntaf yn fach';
$labels['varupperfirst'] = 'llythyren gyntaf yn briflythyren';
$labels['varquotewildcard'] = 'dyfynnu nodau arbennig';
$labels['varlength'] = 'hyd';
$labels['varencodeurl'] = 'amgodwyd-canran (ar gyfer URLs)';
$labels['notify'] = 'Anfon hysbysiad';
$labels['notifytarget'] = 'Target hysbysu:';
$labels['notifymessage'] = 'Neges hysbysu (dewisol):';
$labels['notifyoptions'] = 'Dewisiadau hysbysu (dewisol):';
$labels['notifyfrom'] = 'Anfonwr hysbysiad (dewisol):';
$labels['notifyimportance'] = 'Pwysigrwydd:';
$labels['notifyimportancelow'] = 'isel';
$labels['notifyimportancenormal'] = 'arferol';
$labels['notifyimportancehigh'] = 'uchel';
$labels['notifymethodmailto'] = 'Ebost';
$labels['notifymethodtel'] = 'Ffôn';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Creu hidlydd';
$labels['usedata'] = 'Defnyddio\'r wybodaeth ganlynol yn yr hidlydd:';
$labels['nextstep'] = 'Cam nesaf';
$labels['...'] = '...';
$labels['string'] = 'Llinyn';
$labels['currdate'] = 'Dyddiad cyfredol';
$labels['datetest'] = 'Dyddiad';
$labels['dateheader'] = 'pennawd:';
$labels['year'] = 'blwyddyn';
$labels['month'] = 'mis';
$labels['day'] = 'dydd';
$labels['date'] = 'dyddiad (bbbb-mm-dd)';
$labels['julian'] = 'dyddiad (julian)';
$labels['hour'] = 'awr';
$labels['minute'] = 'munud';
$labels['second'] = 'eiliad';
$labels['time'] = 'amser (aa:mm:ee)';
$labels['iso8601'] = 'dyddiad (ISO8601)';
$labels['std11'] = 'dyddiad (RFC2822)';
$labels['zone'] = 'parth-amser';
$labels['weekday'] = 'dydd yr wythnos (0-6)';
$labels['advancedopts'] = 'Dewisiadau uwch';
$labels['body'] = 'Corff';
$labels['address'] = 'cyfeiriad';
$labels['envelope'] = 'amlen';
$labels['modifier'] = 'newidydd:';
$labels['text'] = 'testun';
$labels['undecoded'] = 'heb ei ddatgodi (amrwd)';
$labels['contenttype'] = 'math cynnwys';
$labels['modtype'] = 'math:';
$labels['allparts'] = 'popeth';
$labels['domain'] = 'parth';
$labels['localpart'] = 'darn lleol';
$labels['user'] = 'defnyddiwr';
$labels['detail'] = 'manylion';
$labels['comparator'] = 'cymharydd';
$labels['default'] = 'rhagosodiad';
$labels['octet'] = 'llym (octet)';
$labels['asciicasemap'] = 'maint llythrennau (ascii-casemap)';
$labels['asciinumeric'] = 'rhifau (ascii-numeric)';
$labels['index'] = 'mynegai:';
$labels['indexlast'] = 'o chwith';
$labels['spamtest'] = 'Lefel sbam';
$labels['spamtestisgreaterthan'] = 'yn fwy na';
$labels['spamtestisgreaterthanequal'] = 'yn fwy na neu hafal i';
$labels['spamtestislessthan'] = 'yn llai na';
$labels['spamtestislessthanequal'] = 'yn llai na neu hafal i';
$labels['spamtestequals'] = 'yn hafal i';
$labels['spamtestnotequals'] = 'ddim yn hafal i';
$labels['spamtestisunknown'] = 'yn anhysbys';
$labels['vacation'] = 'Allan o\'r Swyddfa';
$labels['vacation.reply'] = 'Neges ymateb';
$labels['vacation.advanced'] = 'Gosodiadau uwch';
$labels['vacation.from'] = 'Cyfeiriad ymateb anfonwr';
$labels['vacation.subject'] = 'Pwnc';
$labels['vacation.body'] = 'Corff';
$labels['vacation.start'] = 'Amser cychwyn';
$labels['vacation.end'] = 'Amser gorffen';
$labels['vacation.status'] = 'Statws';
$labels['vacation.on'] = 'Ymlaen';
$labels['vacation.off'] = 'I ffwrdd';
$labels['vacation.addresses'] = 'Fy nghyfeiriadau ebost:';
$labels['vacation.interval'] = 'Cyfnod ymateb';
$labels['vacation.after'] = 'Rhoi\'r rheol allan-o\'r-swyddfa wedyn';
$labels['vacation.saving'] = 'Yn cadw\'r data...';
$labels['vacation.action'] = 'Gweithred neges i fewn';
$labels['vacation.keep'] = 'Cadw';
$labels['vacation.discard'] = 'Gwaredu';
$labels['vacation.redirect'] = 'Ailgyfeirio i';
$labels['vacation.copy'] = 'Danfon copi i';
$labels['forward'] = 'Danfon ymlaen';
$labels['forward.redirect'] = 'Ailgyfeirio i';
$labels['forward.copy'] = 'Danfon copi i';
$labels['forward.on'] = 'Ymlaen';
$labels['forward.off'] = 'I ffwrdd';
$labels['forward.status'] = 'Statws:';
$labels['forward.action'] = 'Am negeseuon sy\'n dod i fewn, gwneud y weithred ganlynol:';
$labels['forward.saving'] = 'Yn cadw\'r data...';
$labels['filladdresses'] = 'Llenwi gyda fy nghyfeiriadau ychwanegol';
$labels['arialabelfiltersetactions'] = 'Gweithrediadau set hidlydd';
$labels['arialabelfilteractions'] = 'Gweithrediadau hidlydd';
$labels['arialabelfilterform'] = 'Nodweddion hidlydd';
$labels['ariasummaryfilterslist'] = 'Rhestr o hidlyddion';
$labels['ariasummaryfiltersetslist'] = 'Rhestr o setiau hidlyddion';
$labels['filterstitle'] = 'Golygu hidlyddion ebost i fewn';
$labels['vacationtitle'] = 'Golygu rheol allan-o\'r-swyddfa';
$labels['forwardtitle'] = 'Golygu rheol danfon negeseuon ymlaen';
$labels['message'] = 'Neges';
$labels['duplicate'] = 'wedi dyblygu';
$labels['notduplicate'] = 'ddim wedi dyblygu';
$labels['duplicate.handle'] = 'dolen:';
$labels['duplicate.header'] = 'pennawd:';
$labels['duplicate.uniqueid'] = 'dynodwr:';
$labels['duplicate.seconds'] = 'terfyn amser (eiliadau):';
$labels['duplicate.last'] = 'yn berthnol i\'r gweithrediad diwethaf';
$messages['filterunknownerror'] = 'Gwall gweinydd anhysbys.';
$messages['filterconnerror'] = 'Methwyd cysylltu a\'r gweinydd.';
$messages['filterdeleteerror'] = 'Methwyd dileu hidlydd. Cafwydd gwall gweinydd.';
$messages['filterdeleted'] = 'Dilëuwyd hidlydd yn llwyddiannus.';
$messages['filtersaved'] = 'Cadwyd hidlydd yn llwyddiannus.';
$messages['filtersaveerror'] = 'Methwyd cadw hidlydd. Cafwyd gwall gweinydd.';
$messages['filterformerror'] = 'Mae gwallau yn y ffurflen hidlo.';
$messages['filterdeleteconfirm'] = 'Ydych chi wir am ddileu yr hidlydd ddewiswyd?';
$messages['ruledeleteconfirm'] = 'Ydych chi\'n siwr eich bod am ddileu\'r rheol ddewiswyd?';
$messages['actiondeleteconfirm'] = 'Ydych chi\'n siwr eich bod am ddileu\'r weithred ddewiswyd?';
$messages['forbiddenchars'] = 'Llythrennau gwaharddedig yn y maes.';
$messages['cannotbeempty'] = 'Ni all y maes fod yn wag.';
$messages['ruleexist'] = 'Mae hidlydd gyda\'r enw yma yn bodoli\'n barod.';
$messages['setactivateerror'] = 'Methwyd gweithredu y set hidlo ddewiswyd. Cafwyd gwall gweinydd.';
$messages['setdeactivateerror'] = 'Methwyd dadweithredu y set hidlo ddewiswyd. Cafwyd gwall gweinydd.';
$messages['setdeleteerror'] = 'Methwyd dileu y set hidlo ddewiswyd. Cafwyd gwall gweinydd.';
$messages['setactivated'] = 'Gweithredwyd y set hidlo yn llwyddiannus.';
$messages['setdeactivated'] = 'Anweithredwyd y set hidlo yn llwyddiannus.';
$messages['setdeleted'] = 'Dileuwyd y set hidlo yn llwyddiannus.';
$messages['setupdated'] = 'Diweddarwyd y set hidlo yn llwyddiannus.';
$messages['setdeleteconfirm'] = 'Ydych chi\'n siwr eich bod am ddileu\'r set hidlo ddewiswyd?';
$messages['setcreateerror'] = 'Methwyd creu set hidlo. Cafwyd gwall gweinydd.';
$messages['setcreated'] = 'Creuwyd y set hidlo yn llwyddiannus.';
$messages['activateerror'] = 'Methwyd galluogi y hidlydd(ion) dewiswyd. Cafwyd gwall gweinydd.';
$messages['deactivateerror'] = 'Methwyd analluogi y hidlydd(ion) dewiswyd. Cafwyd gwall gweinydd.';
$messages['deactivated'] = 'Galluogwyd y hidlydd(ion) yn llwyddiannus.';
$messages['activated'] = 'Analluogwyd y hidlydd(ion) yn llwyddiannus.';
$messages['moved'] = 'Symudwyd y hidlydd yn llwyddiannus.';
$messages['moveerror'] = 'Methwyd symud y hidlydd dewiswyd. Cafwyd gwall gweinydd.';
$messages['nametoolong'] = 'Enw yn rhy hir.';
$messages['namereserved'] = 'Enw neilltuedig.';
$messages['setexist'] = 'Mae\'r set yn bodoli\'n barod.';
$messages['nodata'] = 'Rhaid dewis o leia un safle!';
$messages['invaliddateformat'] = 'Dyddiad neu fformat dyddiad annilys';
$messages['saveerror'] = 'Methwyd cadw\'r data. Cafwyd gwall gweinydd.';
$messages['vacationsaved'] = 'Cadwyd y data allan-o\'r-swyddfa yn llwyddiannus.';
$messages['forwardsaved'] = 'Cadwyd y data danfon yn llwyddiannus.';
$messages['emptyvacationbody'] = 'Mae angen rhoi corff y neges wyliau!';
$messages['duplicate.conflict.err'] = 'Ni ganiateir defnyddio pennawd a dynodwr unigryw.';
$messages['disabledaction'] = 'Ni ganiateir y weithred.';
$messages['lastindexempty'] = 'Mae angen mynegai wrth gyfri o\'r diwedd';
$messages['noflagset'] = 'Rhaid dewis o leia un fflag';
$messages['saving.actionordererror'] = 'Rhaid i\'r weithred \'$previous\' ddod ar ôl y weithred \'$current\'.';
