<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Filtre';
$labels['managefilters'] = 'Administreaza filtrele pentru mesaje primite.';
$labels['filtername'] = 'Nume filtru';
$labels['newfilter'] = 'Filtru nou';
$labels['filteradd'] = 'Adauga un filtru';
$labels['filterdel'] = 'Sterge filtru.';
$labels['actions'] = 'Acțiuni';
$labels['scope'] = 'Scop';
$labels['moveup'] = 'Muta mai sus';
$labels['movedown'] = 'Muta mai jos';
$labels['filterallof'] = 'se potriveste cu toate regulile urmatoare';
$labels['filteranyof'] = 'se potriveste cu oricare din regulile urmatoare';
$labels['filterany'] = 'toate mesajele';
$labels['filtercontains'] = 'contine';
$labels['filternotcontains'] = 'nu contine';
$labels['filteris'] = 'este egal cu';
$labels['filterisnot'] = 'este diferit de';
$labels['filterexists'] = 'exista';
$labels['filternotexists'] = 'nu exista';
$labels['filtermatches'] = 'se potriveste cu expresia';
$labels['filternotmatches'] = 'nu se potriveste cu expresia';
$labels['filterregex'] = 'se potriveste cu expresia regulata';
$labels['filternotregex'] = 'nu se potriveste cu expresia regulata';
$labels['filterunder'] = 'sub';
$labels['filterover'] = 'peste';
$labels['addrule'] = 'Adauga regula';
$labels['delrule'] = 'Sterge regula';
$labels['messagemoveto'] = 'Muta mesajul in';
$labels['messageredirect'] = 'Redirectioneaza mesajul catre';
$labels['messagecopyto'] = 'Copiaza mesajul in';
$labels['messagesendcopy'] = 'Trimite o copie a mesajului catre';
$labels['messagereply'] = 'Raspunde cu mesajul';
$labels['messagedelete'] = 'Sterge mesajul';
$labels['messagediscard'] = 'Respinge cu mesajul';
$labels['messagekeep'] = 'Pastreaza mesajele in Inbox';
$labels['messagesrules'] = 'Pentru e-mail primit:';
$labels['messagesactions'] = '...executa urmatoarele actiuni:';
$labels['add'] = 'Adauga';
$labels['del'] = 'Sterge';
$labels['sender'] = 'Expeditor';
$labels['recipient'] = 'Destinatar';
$labels['vacationaddr'] = 'Adresele mele de e-mail ';
$labels['vacationdays'] = 'Cat de des sa trimit mesajele (in zile):';
$labels['vacationinterval'] = 'Cât de des să trimit mesaje:';
$labels['vacationreason'] = 'Corpul mesajului (motivul vacantei):';
$labels['vacationfrom'] = 'Adresa expeditorului răspunsului:';
$labels['vacationsubject'] = 'Subiectul mesajului:';
$labels['days'] = 'zile';
$labels['seconds'] = 'secunde';
$labels['rulestop'] = 'Nu mai evalua reguli';
$labels['enable'] = 'Activeaza/Dezactiveaza';
$labels['filtersets'] = 'Filtrul seteaza';
$labels['filterseteditraw'] = 'Modifică set filtre';
$labels['filterdef'] = 'Definiţie filtru';
$labels['active'] = 'activ';
$labels['none'] = 'niciunul';
$labels['fromset'] = 'din setul';
$labels['fromfile'] = 'din fişier';
$labels['filterdisabled'] = 'Filtru dezactivat';
$labels['countisgreaterthan'] = 'numărul este mai mare ca';
$labels['countisgreaterthanequal'] = 'numărul este mai mare sau egal cu';
$labels['countislessthan'] = 'numărul este mai mic decât';
$labels['countislessthanequal'] = 'numărul este mai mic sau egal cu';
$labels['countequals'] = 'numărul este egal cu';
$labels['countnotequals'] = 'numaratoarea nu este egala cu';
$labels['valueisgreaterthan'] = 'valoarea este egală cu';
$labels['valueisgreaterthanequal'] = 'valoarea este mai mare sau egala cu';
$labels['valueislessthan'] = 'valoarea este mai mică decât';
$labels['valueislessthanequal'] = 'valoarea este mai mică sau egală cu';
$labels['valueequals'] = 'valoarea este egală cu';
$labels['valuenotequals'] = 'valoarea nu este egala cu';
$labels['setflags'] = 'Pune marcaje mesajului';
$labels['addflags'] = 'Adaugă marcaje mesajului';
$labels['removeflags'] = 'Şterge marcajele mesajului';
$labels['flagread'] = 'Citit';
$labels['flagdeleted'] = 'Șters';
$labels['flaganswered'] = 'Răspuns';
$labels['flagflagged'] = 'Marcat';
$labels['flagdraft'] = 'Schiță';
$labels['setvariable'] = 'Setare variabilă';
$labels['setvarname'] = 'Nume variabilă:';
$labels['setvarvalue'] = 'Valoare variabilă:';
$labels['setvarmodifiers'] = 'Modificatori:';
$labels['varlower'] = 'cu litere mici';
$labels['varupper'] = 'cu litere mari';
$labels['varlowerfirst'] = 'primul caracter cu litre mici';
$labels['varupperfirst'] = 'primul caracter cu litre mari';
$labels['varquotewildcard'] = 'caracterele speciale in citat';
$labels['varlength'] = 'lungime';
$labels['notify'] = 'Notificare trimitere';
$labels['notifytarget'] = 'Scopul notificării:';
$labels['notifymessage'] = 'Mesaj notificare (opțional)';
$labels['notifyoptions'] = 'Opțiuni notificare (opțional)';
$labels['notifyfrom'] = 'Expeditor notificare (opțional)';
$labels['notifyimportance'] = 'Importanța:';
$labels['notifyimportancelow'] = 'mică';
$labels['notifyimportancenormal'] = 'normală';
$labels['notifyimportancehigh'] = 'mare';
$labels['notifymethodmailto'] = 'Email';
$labels['notifymethodtel'] = 'Telefon';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Crează filtru';
$labels['usedata'] = 'Foloseşte următoarele date în filtru:';
$labels['nextstep'] = 'Următorul Pas';
$labels['...'] = '...';
$labels['string'] = 'Text';
$labels['currdate'] = 'Data curenta';
$labels['datetest'] = 'Data';
$labels['dateheader'] = 'header:';
$labels['year'] = 'an';
$labels['month'] = 'luna';
$labels['day'] = 'zi';
$labels['date'] = 'data (AAAA-LL-ZZ)';
$labels['julian'] = 'data (calendar iulian)';
$labels['hour'] = 'ora';
$labels['minute'] = 'minut';
$labels['second'] = 'secunda';
$labels['time'] = 'ora (hh:mm:ss)';
$labels['iso8601'] = 'data (ISO8601)';
$labels['std11'] = 'data (RFC2822)';
$labels['zone'] = 'fus orar';
$labels['weekday'] = 'zi saptamana (0-6)';
$labels['advancedopts'] = 'Opţiuni avansate';
$labels['body'] = 'Corp';
$labels['address'] = 'adresă';
$labels['envelope'] = 'plic';
$labels['modifier'] = 'modificator:';
$labels['text'] = 'text';
$labels['undecoded'] = 'nedecodat (brut)';
$labels['contenttype'] = 'tip conţinut';
$labels['modtype'] = 'tip:';
$labels['allparts'] = 'toate';
$labels['domain'] = 'domeniu';
$labels['localpart'] = 'partea locală';
$labels['user'] = 'utilizator';
$labels['detail'] = 'detaliu';
$labels['comparator'] = 'comparator:';
$labels['default'] = 'implicit';
$labels['octet'] = 'strict (octet)';
$labels['asciicasemap'] = 'ignoră majusculele (ascii-casemap)';
$labels['asciinumeric'] = 'numeric (ascii-numeric)';
$labels['index'] = 'index:';
$labels['indexlast'] = 'invers';
$labels['spamtestequals'] = 'este egal cu';
$labels['spamtestnotequals'] = 'este diferit de';
$labels['vacation.reply'] = 'Raspunde mesajului';
$labels['vacation.advanced'] = 'Setari avansate';
$labels['vacation.from'] = 'Adresa expeditorului răspunsului';
$labels['vacation.subject'] = 'Subiect';
$labels['vacation.body'] = 'Corp';
$labels['vacation.status'] = 'Statut';
$labels['vacation.on'] = 'Pe';
$labels['vacation.off'] = 'De pe';
$labels['vacation.addresses'] = 'Adresele mele de e-mail';
$labels['vacation.interval'] = 'Interval de raspundere';
$labels['vacation.saving'] = 'Salvez datele...';
$labels['vacation.action'] = 'Acțiune mesaj primit';
$labels['vacation.keep'] = 'Păstrează';
$labels['vacation.discard'] = 'Renunță';
$labels['vacation.redirect'] = 'Redirecționează către';
$labels['vacation.copy'] = 'Trimite o copie către';
$labels['forward.redirect'] = 'Redirecționează către';
$labels['forward.copy'] = 'Trimite o copie către';
$labels['forward.on'] = 'Pe';
$labels['forward.off'] = 'De pe';
$labels['forward.saving'] = 'Salvez datele...';
$labels['filladdresses'] = 'Completează cu toate adresele mele';
$labels['arialabelfiltersetactions'] = 'Acțiuni set filtre';
$labels['arialabelfilteractions'] = 'Acțiuni filtru';
$labels['arialabelfilterform'] = 'Propretăți filtru';
$labels['ariasummaryfilterslist'] = 'Listă filtre';
$labels['ariasummaryfiltersetslist'] = 'Listă seturi filtre';
$labels['filterstitle'] = 'Modifică filtre de mesaje primite';
$labels['vacationtitle'] = 'Modifică regulă out-of-office';
$labels['message'] = 'Mesaj';
$labels['duplicate'] = 'este duplicat';
$labels['notduplicate'] = 'nu este duplicat';
$labels['duplicate.header'] = 'antet:';
$labels['duplicate.uniqueid'] = 'identificator:';
$labels['duplicate.seconds'] = 'timeout (secunde):';
$labels['duplicate.last'] = 'relativ ultimei execuții';
$messages['filterunknownerror'] = 'Eroare necunoscută la server:';
$messages['filterconnerror'] = 'Nu mă pot conecta la server.';
$messages['filterdeleteerror'] = 'Nu pot şterge filtrul. S-a produs o eroare la server.';
$messages['filterdeleted'] = 'Filtrul a fost şters cu succes.';
$messages['filtersaved'] = 'Filtrul a fost salvat cu succes.';
$messages['filtersaveerror'] = 'Nu am putut salva filtrul. S-a produs o eroare la server.';
$messages['filterformerror'] = 'Formularul de filtre conține erori.';
$messages['filterdeleteconfirm'] = 'Chiar vrei să ştergi filtrul selectat?';
$messages['ruledeleteconfirm'] = 'Eşti sigur că vrei să ştergi regula selectată?';
$messages['actiondeleteconfirm'] = 'Eşti sigur că vrei să ştergi acţiunea selectată?';
$messages['forbiddenchars'] = 'Caractere nepermise în câmp.';
$messages['cannotbeempty'] = 'Câmpul nu poate fi gol.';
$messages['ruleexist'] = 'Filtrul cu numele specificat există deja.';
$messages['activateerror'] = 'Nu am putut activa filtrul (filtrele) selectate. S-a produs o eroare la server.';
$messages['deactivateerror'] = 'Nu am putut dezactiva filtrele (filtrele) selectate. S-a produs o eroare la server.';
$messages['deactivated'] = 'Filtrele au fost activate cu succes.';
$messages['activated'] = 'Filtrele au fost dezactivate cu succes.';
$messages['moved'] = 'Filtrele au fost mutate cu succes.';
$messages['moveerror'] = 'Nu am putut muta filtrul selectat. S-a produs o eroare la server.';
$messages['nametoolong'] = 'Numele este prea lung.';
$messages['namereserved'] = 'Nume rezervat.';
$messages['setexist'] = 'Setul există deja.';
$messages['nodata'] = 'Trebuie selectată cel putin o poziţie!';
$messages['invaliddateformat'] = 'Data sau parte din data in format invalid';
$messages['saveerror'] = 'Nu am putut salva datele. A aparut o eroare de server.';
$messages['emptyvacationbody'] = 'Corpul mesajului de vacanță este obligatoriu!';
$messages['duplicate.conflict.err'] = 'Atât antetul, cât și identificatorul unic nu sunt permise.';
