<?php

declare(strict_types=1);

/*
 * This file is part of the league/config package.
 *
 * (c) Colin O'Dell <colinodell@gmail.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace League\Config\Exception;

/**
 * Marker interface for any/all exceptions thrown by this library
 */
interface ConfigurationExceptionInterface extends \Throwable
{
}
