<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Password plugin            |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['changepasswd']  = 'Borinpeyvê biguherîne';
$labels['curpasswd']  = 'Borinpeyva heyî:';
$labels['newpasswd']  = 'Borinpeyva nû:';
$labels['confpasswd']  = 'Borinpeyva nû bipejirîne:';
$messages['nopassword'] = 'Borînpeyva nû binivîse.';
$messages['nocurpassword'] = 'Borînpeyva heyî binivîse.';
$messages['passwordincorrect'] = 'Borînpeyva heyî şaş e.';
$messages['passwordinconsistency'] = 'Borînpeyv li hev nayên, dîsa binêre.';
$messages['crypterror'] = 'Borînpeyva nû nehat tomarkirin. Fonksiyona şîfrekirinê kêm e.';
$messages['connecterror'] = 'Borînpeyva nû nehat tomarkirin. Şaşetiya girêdanê.';
$messages['internalerror'] = 'Şîfre nehat tomarkirin.';
$messages['passwordshort'] = 'Divê şîfre ji $length karakterek kêmtir nebe.';
$messages['passwordweak'] = 'Borînpeyv divê herî kêm hejmarek û karakterek xalbendî hebe.';
$messages['passwordtooweak'] = 'Borînpeyv pir lawaz e.';
$messages['passwordnoseq'] = 'Borînpeyv divê rêzek mîna 123456 an QWERTY nebe.';
$messages['passwordnocommon'] = 'Borînpeyv divê ne peyvek an navek hevpar be.';
$messages['passwordforbidden'] = 'Di borînpeyvê karakterên qedexe heye .';
$messages['firstloginchange'] = 'Ev têketina te ya yekemîn e. Ji kerema xwe borînpeyva xwe biguherîne.';
$messages['disablednotice'] = 'Pergal niha di bin sexbêrî ye de ye û guhertina şîfreyborîbpeyvê niha ne pêkan e. Divê her tişt di demek nêzîk de vegere rewşa xwe ya normal. Ji bo vê yekê em lêborînê dixwazin.';
$messages['passwinhistory'] = 'Ev borînpeyv berê hatiye bikaranîn.';
$messages['samepasswd'] = 'Divê borînpeyva nû ji ya kevin cûda be.';
$messages['passwdexpirewarning'] = 'Hişyarî! Dema borînpeyva te di demek nêzîk de diqede, berî $expirationdatetime biguherîne.';
$messages['passwdexpired'] = 'Dema borînpeyva te qediya ye, divê tu niha biguherînî!';
$messages['passwdconstraintviolation'] = 'Binpêkirina sînorê borînpeyvê. Dibe ku borînpeyv pir lawaz be.';
$messages['pwned_mustnotbedisclosed'] = 'Borînpeyv divê bi <a href="$href" target="_blank">gelemperî neyê zanîn</a>.';
$messages['pwned_isdisclosed'] = 'Ev borînpeyv bi gelemperî tê zanîn.';
$messages['pwned_fetcherror'] = 'Pejirandina bihêziya borînpeyvê têk çû.';
