<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail MarkdownEditor plugin      |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['editor_icon_alt'] = 'Përpunues Markdown';
$labels['editor_button_title'] = 'Hartoni mesazh në Markdown dhe kijeni të dërguar si HTML';
$labels['toolbar_button_quit'] = 'Mbrapsht te përpunues i thjeshtë tekstesh';
$labels['toolbar_button_help'] = 'Hapni një udhërrëfyes sintakse Markdown në një dritare të re';
$labels['toolbar_button_preview'] = 'Bëni paraparje të HTML-it siç do të dërgohej';
$labels['toolbar_button_bold'] = 'Të trasha';
$labels['toolbar_button_italic'] = 'Të pjerrëta';
$labels['toolbar_button_strike'] = 'Hequrvije';
$labels['toolbar_button_h1'] = 'Nivel 1 kryesh';
$labels['toolbar_button_h2'] = 'Nivel 2 kryesh';
$labels['toolbar_button_h3'] = 'Nivel 3 kryesh';
$labels['toolbar_button_h4'] = 'Nivel 4 kryesh';
$labels['toolbar_button_h5'] = 'Nivel 5 kryesh';
$labels['toolbar_button_h6'] = 'Nivel 6 kryesh';
$labels['toolbar_button_blockquote'] = 'Bllok citimi';
$labels['toolbar_button_unordered_list'] = 'Listë e parenditur';
$labels['toolbar_button_ordered_list'] = 'Listë e renditur';
$labels['toolbar_button_link'] = 'Lidhje';
$labels['toolbar_button_image'] = 'Figurë';
$labels['toolbar_button_undo'] = 'Zhbëje';
$labels['toolbar_button_redo'] = 'Ribëje';
