<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = '¡Hebo un fallu!';
$messages['loginfailed']  = 'Contraseña o nome d\'usuariu incorreutu.';
$messages['cookiesdisabled'] = 'El to restolador nun aceuta cookies.';
$messages['sessionerror'] = 'La to sesión nun val o caducó.';
$messages['storageerror'] = 'Fallu de conexón col sirvidor IMAP';
$messages['servererror'] = '¡Fallu del sirvidor!';
$messages['servererrormsg'] = 'Fallu de sirvidor: $msg';
$messages['connerror'] = '¡Fallu de conexón (Fallu al algamar el sirvidor)!';
$messages['dberror'] = '¡Fallu na base de datos!';
$messages['windowopenerror'] = '¡Bloquióse\'l ventanu emerxente!';
$messages['requesttimedout'] = 'Caducó\'l tiempu de rempuesta.';
$messages['errorreadonly'] = 'Imposible facer la operación. La bandexa ye de namái-llectura.';
$messages['errornoperm'] = 'Imposible facer la operación. Denegóse\'l permisu.';
$messages['erroroverquota'] = 'Nun pudo completase la operación. Nun queda espaciu nel discu.';
$messages['erroroverquotadelete'] = 'Nun queda espaciu nel discu. Usa Shift+Supr pa desaniciar un mensaxe.';
$messages['invalidrequest'] = 'Fallu de la solicitú. Nun se guardaron datos.';
$messages['invalidhost'] = 'Nome de sirvidor inválidu.';
$messages['nomessagesfound'] = 'Nun s\'atoparon mensaxes na bandexa';
$messages['mailboxempty'] = 'La bandexa de corréu ta balera';
$messages['nomessages'] = 'Nun hai mensaxes';
$messages['refreshing'] = 'Anovando...';
$messages['loading'] = 'Cargando...';
$messages['uploading'] = 'Xubiendo ficheru';
$messages['uploadingmany'] = 'Xubiendo ficheros...';
$messages['loadingdata'] = 'Cargando datos...';
$messages['checkingmail'] = 'A la gueta de mensaxes nuevos...';
$messages['sendingmessage'] = 'Unviando mensaxe...';
$messages['messagesent'] = 'Unvióse\'l mensaxe.';
$messages['savingmessage'] = 'Guardar mensaxe...';
$messages['messagesaved'] = 'El mensaxe guardóse en borradores';
$messages['successfullysaved'] = 'Guardóse correchamente';
$messages['savingresponse'] = 'Guardando mensaxe de rempuesta...';
$messages['deleteresponseconfirm'] = '¿De xuru quies desaniciar esti testu de rempuesta?';
$messages['addedsuccessfully'] = 'El contautu amestóse correchamente a la llibreta de direiciones';
$messages['contactnameexists'] = 'Yá esiste un contautu col mesmu nome.';
$messages['blockedimages'] = 'Pa protexer la to privacidá, torgáronse les imáxenes esternes nesti mensaxe.';
$messages['encryptedmessage'] = 'Esti ye un mensaxe cifráu y nun soi a amosalu. ¡Sentímoslo!';
$messages['nocontactsfound'] = 'Nun doi con dengún contautu';
$messages['contactnotfound'] = 'Nun s\'atopa\'l contautu solicitáu.';
$messages['sendingfailed'] = 'Falló l\'unviu del mensaxe';
$messages['senttooquickly'] = 'Por favor espera $sec segundu/os enantes d\'unviar esti mensaxe.';
$messages['errorsavingsent'] = 'Hebo un fallu al guardar el mensaxe unviáu.';
$messages['errorsaving'] = 'Hebo un fallu al guardar.';
$messages['errormoving'] = 'Nun pudo movese el/los mensaxe(s).';
$messages['errorcopying'] = 'Nun pudo copiase el/los mensaxe(s).';
$messages['errordeleting'] = 'Nun pudo desaniciase el/los mensaxe(s)';
$messages['errormarking'] = 'Nun pudo marcase el/los mensaxe(s)';
$messages['deletecontactconfirm']  = '¿Daveres que quies desaniciar el contautu(os) seleicionáu(os)?';
$messages['deletegroupconfirm']  = '¿Daveres que quies desaniciar el grupu seleicionáu?';
$messages['deletemessagesconfirm'] = '¿Tas seguru de desaniciar los mensaxes que marcaste?';
$messages['deletefolderconfirm']  = '¿Daveres que quies desaniciar esta bandexa?';
$messages['purgefolderconfirm']  = '¿Daveres que quies desaniciar tolos mensaxes d\'esta bandexa?';
$messages['contactdeleting'] = 'Desaniciando contautu(os)...';
$messages['groupdeleting'] = 'Desaniciando grupu...';
$messages['folderdeleting'] = 'Desaniciando la bandexa...';
$messages['foldermoving'] = 'Moviendo la bandexa...';
$messages['foldersubscribing'] = 'Soscribiendo bandexa...';
$messages['folderunsubscribing'] = 'Desoscribiendo bandexa...';
$messages['formincomplete'] = 'Tienes de rellenar tolos campos del formulariu.';
$messages['noemailwarning'] = 'Por favor, introduz un corréu válidu.';
$messages['nonamewarning']  = 'Por favor, introduz un nome.';
$messages['nopagesizewarning'] = 'Por favor, introduz un tamañu de páxina.';
$messages['norecipientwarning'] = 'Por favor, introduz polo menos un destinatariu';
$messages['nosubjectwarning']  = 'El campo "Asuntu" ta vacíu. ¿Quies rellenalu agora?';
$messages['nobodywarning'] = '¿Quies unviar esti mensaxe ensin testu?';
$messages['restoresavedcomposedata'] = 'Alcontróse un mensaxe redactáu anterior ensin unviar.n\nAsuntu: $subject\nGuardáu: $date\n\n¿Quies restaurar esti mensaxe?';
$messages['nosearchname'] = 'Por favor, introduz un nome o una direición de corréu-e.';
$messages['notuploadedwarning'] = 'Entá nun se xubieron tolos axuntos. Por favor, espera o encaboxa la xuba.';
$messages['searchsuccessful'] = 'Atopáronse $nr mensaxes.';
$messages['contactsearchsuccessful'] = 'Atopáronse $nr contautos.';
$messages['searchnomatch'] = 'Nun s\'atopó dengún resultáu';
$messages['searching'] = 'A la gueta...';
$messages['checking'] = 'Comprobando...';
$messages['stillsearching'] = 'Guetando entá...';
$messages['nospellerrors'] = 'Nun s\'atoparon errores ortográficos';
$messages['folderdeleted'] = 'Desanicióse la bandexa correchamente';
$messages['foldersubscribed'] = 'Soscritu a bandexa correchamente.';
$messages['folderunsubscribed'] = 'Soscripción a bandexa anulada correchamente.';
$messages['deletedsuccessfully'] = 'Desanicióse correchamente';
$messages['converting'] = 'Desaniciando\'l formatu del mensaxe...';
$messages['messageopenerror'] = 'Nun pue descargase\'l mensaxe del sirvidor.';
$messages['fileuploaderror'] = 'Fallu al xubir ficheros.';
$messages['filesizeerror'] = 'El ficheru ye más grande de lo permitío ($size)';
$messages['copysuccess'] = '$nr contautos copiaos correchamente.';
$messages['movesuccess'] = '$nr contautos movíos correchamente.';
$messages['copyerror'] = 'Nun pudo copiase dengún contautu.';
$messages['moveerror'] = 'Nun pudo movese dengún contautu.';
$messages['sourceisreadonly'] = 'Esta direición ye de namái-llectura';
$messages['errorsavingcontact'] = 'Nun pudo guardase la direición del contautu';
$messages['movingmessage'] = 'Moviendo mensaxe(s)...';
$messages['copyingmessage'] = 'Copiando mensaxe(s)...';
$messages['copyingcontact'] = 'Copiando contautu(os)...';
$messages['movingcontact'] = 'Moviendo contautu(os)...';
$messages['deletingmessage'] = 'Desaniciando mensaxe(s)...';
$messages['markingmessage'] = 'Marcando mensaxe(s)...';
$messages['addingmember'] = 'Amestando contautu(os) al grupu...';
$messages['removingmember'] = 'Quitando contautu(os) del grupu...';
$messages['receiptsent'] = 'Unvióse correchamente l\'avisu de llectura.';
$messages['errorsendingreceipt'] = 'Nun pudo unviase l\'avisu de llectura.';
$messages['deleteidentityconfirm'] = '¿Daveres que quies desaniciar esta identidá?';
$messages['nodeletelastidentity'] = 'Nun pue desaniciase esa identidá porque ye la última.';
$messages['forbiddencharacter'] = 'El nome de la bandexa tien un caráuter non validu.';
$messages['selectimportfile'] = 'Por favor escueyi\'l ficheru que quies xubir';
$messages['addresswriterror'] = 'Nun pue escribise na llibreta de direiciones seleicionada.';
$messages['contactaddedtogroup'] = 'Amestáronse correutamente los contautos a esti grupu.';
$messages['contactremovedfromgroup'] = 'Desaniciáronse correutamente los contautos a esti grupu.';
$messages['nogroupassignmentschanged'] = 'Nun hai cambeos n\'asignación de grupos.';
$messages['importwait'] = 'Importando, dame un minutín...';
$messages['importformaterror'] = '¡La importación falló! El ficheru unviáu nun ye un ficheru válidu d\'importación.';
$messages['importconfirm'] = '<b>Importáronse correchamente $inserted contautos</b>';
$messages['importmessagesuccess'] = '$nr mensaxes importaos con éxitu';
$messages['importmessageerror'] = '¡Falló la importación! El ficheru xubíu nun ye un ficheru válidu de mensaxe o buzón de corréu';
$messages['opnotpermitted'] = '¡Nun tienes permisu pa facelo!';
$messages['editorwarning'] = 'Cambear la triba d\'editor pue causar perda del formatu del testu. ¿Deseyes continuar?';
$messages['httpreceivedencrypterror'] = 'Hai un fallu grave de configuración. Contauta col alministrador de secute. <b>Nun pue unviase\'l mensaxe</b>';
$messages['smtpconnerror'] = 'Fallu SMTP ($code): Fallu de conexón col sirvidor';
$messages['smtpautherror'] = 'Fallu SMTP ($code): Fallu d\'autorización';
$messages['smtpfromerror'] = 'Fallu SMTP ($code): Fallu al afitar l\'emisor "$from" ($msg)';
$messages['smtptoerror'] = 'Fallu SMTP ($code): Fallu al amestar el destinatariu "$to" ($msg)';
$messages['smtprecipientserror'] = 'Fallu SMTP: Nun pue amosase la llista de destinatarios.';
$messages['smtperror'] = 'Fallu SMTP: $msg';
$messages['toomanyrecipients'] = 'Hai munchos destinatarios. Amenorga\'l númberu de destinatarios a $max.';
$messages['maxgroupmembersreached'] = 'El númberu de miembros del grupu perpasa\'l máximu de $max.';
$messages['internalerror'] = 'Hebo un fallu internu. Por favor, vuelvi intentalo.';
$messages['contactdelerror'] = 'Nun pudo desaniciase el/los contautu(os).';
$messages['contactdeleted'] = 'Contautu(os) desaniciáu(os) correchamente.';
$messages['contactrestoreerror'] = 'Nun pudieron restaurase los contautos desaniciaos.';
$messages['contactrestored'] = 'Los contautos restauráronse con éxitu.';
$messages['groupdeleted'] = 'Grupu desaniciáu correchamente.';
$messages['grouprenamed'] = 'Grupu renomáu correchamente.';
$messages['groupcreated'] = 'Grupu creáu correchamente.';
$messages['savedsearchdeleted'] = 'La busca guardada, desanicióse con éxitu.';
$messages['savedsearchdeleteerror'] = 'Nun pudo desaniciase la busca guardada.';
$messages['savedsearchcreated'] = 'Guardóse correchamente la busca.';
$messages['savedsearchcreateerror'] = 'Nun pudo guardase la busca.';
$messages['messagedeleted'] = 'Mensaxe(s) desaniciaos correchamente.';
$messages['messagemoved'] = 'Mensaxe(s) movíos correchamente.';
$messages['messagecopied'] = 'Mensaxe(s) copiaos correchamente.';
$messages['messagemarked'] = 'Mensaxe(s) marcaos correchamente.';
$messages['autocompletechars'] = 'Introduz a lo menso $min caráuteres p\'autocompletar.';
$messages['autocompletemore'] = 'Atopáronse más coincidencies. Por favor, escribi más caráuteres.';
$messages['namecannotbeempty'] = 'Hai que poner el nome.';
$messages['nametoolong'] = 'El nome ye abondo llargu.';
$messages['folderupdated'] = 'Bandexa anovada correchamente.';
$messages['foldercreated'] = 'Bandexa creada correchamente.';
$messages['invalidimageformat'] = 'Nun ye un formatu d\'imaxe válidu.';
$messages['mispellingsfound'] = 'Deteutáronse fallos ortográficos nel mensaxe.';
$messages['parentnotwritable'] = 'Nun puede crease/movese la carpeta a la carpeta superior elexida. Nun tienes permisos d\'accesu.';
$messages['messagetoobig'] = 'Esta parte del mensaxe ye enforma grande pa procesala';
$messages['noscriptwarning'] = 'Avisu: ¡esti serviciu de webmail necesita Javascript! Pa poder usalu, habilita\'l soporte de Javascript nel to navegador, por favor.';
