<?php

/*
 +-----------------------------------------------------------------------+
 | localization/<lang>/csv2vcard.inc                                     |
 |                                                                       |
 | Localization file of the Roundcube Webmail client                     |
 | Copyright (C) 2005-2013, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Marek Mečiar <mmmeciar@gmail.com>                             |
 +-----------------------------------------------------------------------+
*/
$map = array();
$map['Výročie'] = 'anniversary';
$map['Meno asistenta'] = 'assistant';
$map['Telefón asistenta'] = 'phone:assistant';
$map['Narodeniny'] = 'birthday';
$map['Mesto (práca)'] = 'locality:work';
$map['Krajina/oblasť (práca)'] = 'country:work';
$map['Fax do práce'] = 'phone:workfax';
$map['Telefón do práce'] = 'phone:work';
$map['Telefón do práce 2'] = 'phone:work2';
$map['PSČ (práca)'] = 'zipcode:work';
$map['Okres (práca)'] = 'region:work';
$map['Ulica (práca)'] = 'street:work';
$map['Autotelefón'] = 'phone:car';
$map['Kategórie'] = 'groups';
$map['Spoločnosť'] = 'organization';
$map['Oddelenie'] = 'department';
$map['E-mailová adresa'] = 'email:other';
$map['Krstné meno'] = 'firstname';
$map['Pohlavie'] = 'gender';
$map['Mesto (domov)'] = 'locality:home';
$map['Krajina/oblasť (domov)'] = 'country:home';
$map['Fax domov'] = 'phone:homefax';
$map['Telefón domov'] = 'phone:home';
$map['Telefón domov 2'] = 'phone:home2';
$map['PSČ (domov)'] = 'zipcode:home';
$map['Okres (domov)'] = 'region:home';
$map['Ulica (domov)'] = 'street:home';
$map['Funkcia'] = 'jobtitle';
$map['Priezvisko'] = 'surname';
$map['Meno manažéra'] = 'manager';
$map['Ďalšie meno'] = 'middlename';
$map['Mobilný telefón'] = 'phone:mobile';
$map['Poznámky'] = 'notes';
$map['Iné mesto'] = 'locality:other';
$map['Krajina/oblasť (iné)'] = 'country:other';
$map['Iný fax'] = 'phone:other';
$map['Iný telefón'] = 'phone:other';
$map['Iné PSČ'] = 'zipcode:other';
$map['Krajina/oblasť (iné)'] = 'region:other';
$map['Iná ulica'] = 'street:other';
$map['Operátor'] = 'phone:pager';
$map['Primárny telefón'] = 'phone:main';
$map['Manžel(ka)'] = 'spouse';
$map['Prípona'] = 'suffix';
$map['Titul'] = 'prefix';
$map['Webová stránka'] = 'website:homepage';
$map['Deň narodenia'] = 'birthday-d';
$map['Mesiac narodenia'] = 'birthday-m';
$map['Rok narodenia'] = 'birthday-y';
$map['Zobrazované meno'] = 'name';
$map['Fax'] = 'phone:homefax';
$map['Adresa domov'] = 'street:home';
$map['Štát domov'] = 'country:home';
$map['PSČ domov'] = 'zipcode:home';
$map['Mobil'] = 'phone:mobile';
$map['Prezývka'] = 'nickname';
$map['Organizácia'] = 'organization';
$map['Pager'] = 'phone:pager';
$map['E-mailová adresa'] = 'email:home';
$map['Ďalšia e-mailová adresa'] = 'email:other';
$map['Webová stránka 1'] = 'website:homepage';
$map['Webová stránka 2'] = 'website:other';
$map['Telefón do zamestnania'] = 'phone:work';
$map['Pracovná adresa'] = 'street:work';
$map['Štát zamestnania'] = 'country:work';
$map['PSČ zamestnania'] = 'zipcode:work';
