<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Password plugin            |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['changepasswd']  = 'مەخپىي نۇمۇرنى ئۆزگەرتىش';
$labels['curpasswd']  = 'نۆۋەتتىكى مەخپىي نۇمۇر:';
$labels['newpasswd']  = 'يېڭى مەخپىي نۇمۇر:';
$labels['confpasswd']  = 'يېڭى مەخپىي نۇمۇرنى جەزىملەشتۈرۈش:';
$messages['nopassword'] = 'يېڭى مەخپىي نۇمۇرنى كىرگۈزۈڭ.';
$messages['nocurpassword'] = 'نۆۋەتتىكى مەخپىي نۇمۇرنى كىرگۈزۈڭ.';
$messages['passwordincorrect'] = 'نۆۋەتتىكى مەخپىي نۇمۇر خاتا.';
$messages['passwordinconsistency'] = 'مەخپىي نۇمۇرلار ماس كەلمىدى، قايتا سىناڭ.';
$messages['crypterror'] = 'يېڭى مەخپىي نۇمۇرنى ساقلىغىلى بولمىدى. شىفىرلاش فونكىسيەسى كەم.';
$messages['connecterror'] = 'يېڭى مەخپىي نۇمۇرنى ساقلىغىلى بولمىدى. ئۇلىنىش خاتالىقى.';
$messages['internalerror'] = 'يېڭى مەخپىي نۇمۇرنى ساقلىغىلى بولمىدى.';
$messages['passwordshort'] = 'مەخپىي نۇمۇر ئەڭ كەمدە length$ ھەرىپ ئۇزۇنلىقىدا بۇلىشى كېرەك.';
$messages['passwordweak'] = 'مەخپىي نۇمۇر ئەڭ كەمدە بىر سان ھەمدە بىر تىنىش بەلگىسىنى ئۆز-ئىچىگە ئېلىشى كېرەك.';
$messages['passwordtooweak'] = 'مەخپىي نۇمۇر بەك ئاجىز.';
$messages['passwordnoseq'] = 'مەخپىي نۇمۇر قاتار سان 123456 ياكى قاتار ھەرىپ ئا ب س د بولماسلىقى كېرەك.';
$messages['passwordnocommon'] = 'مەخپىي نۇمۇر كۆپ ئۇچىرايدىغان سۆز ياكى ئىسىم بولماسلىقى كېرەك.';
$messages['passwordforbidden'] = 'مەخپىي نۇمۇر مەنئىي قىلىنغان ھەرىپنى ئۆز-ئىچىگە ئالىدۇ.';
$messages['firstloginchange'] = 'بۇ سىزنىڭ تۇنجى كىرىشىڭىز. مەخپىي نۇمۇرىڭىزنى ئۆزگەرتىڭ.';
$messages['disablednotice'] = 'سېستىما نۆۋەتتە ئاسىرىلىۋاتىدۇ شۇڭا مەخپىي نۇمۇرنى ئۆزگەرتىش ھازىرچە مۇمكىن ئەمەس. ھەممە ئىقتىدار تېزلا ئەسلىگە قايتىدۇ. ھەرقانداق قولايسىزلىق ئۈچۈن سىزدىن كەچۈرۈم سورايمىز.';
$messages['passwinhistory'] = 'بۇ مەخپىي نۇمۇر ئىلگىرى ئىشلىتىپ بۇلۇنغان.';
$messages['samepasswd'] = 'يېڭى مەخپىي نۇمۇر كونا مەخپىي نۇمۇردىن پەرىقلىق بۇلىشى كېرەك.';
$messages['passwdexpirewarning'] = 'ئاگاھلاندۇرۇش! سىزنىڭ مەخپىي نۇمۇرىڭىزنىڭ ۋاقتى تېزلا ئۆتۈپ كېتىدۇ. expirationdatetime$دىن بۇرۇن ئۇنى ئۆزگەرتىڭ.';
$messages['passwdexpired'] = 'مەخپىي نۇمۇرىڭىزنىڭ ۋاقتى ئۆتتى. سىز ئۇنى دەرھال ئۆزگەرتىشىڭىز كېرەك!';
$messages['passwdconstraintviolation'] = 'مەخپىي نۇمۇر قائىدىسىگە خىلاپلىق قىلىندى. مەخپىي نۇمۇر بەلكىم بەك ئاجىز.';
$messages['pwned_mustnotbedisclosed'] = 'مەخپىي نۇمۇر <a href="$href" target="_blank"> ئادەتتە تۇنۇشلۇق </a>بولماسلىقى كېرەك.';
$messages['pwned_isdisclosed'] = 'بۇ مەخپىي نۇمۇر ئادەتتە تۇنۇشلۇق';
$messages['pwned_fetcherror'] = 'مەخپىي نۇمۇر كۈچىنى دەلىللەش مەغلۇپ بولدى.';
