<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['requesttimedout'] = 'ವಿನಂತಿ ಸಮಯ ಮೀರಿತು';
$messages['checkingmail'] = 'ಹೊಸ ಸಂದೇಶಗಳನ್ನು ಪರಿಶೀಲಿಸಲಾಗುತ್ತಿದೆ...';
$messages['sendingmessage'] = 'ಸಂದೇಶ ಕಳುಹಿಸಲಾಗುತ್ತಿದೆ...';
$messages['messagesent'] = 'ಸಂದೇಶ ಯಶಸ್ವಿಯಾಗಿ ಕಳುಹಿಸಲಾಗಿದೆ.';
$messages['savingmessage'] = 'ಸಂದೇಶ ಉಳಿಸಲಾಗುತ್ತಿದೆ...';
$messages['successfullysaved'] = 'ಯಶಸ್ವಿಯಾಗಿ ಉಳಿಸಲಾಗಿದೆ.';
$messages['contactnameexists'] = 'ಅದೇ ಹೆಸರಿನ ಸಂಪರ್ಕ ಈಗಾಗಲೇ ಅಸ್ತಿತ್ವದಲ್ಲಿದೆ.';
$messages['nocontactsfound'] = 'ಯಾವುದೇ ಸಂಪರ್ಕಗಳು ಕಂಡುಬಂದಿಲ್ಲ.';
$messages['contactnotfound'] = 'ವಿನಂತಿಸಿದ ಸಂಪರ್ಕ ಕಂಡುಬಂದಿಲ್ಲ.';
$messages['sendingfailed'] = 'ಸಂದೇಶವನ್ನು ಕಳುಹಿಸಲು ವಿಫಲವಾಗಿದೆ.';
$messages['senttooquickly'] = 'ಈ ಸಂದೇಶವನ್ನು ಕಳುಹಿಸುವ ಮೊದಲು, $sec ಸೆಕೆಂಡು (ಗಳು) ನಿರೀಕ್ಷಿಸಿ';
$messages['deletecontactconfirm']  = 'ನೀವು ನಿಜವಾಗಿಯೂ ಆಯ್ಕೆ ಸಂಪರ್ಕ (ಗಳನ್ನು) ಅಳಿಸಲು ಬಯಸುತ್ತೀರಾ?';
$messages['deletegroupconfirm']  = 'ನೀವು ನಿಜವಾಗಿಯೂ ಆಯ್ಕೆ ಗುಂಪು ಅಳಿಸಲು ಬಯಸುತ್ತೀರಾ?';
$messages['deletemessagesconfirm'] = 'ನೀವು ನಿಜವಾಗಿಯೂ ಆಯ್ದ ಸಂದೇಶ (ಗಳು ) ಅಳಿಸಲು ಬಯಸುತ್ತೀರಾ?';
$messages['contactdeleting'] = 'ಸಂಪರ್ಕ(ಗಳು ) ಅಳಿಸಲಾಗುತ್ತಿದೆ ...';
$messages['nonamewarning']  = 'ದಯವಿಟ್ಟು ಒಂದು ಹೆಸರನ್ನು ನಮೂದಿಸಿ.';
$messages['nopagesizewarning'] = 'ದಯವಿಟ್ಟು ಒಂದು ಪುಟದ ಗಾತ್ರ ನಮೂದಿಸಿ.';
$messages['norecipientwarning'] = 'ದಯವಿಟ್ಟು ಕನಿಷ್ಠ ಒಬ್ಬ ಸ್ವೀಕರಿಸುವವರನ್ನು  ನಮೂದಿಸಿ.';
$messages['nosubjectwarning']  = '"ವಿಷಯ" ಕ್ಷೇತ್ರ ಖಾಲಿಯಾಗಿದೆ. ನೀವು ಈಗ ಒಂದು ದಾಖಲಿಸಲು ಇಚ್ಛಿಸುವಿರ?';
$messages['nosearchname'] = 'ದಯವಿಟ್ಟು ಸಂಪರ್ಕ ಹೆಸರು ಅಥವಾ ಇಮೇಲ್ ವಿಳಾಸವನ್ನು ನಮೂದಿಸಿ.';
$messages['contactsearchsuccessful'] = '$nr ಸಂಪರ್ಕಗಳು ಸಿಕ್ಕಿವೆ.';
$messages['searching'] = 'ಹುಡುಕಲಾಗುತ್ತಿದೆ...';
$messages['checking'] = 'ಪರಿಶೀಲಿಸಲಾಗುತ್ತಿದೆ...';
$messages['nospellerrors'] = 'ಕಾಗುಣಿತ ದೋಷಗಳನ್ನು ಕಂಡುಬಂದಿಲ್ಲ.';
$messages['deletedsuccessfully'] = 'ಯಶಸ್ವಿಯಾಗಿ ಅಳಿಸಲಾಗಿದೆ.';
$messages['fileuploaderror'] = 'ಫೈಲ್ ಅಪ್ಲೋಡ್ ವಿಫಲವಾಗಿದೆ.';
$messages['filesizeerror'] = 'ಅಪ್ಲೋಡ್ ಮಾಡಿದ ಫೈಲ್ $size ಗರಿಷ್ಠ ಗಾತ್ರವನ್ನು ಮೀರಿದೆ';
$messages['errorsavingcontact'] = 'ಸಂಪರ್ಕ ವಿಳಾಸ ಉಳಿಸಲಾಗಲಿಲ್ಲ.';
$messages['selectimportfile'] = 'ಅಪ್ಲೋಡ್ ಮಾಡಲು ಫೈಲ್ ಆಯ್ಕೆ ಮಾಡಿ.';
$messages['autocompletechars'] = 'ಸ್ವಯಂಪೂರ್ಣಗೊಳಿಸುವಿಕೆ ಕನಿಷ್ಠ $min ಅಕ್ಷರಗಳನ್ನು ನಮೂದಿಸಿ.';
$messages['namecannotbeempty'] = 'ಹೆಸರು ಖಾಲಿ ಇರುವಂತಿಲ್ಲ.';
$messages['nametoolong'] = 'ಹೆಸರು ತುಂಬಾ ಉದ್ದವಾಗಿದೆ.';
$messages['mispellingsfound'] = 'ಸಂದೇಶದಲ್ಲಿ ಕಾಗುಣಿತ ದೋಷಗಳು ಪತ್ತೆಯಾಗಿವೆ.';
