<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'تصفية';
$labels['managefilters'] = 'ادارة تصفية البريد الوارد';
$labels['filtername'] = 'اسم التصفية';
$labels['newfilter'] = 'تصفية جديدة';
$labels['filteradd'] = 'اضافة تصفية';
$labels['filterdel'] = 'حذف تصفية';
$labels['rules'] = 'القواعد';
$labels['actions'] = 'الإجراءات';
$labels['scope'] = 'مجال';
$labels['moveup'] = 'نقل الى الاعلى ';
$labels['movedown'] = 'نقل الى الاسفل';
$labels['filterallof'] = 'مطابقة جميع القواعد التالية';
$labels['filteranyof'] = 'مطابقة اي القواعد التالية';
$labels['filterany'] = 'كل الرسائل';
$labels['filtercontains'] = 'محتوى';
$labels['filternotcontains'] = 'بدون محتوى';
$labels['filteris'] = 'مساوي الى';
$labels['filterisnot'] = 'لا يساوي';
$labels['filterexists'] = 'موجود';
$labels['filternotexists'] = 'غير موجود';
$labels['filtermatches'] = 'يطابق التعبير';
$labels['filternotmatches'] = 'لا يطابق التعبير';
$labels['filterregex'] = 'يطابق التعبير العادي';
$labels['filternotregex'] = 'لا يطابق التعبير العادي';
$labels['filterunder'] = 'تحت';
$labels['filterover'] = 'خلال';
$labels['mime'] = 'امتدادات بريد الإنترنت متعددة الأغراض -MIME-:';
$labels['mimepart'] = 'جزء امتدادات بريد الإنترنت متعددة الأغراض -MIME-:';
$labels['mime-message'] = 'الرسالة';
$labels['mime-anychild'] = 'أي';
$labels['mime-type'] = 'النوع';
$labels['mime-subtype'] = 'النوع الفرعي';
$labels['mime-contenttype'] = 'نوع المحتوى';
$labels['mime-param'] = 'الحد';
$labels['addrule'] = 'اضافة قاعدة';
$labels['delrule'] = 'حذف قاعدة';
$labels['messagemoveto'] = 'نقل الرساله الى ';
$labels['messageredirect'] = 'إعادة توجيه الرسالة الى ';
$labels['messagecopyto'] = 'نسخ الرسالة الى ';
$labels['messagesendcopy'] = 'ارسال نسخة من الرسالة الى ';
$labels['messagereply'] = 'الرد مع رسالة';
$labels['messagedelete'] = 'حذف الرسالة';
$labels['messagediscard'] = 'تجاهل مع الرسالة';
$labels['messagekeep'] = 'إبقاء الرسالة في علبة الوارد';
$labels['messagesrules'] = 'للبريد الوارد:';
$labels['messagesactions'] = '...تنفيذ المهام التالية:';
$labels['add'] = 'إضافة';
$labels['del'] = 'حذف';
$labels['sender'] = 'المرسل';
$labels['recipient'] = 'مستلم';
$labels['vacationaddr'] = 'عناوين البريد الإلكترونية الخاصة بي :';
$labels['vacationdays'] = 'في الغالب كم رسالة ترسل (بالايام):';
$labels['vacationinterval'] = 'كم عدد الرسائل المرسلة عادةً:';
$labels['vacationreason'] = 'نص الرسالة (بسبب الاجازة):';
$labels['vacationfrom'] = 'عنوان مرسل الرد:';
$labels['vacationsubject'] = 'موضوع الرسالة:';
$labels['days'] = 'ايام';
$labels['seconds'] = 'ثواني';
$labels['rulestop'] = 'ايقاف تقييم القواعد';
$labels['enable'] = 'تفعيل/تعطيل';
$labels['filterset'] = 'مجموعة المرشحات';
$labels['filtersets'] = 'مجموعة تصفية';
$labels['filtersetadd'] = 'إضافة مجموعة المرشحات';
$labels['filtersetdel'] = 'حذف مجموعة المرشحات';
$labels['filtersetact'] = 'تفعيل مجموعة المرشحات الحالية';
$labels['filtersetdeact'] = 'إلغاء مجموعة المرشحات الحالية';
$labels['filterseteditraw'] = 'تحرير مجموعة المرشحات';
$labels['filtersetswitch'] = 'تفعيل / تعطيل مجموعة المرشحات';
$labels['filterdef'] = 'تعريف التصفية ';
$labels['filtersetname'] = 'اسم مجموعة المرشح';
$labels['newfilterset'] = 'مجموعة مرشحات جديدة';
$labels['active'] = 'نشط';
$labels['none'] = 'لاشيء';
$labels['fromset'] = 'من مجموعة';
$labels['fromfile'] = 'من ملف';
$labels['filterdisabled'] = 'تعطيل التصفية';
$labels['filterenabled'] = 'تم تمكين المرشح';
$labels['countisgreaterthan'] = 'العدد اكبر من ';
$labels['countisgreaterthanequal'] = 'العدد اكبر من او يساوي ';
$labels['countislessthan'] = 'العدد اقل من ';
$labels['countislessthanequal'] = 'العدد اقل من او يساوي';
$labels['countequals'] = 'العدد يساوي ';
$labels['countnotequals'] = 'العدد لا يساوي';
$labels['valueisgreaterthan'] = 'القيمة اكبر من ';
$labels['valueisgreaterthanequal'] = 'القيمة اكبر من او تساوي';
$labels['valueislessthan'] = 'القيمة اقل من ';
$labels['valueislessthanequal'] = 'القيمة اقل من او يساوي';
$labels['valueequals'] = 'القيمة تساوي';
$labels['valuenotequals'] = 'القيمة لا تساوي';
$labels['setflags'] = 'ضع وسم على هذه الرسالة ';
$labels['addflags'] = 'اضف وسم على هذه الرسالة ';
$labels['removeflags'] = 'احذف الوسم الموجود على هذه الرسالة ';
$labels['flagread'] = 'قراءة ';
$labels['flagdeleted'] = 'محذوف';
$labels['flaganswered'] = 'مجابة';
$labels['flagflagged'] = 'موسوم';
$labels['flagdraft'] = 'مسودة';
$labels['addheader'] = 'إضافة المقدمة إلى الرسالة';
$labels['deleteheader'] = 'إزالة المقدمة من الرسالة';
$labels['headername'] = 'اسم المقدمة';
$labels['headervalue'] = 'قيمة المقدمة';
$labels['headerpos'] = 'موضع المقدمة';
$labels['headeratstart'] = 'في البداية';
$labels['headeratend'] = 'في النهاية';
$labels['headeroccurrence'] = 'موضع/ظهور المقدمة';
$labels['headerfromstart'] = 'من البداية';
$labels['headerfromend'] = 'من النهاية';
$labels['headerpatterns'] = 'أنماط قيمة المقدمة';
$labels['headermatchtype'] = 'نوع التطابق:';
$labels['setvariable'] = 'تعيين متغير';
$labels['setvarname'] = 'اسم المتغير:';
$labels['setvarvalue'] = 'قيمة المتغير:';
$labels['setvarmodifiers'] = 'تعديلات:';
$labels['varlower'] = 'أحرف إنجليزية صغيرة';
$labels['varupper'] = 'أحرف إنجليزية كبيرة';
$labels['varlowerfirst'] = 'الحرف الأول صغير';
$labels['varupperfirst'] = 'الحرف الأول كبير';
$labels['varquotewildcard'] = 'أقتبس أحرف خاصة';
$labels['varlength'] = 'الطول';
$labels['varencodeurl'] = 'مُرمَّز بنسبة مئوية (لعناوين محدد موقع الموارد الموحد URL)';
$labels['notify'] = 'ارسل تنبية';
$labels['notifytarget'] = 'هدف التنبيه:';
$labels['notifymessage'] = 'رسالة التنبيه (اختياري):';
$labels['notifyoptions'] = 'خيارات التنبيه (اختياري):';
$labels['notifyfrom'] = 'مُرسِل التنبيه (اختياري):';
$labels['notifyimportance'] = 'اهمية:';
$labels['notifyimportancelow'] = 'منخفض';
$labels['notifyimportancenormal'] = 'عادي';
$labels['notifyimportancehigh'] = 'مرتفع';
$labels['notifymethodmailto'] = 'البريد الإلكتروني';
$labels['notifymethodtel'] = 'الهاتف';
$labels['notifymethodsms'] = 'رُسَيلة -SMS-';
$labels['filtercreate'] = 'انشئ تصفية';
$labels['usedata'] = 'استخدم البيانات التالية في الفلتر:';
$labels['nextstep'] = 'الخطوة التالية';
$labels['...'] = '...';
$labels['string'] = 'سلسلة نصية';
$labels['currdate'] = 'التاريخ الحالي';
$labels['datetest'] = 'التاريخ';
$labels['dateheader'] = 'المقدمة';
$labels['year'] = 'السنة';
$labels['month'] = 'شهر';
$labels['day'] = 'يوم';
$labels['date'] = 'التاريخ (yyyy-mm-dd)';
$labels['julian'] = 'التاريخ (يوليان)';
$labels['hour'] = 'ساعات';
$labels['minute'] = 'دقائق';
$labels['second'] = 'ثواني';
$labels['time'] = 'الوقت (hh:mm:ss)';
$labels['iso8601'] = 'التاريخ (ISO8601)';
$labels['std11'] = 'التاريخ (RFC2822)';
$labels['zone'] = 'المنطقة الزمنية';
$labels['weekday'] = 'ايام العمل (0-6)';
$labels['advancedopts'] = 'خيارات متقدّمة';
$labels['body'] = 'نص';
$labels['address'] = 'العنوان';
$labels['envelope'] = 'ظرف -مغلف-';
$labels['modifier'] = 'تعديل:';
$labels['text'] = 'نص';
$labels['undecoded'] = 'غير مُرمَّز (خام)';
$labels['contenttype'] = 'نوع المحتوى';
$labels['modtype'] = 'نوع:';
$labels['allparts'] = 'الكل';
$labels['domain'] = 'المجال';
$labels['localpart'] = 'الجزء المحلي';
$labels['user'] = 'مستخدم';
$labels['detail'] = 'تفاصيل';
$labels['comparator'] = 'المقارن:';
$labels['default'] = 'افتراضي';
$labels['octet'] = 'صارم (ثُماني)';
$labels['asciicasemap'] = 'أحرف صغيرة أو كبيرة (ascii-casemap)';
$labels['asciinumeric'] = 'رقمية (ascii-numeric)';
$labels['index'] = 'الوارد:';
$labels['indexlast'] = 'تراجع';
$labels['spamtest'] = 'مستوى البريد العشوائي';
$labels['spamtestisgreaterthan'] = 'أكبر من';
$labels['spamtestisgreaterthanequal'] = 'أكبر من أو يساوي';
$labels['spamtestislessthan'] = 'أقل من';
$labels['spamtestislessthanequal'] = 'أقل من أو يساوي';
$labels['spamtestequals'] = 'مساوي الى';
$labels['spamtestnotequals'] = 'لا يساوي';
$labels['spamtestisunknown'] = 'غير معروف';
$labels['vacation'] = 'خارج المكتب';
$labels['vacation.reply'] = 'رسالة الرد';
$labels['vacation.advanced'] = 'اعدادات متقدمة';
$labels['vacation.from'] = 'الرد على عنوان المرسل';
$labels['vacation.subject'] = 'موضوع';
$labels['vacation.body'] = 'محتوى ';
$labels['vacation.start'] = 'وقت البدء';
$labels['vacation.end'] = 'وقت النهاية';
$labels['vacation.status'] = 'الحالة ';
$labels['vacation.on'] = 'تشغيل';
$labels['vacation.off'] = 'ايقاف';
$labels['vacation.addresses'] = 'عناوين بريدي الإلكتروني';
$labels['vacation.interval'] = 'فترة الرد';
$labels['vacation.after'] = 'ضع قاعدة الخروج من المنصب بعد ذلك';
$labels['vacation.saving'] = 'يتم حفظ البيانات...';
$labels['vacation.action'] = 'إجراء الرسالة الواردة';
$labels['vacation.keep'] = 'ابقاء';
$labels['vacation.discard'] = 'حذف';
$labels['vacation.redirect'] = 'إعادة التوجيه إلى';
$labels['vacation.copy'] = 'أرسل نسخة إلى';
$labels['forward'] = 'إعادة الإرسال';
$labels['forward.redirect'] = 'إعادة التوجيه إلى';
$labels['forward.copy'] = 'أرسل نسخة إلى';
$labels['forward.on'] = 'تشغيل';
$labels['forward.off'] = 'ايقاف';
$labels['forward.status'] = 'الحالة:';
$labels['forward.action'] = 'بالنسبة للرسائل الواردة، قم بتنفيذ الإجراء التالي:';
$labels['forward.saving'] = 'يتم حفظ البيانات...';
$labels['filladdresses'] = 'املأ جميع عناويني';
$labels['arialabelfiltersetactions'] = 'إجراءات مجموعة التصفية';
$labels['arialabelfilteractions'] = 'إجراءات التصفية';
$labels['arialabelfilterform'] = 'خصائص التصفية';
$labels['ariasummaryfilterslist'] = 'قائمة المصفيات';
$labels['ariasummaryfiltersetslist'] = 'قائمة مجموعات المصفيات';
$labels['filterstitle'] = 'تعديل مصفيات البريد الوارد';
$labels['vacationtitle'] = 'تعديل قاعدة خارج المكتب';
$labels['forwardtitle'] = 'تعديل قاعدة إعادة توجيه البريد';
$labels['message'] = 'الرسالة';
$labels['duplicate'] = 'مكرر';
$labels['notduplicate'] = 'غير مكرر';
$labels['duplicate.handle'] = 'المعالج:';
$labels['duplicate.header'] = 'المقدمة';
$labels['duplicate.uniqueid'] = 'المعرف:';
$labels['duplicate.seconds'] = 'المهلة الزمنية (بالثواني):';
$labels['duplicate.last'] = 'بالنسبة إلى التنفيذ الأخير';
$messages['filterunknownerror'] = 'خطا غير معروف من الخادم.';
$messages['filterconnerror'] = 'لا يمكن الاتصال بالخادم.';
$messages['filterdeleteerror'] = 'لا يمكن حذف التصفية.خطا في الخادم.';
$messages['filterdeleted'] = 'تم حذف التصفية بنجاح.';
$messages['filtersaved'] = 'تم حفظ التصفية بنجاح.';
$messages['filtersaveerror'] = 'لا يمكن حفظ التصفية.خطا في الخادم.';
$messages['filterformerror'] = 'المصفي يحتوي على أخطاء.';
$messages['filterdeleteconfirm'] = 'هل تريد فعلاً حذف التصفية المحددة؟';
$messages['ruledeleteconfirm'] = 'هل تريد فعلاً حذف القواعد المحددة؟';
$messages['actiondeleteconfirm'] = 'هل تريد فعلاً حذف الاجراءات المحددة؟';
$messages['forbiddenchars'] = 'احرف محظورة في هذا الحقل.';
$messages['cannotbeempty'] = 'لا يمكن ترك الحقل فارغاً';
$messages['ruleexist'] = 'اسم هذة التصفية موجود مسبقاً';
$messages['setactivateerror'] = 'تعذر تنشيط مجموعة التصفية المحددة. حدث خطأ في الخادم.';
$messages['setdeactivateerror'] = 'تعذر إلغاء تنشيط مجموعة التصفية المحددة. حدث خطأ في الخادم.';
$messages['setdeleteerror'] = 'تعذر حذف مجموعة المرشحات المحددة. حدث خطأ في الخادم.';
$messages['setactivated'] = 'تم تفعيل مجموعة التصفية بنجاح.';
$messages['setdeactivated'] = 'تم إلغاء تنشيط مجموعة التصفية بنجاح.';
$messages['setdeleted'] = 'تم حذف مجموعة التصفية بنجاح.';
$messages['setupdated'] = 'تم تحديث مجموعة التصفية بنجاح.';
$messages['setdeleteconfirm'] = 'هل أنت متأكد أنك تريد حذف مجموعة المصفيات المحددة؟';
$messages['setcreateerror'] = 'تعذر إنشاء مجموعة المصفيات. حدث خطأ في الخادم.';
$messages['setcreated'] = 'تم إنشاء مجموعة المصفيات بنجاح.';
$messages['activateerror'] = 'لا يمكن تمكين التصفية(ـات) المحددة .خطا في الخادم.';
$messages['deactivateerror'] = 'لا يمكن تعطيل التصفية(ـات) المحددة .خطا في الخادم.';
$messages['deactivated'] = 'تم تعطيل المصفيـ(ـاة) بنجاح.';
$messages['activated'] = 'تم تفعيل المصفيـ(ـاة) بنجاح.';
$messages['moved'] = 'تم نقل التصفية بنجاح.';
$messages['moveerror'] = 'لا يمكن نقل التصفياة المحددة.خطا في الخادم.';
$messages['nametoolong'] = 'الإسم طويل جداً';
$messages['namereserved'] = 'الاسم محجوز.';
$messages['setexist'] = 'المجموعة موجودة مسبقا.';
$messages['nodata'] = 'يجب تحديد موضع واحد على الأقل!';
$messages['invaliddateformat'] = 'تاريخ غير صحيح او يوجد خطا في تنسق اجزاء التاريخ';
$messages['saveerror'] = 'لا يمكن حفظ البيانات. خطا في الخادم.';
$messages['vacationsaved'] = 'تم حفظ بيانات خارج المكتب بنجاح.';
$messages['forwardsaved'] = 'تم حفظ البيانات المرسلة بنجاح.';
$messages['emptyvacationbody'] = 'يجب أن يكون نص رسالة الإجازة مطلوبًا!';
$messages['duplicate.conflict.err'] = 'لا يُسمح باستخدام كل من المقدمة والمعرف الفريد.';
$messages['disabledaction'] = 'لا يجوز التصرف.';
$messages['lastindexempty'] = 'يجب استخدام الفهرس عند العد من النهاية';
$messages['noflagset'] = 'يجب تحديد علم واحد على الأقل.';
