<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['tz:utc'] = 'UTC (Pasaulinis koordinuotasis laikas)';
$labels['tz:africa'] = 'Afrika';
$labels['tz:africa:abidjan'] = 'Abidžanas';
$labels['tz:africa:accra'] = 'Akra';
$labels['tz:africa:addis_ababa'] = 'Adis Abeba';
$labels['tz:africa:algiers'] = 'Alžyras';
$labels['tz:africa:asmara'] = 'Asmara';
$labels['tz:africa:bamako'] = 'Bamakas';
$labels['tz:africa:bangui'] = 'Bangis';
$labels['tz:africa:banjul'] = 'Bandžulis';
$labels['tz:africa:bissau'] = 'Bisau';
$labels['tz:africa:blantyre'] = 'Blantairas';
$labels['tz:africa:brazzaville'] = 'Brazavilis';
$labels['tz:africa:bujumbura'] = 'Bužumbūra';
$labels['tz:africa:cairo'] = 'Kairas';
$labels['tz:africa:casablanca'] = 'Kasablanka';
$labels['tz:africa:ceuta'] = 'Seuta';
$labels['tz:africa:conakry'] = 'Konakris';
$labels['tz:africa:dakar'] = 'Dakaras';
$labels['tz:africa:dar_es_salaam'] = 'Dar es Salamas';
$labels['tz:africa:djibouti'] = 'Džibutis';
$labels['tz:africa:douala'] = 'Duala';
$labels['tz:africa:el_aaiun'] = 'Al Ajunas';
$labels['tz:africa:freetown'] = 'Fritaunas';
$labels['tz:africa:gaborone'] = 'Gaboronas';
$labels['tz:africa:harare'] = 'Hararė';
$labels['tz:africa:johannesburg'] = 'Johanesburgas';
$labels['tz:africa:juba'] = 'Džuba';
$labels['tz:africa:kampala'] = 'Kampala';
$labels['tz:africa:khartoum'] = 'Chartumas';
$labels['tz:africa:kigali'] = 'Kigalis';
$labels['tz:africa:kinshasa'] = 'Kinšasa';
$labels['tz:africa:lagos'] = 'Lagosas';
$labels['tz:africa:libreville'] = 'Librevilis';
$labels['tz:africa:lome'] = 'Lomė';
$labels['tz:africa:luanda'] = 'Luanda';
$labels['tz:africa:lubumbashi'] = 'Lubumbašis';
$labels['tz:africa:lusaka'] = 'Lusaka';
$labels['tz:africa:malabo'] = 'Malabas';
$labels['tz:africa:maputo'] = 'Maputu';
$labels['tz:africa:maseru'] = 'Maseru';
$labels['tz:africa:mbabane'] = 'Mbabanė';
$labels['tz:africa:mogadishu'] = 'Mogadišas';
$labels['tz:africa:monrovia'] = 'Monrovija';
$labels['tz:africa:nairobi'] = 'Nairobis';
$labels['tz:africa:ndjamena'] = 'Ndžamena';
$labels['tz:africa:niamey'] = 'Niamėjus';
$labels['tz:africa:nouakchott'] = 'Nuakšotas';
$labels['tz:africa:ouagadougou'] = 'Uagadugu';
$labels['tz:africa:porto-novo'] = 'Porto Novas';
$labels['tz:africa:sao_tome'] = 'San Tomė';
$labels['tz:africa:tripoli'] = 'Tripolis';
$labels['tz:africa:tunis'] = 'Tunisas';
$labels['tz:africa:windhoek'] = 'Vindhukas';
$labels['tz:america'] = 'Amerika';
$labels['tz:america:adak'] = 'Adakas';
$labels['tz:america:anchorage'] = 'Ankoridžas';
$labels['tz:america:anguilla'] = 'Angilija';
$labels['tz:america:antigua'] = 'Antigva';
$labels['tz:america:araguaina'] = 'Araguaina';
$labels['tz:america:argentina'] = 'Argentina';
$labels['tz:america:argentina:buenos_aires'] = 'Buenos Airės';
$labels['tz:america:argentina:catamarca'] = 'Katamarka';
$labels['tz:america:argentina:cordoba'] = 'Kordoba';
$labels['tz:america:argentina:jujuy'] = 'Chuchujus';
$labels['tz:america:argentina:la_rioja'] = 'La Riocha';
$labels['tz:america:argentina:mendoza'] = 'Mendosa';
$labels['tz:america:argentina:rio_gallegos'] = 'Rio Galjegosas';
$labels['tz:america:argentina:salta'] = 'Salta';
$labels['tz:america:argentina:san_juan'] = 'San Chuanas';
$labels['tz:america:argentina:san_luis'] = 'San Luisas';
$labels['tz:america:argentina:tucuman'] = 'Tukumanas';
$labels['tz:america:argentina:ushuaia'] = 'Ušuaja';
$labels['tz:america:aruba'] = 'Aruba';
$labels['tz:america:asuncion'] = 'Asunsjonas';
$labels['tz:america:atikokan'] = 'Atikokanas';
$labels['tz:america:bahia'] = 'Bahija';
$labels['tz:america:bahia_banderas'] = 'Bahija de Banderas';
$labels['tz:america:barbados'] = 'Barbadosas';
$labels['tz:america:belem'] = 'Belenas';
$labels['tz:america:belize'] = 'Belizas';
$labels['tz:america:blanc-sablon'] = 'Blansablonas';
$labels['tz:america:boa_vista'] = 'Boa Vista';
$labels['tz:america:bogota'] = 'Bogota';
$labels['tz:america:boise'] = 'Boizis';
$labels['tz:america:cambridge_bay'] = 'Kembridž Bėjus';
$labels['tz:america:campo_grande'] = 'Kampo Grandė';
$labels['tz:america:cancun'] = 'Kankunas';
$labels['tz:america:caracas'] = 'Karakasas';
$labels['tz:america:cayenne'] = 'Kajena';
$labels['tz:america:cayman'] = 'Kaimanai';
$labels['tz:america:chicago'] = 'Čikaga';
$labels['tz:america:chihuahua'] = 'Čihuahua';
$labels['tz:america:costa_rica'] = 'Kosta Rika';
$labels['tz:america:creston'] = 'Krestonas';
$labels['tz:america:cuiaba'] = 'Kujaba';
$labels['tz:america:curacao'] = 'Kiurasao';
$labels['tz:america:danmarkshavn'] = 'Danmarkshavnas';
$labels['tz:america:dawson'] = 'Dosonas';
$labels['tz:america:dawson_creek'] = 'Dosono įlanka';
$labels['tz:america:denver'] = 'Denveris';
$labels['tz:america:detroit'] = 'Detroitas';
$labels['tz:america:dominica'] = 'Dominika';
$labels['tz:america:edmonton'] = 'Edmontonas';
$labels['tz:america:eirunepe'] = 'Eirunepė';
$labels['tz:america:el_salvador'] = 'Salvadoras';
$labels['tz:america:fort_nelson'] = 'Fort Nelsonas';
$labels['tz:america:fortaleza'] = 'Fortaleza';
$labels['tz:america:glace_bay'] = 'Gleis Bėjus';
$labels['tz:america:godthab'] = 'Nukas';
$labels['tz:america:goose_bay'] = 'Gus Bėjus';
$labels['tz:america:grand_turk'] = 'Grand Terkas';
$labels['tz:america:grenada'] = 'Grenada';
$labels['tz:america:guadeloupe'] = 'Gvadelupa';
$labels['tz:america:guatemala'] = 'Gvatemala';
$labels['tz:america:guayaquil'] = 'Gvajakilis';
$labels['tz:america:guyana'] = 'Gajana';
$labels['tz:america:halifax'] = 'Halifaksas';
$labels['tz:america:havana'] = 'Havana';
$labels['tz:america:hermosillo'] = 'Hermosiljas';
$labels['tz:america:indiana'] = 'Indiana';
$labels['tz:america:indiana:indianapolis'] = 'Indianapolis';
$labels['tz:america:indiana:knox'] = 'Noksas';
$labels['tz:america:indiana:marengo'] = 'Marengas';
$labels['tz:america:indiana:petersburg'] = 'Petersburgas';
$labels['tz:america:indiana:tell_city'] = 'Telsitis';
$labels['tz:america:indiana:vevay'] = 'Vivi';
$labels['tz:america:indiana:vincennes'] = 'Vensenas';
$labels['tz:america:indiana:winamac'] = 'Vinamakas';
$labels['tz:america:inuvik'] = 'Inuvikas';
$labels['tz:america:iqaluit'] = 'Ikaluitas';
$labels['tz:america:jamaica'] = 'Jamaika';
$labels['tz:america:juneau'] = 'Džunas';
$labels['tz:america:kentucky'] = 'Kentukis';
$labels['tz:america:kentucky:louisville'] = 'Luisvilis';
$labels['tz:america:kentucky:monticello'] = 'Montičelas';
$labels['tz:america:kralendijk'] = 'Kralendeikas';
$labels['tz:america:la_paz'] = 'La Pasas';
$labels['tz:america:lima'] = 'Lima';
$labels['tz:america:los_angeles'] = 'Los Andželas';
$labels['tz:america:lower_princes'] = 'Louer Prinses';
$labels['tz:america:maceio'] = 'Masejas';
$labels['tz:america:managua'] = 'Managva';
$labels['tz:america:manaus'] = 'Manausas';
$labels['tz:america:marigot'] = 'Marigo';
$labels['tz:america:martinique'] = 'Martinika';
$labels['tz:america:matamoros'] = 'Matamorosas';
$labels['tz:america:mazatlan'] = 'Masatlanas';
$labels['tz:america:menominee'] = 'Menominė';
$labels['tz:america:merida'] = 'Merida';
$labels['tz:america:metlakatla'] = 'Metlakatla';
$labels['tz:america:mexico_city'] = 'Meksikas';
$labels['tz:america:miquelon'] = 'Mikelonas';
$labels['tz:america:moncton'] = 'Monktonas';
$labels['tz:america:monterrey'] = 'Monterėjus';
$labels['tz:america:montevideo'] = 'Montevidėjas';
$labels['tz:america:montserrat'] = 'Montseratas';
$labels['tz:america:nassau'] = 'Nasau';
$labels['tz:america:new_york'] = 'Niujorkas';
$labels['tz:america:nipigon'] = 'Nipigonas';
$labels['tz:america:nome'] = 'Nomas';
$labels['tz:america:noronha'] = 'Noronija';
$labels['tz:america:north_dakota'] = 'Šiaurės Dakota';
$labels['tz:america:north_dakota:beulah'] = 'Beula';
$labels['tz:america:north_dakota:center'] = 'Centras';
$labels['tz:america:north_dakota:new_salem'] = 'Niu Seilemas';
$labels['tz:america:ojinaga'] = 'Ochinaga';
$labels['tz:america:panama'] = 'Panama';
$labels['tz:america:pangnirtung'] = 'Pangnirtungas';
$labels['tz:america:paramaribo'] = 'Paramaribas';
$labels['tz:america:phoenix'] = 'Fyniksas';
$labels['tz:america:port-au-prince'] = 'Port o Prensas';
$labels['tz:america:port_of_spain'] = 'Port of Speinas';
$labels['tz:america:porto_velho'] = 'Porto Veljas';
$labels['tz:america:puerto_rico'] = 'Puerto Rikas';
$labels['tz:america:rainy_river'] = 'Reini Riveris';
$labels['tz:america:rankin_inlet'] = 'Rankin Inletas';
$labels['tz:america:recife'] = 'Resifė';
$labels['tz:america:regina'] = 'Redžaina';
$labels['tz:america:resolute'] = 'Resolutas';
$labels['tz:america:rio_branco'] = 'Rio Brankas';
$labels['tz:america:santarem'] = 'Santarenas';
$labels['tz:america:santiago'] = 'Santjagas';
$labels['tz:america:santo_domingo'] = 'Santo Domingas';
$labels['tz:america:sao_paulo'] = 'San Paulas';
$labels['tz:america:scoresbysund'] = 'Skorsbio užutėkis';
$labels['tz:america:sitka'] = 'Sitka';
$labels['tz:america:st_barthelemy'] = 'Šv. Bartolomėjaus sala';
$labels['tz:america:st_johns'] = "Šv. Jono sala";
$labels['tz:america:st_kitts'] = 'Sent Kitsas';
$labels['tz:america:st_lucia'] = 'Sent Lusija';
$labels['tz:america:st_thomas'] = 'Šv. Tomo sala';
$labels['tz:america:st_vincent'] = 'Sent Vinsentas';
$labels['tz:america:swift_current'] = 'Scift Karentas';
$labels['tz:america:tegucigalpa'] = 'Tegusigalpa';
$labels['tz:america:thule'] = 'Tulė';
$labels['tz:america:thunder_bay'] = 'Tander Bėjus';
$labels['tz:america:tijuana'] = 'Tichuana';
$labels['tz:america:toronto'] = 'Torontas';
$labels['tz:america:tortola'] = 'Tortola';
$labels['tz:america:vancouver'] = 'Vankuveris';
$labels['tz:america:whitehorse'] = 'Vaithorsas';
$labels['tz:america:winnipeg'] = 'Vinipegas';
$labels['tz:america:yakutat'] = 'Jakutatas';
$labels['tz:america:yellowknife'] = 'Jelounaifas';
$labels['tz:antarctica'] = 'Antarktida';
$labels['tz:antarctica:casey'] = 'Keisis';
$labels['tz:antarctica:davis'] = 'Deivisas';
$labels['tz:antarctica:dumontdurville'] = "Diumono d’Urvilio stotis";
$labels['tz:antarctica:macquarie'] = 'Makvorio sala';
$labels['tz:antarctica:mawson'] = 'Mausono stotis';
$labels['tz:antarctica:mcmurdo'] = 'Makmerdo stotis';
$labels['tz:antarctica:palmer'] = 'Palmerio stotis';
$labels['tz:antarctica:rothera'] = 'Roteros stotis';
$labels['tz:antarctica:syowa'] = 'Šiova stotis';
$labels['tz:antarctica:troll'] = 'Trolio stotis';
$labels['tz:antarctica:vostok'] = 'Vostokas';
$labels['tz:arctic'] = 'Arktis';
$labels['tz:arctic:longyearbyen'] = 'Longjyrbienas';
$labels['tz:asia'] = 'Azija';
$labels['tz:asia:aden'] = 'Adenas';
$labels['tz:asia:almaty'] = 'Almata';
$labels['tz:asia:amman'] = 'Amanas';
$labels['tz:asia:anadyr'] = 'Anadyris';
$labels['tz:asia:aqtau'] = 'Aktau';
$labels['tz:asia:aqtobe'] = 'Aktobė';
$labels['tz:asia:ashgabat'] = 'Ašchabadas';
$labels['tz:asia:atyrau'] = 'Atyrau';
$labels['tz:asia:baghdad'] = 'Bagdadas';
$labels['tz:asia:bahrain'] = 'Bahreinas';
$labels['tz:asia:baku'] = 'Baku';
$labels['tz:asia:bangkok'] = 'Bankokas';
$labels['tz:asia:barnaul'] = 'Barnaulas';
$labels['tz:asia:beirut'] = 'Beirutas';
$labels['tz:asia:bishkek'] = 'Biškekas';
$labels['tz:asia:brunei'] = 'Brunėjus';
$labels['tz:asia:chita'] = 'Čita';
$labels['tz:asia:choibalsan'] = 'Čoibalsanas';
$labels['tz:asia:colombo'] = 'Kolombas';
$labels['tz:asia:damascus'] = 'Damaskas';
$labels['tz:asia:dhaka'] = 'Daka';
$labels['tz:asia:dili'] = 'Dilis';
$labels['tz:asia:dubai'] = 'Dubajus';
$labels['tz:asia:dushanbe'] = 'Dušanbė';
$labels['tz:asia:famagusta'] = 'Famagusta';
$labels['tz:asia:gaza'] = 'Gaza';
$labels['tz:asia:hebron'] = 'Hebronas';
$labels['tz:asia:ho_chi_minh'] = 'Hošiminas';
$labels['tz:asia:hong_kong'] = 'Honkongas';
$labels['tz:asia:hovd'] = 'Chovdas';
$labels['tz:asia:irkutsk'] = 'Irkutskas';
$labels['tz:asia:jakarta'] = 'Džakarta';
$labels['tz:asia:jayapura'] = 'Džajapura';
$labels['tz:asia:jerusalem'] = 'Jeruzalė';
$labels['tz:asia:kabul'] = 'Kabulas';
$labels['tz:asia:kamchatka'] = 'Kamčiatka';
$labels['tz:asia:karachi'] = 'Karačis';
$labels['tz:asia:kathmandu'] = 'Katmandu';
$labels['tz:asia:khandyga'] = 'Chandyga';
$labels['tz:asia:kolkata'] = 'Kolkata';
$labels['tz:asia:krasnoyarsk'] = 'Krasnojarskas';
$labels['tz:asia:kuala_lumpur'] = 'Kvala Lumpūras';
$labels['tz:asia:kuching'] = 'Kučingas';
$labels['tz:asia:kuwait'] = 'Kuveitas';
$labels['tz:asia:macau'] = 'Makau';
$labels['tz:asia:magadan'] = 'Magadanas';
$labels['tz:asia:makassar'] = 'Makasaras';
$labels['tz:asia:manila'] = 'Manila';
$labels['tz:asia:muscat'] = 'Muskatas';
$labels['tz:asia:nicosia'] = 'Nikosija';
$labels['tz:asia:novokuznetsk'] = 'Novokuzneckas';
$labels['tz:asia:novosibirsk'] = 'Novosibirskas';
$labels['tz:asia:omsk'] = 'Omskas';
$labels['tz:asia:oral'] = 'Oralas';
$labels['tz:asia:phnom_penh'] = 'Pnompenis';
$labels['tz:asia:pontianak'] = 'Pontianakas';
$labels['tz:asia:pyongyang'] = 'Pchenjanas';
$labels['tz:asia:qatar'] = 'Kataras';
$labels['tz:asia:qyzylorda'] = 'Kyzylorda';
$labels['tz:asia:riyadh'] = 'Rijadas';
$labels['tz:asia:sakhalin'] = 'Sachalinas';
$labels['tz:asia:samarkand'] = 'Samarkandas';
$labels['tz:asia:seoul'] = 'Seulas';
$labels['tz:asia:shanghai'] = 'Šanchajus';
$labels['tz:asia:singapore'] = 'Singapūras';
$labels['tz:asia:srednekolymsk'] = 'Srednekolymskas';
$labels['tz:asia:taipei'] = 'Taipėjus';
$labels['tz:asia:tashkent'] = 'Taškentas';
$labels['tz:asia:tbilisi'] = 'Tbilisis';
$labels['tz:asia:tehran'] = 'Teheranas';
$labels['tz:asia:thimphu'] = 'Timpu';
$labels['tz:asia:tokyo'] = 'Tokijas';
$labels['tz:asia:tomsk'] = 'Tomskas';
$labels['tz:asia:ulaanbaatar'] = 'Ulan Batoras';
$labels['tz:asia:urumqi'] = 'Urumčis';
$labels['tz:asia:ust-nera'] = 'Ust Nera';
$labels['tz:asia:vientiane'] = 'Vientianas';
$labels['tz:asia:vladivostok'] = 'Vladivostokas';
$labels['tz:asia:yakutsk'] = 'Jakutskas';
$labels['tz:asia:yangon'] = 'Jangonas';
$labels['tz:asia:yekaterinburg'] = 'Jekaterinburgas';
$labels['tz:asia:yerevan'] = 'Jerevanas';
$labels['tz:atlantic'] = 'Atlanto vandenynas';
$labels['tz:atlantic:azores'] = 'Azorai';
$labels['tz:atlantic:bermuda'] = 'Bermudai';
$labels['tz:atlantic:canary'] = 'Kanarai';
$labels['tz:atlantic:cape_verde'] = 'Žaliasis Kyšulys';
$labels['tz:atlantic:faroe'] = 'Farerai';
$labels['tz:atlantic:madeira'] = 'Madeira';
$labels['tz:atlantic:reykjavik'] = 'Reikjavikas';
$labels['tz:atlantic:south_georgia'] = 'Pietų Džordžija';
$labels['tz:atlantic:st_helena'] = 'Šv. Elenos sala';
$labels['tz:atlantic:stanley'] = 'Stenlis';
$labels['tz:australia'] = 'Australija';
$labels['tz:australia:adelaide'] = 'Adelaidė';
$labels['tz:australia:brisbane'] = 'Brisbanas';
$labels['tz:australia:broken_hill'] = 'Broken Hilas';
$labels['tz:australia:currie'] = 'Kiuris';
$labels['tz:australia:darwin'] = 'Darvinas';
$labels['tz:australia:eucla'] = 'Jukla';
$labels['tz:australia:hobart'] = 'Hobartas';
$labels['tz:australia:lindeman'] = 'Lindemanas';
$labels['tz:australia:lord_howe'] = 'Lordo Hau sala';
$labels['tz:australia:melbourne'] = 'Melburnas';
$labels['tz:australia:perth'] = 'Pertas';
$labels['tz:australia:sydney'] = 'Sidnėjus';
$labels['tz:europe'] = 'Europa';
$labels['tz:europe:amsterdam'] = 'Amsterdamas';
$labels['tz:europe:andorra'] = 'Andora';
$labels['tz:europe:astrakhan'] = 'Astrachanė';
$labels['tz:europe:athens'] = 'Atėnai';
$labels['tz:europe:belgrade'] = 'Belgradas';
$labels['tz:europe:berlin'] = 'Berlynas';
$labels['tz:europe:bratislava'] = 'Bratislava';
$labels['tz:europe:brussels'] = 'Briuselis';
$labels['tz:europe:bucharest'] = 'Bukareštas';
$labels['tz:europe:budapest'] = 'Budapeštas';
$labels['tz:europe:busingen'] = 'Biusingenas';
$labels['tz:europe:chisinau'] = 'Kišiniovas';
$labels['tz:europe:copenhagen'] = 'Kopenhaga';
$labels['tz:europe:dublin'] = 'Dublinas';
$labels['tz:europe:gibraltar'] = 'Gibraltaras';
$labels['tz:europe:guernsey'] = 'Gernsis';
$labels['tz:europe:helsinki'] = 'Helsinkis';
$labels['tz:europe:isle_of_man'] = 'Meno sala';
$labels['tz:europe:istanbul'] = 'Stambulas';
$labels['tz:europe:jersey'] = 'Džersis';
$labels['tz:europe:kaliningrad'] = 'Karaliaučius';
$labels['tz:europe:kiev'] = 'Kyjivas';
$labels['tz:europe:kirov'] = 'Kirovas';
$labels['tz:europe:lisbon'] = 'Lisabona';
$labels['tz:europe:ljubljana'] = 'Liubliana';
$labels['tz:europe:london'] = 'Londonas';
$labels['tz:europe:luxembourg'] = 'Liuksemburgas';
$labels['tz:europe:madrid'] = 'Madridas';
$labels['tz:europe:malta'] = 'Malta';
$labels['tz:europe:mariehamn'] = 'Marianhamina';
$labels['tz:europe:minsk'] = 'Minskas';
$labels['tz:europe:monaco'] = 'Monakas';
$labels['tz:europe:moscow'] = 'Maskva';
$labels['tz:europe:oslo'] = 'Oslas';
$labels['tz:europe:paris'] = 'Paryžius';
$labels['tz:europe:podgorica'] = 'Podgorica';
$labels['tz:europe:prague'] = 'Praha';
$labels['tz:europe:riga'] = 'Ryga';
$labels['tz:europe:rome'] = 'Roma';
$labels['tz:europe:samara'] = 'Samara';
$labels['tz:europe:san_marino'] = 'San Marinas';
$labels['tz:europe:sarajevo'] = 'Sarajevas';
$labels['tz:europe:saratov'] = 'Saratovas';
$labels['tz:europe:simferopol'] = 'Simferopolis';
$labels['tz:europe:skopje'] = 'Skopjė';
$labels['tz:europe:sofia'] = 'Sofija';
$labels['tz:europe:stockholm'] = 'Stokholmas';
$labels['tz:europe:tallinn'] = 'Talinas';
$labels['tz:europe:tirane'] = 'Tirana';
$labels['tz:europe:ulyanovsk'] = 'Uljanovskas';
$labels['tz:europe:uzhgorod'] = 'Užhorodas';
$labels['tz:europe:vaduz'] = 'Vaducas';
$labels['tz:europe:vatican'] = 'Vatikanas';
$labels['tz:europe:vienna'] = 'Viena';
$labels['tz:europe:vilnius'] = 'Vilnius';
$labels['tz:europe:volgograd'] = 'Volgogradas';
$labels['tz:europe:warsaw'] = 'Varšuva';
$labels['tz:europe:zagreb'] = 'Zagrebas';
$labels['tz:europe:zaporozhye'] = 'Zaporižia';
$labels['tz:europe:zurich'] = 'Ciurichas';
$labels['tz:indian'] = 'Indijos vandenynas';
$labels['tz:indian:antananarivo'] = 'Antananaryvas';
$labels['tz:indian:chagos'] = 'Čagoso salynas';
$labels['tz:indian:christmas'] = 'Kalėdų sala';
$labels['tz:indian:cocos'] = 'Kokosų salos';
$labels['tz:indian:comoro'] = 'Komorai';
$labels['tz:indian:kerguelen'] = 'Kergelenas';
$labels['tz:indian:mahe'] = 'Mahė';
$labels['tz:indian:maldives'] = 'Maldyvai';
$labels['tz:indian:mauritius'] = 'Mauricijus';
$labels['tz:indian:mayotte'] = 'Majotas';
$labels['tz:indian:reunion'] = 'Reunjonas';
$labels['tz:pacific'] = 'Ramusis vandenynas';
$labels['tz:pacific:apia'] = 'Apija';
$labels['tz:pacific:auckland'] = 'Oklando salos';
$labels['tz:pacific:bougainville'] = 'Bugenvilio sala';
$labels['tz:pacific:chatham'] = 'Čatamas';
$labels['tz:pacific:chuuk'] = 'Čiukas';
$labels['tz:pacific:easter'] = 'Velykų sala';
$labels['tz:pacific:efate'] = 'Efatė';
$labels['tz:pacific:enderbury'] = 'Enderberio sala';
$labels['tz:pacific:fakaofo'] = 'Fakaofas';
$labels['tz:pacific:fiji'] = 'Fidžis';
$labels['tz:pacific:funafuti'] = 'Funafutis';
$labels['tz:pacific:galapagos'] = 'Galapagai';
$labels['tz:pacific:gambier'] = 'Gambjė salos';
$labels['tz:pacific:guadalcanal'] = 'Gvadalkanalis';
$labels['tz:pacific:guam'] = 'Guamas';
$labels['tz:pacific:honolulu'] = 'Honolulu';
$labels['tz:pacific:johnston'] = 'Džonstonas';
$labels['tz:pacific:kiritimati'] = 'Kirimatis';
$labels['tz:pacific:kosrae'] = 'Kosraė';
$labels['tz:pacific:kwajalein'] = 'Kvadžaleinas';
$labels['tz:pacific:majuro'] = 'Madžūras';
$labels['tz:pacific:marquesas'] = 'Markizo salos';
$labels['tz:pacific:midway'] = 'Midvėjus';
$labels['tz:pacific:nauru'] = 'Nauru';
$labels['tz:pacific:niue'] = 'Niuė';
$labels['tz:pacific:norfolk'] = 'Norfolko sala';
$labels['tz:pacific:noumea'] = 'Numėja';
$labels['tz:pacific:pago_pago'] = 'Pago Pago';
$labels['tz:pacific:palau'] = 'Palau';
$labels['tz:pacific:pitcairn'] = 'Pitkerno salos';
$labels['tz:pacific:pohnpei'] = 'Ponapė';
$labels['tz:pacific:port_moresby'] = 'Port Morsbis';
$labels['tz:pacific:rarotonga'] = 'Rarotonga';
$labels['tz:pacific:saipan'] = 'Saipanas';
$labels['tz:pacific:tahiti'] = 'Taitis';
$labels['tz:pacific:tarawa'] = 'Tarava';
$labels['tz:pacific:tongatapu'] = 'Tongatapu';
$labels['tz:pacific:wake'] = 'Veiko sala';
$labels['tz:pacific:wallis'] = 'Volisas';
