<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Archif';
$labels['buttontitle'] = 'Archifo\'r neges hwn';
$labels['archived'] = 'Archifwyd yn llwyddiannus';
$labels['archivedreload'] = 'Archifwyd yn llwyddiannus. Ail-lwythwch y dudalen i weld ffolderi archif newydd.';
$labels['archiveerror'] = 'Nid oedd yn bosib archifo rhai negeseuon';
$labels['archivefolder'] = 'Archif';
$labels['settingstitle'] = 'Archif';
$labels['archivetype'] = 'Rhannu archif yn ôl';
$labels['archivetypeyear'] = 'Blwyddyn (e.g. Archif/2012)';
$labels['archivetypemonth'] = 'Mis (e.g. Archif/2012/06)';
$labels['archivetypetbmonth'] = 'Mis - Cydnaws a Thunderbird (e.e. Archif/2012/2012-06)';
$labels['archivetypefolder'] = 'Ffolder gwreiddiol';
$labels['archivetypefolderyear'] = 'Blwyddyn a ffolder gwreiddiol (e.e. Archif/2012/...)';
$labels['archivetypefoldermonth'] = 'Blwyddyn, mis a\'r ffolder gwreiddiol (e.e. Archif/2012/06...)';
$labels['archivetypesender'] = 'Ebost anfonwr';
$labels['unkownsender'] = 'anhysbys';
$labels['readonarchive'] = 'Nodi\'r neges fel darllenwyd ar archif';
