<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = 'Sveiki! Čia $product';
$labels['username'] = 'Naudotojo vardas';
$labels['password'] = 'Slaptažodis';
$labels['server'] = 'Serveris';
$labels['login'] = 'Prisijungti';
$labels['oauthlogin'] = 'Prisijungti per $provider';
$labels['menu'] = 'Meniu';
$labels['logout'] = 'Atsijungti';
$labels['mail'] = 'El. paštas';
$labels['settings'] = 'Nuostatos';
$labels['addressbook'] = 'Adresų knyga';
$labels['darkmode'] = 'Tamsi veiksena';
$labels['lightmode'] = 'Šviesi veiksena';
$labels['inbox'] = 'Gauti laiškai';
$labels['drafts'] = 'Juodraščiai';
$labels['sent'] = 'Išsiųsti laiškai';
$labels['trash'] = 'Šiukšlinė';
$labels['junk'] = 'Brukalas';
$labels['show_real_foldernames'] = 'Rodyti tikrus specialiųjų aplankų vardus';
$labels['subject'] = 'Tema';
$labels['from'] = 'Siuntėjas';
$labels['sender'] = 'Siuntikas';
$labels['to'] = 'Gavėjas';
$labels['cc'] = 'Kopija';
$labels['bcc'] = 'Slaptoji kopija';
$labels['replyto'] = 'Atsakymą gaus';
$labels['followupto'] = 'Followup-To';
$labels['date'] = 'Data';
$labels['size'] = 'Dydis';
$labels['priority'] = 'Prioritetas';
$labels['organization'] = 'Organizacija';
$labels['readstatus'] = 'Neskaitytas';
$labels['listoptions'] = 'Sąrašo nuostatos…';
$labels['listoptionstitle'] = 'Sąrašo nuostatos';
$labels['mailboxlist'] = 'Aplankai';
$labels['messagesfromto'] = 'Laiškai nuo $from iki $to iš $count';
$labels['threadsfromto'] = 'Gijos nuo $from iki $to iš $count';
$labels['messagenrof'] = 'Laiškas $nr iš $count';
$labels['fromtoshort'] = '$from – $to iš $count';
$labels['copy'] = 'Kopijuoti';
$labels['move'] = 'Perkelti';
$labels['moveto'] = 'Perkelti į…';
$labels['copyto'] = 'Kopijuoti į...';
$labels['download'] = 'Parsisiųsti';
$labels['open'] = 'Atverti';
$labels['showattachment'] = 'Rodyti';
$labels['showanyway'] = 'Vistiek rodyti';
$labels['filename'] = 'Failo vardas';
$labels['filesize'] = 'Failo dydis';
$labels['addtoaddressbook'] = 'Įtraukti į adresų knygą';
$labels['sun'] = 'Sek';
$labels['mon'] = 'Pir';
$labels['tue'] = 'Ant';
$labels['wed'] = 'Tre';
$labels['thu'] = 'Ket';
$labels['fri'] = 'Pen';
$labels['sat'] = 'Šeš';
$labels['sunday'] = 'Sekmadienis';
$labels['monday'] = 'Pirmadienis';
$labels['tuesday'] = 'Antradienis';
$labels['wednesday'] = 'Trečiadienis';
$labels['thursday'] = 'Ketvirtadienis';
$labels['friday'] = 'Penktadienis';
$labels['saturday'] = 'Šeštadienis';
$labels['jan'] = 'Sau';
$labels['feb'] = 'Vas';
$labels['mar'] = 'Kov';
$labels['apr'] = 'Bal';
$labels['may'] = 'Gegužė';
$labels['jun'] = 'Bir';
$labels['jul'] = 'Lie';
$labels['aug'] = 'Rgp';
$labels['sep'] = 'Rgs';
$labels['oct'] = 'Spl';
$labels['nov'] = 'Lap';
$labels['dec'] = 'Grd';
$labels['longjan'] = 'Sausis';
$labels['longfeb'] = 'Vasaris';
$labels['longmar'] = 'Kovas';
$labels['longapr'] = 'Balandis';
$labels['longmay'] = 'Gegužė';
$labels['longjun'] = 'Biržėlis';
$labels['longjul'] = 'Liepa';
$labels['longaug'] = 'Rugpjūtis';
$labels['longsep'] = 'Rugsėjis';
$labels['longoct'] = 'Spalis';
$labels['longnov'] = 'Lapkritis';
$labels['longdec'] = 'Gruodis';
$labels['today'] = 'Šiandien';
$labels['refresh'] = 'Atnaujinti';
$labels['checkmail'] = 'Tikrinti, ar yra naujų laiškų';
$labels['compose'] = 'Rašyti';
$labels['writenewmessage'] = 'Rašyti naują laišką';
$labels['reply'] = 'Atsakyti';
$labels['replytomessage'] = 'Atsakyti siuntėjui';
$labels['replytoallmessage'] = 'Atsakyti el. pašto grupei arba laiško siuntėjui ir visiems jo gavėjams';
$labels['replyall'] = 'Atsakyti visiems';
$labels['replylist'] = 'Atsakyti el. pašto grupei';
$labels['forward'] = 'Persiųsti';
$labels['forwardinline'] = 'Persiųsti cituojant';
$labels['forwardattachment'] = 'Persiųsti priedu';
$labels['forwardmessage'] = 'Persiųsti laišką';
$labels['bouncemsg'] = 'Siųsti iš naujo (grąžinimas)';
$labels['bounce'] = 'Siųsti iš naujo';
$labels['deletemessage'] = 'Pašalinti laišką';
$labels['undeletemessage'] = 'Atšaukti laiško pašalinimą';
$labels['movemessagetotrash'] = 'Perkelti laišką į šiukšlinę';
$labels['printmessage'] = 'Atspausdinti laišką';
$labels['previousmessage'] = 'Rodyti ankstesnį laišką';
$labels['firstmessage'] = 'Rodyti pirmąjį laišką';
$labels['nextmessage'] = 'Rodyti tolesnį laišką';
$labels['lastmessage'] = 'Rodyti paskutinį laišką';
$labels['backtolist'] = 'Grižti į laiškų sarašą';
$labels['viewsource'] = 'Rodyti pirminį tekstą';
$labels['mark'] = 'Pažymėti';
$labels['markmessages'] = 'Pažymėti laiškus';
$labels['markread'] = 'Kaip skaitytus';
$labels['markunread'] = 'Kaip neskaitytus';
$labels['markflagged'] = 'Pažymėti gairele';
$labels['markunflagged'] = 'Pašalinti gairelę';
$labels['markundeleted'] = 'Kaip nepašalintus';
$labels['markasread'] = 'Žymėti kaip skaitytą';
$labels['markasunread'] = 'Žymėti kaip neskaitytą';
$labels['markasflagged'] = 'Pažymėti gairele';
$labels['markasunflagged'] = 'Pašalinti gairelę';
$labels['moreactions'] = 'Kiti veiksmai…';
$labels['markallread'] = 'Žymėti visus kaip skaitytus';
$labels['folders-cur'] = 'Tik pasirinktas aplankas';
$labels['folders-sub'] = 'Pasirinktas aplankas ir jo poaplankiai';
$labels['folders-all'] = 'Visi aplankai';
$labels['more'] = 'Kita';
$labels['back'] = 'Grįžti';
$labels['options'] = 'Nuostatos';
$labels['composeoptions'] = 'Laiško kūrimo nuostatos';
$labels['optionsandattachments'] = 'Nuostatos ir priedai';
$labels['actions'] = 'Veiksmai';
$labels['first'] = 'Pirmas';
$labels['last'] = 'Paskutinis';
$labels['previous'] = 'Ankstesnis';
$labels['next'] = 'Sekantis';
$labels['select'] = 'Pažymėti';
$labels['selection'] = 'Žymėjimas';
$labels['all'] = 'visus';
$labels['none'] = 'Nieko';
$labels['currpage'] = 'matomus šiame puslapyje';
$labels['isread'] = 'Skaityti';
$labels['unread'] = 'neskaitytus';
$labels['flagged'] = 'su gairele';
$labels['unflagged'] = 'Nepažymėti vėliavėle';
$labels['unanswered'] = 'neatsakytus';
$labels['withattachment'] = 'Su priedu';
$labels['deleted'] = 'pašalintus';
$labels['undeleted'] = 'Neištrintas';
$labels['replied'] = 'Atsakytieji';
$labels['forwarded'] = 'Persiųstieji';
$labels['invert'] = 'invertuoti';
$labels['filter'] = 'Rodyti';
$labels['list'] = 'Sąrašas';
$labels['threads'] = 'Gijos';
$labels['expand-all'] = 'išskleisti visas';
$labels['expand-unread'] = 'išskleisti turinčias neskaitytų laiškų';
$labels['collapse-all'] = 'suskleisti visas';
$labels['threaded'] = 'Rodyti gijas';
$labels['showunread'] = 'Rodyti neskaitytus laiškus';
$labels['autoexpand_threads'] = 'Išskleisti gijas';
$labels['do_expand'] = 'visas';
$labels['expand_only_unread'] = 'tik turinčias neskaitytų laiškų';
$labels['fromto'] = 'Siuntėjas/Gavėjas';
$labels['flag'] = 'Gairelė';
$labels['attachment'] = 'Priedas';
$labels['nonesort'] = 'Nerūšiuoti';
$labels['sentdate'] = 'Išsiuntimo laikas';
$labels['arrival'] = 'Gavimo laikas';
$labels['asc'] = 'didėjančiai';
$labels['desc'] = 'mažėjančiai';
$labels['listcolumns'] = 'Stulpelių sąrašas';
$labels['listsorting'] = 'Stulpelis rikiavimui';
$labels['listorder'] = 'Rikiavimo tvarka';
$labels['listmode'] = 'Sąrašo rodymo veiksena';
$labels['lmode'] = 'Sąrašo veiksena';
$labels['layout'] = 'Išdėstymas';
$labels['layoutwidescreen'] = 'Platus ekranas';
$labels['layoutdesktop'] = 'Darbalaukis';
$labels['layoutlist'] = 'Sąrašas';
$labels['layoutwidescreendesc'] = 'Plačiaekranis (3 stulpelių rodymas)';
$labels['layoutdesktopdesc'] = 'Darbalaukis (platus sąrašas, o žemiau pašto peržiūra)';
$labels['layoutlistdesc'] = 'Sąrašas (be pašto peržiūros)';
$labels['folderactions'] = 'Veiksmai su aplankais…';
$labels['compact'] = 'Suglaudinti';
$labels['empty'] = 'Ištuštinti';
$labels['importmessages'] = 'Importuoti laiškus';
$labels['mailimportdesc'] = 'Jūs galite įkelti paštą, naudodami failus <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> ar <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a> formatu.';
$labels['mailimportzip'] = 'Keli failai gali būti suglaudinti į zip archyvus.';
$labels['quota'] = 'Disko naudojimas';
$labels['unknown'] = 'nežinomas';
$labels['unlimited'] = 'neribotas';
$labels['quotatype'] = 'Kvotos tipas';
$labels['quotatotal'] = 'Limitas';
$labels['quotaused'] = 'Išnaudota';
$labels['quotastorage'] = 'Disko talpa';
$labels['quotamessage'] = 'Laiškų skaičius';
$labels['shortheaderdate'] = 'Ties $date';
$labels['shortheaderto'] = 'Skirtas $to ties $date';
$labels['shortheaderfrom'] = 'Nuo $from ties $date';
$labels['quicksearch'] = 'Sparčioji paieška';
$labels['searchplaceholder'] = 'Ieškoti...';
$labels['resetsearch'] = 'Atšaukti paiešką';
$labels['searchmod'] = 'Paieškos modifikatoriai';
$labels['msgtext'] = 'Visas laiškas';
$labels['body'] = 'Laiško tekstas';
$labels['type'] = 'Tipas';
$labels['namex'] = 'Vardas';
$labels['searchscope'] = 'Sritis';
$labels['currentfolder'] = 'Šis aplankas';
$labels['subfolders'] = 'Šis ir poaplankiai';
$labels['allfolders'] = 'Visi aplankai';
$labels['searchinterval-1W'] = 'senesni nei savaitės';
$labels['searchinterval-1M'] = 'senesni nei mėnesio';
$labels['searchinterval-1Y'] = 'senesni nei metų';
$labels['searchinterval1W'] = 'ne senesni nei savaitės';
$labels['searchinterval1M'] = 'ne senesni nei mėnesio';
$labels['searchinterval1Y'] = 'ne senesni nei metų';
$labels['openinextwin'] = 'Atverti naujame lange';
$labels['emlsave'] = 'Parsisiųsti (.eml)';
$labels['changeformattext'] = 'Rodyti grynojo teksto formatu';
$labels['changeformathtml'] = 'Rodyti HTML formatu';
$labels['editasnew'] = 'Redaguoti kaip naują';
$labels['send'] = 'Siųsti';
$labels['sendmessage'] = 'Išsiųsti laiską';
$labels['savemessage'] = 'Išsaugoti šį juodraštį';
$labels['addattachment'] = 'Pridėti failą';
$labels['charset'] = 'Koduotė';
$labels['editortype'] = 'Laiško tipas';
$labels['returnreceipt'] = 'Prašyti pristatymo pažymos';
$labels['dsn'] = 'Laiško pristatymo pažyma';
$labels['keepformatting'] = 'Išlaikyti formatavimą';
$labels['mailreplyintro'] = '$date, $sender rašė:';
$labels['originalmessage'] = 'Originalus laiškas';
$labels['selectimage'] = 'Pažymėti paveikslą';
$labels['addimage'] = 'Pridėti paveikslą';
$labels['selectmedia'] = 'Pažymėti vaizdo įrašą';
$labels['addmedia'] = 'Pridėti vaizdo įrašą';
$labels['encrypt'] = 'Šifruoti';
$labels['encryptmessage'] = 'Šifruoti laišką';
$labels['encryptmessagemailvelope'] = 'Šifruoti laišką, naudojant „Mailvelope“ naršyklės plėtinį';
$labels['importpubkeys'] = 'Importuoti viešuosius raktus';
$labels['encryptedsendialog'] = 'Siunčiamas šifruotas laiškas';
$labels['encryptandsign'] = 'Šifruoti ir pasirašyti';
$labels['keyid'] = 'Rakto ID';
$labels['keylength'] = 'Bitai';
$labels['keyexpired'] = 'Nebegalioja';
$labels['keyrevoked'] = 'Atšauktas';
$labels['bccinstead'] = 'Naudoti Bcc';
$labels['addheader'] = 'Pridėti lauką (Cc, Bcc, ...)';
$labels['insert'] = 'Įterpti';
$labels['insertcontact'] = 'Įterpti adresatą(-us)';
$labels['recipient'] = 'Gavėjas';
$labels['recipientedit'] = 'Gavėjo taisymas';
$labels['editidents'] = 'Tvarkyti tapatybes';
$labels['spellcheck'] = 'Tikrinti rašybą';
$labels['checkspelling'] = 'Tikrinti rašybą';
$labels['resumeediting'] = 'Tęsti redagavimą';
$labels['revertto'] = 'Atstatyti į';
$labels['restore'] = 'Atkurti';
$labels['restoremessage'] = 'Atkurti pranešimus?';
$labels['ignore'] = 'Ignoruoti';
$labels['responses'] = 'Atsakymai';
$labels['insertresponse'] = 'Įterpti atsakymą';
$labels['manageresponses'] = 'Tvarkyti atsakymus';
$labels['newresponse'] = 'Kurti naują atsakymą';
$labels['addresponse'] = 'Pridėti atsakymą';
$labels['editresponse'] = 'Taisyti atsakymą';
$labels['editresponses'] = 'Taisyti atsakymus';
$labels['responsename'] = 'Pavadinimas';
$labels['responsetext'] = 'Atsakymo tekstas';
$labels['attach'] = 'Pridėti failą';
$labels['attachments'] = 'Pridėti failai';
$labels['upload'] = 'Įkelti';
$labels['uploadprogress'] = '$percent ($current iš $total)';
$labels['close'] = 'Užverti';
$labels['messageoptions'] = 'Laiško savybės…';
$labels['togglecomposeoptions'] = 'Rodyti/slėpti nustatymus';
$labels['attachmentrename'] = 'Pervardinti priedą';
$labels['low'] = 'Žemas';
$labels['lowest'] = 'Žemiausias';
$labels['normal'] = 'Normalus';
$labels['high'] = 'Aukštas';
$labels['highest'] = 'Aukščiausias';
$labels['nosubject'] = '(tema nenurodyta)';
$labels['showimages'] = 'Rodyti paveikslėlius';
$labels['allow'] = 'Leisti';
$labels['alwaysshow'] = 'Visada rodyti paveikslėlius $sender laiškuose';
$labels['alwaysallow'] = 'Visada leisti nuo $sender';
$labels['isdraft'] = 'Tai – laiško juodraštis.';
$labels['andnmore'] = '$nr daugiau...';
$labels['details'] = 'Išsamiau';
$labels['summary'] = 'Santrauka';
$labels['headers'] = 'Antraštės';
$labels['allheaders'] = 'Visos antraštės...';
$labels['togglemoreheaders'] = 'Rodyti daugiau antraščių';
$labels['togglefullheaders'] = 'Įjungti/išjungti neapdorotas laiškų antraštes';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Grynasis tekstas';
$labels['savesentmessagein'] = 'Išsiųstus laiškus įrašyti į';
$labels['dontsave'] = 'neįrašyti';
$labels['maxuploadsize'] = 'Maksimalus leistinas failo dydis yra $size';
$labels['addcc'] = 'Pridėti Cc';
$labels['addbcc'] = 'Pridėti Bcc';
$labels['addreplyto'] = 'Pridėti Reply-To';
$labels['addfollowupto'] = 'Pridėti Followup-To';
$labels['sendreceipt'] = 'Išsiųsti perskaitymo patvirtinimą?';
$labels['mdnrequest'] = 'Šio laiško siuntėjas paprašė patvirtinti, kad jūs jį perskaitėte. Ar išsiųsti tai patvirtinančią pažymą?';
$labels['receiptread'] = 'Patvirtinimas (laiškas perskaitytas)';
$labels['yourmessage'] = 'Tai – pažyma, patvirtinanti, jog buvo perskaitytas Jūsų laiškas';
$labels['receiptnote'] = 'Pastaba: šia pažyma patvirtinamas tik faktas, jog laiškas buvo parodytas gavėjui. Ja negarantuojama, jog gavėjas perskaitė ir suprato laiško turinį.';
$labels['sendalwaysto'] = 'Visada siųsti adresu $email';
$labels['zoomin'] = 'Didinti';
$labels['zoomout'] = 'Mažinti';
$labels['rotate'] = 'Pasukti';
$labels['increaseimage'] = 'Padidinti paveikslo dydį';
$labels['decreaseimage'] = 'Sumažinti paveikslo dydį';
$labels['rotateimage'] = 'Pasukti paveikslą';
$labels['showtools'] = 'Rodyti paveikslų įrankius';
$labels['hidetools'] = 'Slėpti paveikslų įrankius';
$labels['name'] = 'Rodomas vardas';
$labels['firstname'] = 'Vardas';
$labels['surname'] = 'Pavardė';
$labels['middlename'] = 'Kiti vardai';
$labels['nameprefix'] = 'Titulas';
$labels['namesuffix'] = 'Sufiksas';
$labels['nickname'] = 'Pravardė';
$labels['jobtitle'] = 'Pareigos';
$labels['department'] = 'Padalinys';
$labels['gender'] = 'Lytis';
$labels['maidenname'] = 'Mergautinė pavardė';
$labels['email'] = 'El. paštas';
$labels['phone'] = 'Telefono numeris';
$labels['address'] = 'Adresas';
$labels['street'] = 'Gatvė, namas ir butas';
$labels['locality'] = 'Miestas';
$labels['zipcode'] = 'Pašto kodas';
$labels['region'] = 'Regionas';
$labels['country'] = 'Valstybė';
$labels['birthday'] = 'Gimimo data';
$labels['anniversary'] = 'Jubiliejus';
$labels['website'] = 'Svetainė';
$labels['instantmessenger'] = 'Tikralaikiai pokalbiai';
$labels['notes'] = 'Pastabos';
$labels['male'] = 'vyras';
$labels['female'] = 'moteris';
$labels['manager'] = 'Vadybininkas(-ė)';
$labels['assistant'] = 'Padėjėjo(-os)';
$labels['spouse'] = 'Sutuoktinis';
$labels['allfields'] = 'Visi laukai';
$labels['search'] = 'Paieška';
$labels['searchresult'] = 'Paieškos rezultatas';
$labels['advsearch'] = 'Išplėstinė paieška';
$labels['advanced'] = 'Išsamiau';
$labels['other'] = 'Kitas';
$labels['printcontact'] = 'Spausdinti kontakto duomenis';
$labels['qrcode'] = 'QR kodas';
$labels['typehome'] = 'Namų';
$labels['typework'] = 'Darbo';
$labels['typeother'] = 'Kitas';
$labels['typemobile'] = 'Mobilusis';
$labels['typemain'] = 'Pagrindinis';
$labels['typehomefax'] = 'Namų faksas';
$labels['typeworkfax'] = 'Darbo faksas';
$labels['typecar'] = 'Automobilyje';
$labels['typepager'] = 'Pranešimų gaviklis';
$labels['typevideo'] = 'Vaizdo';
$labels['typeassistant'] = 'Padėjėjo(-os)';
$labels['typehomepage'] = 'Tinklalapis';
$labels['typeblog'] = 'Tinklaraštis';
$labels['typeprofile'] = 'Profilis';
$labels['addfield'] = 'Pridėti lauką…';
$labels['addcontact'] = 'Pridėti adresatą';
$labels['editcontact'] = 'Taisyti adresatą';
$labels['contacts'] = 'Adresatai';
$labels['contactproperties'] = 'Adresato savybės';
$labels['contactnameandorg'] = 'Vardas ir organizacija';
$labels['personalinfo'] = 'Asmeniniai duomenys';
$labels['personal'] = 'Asmeninis';
$labels['contactphoto'] = 'Adresato nuotrauka';
$labels['edit'] = 'Redaguoti';
$labels['cancel'] = 'Atsisakyti';
$labels['save'] = 'Įrašyti';
$labels['delete'] = 'Pašalinti';
$labels['discard'] = 'Panaikinti';
$labels['continue'] = 'Tęsti';
$labels['ok'] = 'Gerai';
$labels['rename'] = 'Pervardinti';
$labels['addphoto'] = 'Pridėti';
$labels['replacephoto'] = 'Pakeisti';
$labels['uploadphoto'] = 'Įkelti nuotrauką';
$labels['choosefile'] = 'Pasirinkti failą...';
$labels['choosefiles'] = 'Pasirinkti failus...';
$labels['browse'] = 'Naršyti';
$labels['newcontact'] = 'Sukurti naują adresatą';
$labels['deletecontact'] = 'Ištrinti pažymėtus adresatus';
$labels['composeto'] = 'Rašyti laišką';
$labels['contactsfromto'] = 'Adresatai nuo $from iki $to iš $count';
$labels['print'] = 'Spausdinti';
$labels['export'] = 'Eksportuoti';
$labels['exportall'] = 'Eksportuoti visus';
$labels['exportsel'] = 'Eksportuoti pažymėtus';
$labels['exportvcards'] = 'Eksportuoti adresatus  „vCard“ formatu';
$labels['newgroup'] = 'Kurti naują grupę';
$labels['addgroup'] = 'Pridėti grupę';
$labels['grouprename'] = 'Pervardinti grupę';
$labels['groupdelete'] = 'Pašalinti grupę';
$labels['groupassign'] = 'Priskirti grupei...';
$labels['groupremove'] = 'Šalinti iš grupės';
$labels['groupremoveselected'] = 'Pašalinti pažymėtus adresatus iš grupės';
$labels['uponelevel'] = 'Į viršų per vieną';
$labels['previouspage'] = 'Rodyti ankstesnį puslapį';
$labels['firstpage'] = 'Rodyti pirmąjį puslapį';
$labels['nextpage'] = 'Rodyti tolesnį puslapį';
$labels['lastpage'] = 'Rodyti paskutinį puslapį';
$labels['group'] = 'Grupė';
$labels['groups'] = 'Grupės';
$labels['listgroup'] = 'Išvardinti grupės narius';
$labels['personaladrbook'] = 'Asmeniniai adresai';
$labels['searchsave'] = 'Įrašyti kaip radinių aplanką';
$labels['searchdelete'] = 'Pašalinti radinių aplanką';
$labels['import'] = 'Importuoti';
$labels['importcontacts'] = 'Importuoti adresatus';
$labels['importfromfile'] = 'Importuoti iš failo';
$labels['importtarget'] = 'Pridėti adresatus į';
$labels['importreplace'] = 'Perrašyti visą adresų knygą';
$labels['importgroups'] = 'Importuoti priskyrimus grupėms';
$labels['importgroupsall'] = 'Visus (sukurti trūkstamas grupes)';
$labels['importgroupsexisting'] = 'Tik esamoms grupėms';
$labels['importdesc'] = 'Galite įkelti kontaktus iš jau turimos adresų knygos.<br/>Šiuo metu galima importuoti kontaktus iš <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> ar CSV (comma-separated) duomenų formatų.';
$labels['importmapdesc'] = 'Prieš tęsdami CSV importą, patvirtinkite, jog žemiau pateikti laukų atitikmenys yra teisingi.';
$labels['fieldnotmapped'] = 'Laukas nesusietas (neimportuoti)';
$labels['skipheader'] = 'Neimportuoti pirmosios (antraštinės) eilutės';
$labels['done'] = 'Baigta';
$labels['settingsfor'] = 'Nuostatos';
$labels['about'] = 'Apie';
$labels['preferences'] = 'Nuostatos';
$labels['userpreferences'] = 'Naudotojo nuostatos';
$labels['editpreferences'] = 'Keisti naudotojo nuostatas';
$labels['identities'] = 'Tapatybės';
$labels['manageidentities'] = 'Tvarkyti tapatybes';
$labels['newidentity'] = 'Sukurti naują tapatybę';
$labels['addidentity'] = 'Pridėti tapatybę';
$labels['editidentity'] = 'Tvarkyti tapatybę';
$labels['identityencryption'] = 'Šifravimas';
$labels['preferhtml'] = 'Rodyti HTML';
$labels['defaultcharset'] = 'Numatytoji koduotė';
$labels['htmlmessage'] = 'HTML laiškas';
$labels['messagepart'] = 'Dalis';
$labels['digitalsig'] = 'Skaitmeninis parašas';
$labels['dateformat'] = 'Datos formatas';
$labels['timeformat'] = 'Laiko formatas';
$labels['prettydate'] = 'Dailios datos';
$labels['setdefault'] = 'Laikyti numatytąja';
$labels['autodetect'] = 'Aptikti automatiškai';
$labels['language'] = 'Kalba';
$labels['timezone'] = 'Laiko juosta';
$labels['pagesize'] = 'Eilučių skaičius puslapyje';
$labels['signature'] = 'Parašas';
$labels['dstactive'] = 'Vasaros laikas skiriasi';
$labels['showinextwin'] = 'Atidaryti pranešimą naujame lange';
$labels['composeextwin'] = 'Rašyti naujame lange';
$labels['htmleditor'] = 'Laiškus kurti HTML formatu';
$labels['htmlonreply'] = 'tik atsakymus į HTML formato laiškus';
$labels['htmlonreplyandforward'] = 'atsakant į HTML laišką arba jį persiunčiant';
$labels['htmlsignature'] = 'HTML parašas';
$labels['showemail'] = 'Rodyti el. pašto adresą ir asmenvardį';
$labels['previewpane'] = 'Rodyti laiško peržiūros polangį';
$labels['skin'] = 'Grafinis apvalkalas';
$labels['logoutclear'] = 'Išvalyti Šiukšlinę atsijungiant';
$labels['logoutcompact'] = 'Suglaudinti gautųjų laiškų aplanką atsijungiant';
$labels['uisettings'] = 'Naudotojo sąsaja';
$labels['serversettings'] = 'Serverio nuostatos';
$labels['mailboxview'] = 'Pašto dėžutės rodymas';
$labels['mdnrequests'] = 'Gavus prašymą patvirtinti, jog laiškas perskaitytas';
$labels['askuser'] = 'visuomet klausti, ar siųsti patvirtinimą';
$labels['autosend'] = 'visuomet siųsti patvirtinimą automatiškai';
$labels['autosendknown'] = 'automatiškai siųsti patvirtinimą adresų knygoje esantiems adresatams, kitu atveju klausti';
$labels['autosendknownignore'] = 'automatiškai siųsti patvirtinimą adresų knygoje esantiems adresatams, kitu atveju nesiųsti';
$labels['autosendtrusted'] = 'automatiškai siųsti patvirtinimą patikimiems siuntėjams, kitu atveju klausti';
$labels['autosendtrustedignore'] = 'automatiškai siųsti patvirtinimą patikimiems siuntėjams, kitu atveju nesiųsti';
$labels['ignorerequest'] = 'Ignoruoti prašymą';
$labels['readwhendeleted'] = 'Pažymėti laišką kaip skaitytą prieš šalinant';
$labels['flagfordeletion'] = 'Pažymėti laišką šalinimui užuot šalinus';
$labels['skipdeleted'] = 'Nerodyti pašalintų laiškų';
$labels['deletealways'] = 'Pašalinti laiškus, jeigu nepavyksta jų perkelti į Šiukšlinę';
$labels['deletejunk'] = 'Pašalinti Brukalo aplanke esančius laiškus';
$labels['showremoteimages'] = 'Įkelti paveikslėlius iš interneto serverių';
$labels['allowremoteresources'] = 'Leisti nuotolinius išteklius (paveikslėlius, stilius)';
$labels['fromknownsenders'] = 'tik žinomų siuntėjų laiškuose';
$labels['fromtrustedsenders'] = 'iš patikimų siuntėjų';
$labels['frommycontacts'] = 'iš mano adresatų knygos adresatų';
$labels['always'] = 'visada';
$labels['alwaysbutplain'] = 'visuomet, išskyrus atsakant į grynojo teksto laiškus';
$labels['showinlineimages'] = 'Rodyti pridėtus paveikslėlius žemiau laiško';
$labels['autosavedraft'] = 'Automatiškai įrašyti juodraščius';
$labels['everynminutes'] = 'kas $n min.';
$labels['refreshinterval'] = 'Atnaujinti (patikrinti, ar nėra naujų laiškų ir pan.)';
$labels['never'] = 'niekada';
$labels['immediately'] = 'nedelsiant';
$labels['messagesdisplaying'] = 'Laiškų rodymas';
$labels['messagescomposition'] = 'Laiškų rašymas';
$labels['mimeparamfolding'] = 'Prisegtų failų vardų kodavimas';
$labels['2231folding'] = 'visiškas RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'visiškas RFC 2047 (kitos programos)';
$labels['force7bit'] = 'Naudoti MIME kodavimą 8 bitų simboliams';
$labels['savelocalstorage'] = "Išsaugoti naršyklės laikinoje saugykloje (keše)";
$labels['advancedoptions'] = 'Papildomos nuostatos';
$labels['toggleadvancedoptions'] = 'Rodyti/slėpti papildomus nustatymus';
$labels['focusonnewmessage'] = 'Fokusuoti naršyklės langą gavus naują laišką';
$labels['checkallfolders'] = 'Naujų laiškų ieškoti visuose aplankuose';
$labels['displaynext'] = 'Rodyti kitą sąrašo įrašą ištrinus/perkėlus';
$labels['defaultfont'] = 'Numatytasis HTML laiškų šriftas';
$labels['mainoptions'] = 'Pagrindinės nuostatos';
$labels['browseroptions'] = 'Naršyklės nuostatos';
$labels['section'] = 'Sekcija';
$labels['maintenance'] = 'Priežiūra';
$labels['newmessage'] = 'Naujas laiškas';
$labels['signatureoptions'] = 'Parašo nuostatos';
$labels['whenreplying'] = 'Kuriant atsakymą';
$labels['replyempty'] = 'necituoti originalaus laiško';
$labels['replytopposting'] = 'rašyti atsakymą virš cituojamo laiško';
$labels['replytoppostingnoindent'] = 'rašyti atsakymą virš cituojamo laiško (be įtraukos)';
$labels['replybottomposting'] = 'rašyti atsakymą po cituojamu laišku';
$labels['replyremovesignature'] = 'Pašalinti cituojamame laiške esantį parašą';
$labels['autoaddsignature'] = 'Automatiškai pridėti parašą';
$labels['newmessageonly'] = 'tik naujuose laiškuose';
$labels['replyandforwardonly'] = 'tik atsakymuose ir persiunčiamuose laiškuose';
$labels['insertsignature'] = 'Pridėti parašą';
$labels['sigbelow'] = 'Įterpti parašą žemiau kabutėmis išskirto laiško turinio';
$labels['sigseparator'] = 'Priverstinai naudoti standartinį skyriklį parašuose';
$labels['automarkread'] = 'Pažymėti laiškus kaip skaitytus';
$labels['afternseconds'] = 'praėjus $n sek.';
$labels['reqmdn'] = 'Visuomet prašyti patvirtinimo, jog laiškas perskaitytas';
$labels['reqdsn'] = 'Visuomet prašyti laiško pristatymo pažymos';
$labels['replysamefolder'] = 'Atsakymus talpinti į tą patį aplanką, kuriame yra pirminis laiškas';
$labels['defaultabook'] = 'Numatytoji adresų knyga';
$labels['autocompletesingle'] = 'Užbaigiant adresus, praleisti antrinius';
$labels['listnamedisplay'] = 'Rodyti adresatus kaip';
$labels['contactformmode'] = 'Numatytieji adresato laukai';
$labels['privatemode'] = 'Namų';
$labels['businessmode'] = 'Darbo';
$labels['collectedaddresses'] = 'Surinkti adresai';
$labels['collectedrecipients'] = 'Surinkti gavėjai';
$labels['collectedrecipientsopt'] = 'Laikyti išsiunčiamų el. laiškų gavėjus ties';
$labels['collectedsendersopt'] = 'Laikyti patikimus siuntėjus ties';
$labels['trustedsenders'] = 'Patikimi siuntėjai';
$labels['spellcheckbeforesend'] = 'Tikrinti rašybą prieš išsiunčiant laišką';
$labels['spellcheckoptions'] = 'Rašybos tikrinimo nuostatos';
$labels['spellcheckignoresyms'] = 'Nepaisyti žodžių su spec. simboliais';
$labels['spellcheckignorenums'] = 'Nepaisyti žodžių su skaitmenimis';
$labels['spellcheckignorecaps'] = 'Nepaisyti žodžių vien iš didžiųjų raidžių';
$labels['addtodict'] = 'Įtraukti į žodyną';
$labels['editoroptions'] = 'Redaktoriaus nuostatos';
$labels['enableautolink'] = 'Automatiškai konvertuoti tinkamus URL adresus į hipersaitus';
$labels['mailtoprotohandler'] = 'Užregistruoti svetainę kaip dirbančią su „mailto:“ saitais';
$labels['standardwindows'] = 'Iškylančiuosius langus traktuoti kaip įprastus';
$labels['forwardmode'] = 'Laiškų persiuntimo būdas';
$labels['inline'] = 'kaip citatą';
$labels['asattachment'] = 'kaip priedas';
$labels['replyallmode'] = 'Numatytasis mygtuko „Atsakyti visiems“ veiksmas';
$labels['replyalldefault'] = 'atsakyti visiems';
$labels['replyalllist'] = 'atsakyti el. pašto grupei (jei aptikta)';
$labels['allmessages'] = 'visi laiškai';
$labels['olderxdays'] = 'senesni nei $x d.';
$labels['folder'] = 'Aplankas';
$labels['folders'] = 'Aplankai';
$labels['foldername'] = 'Aplanko vardas';
$labels['subscribed'] = 'Užsakytas';
$labels['messagecount'] = 'Laiškai';
$labels['create'] = 'Sukurti';
$labels['createfolder'] = 'Sukurti naują aplanką';
$labels['managefolders'] = 'Tvarkyti aplankus';
$labels['specialfolders'] = 'Specialieji aplankai';
$labels['properties'] = 'Savybės';
$labels['folderproperties'] = 'Aplanko savybės';
$labels['parentfolder'] = 'Tėvinis aplankas';
$labels['location'] = 'Vieta';
$labels['info'] = 'Informacija';
$labels['getfoldersize'] = 'Spustelėkite, norėdami sužinoti aplanko dydį';
$labels['changesubscription'] = 'Spustelėkite, norėdami keisti prenumeratos nuostatas';
$labels['foldertype'] = 'Aplanko tipas';
$labels['personalfolder'] = 'Asmeninis aplankas';
$labels['otherfolder'] = 'Kito naudotojo aplankas';
$labels['sharedfolder'] = 'Viešas aplankas';
$labels['findfolders'] = 'Ieškoti aplankų';
$labels['findcontacts'] = 'Rasti adresatus';
$labels['findmail'] = 'Rasti el. laiškus';
$labels['namespace.personal'] = 'Asmeninis';
$labels['namespace.other'] = 'Kito naudotojo';
$labels['namespace.shared'] = 'Bendrinamas';
$labels['dualuselabel'] = 'Savyje gali turėti tik';
$labels['dualusemail'] = 'laiškai';
$labels['dualusefolder'] = 'aplankai';
$labels['generate'] = 'Generuoti';
$labels['encryptioncreatekey'] = 'Kurti naują raktų porą';
$labels['openmailvelopesettings'] = 'Atverti Mailvelope nustatymus';
$labels['encryptionprivkeysinmailvelope'] = 'Turite $nr atitinkančius privačiuosius raktus, saugomus jūsų Mailvelope raktinėje:';
$labels['encryptionnoprivkeysinmailvelope'] = 'Šio siuntėjo tapatybė kol kas neturi jūsų Mailvelope priede saugomo PGP privačiojo rakto. Ar norėtumėte jį sukurti, kad būtų įjungtas šifruotas susirašinėjimas?';
$labels['encryption'] = 'Šifravimas';
$labels['mailvelopeoptions'] = 'Mailvelope nuostatos';
$labels['mailvelopemainkeyring'] = 'Naudoti Mailvelope pagrindinę raktinę';
$labels['mailvelopenotfound'] = 'Jūsų naršyklėje nėra įjungtas/įdiegtas Mailvelope priedas.';
$labels['mailvelopeenable'] = 'Įjungti';
$labels['sortby'] = 'Rikiuoti pagal';
$labels['sortasc'] = 'Rikiuoti didėjančiai';
$labels['sortdesc'] = 'Rikiuoti mažėjančiai';
$labels['undo'] = 'Atšaukti';
$labels['installedplugins'] = 'Įdiegti įskiepiai';
$labels['plugin'] = 'Papildinys';
$labels['version'] = 'Versija';
$labels['source'] = 'Šaltinis';
$labels['destination'] = 'Paskirtis';
$labels['license'] = 'Licencija';
$labels['skinauthor'] = 'pagal $author';
$labels['support'] = 'Gauti pagalbos';
$labels['savedsearches'] = 'Įrašytos paieškos';
$labels['dateformatY'] = 'MMMM';
$labels['dateformaty'] = 'MM';
$labels['dateformatm'] = 'mm';
$labels['dateformatd'] = 'dd';
$labels['dateformatj'] = 'd';
$labels['dateformatn'] = 'm';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unikodas';
$labels['english'] = 'Anglų';
$labels['westerneuropean'] = 'Vakarų Europos';
$labels['easterneuropean'] = 'Rytų Europos';
$labels['southeasterneuropean'] = 'Pietryčių Europos';
$labels['baltic'] = 'Baltijos šalių';
$labels['cyrillic'] = 'Kirilica';
$labels['arabic'] = 'Arabų';
$labels['greek'] = 'Graikų';
$labels['hebrew'] = 'Hebrajų';
$labels['turkish'] = 'Turkų';
$labels['nordic'] = 'Šiaurės šalių';
$labels['thai'] = 'Tajų';
$labels['celtic'] = 'Keltų';
$labels['vietnamese'] = 'Vietnamiečių';
$labels['japanese'] = 'Japonų';
$labels['korean'] = 'Korėjiečių';
$labels['chinese'] = 'Kinų';
$labels['arialabeltopnav'] = 'Lango valdymas';
$labels['arialabeltasknav'] = 'Aplikacijos užduotys';
$labels['arialabeltoolbar'] = 'Aplikacijos įrankių juosta';
$labels['arialabellistnav'] = 'Naršymas sąraše';
$labels['arialabelactivetask'] = 'Aktyvi užduotis';
$labels['arialabelmessagessearchfilter'] = 'Laiškų sąrašo filtras';
$labels['arialabelmailsearchform'] = 'El. laiško paieškos forma';
$labels['arialabelcontactsearchform'] = 'Adresatų paieškos forma';
$labels['arialabelmailquicksearchbox'] = 'El. pašto paieškos įvestis';
$labels['arialabelquicksearchbox'] = 'Paieškos įvestis';
$labels['arialabelfoldersearchfilter'] = 'Aplankų sąrašo filtras';
$labels['arialabelfoldersearchform'] = 'Aplanko paieškos forma';
$labels['arialabelfolderlist'] = 'Laiškų aplanko pasirinkimas';
$labels['arialabelmessagelist'] = 'Elektroninių laiškų sąrašas';
$labels['arialabelmailpreviewframe'] = 'Laiško peržiūra';
$labels['arialabelmailboxmenu'] = 'Veiksmų su aplankais meniu';
$labels['arialabellistselectmenu'] = 'Sąrašo pasirinkimo meniu';
$labels['arialabelthreadselectmenu'] = 'Gijų sąrašo meniu';
$labels['arialabelmessagelistoptions'] = 'Laiškų rodymo ir rikiavimo nustatymai';
$labels['arialabelmailimportdialog'] = 'Laiškų importavimo dialogas';
$labels['arialabelmessagenav'] = 'Navigacija tarp laiškų';
$labels['arialabelmessagebody'] = 'Laiško turinys';
$labels['arialabelmessageactions'] = 'Veiksmai su laišku';
$labels['arialabelcontactquicksearch'] = 'Adresatų paieškos forma';
$labels['arialabelcontactsearchbox'] = 'Kontaktų paieškos įvestis';
$labels['arialabelmessageheaders'] = 'Laiško antraštės';
$labels['arialabelforwardingoptions'] = 'Persiuntimo nustatymai';
$labels['arialabelreplyalloptions'] = 'Atsakyti visiems nustatymai';
$labels['arialabelmoremessageactions'] = 'Daugiau laiškų veiksmų';
$labels['arialabelmorecontactactions'] = 'Daugiau adresatų veiksmų';
$labels['arialabelmarkmessagesas'] = 'Pažymėti pasirinktus laiškus kaip...';
$labels['arialabelcomposeoptions'] = 'Laiško kūrimo nustatymai';
$labels['arialabelresponsesmenu'] = 'Atsakymų meniu';
$labels['arialabelattachmentuploadform'] = 'Priedo įkėlimo forma';
$labels['arialabelattachmentmenu'] = 'Priedo nuostatos';
$labels['arialabelmailtomenu'] = 'El. pašto adreso nuostatos';
$labels['arialabelattachmentpreview'] = 'Priedo peržiūra';
$labels['ariasummarycomposecontacts'] = 'Sąrašas adresatų ir grupių, kuriuos galima pasirinkti kaip gavėją';
$labels['arialabelcontactexportoptions'] = 'Adresatų eksportavimo nustymai';
$labels['arialabelabookgroupoptions'] = 'Adresų knygos/grupių nustatymai';
$labels['arialabelpreferencesform'] = 'Nustatymų forma';
$labels['arialabelidentityeditfrom'] = 'Tapatybės redagavimo forma';
$labels['arialabelresponseeditfrom'] = 'Atsakymo redagavimo forma';
$labels['arialabelsearchterms'] = 'Paieškos žodžiai';
$labels['arialabeldropactionmenu'] = 'Vilkimo veiksmo meniu';
$labels['arialabelheadersmenu'] = 'Gavėjo (antraštė) pridėjimo meniu';
$labels['arialabelimagetools'] = 'Paveikslų įrankiai';
$labels['helplistnavigation'] = 'Navigacija klaviatūra sąraše';
$labels['helplistkeyboardnavigation'] = "Rodyklė aukštyn / žemyn: fokusuoti / pasirinkti kitą eilutę.
Tarpas: pasirinkti sufokusuoą eilutę.
Lyg2 + rodyklė aukštyn / žemyn: pasirinkti papildomą eilutę viršuje / apačioje.
Vald + tarpas: įtraukti sufokusuotą eilutę į pasirinktų sąrašą / pašalinti ją iš jo.";
$labels['helplistkeyboardnavmessages'] = "Rodyklė dešinėn / kairėn: išskleisti / suskleisti laiškų giją (esant gijų veiksenoje).
Įvesti: atverti pasirinktą / sufokusuotą laišką.
Šalinti: perkelti pasirinktus laiškus į Šiukšlinę.";
$labels['helplistkeyboardnavcontacts'] = "Enter: Atidaryti pasirinktą adresatą";
