<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Vcard Attachments plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['addvcardmsg'] = 'vCard hozzáadása a címjegyzékhez';
$labels['vcardsavefailed'] = 'A vCard mentése nem lehetséges';
$labels['attachvcard'] = 'vCard csatolása';
$labels['vcardattached'] = 'vCard csatolva.';
$labels['vcard'] = 'vCard';
$labels['forwardvcard'] = 'vCard továbbítása';
$labels['contactsattached'] = 'Az üzenethez $num kapcsolat tartozik.';
$labels['importedsuccessfully'] = 'A kapcsolat(ok) sikeresen importálódtak a címjegyzékbe.';
