<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = '$product غا خۇش كەلدىڭىز';
$labels['username'] = 'ئىشلەتكۈچى نامى';
$labels['password'] = 'مەخپىي نۇمۇر';
$labels['server'] = 'مۇلازىمېتىر';
$labels['login'] = 'كىرىش';
$labels['oauthlogin'] = '$تەمىنلىگۈچى بىلەن كىرىش';
$labels['menu'] = 'تىزىملىك';
$labels['logout'] = 'چىكىنىش';
$labels['mail'] = 'خەت';
$labels['settings'] = 'تەڭشەك';
$labels['addressbook'] = 'ئادىرىس دەپتىرى';
$labels['darkmode'] = 'قاراڭغۇ ھالەت';
$labels['lightmode'] = 'يۇرۇق ھالەت';
$labels['inbox'] = 'كىلىش ساندۇقى';
$labels['drafts'] = 'قوليازمىلار';
$labels['sent'] = 'ئەۋەتىلگەن';
$labels['trash'] = 'ئەخلەت';
$labels['junk'] = 'ئەخلەت';
$labels['show_real_foldernames'] = 'ئالاھىدە قىسقۇچلارنىڭ ھەقىقىي ئىسمىنى كۆرسىتىڭ';
$labels['subject'] = 'تىما';
$labels['from'] = 'دىن';
$labels['sender'] = 'ئەۋەتكۈچى';
$labels['to'] = 'غا';
$labels['cc'] = 'قۇشۇمچە';
$labels['bcc'] = 'ب چ چ';
$labels['replyto'] = 'غا جاۋاپ قايتۇرۇش';
$labels['followupto'] = 'غا ئەگىشىش';
$labels['date'] = 'چېسلا';
$labels['size'] = 'چوڭلۇق';
$labels['priority'] = 'مۇھىملىق دەرىجىسى';
$labels['organization'] = 'ئورگان';
$labels['readstatus'] = 'ئۇقۇش ھالىتى';
$labels['listoptions'] = 'تاللانمىلارنى تىزىش...';
$labels['listoptionstitle'] = 'تاللانمىلارنى تىزىش';
$labels['mailboxlist'] = 'قىسقۇچلار';
$labels['messagesfromto'] = 'from$نىڭ to$گە ئەۋەتكەن count$-ئۇچۇرى';
$labels['threadsfromto'] = 'from$نىڭ to$گە ئەۋەتكەن count$-يىپى';
$labels['messagenrof'] = 'nr/$count$ خەت';
$labels['fromtoshort'] = 'to  - $from$ جەمئىي count$';
$labels['copy'] = 'كۆچۈرۈش';
$labels['move'] = 'يۆتكەش';
$labels['moveto'] = '...غا يۆتكەش';
$labels['copyto'] = '...غا كۆچۈرۈش';
$labels['download'] = 'چۈشۈرۈش';
$labels['open'] = 'ئېچىش';
$labels['showattachment'] = 'كۆرسىتىش';
$labels['showanyway'] = 'بەرىبىر ئۇنى كۆرسىتىڭ';
$labels['filename'] = 'ھۆججەت ئىسمى';
$labels['filesize'] = 'ھۆججەت چوڭلۇقى';
$labels['addtoaddressbook'] = 'ئادىرىس دەپتىرىگە قېتىش';
$labels['sun'] = 'يەكشەنبە';
$labels['mon'] = 'دۈشەنبە';
$labels['tue'] = 'سەيشەنبە';
$labels['wed'] = 'چارشەنبە';
$labels['thu'] = 'پەيشەنبە';
$labels['fri'] = 'جۈمە';
$labels['sat'] = 'شەنبە';
$labels['sunday'] = 'يەكشەنبە';
$labels['monday'] = 'دۈشەنبە';
$labels['tuesday'] = 'سەيشەنبە';
$labels['wednesday'] = 'چارشەنبە';
$labels['thursday'] = 'پەيشەنبە';
$labels['friday'] = 'جۈمە';
$labels['saturday'] = 'شەنبە';
$labels['jan'] = 'يانۋار';
$labels['feb'] = 'فېۋرال';
$labels['mar'] = 'مارت';
$labels['apr'] = 'ئاپرىل';
$labels['may'] = 'ماي';
$labels['jun'] = 'ئىيۇن';
$labels['jul'] = 'ئىيۇل';
$labels['aug'] = 'ئاۋغۇست';
$labels['sep'] = 'سىنتەبىر';
$labels['oct'] = 'ئۆكتەبىر';
$labels['nov'] = 'نويابىر';
$labels['dec'] = 'دېكابىر';
$labels['longjan'] = 'يانۋار';
$labels['longfeb'] = 'فېۋرال';
$labels['longmar'] = 'مارت';
$labels['longapr'] = 'ئاپرىل';
$labels['longmay'] = 'ماي';
$labels['longjun'] = 'ئىيۇن';
$labels['longjul'] = 'ئىيۇل';
$labels['longaug'] = 'ئاۋغۇست';
$labels['longsep'] = 'سىنتەبىر';
$labels['longoct'] = 'ئۆكتەبىر';
$labels['longnov'] = 'نويابىر';
$labels['longdec'] = 'دېكابىر';
$labels['today'] = 'بۈگۈن';
$labels['refresh'] = 'يېڭىلاش';
$labels['checkmail'] = 'يېڭى خەتلەرنى تەكشۈرۈش';
$labels['compose'] = 'يېزىش';
$labels['writenewmessage'] = 'يېڭى خەت يېزىش';
$labels['reply'] = 'جاۋاپ قايتۇرۇش';
$labels['replytomessage'] = 'ئەۋەتكۈچىگە جاۋاپ بېزىش';
$labels['replytoallmessage'] = 'تىزىملىككە ياكى ئەۋەتكۈچى بىلەن بارلىق تاپشۇرۋالغۇچىلارغا جاۋاپ قايتۇرۇش';
$labels['replyall'] = 'ھەممىسىگە جاۋاپ قايتۇرۇش';
$labels['replylist'] = 'تىزىملىككە جاۋاپ قايتۇرۇش';
$labels['forward'] = 'يوللاش';
$labels['forwardinline'] = 'يېڭى ھالەتتە يوللاش';
$labels['forwardattachment'] = 'قىستۇرما ھالەتتە يوللاش';
$labels['forwardmessage'] = 'بۇ خەتنى يوللاش';
$labels['bouncemsg'] = 'قايتا ئەۋەتىش(قاڭقىتىش)';
$labels['bounce'] = 'قايتا ئەۋەتىش';
$labels['deletemessage'] = 'خەتنى ئۆچۈرۈش';
$labels['movemessagetotrash'] = 'خەتنى ئەخلەت چېلىكىگە سېلىش';
$labels['printmessage'] = 'بۇ خەتنى بېسىپ چىقىرىش';
$labels['previousmessage'] = 'ئالدىنقى خەتنى كۆرسىتىش';
$labels['firstmessage'] = 'بىرىنچى خەتنى كۆرسىتىش';
$labels['nextmessage'] = 'كىيىنكى خەتنى كۆرسىتىش';
$labels['lastmessage'] = 'ئاخىرقى خەتنى كۆرسىتىش';
$labels['backtolist'] = 'خەت تىزىملىكىگە قايتىش';
$labels['viewsource'] = 'مەنبەسىنى كۆرسىتىش';
$labels['mark'] = 'بەلگە قۇيۇش';
$labels['markmessages'] = 'خەتكە بەلگە قۇيۇش';
$labels['markread'] = 'ئۇقۇغان';
$labels['markunread'] = 'ئۇقۇمىغان';
$labels['markflagged'] = 'بايراقلانغان';
$labels['markunflagged'] = 'بايراقسىزلانغان';
$labels['markundeleted'] = 'ئۆچۈرۈلمىگەن';
$labels['moreactions'] = 'تېخىمۇ كۆپ ھەركەت';
$labels['markallread'] = 'ھەممىگە ئوقۇغان بەلگىسىنى قۇيۇش';
$labels['folders-cur'] = 'پەقەتلا تاللانغان قىسقۇچ';
$labels['folders-sub'] = 'تاللانغان قىسقۇچ ھەمدە ئۇنىڭ بالا-قىسقۇچلىرى';
$labels['folders-all'] = 'ھەممە قىسقۇچلار';
$labels['more'] = 'تېخىمۇ كۆپ';
$labels['back'] = 'قايتىش';
$labels['options'] = 'تاللانمىلار';
$labels['composeoptions'] = 'تاللانما قۇرۇش';
$labels['optionsandattachments'] = 'تاللانمىلار ھەمدە قىستۇرمىلار';
$labels['actions'] = 'ھەركەتلەر';
$labels['first'] = 'تۇنجى';
$labels['last'] = 'ئاخىرقى';
$labels['previous'] = 'ئالدىنقى';
$labels['next'] = 'كىيىنكى';
$labels['select'] = 'تاللاڭ';
$labels['selection'] = 'تاللاش';
$labels['all'] = 'ھەممە';
$labels['none'] = 'ھېچنىمە';
$labels['currpage'] = 'نۆۋەتتىكى بەت';
$labels['isread'] = 'ئۇقۇش';
$labels['unread'] = 'ئۇقۇماسلىق';
$labels['flagged'] = 'بايراقلانغان';
$labels['unflagged'] = 'بايراقلانمىغان';
$labels['unanswered'] = 'جاۋاپ قايتۇرمىغان';
$labels['withattachment'] = 'قىستۇرمىلىق';
$labels['deleted'] = 'ئۆچۈرۋەتكەن';
$labels['undeleted'] = 'ئۆچۈرۋەتمىگەن';
$labels['replied'] = 'جاۋاپ قايتۇرغان';
$labels['forwarded'] = 'يوللىغان';
$labels['invert'] = 'تەتۈرلەش';
$labels['filter'] = 'سۈزگۈچ';
$labels['list'] = 'تىزىملىك';
$labels['threads'] = 'يىپلار';
$labels['expand-all'] = 'ھەممىنى يېيىش';
$labels['expand-unread'] = 'ئوقۇلمىغاننى يېيىش';
$labels['collapse-all'] = 'ھەممىنى يېيىش';
$labels['threaded'] = 'يىپلانغان';
$labels['showunread'] = 'ئوقۇلمىغان خەتلەرنى كۆرسىتىش';
$labels['autoexpand_threads'] = 'خەت يىپلىرىنى كۆرسىتىش';
$labels['do_expand'] = 'ھەممە يىپلار';
$labels['expand_only_unread'] = 'پەقەتلا ئوقۇلمىغان خەتلەرنىڭ';
$labels['fromto'] = 'دىن/غا';
$labels['flag'] = 'بايراق';
$labels['attachment'] = 'قىستۇرما';
$labels['nonesort'] = 'ھېچنىمە';
$labels['sentdate'] = 'ئەۋەتىلگەن چېسلا';
$labels['arrival'] = 'كەلگەن چېسلا';
$labels['asc'] = 'چوڭايغان';
$labels['desc'] = 'كىچىكلىگەن';
$labels['listcolumns'] = 'قۇرلارنى تىزىش';
$labels['listsorting'] = 'قۇرلارنى رەتلەش';
$labels['listorder'] = 'رەتلەش تەرتىپى';
$labels['listmode'] = 'كۆرۈش ھالىتىنى تىزىش';
$labels['lmode'] = 'ھالەتنى تىزىش';
$labels['layout'] = 'قۇرۇلما';
$labels['layoutwidescreen'] = 'كەڭرى ئېكران';
$labels['layoutdesktop'] = 'ئۈستەل يۈزى';
$labels['layoutlist'] = 'تىزىملىك';
$labels['layoutwidescreendesc'] = 'كەڭ ئېكران(3-قۇرلۇق كۆرۈنۈش)';
$labels['layoutdesktopdesc'] = 'ئۈستەل يۈزى(كەڭرى تىزىملىك ھەمدە خەتنى تۆۋەندە ئالدىن كۆرسىتىش)';
$labels['layoutlistdesc'] = 'تىزىملىك (خەتنى ئالدىن كۆرسىتىش يوق)';
$labels['folderactions'] = 'قىسقۇچ ھەركەتلىرى...';
$labels['compact'] = 'ئىخچام';
$labels['empty'] = 'قۇرۇق';
$labels['importmessages'] = 'خەتلەرنى كىرگۈزۈش';
$labels['mailimportdesc'] = 'سىز خەتنى <a href="https://en.wikipedia.org/wiki/Email#Message_format"> MIME </a> ياكى <a href="https://en.wikipedia.org/wiki/Mbox"> Mbox </a> فورماتىدىكى ھۆججەتلەرنى ئىشلىتىپ چىقىرالايسىز.';
$labels['mailimportzip'] = 'كۆپلىگەن ھۆججەتلەرنى زىپ ئارخىپىغا سىققىلى بۇلىدۇ.';
$labels['quota'] = 'دىسكا ئىشلىتىشچانلىقى';
$labels['unknown'] = 'ناتۇنۇش';
$labels['unlimited'] = 'چەكسىز';
$labels['quotatype'] = 'بەلگىلەنگەن مىقدار تۈرى';
$labels['quotatotal'] = 'چەك';
$labels['quotaused'] = 'ئىشلەتكەن';
$labels['quotastorage'] = 'دىسكا بوشلۇقى';
$labels['quotamessage'] = 'خەت سانى';
$labels['shortheaderdate'] = '$چېسلادا';
$labels['shortheaderto'] = 'to$ غا date$دا';
$labels['shortheaderfrom'] = 'from$ دىن date$ دا';
$labels['quicksearch'] = 'تېز ئىزدەش';
$labels['searchplaceholder'] = 'ئىزدەش...';
$labels['resetsearch'] = 'ئىزدەشنى ئەسلىگە قايتۇرۇش';
$labels['searchmod'] = 'ئىزدەش ئۆزگەرتكۈچلىرى';
$labels['msgtext'] = 'پۈتۈن خەت';
$labels['body'] = 'مەزمۇن';
$labels['type'] = 'تۈرى';
$labels['namex'] = 'ئىسمى';
$labels['searchscope'] = 'دائىرە';
$labels['currentfolder'] = 'نۆۋەتتىكى قىسقۇچ';
$labels['subfolders'] = 'بۇ ھەمدە بالا-قىسقۇچلار';
$labels['allfolders'] = 'ھەممە قىسقۇچلار';
$labels['searchinterval-1W'] = 'بىر ھەپتىدىن بۇرۇنقى';
$labels['searchinterval-1M'] = 'بىر ئايدىن بۇرۇنقى';
$labels['searchinterval-1Y'] = 'بىر يىلدىن بۇرۇنقى';
$labels['searchinterval1W'] = 'بىر ھەپتىن بۇيانقى';
$labels['searchinterval1M'] = 'بىر ئايدىن بۇيانقى';
$labels['searchinterval1Y'] = 'بىر يىلدىن بۇيانقى';
$labels['openinextwin'] = 'يېڭى كۆزنەكتە ئېچىش';
$labels['emlsave'] = 'چۈشۈرۈش (.ئېلخەت)';
$labels['changeformattext'] = 'ئاددىي تېكىست ھالەتتە كۆرسىتىش';
$labels['changeformathtml'] = 'HTML ھالەتتە كۆرسىتىش';
$labels['editasnew'] = 'يېڭى ھالەتتە تەھرىرلەش';
$labels['send'] = 'ئەۋەتىش';
$labels['sendmessage'] = 'خەتنى ئەۋەتىش';
$labels['savemessage'] = 'قوليازما ھالەتتە ساقلاش';
$labels['addattachment'] = 'بىر ھۆججەت قىستۇرۇش';
$labels['charset'] = 'خەت بولىقى';
$labels['editortype'] = 'تەھرىرلەش تۈرى';
$labels['returnreceipt'] = 'تاپشۇرۋالغۇچىنى قايتۇرۇش';
$labels['dsn'] = 'يەتكۈزۈش ئەھۋالى ئۇقتۇرۇشى';
$labels['keepformatting'] = 'داۋاملىق فورماتلاش';
$labels['mailreplyintro'] = 'date$ دا، sender$ يازدى:';
$labels['originalmessage'] = 'ئەسلىي خەت';
$labels['selectimage'] = 'رەسىم تاللاش';
$labels['addimage'] = 'رەسىم قېتىش';
$labels['selectmedia'] = 'كىنو تاللاش';
$labels['addmedia'] = 'كىنو قېتىش';
$labels['encrypt'] = 'شىفىرلاش';
$labels['encryptmessage'] = 'خەتنى شىفىرلاش';
$labels['encryptmessagemailvelope'] = 'خەتنى Mailvelope بىلەن شىفىرلاش';
$labels['importpubkeys'] = 'ئاممىۋى ئاچقۇچلارنى كىرگۈزۈش';
$labels['encryptedsendialog'] = 'شىفىرلانغان ئۇچۇرنى يوللاۋاتىدۇ';
$labels['encryptandsign'] = 'شىفىرلاش ھەمدە ئىمزا قۇيۇش';
$labels['keyid'] = 'ئاچقۇچ نۇمۇرى';
$labels['keylength'] = 'بىتلار';
$labels['keyexpired'] = 'ۋاقتى ئۆتكەن';
$labels['keyrevoked'] = 'قايتۇرۋالغان';
$labels['bccinstead'] = 'ب چ چىنى ئىشلىتىش';
$labels['insert'] = 'كىرگۈزۈش';
$labels['insertcontact'] = 'تۇنۇش(لار) قېتىش';
$labels['recipient'] = 'تاپشۇرۋالغۇچى';
$labels['recipientedit'] = 'تاپشۇرۋالغۇچىنى تەھرىرلەش';
$labels['editidents'] = 'كىملىكلەرنى تەھرىرلەش';
$labels['spellcheck'] = 'ئىملا';
$labels['checkspelling'] = 'ئىملا تەكشۈرۈش';
$labels['resumeediting'] = 'تەھرىرلەشنى داۋاملاشتۇرۇش';
$labels['revertto'] = 'قايتۇرۇش';
$labels['restore'] = 'ئەسلىگە قايتۇرۇش';
$labels['restoremessage'] = 'ئۇچۇرنى ئەسلىگە قايتۇرامسىز؟';
$labels['ignore'] = 'كارىم يوق';
$labels['responses'] = 'ئىنكاسلار';
$labels['insertresponse'] = 'بىر ئىنكاس يېزىش';
$labels['manageresponses'] = 'ئىنكاسلارنى باشقۇرۇش';
$labels['newresponse'] = 'يېڭى ئىنكاس يېزىش';
$labels['addresponse'] = 'ئىنكاس قېتىش';
$labels['editresponse'] = 'ئىنكاسنى تەھرىرلەش';
$labels['editresponses'] = 'ئىنكاسلارنى تەھرىرلەش';
$labels['responsename'] = 'ئىسمى';
$labels['responsetext'] = 'ئىنكاس تېكىستى';
$labels['attach'] = 'قىستۇرۇش';
$labels['attachments'] = 'قىستۇرمىلار';
$labels['upload'] = 'چىقىرىش';
$labels['uploadprogress'] = 'percent$ (total$ نىڭ current$ )';
$labels['close'] = 'تاقاش';
$labels['messageoptions'] = 'خەت تاللانمىلىرى...';
$labels['togglecomposeoptions'] = 'يېزىش تاللانمىلىرىنى بار-يوق قىلىش';
$labels['attachmentrename'] = 'قىستۇرمىغا يېڭى ئىسىم قۇيۇش';
$labels['low'] = 'تۆۋەن';
$labels['lowest'] = 'ئەڭ تۆۋەن';
$labels['normal'] = 'نورمال';
$labels['high'] = 'يۇقىرى';
$labels['highest'] = 'ئەڭ يۇقىرى';
$labels['nosubject'] = '(تېما يوق)';
$labels['showimages'] = 'رەسىملەرنى كۆرسىتىش';
$labels['allow'] = 'يول قۇيۇش';
$labels['alwaysshow'] = 'sender$ نىڭ رەسىملىرىنى دائىم كۆرسىتىش';
$labels['alwaysallow'] = 'sender$ دىن كەلسە دائىم يول قۇيۇش';
$labels['isdraft'] = 'بۇ يولسا بىر قوليازما خەت';
$labels['andnmore'] = 'nr$ تېخىمۇ كۆپ...';
$labels['details'] = 'تەپسىلاتلار';
$labels['summary'] = 'خۇلاسە';
$labels['headers'] = 'باشلانمىلار';
$labels['allheaders'] = 'بارلىق باشلانمىلار...';
$labels['togglemoreheaders'] = 'تېخىمۇ كۆپ خەت باشلانمىلىرىنى كۆرسىتىش';
$labels['togglefullheaders'] = 'خام ئۇچۇر باشلانمىلىرىنى بار-يوق قىلىش';
$labels['htmltoggle'] = 'خ ت م ل';
$labels['plaintoggle'] = 'ئاددىي تېكىست';
$labels['savesentmessagein'] = 'يوللىغان ئۇچۇرنى ساقلاش';
$labels['dontsave'] = 'ساقلىماسلىق';
$labels['maxuploadsize'] = 'يول قۇيۇلغان ئەڭ چوڭ ھۆججەت چوڭلۇقى بولسا size$';
$labels['addcc'] = 'قۇشۇمچە قېتىش';
$labels['addbcc'] = 'ب چ چ قېتىش';
$labels['addreplyto'] = 'جاۋاپ قايتۇرۇشنى قېتىش';
$labels['addfollowupto'] = 'داۋاملاشتۇرۇش قېتىش';
$labels['sendreceipt'] = 'ئۇقۇش تىلخېتىنى ئەۋەتەمسىز؟';
$labels['mdnrequest'] = 'بۇ خەتنى ئەۋەتكۈچى سىز خەتنى ئۇقۇغاندا ئۇقتۇرۇلۇشنى سورىدى. سىز ئەۋەتكۈچىگە ئۇقتۇرۇشنى خالامسىز؟';
$labels['receiptread'] = 'تېلىخەتنى قايتۇرۇش(ئۇقۇغان)';
$labels['yourmessage'] = 'بۇ بولسا ئۇچۇرىڭىزنىڭ قايتۇرما تېلىخېتى';
$labels['receiptnote'] = 'ئۇقتۇرۇش: بۇ تالون پەقەتلا خەتنىڭ تاپشۇرۋالغۇچىنىڭ كومپىيوتېرىدا كۆرسىتىلگەنلىكىنى ئېتراپ قىلىدۇ. تاپشۇرۋالغۇچىنىڭ خەتنى ئۇقۇغانلىقىنى ياكى خەت مەزمۇنىنى چۈشەنگەنلىكىگە كاپالەتلىك قىلمايدۇ.';
$labels['sendalwaysto'] = 'دائىم email$ غا ئەۋەتىش';
$labels['zoomin'] = 'چوڭايتىش';
$labels['zoomout'] = 'كىچىكلەشتۈرۈش';
$labels['rotate'] = 'ئايلاندۇرۇش';
$labels['increaseimage'] = 'رەسىم چوڭلۇقىنى ئاشۇرۇش';
$labels['decreaseimage'] = 'رەسىم چوڭلۇقىنى كىچىكلىتىش';
$labels['rotateimage'] = 'رەسىمنى ئايلاندۇرۇش';
$labels['showtools'] = 'رەسىم قوراللىرىنى كۆرسىتىش';
$labels['hidetools'] = 'رەسىم قوراللىرىنى يۇشۇرۇش';
$labels['name'] = 'ئىسمىنى كۆرسىتىش';
$labels['firstname'] = 'ئىسمى';
$labels['surname'] = 'فامىلىسى';
$labels['middlename'] = 'ئوتتۇرانچى ئىسمى';
$labels['nameprefix'] = 'ئالدى قۇشۇمچە';
$labels['namesuffix'] = 'ئارقا قۇشۇمچە';
$labels['nickname'] = 'تەخەللۇس';
$labels['jobtitle'] = 'خىزمەت ئۇنىۋانى';
$labels['department'] = 'بۆلۈم';
$labels['gender'] = 'جىنسى';
$labels['maidenname'] = 'توي قىلىشتىن بۇرۇنقى فامىلىسى';
$labels['email'] = 'ئېلىخەت';
$labels['phone'] = 'تېلىفۇن';
$labels['address'] = 'ئادىرىس';
$labels['street'] = 'كوچا';
$labels['locality'] = 'شەھەر';
$labels['zipcode'] = 'پوچتا نۇمۇرى';
$labels['region'] = 'ۋىلايەت';
$labels['country'] = 'دۆلەت';
$labels['birthday'] = 'تۇغۇلغان كۈن';
$labels['anniversary'] = 'خاتىرە كۈن';
$labels['website'] = 'توربەت';
$labels['instantmessenger'] = 'ئى م';
$labels['notes'] = 'خاتىرە';
$labels['male'] = 'ئەر';
$labels['female'] = 'ئايال';
$labels['manager'] = 'دېرىكتور';
$labels['assistant'] = 'ياردەمچى';
$labels['spouse'] = 'جۈپتى';
$labels['allfields'] = 'بارلىق ئورۇنلار';
$labels['search'] = 'ئىزدەش';
$labels['searchresult'] = 'ئىزدەش نەتىنجىسى';
$labels['advsearch'] = 'ئالاھىدە ئىزدەش';
$labels['advanced'] = 'ئالاھىدە';
$labels['other'] = 'باشقا';
$labels['printcontact'] = 'تۇنۇشنى بېسىپ چىقىرىش';
$labels['qrcode'] = 'ئىككىلىك كود';
$labels['typehome'] = 'ئۆي';
$labels['typework'] = 'خىزمەت';
$labels['typeother'] = 'باشقا';
$labels['typemobile'] = 'كۆچمە';
$labels['typemain'] = 'ئاساسىي';
$labels['typehomefax'] = 'ئۆي فاكىس';
$labels['typeworkfax'] = 'خىزمەت فاكىسى';
$labels['typecar'] = 'ماشىنا';
$labels['typepager'] = 'بەتكۈچ';
$labels['typevideo'] = 'سىن';
$labels['typeassistant'] = 'ياردەمچى';
$labels['typehomepage'] = 'باشبەت';
$labels['typeblog'] = 'بىلوگ';
$labels['typeprofile'] = 'تەرجىمال';
$labels['addfield'] = 'ئورۇن قېتىش...';
$labels['addcontact'] = 'تونۇش قېتىش';
$labels['editcontact'] = 'تونۇشنى تەھرىرلەش';
$labels['contacts'] = 'تونۇشلار';
$labels['contactproperties'] = 'تونۇش خاسلىقلىرى';
$labels['contactnameandorg'] = 'ئىسم ۋە ئورگان';
$labels['personalinfo'] = 'شەخسىي ئۇچۇر';
$labels['personal'] = 'شەخسىي';
$labels['contactphoto'] = 'تونۇش رەسىمى';
$labels['edit'] = 'تەھرىرلەش';
$labels['cancel'] = 'ئەمەلدىن قالدۇرۇش';
$labels['save'] = 'ساقلاش';
$labels['delete'] = 'ئۆچۈرۈش';
$labels['discard'] = 'تاشلاش';
$labels['continue'] = 'داۋاملاشتۇرۇش';
$labels['ok'] = 'ھەئە';
$labels['rename'] = 'يېڭى ئىسىم قۇيۇش';
$labels['addphoto'] = 'قېتىش';
$labels['replacephoto'] = 'ئالماشتۇرۇش';
$labels['uploadphoto'] = 'رەسىم چىقىرىش';
$labels['choosefile'] = 'ھۆججەت تاللاش...';
$labels['choosefiles'] = 'ھۆججەتلەرنى تاللاش...';
$labels['browse'] = 'كۆز يۈرگۈزۈش';
$labels['newcontact'] = 'يېڭى تۇنۇش قۇرۇش';
$labels['deletecontact'] = 'تاللانغان تۇنۇشلارنى ئۆچۈرۈش';
$labels['composeto'] = 'غا خەت قۇرۇش';
$labels['contactsfromto'] = 'from$دىن to$غا جەمئىي count$ تۇنۇش';
$labels['print'] = 'بېسىش';
$labels['export'] = 'چىقىرىش';
$labels['exportall'] = 'ھەممىنى چىقىرىش';
$labels['exportsel'] = 'تاللانغاننى چىقىرىش';
$labels['exportvcards'] = 'تۇنۇشلارنى ۋكارتىسى فورماتىدا چىقىرىش';
$labels['newgroup'] = 'يېڭى توپ قۇرۇش';
$labels['addgroup'] = 'توپ قېتىش';
$labels['grouprename'] = 'توپ ئىسمىنى يېڭىلاش';
$labels['groupdelete'] = 'توپنى ئۆچۈرۈش';
$labels['groupassign'] = 'توپقا بەلگىلەش';
$labels['groupremove'] = 'توپتىن چىقىرىش';
$labels['groupremoveselected'] = 'تاللانغان تۇنۇشلارنى توپتىن چىقىرىش';
$labels['uponelevel'] = 'بىر دەرىجە ئۆستۈرۈش';
$labels['previouspage'] = 'ئالدىنقى بەتنى كۆرسىتىش';
$labels['firstpage'] = 'تۇنجى بەتنى كۆرسىتىش';
$labels['nextpage'] = 'كىيىنكى بەتنى كۆرسىتىش';
$labels['lastpage'] = 'ئاخىرقى بەتنى كۆرسىتىش';
$labels['group'] = 'توپ';
$labels['groups'] = 'توپلار';
$labels['listgroup'] = 'توپ ئەزالىرىنى تىزىش';
$labels['personaladrbook'] = 'شەخسىي ئادىرىسلار';
$labels['searchsave'] = 'ئىزدەشنى ساقلاش';
$labels['searchdelete'] = 'ئىزدەشنى ئۆچۈرۈش';
$labels['import'] = 'كىرگۈزۈش';
$labels['importcontacts'] = 'تۇنۇشلارنى كىرگۈزۈش';
$labels['importfromfile'] = 'ھۆججەتتىن كىرگۈزۈش';
$labels['importtarget'] = 'تۇنۇشلارنى قېتىش';
$labels['importreplace'] = 'پۈتۈن ئادرىس دەپتىرىنى ئالماشتۇرۇش';
$labels['importgroups'] = 'توپ تاپشۇرۇقلىرىنى كىرگۈزۈش';
$labels['importgroupsall'] = 'بارلىق (زۆرۆر تېپىلسا توپ قۇرۇش)';
$labels['importgroupsexisting'] = 'پەقەتلا مەۋجۇت توپلار ئۈچۈن';
$labels['importdesc'] = 'سىز مەۋجۇت ئادىرىس دەپتىرىدىن تۇنۇشلارنى چىقىرالايسىز. <br/>بىز نۆۋەتتە ئادىرىسلارنى <a href="https://en.wikipedia.org/wiki/VCard"> ۋىكارتىسى </a> ياكى س ئەس ۋ (پەش بىلەن ئايرىلغان) ئۇچۇر فورماتىدا كىرگۈزۈشنى قوللايمىز.';
$labels['importmapdesc'] = 'س ئەس ۋ (پەش بىلەن ئايرىلغان) ئۇچۇرىنى كىرگۈزۈشتىن بۇرۇن تۆۋەندىكى ئورۇن خەرىتىلەش ئۇچۇرىنىڭ توغىرلىقىنى جەزىملەشتۈرۈڭ.';
$labels['fieldnotmapped'] = 'ئورۇن خەرىتىلەنمىدى (كىرگۈزمەڭ)';
$labels['skipheader'] = 'بىرىنچى قۇرنى كىرگۈزمەڭ (باشلانمىلار)';
$labels['done'] = 'پۈتتى';
$labels['settingsfor'] = 'تەڭشىكى';
$labels['about'] = 'ھەققىدە';
$labels['preferences'] = 'مايىللىقلار';
$labels['userpreferences'] = 'ئىشلەتكۈچى مايىللىقلىرى';
$labels['editpreferences'] = 'ئىشلەتكۈچى مايىللىقلىرىنى تەھرىرلەش';
$labels['identities'] = 'كىملىكلەر';
$labels['manageidentities'] = 'كىملىكلەرنى باشقۇرۇش';
$labels['newidentity'] = 'يېڭى كىملىك قۇرۇش';
$labels['addidentity'] = 'كىملىك قۇشۇش';
$labels['editidentity'] = 'كىملىكنى تەھرىرلەش';
$labels['identityencryption'] = 'شىفىرلاش';
$labels['preferhtml'] = 'خ ت م ل نى كۆرسىتىش';
$labels['defaultcharset'] = 'ئەسلىدىكى يېزىق بولىقى';
$labels['htmlmessage'] = 'خ ت م ل ئۇچۇرى';
$labels['messagepart'] = 'بۆلەك';
$labels['digitalsig'] = 'رەقەملىك ئىمزا';
$labels['dateformat'] = 'چېسلا شەكلى';
$labels['timeformat'] = 'ۋاقىت شەكلى';
$labels['prettydate'] = 'ئۇماق چېسلالار';
$labels['setdefault'] = 'سۈكۈتنى بېكىتىش';
$labels['autodetect'] = 'ئاپتۇماتىك';
$labels['language'] = 'تىل';
$labels['timezone'] = 'ۋاقىت رايۇنى';
$labels['pagesize'] = 'بەت قۇرى';
$labels['signature'] = 'ئىمزا';
$labels['dstactive'] = 'يازلىق ۋاقىت قىسقىرىشى';
$labels['showinextwin'] = 'خەتنى يېڭى كۆزنەكتە ئېچىش';
$labels['composeextwin'] = 'يېڭى كۆزنەكتە يېزىش';
$labels['htmleditor'] = 'خ ت م ل ئۇچۇر يېزىش';
$labels['htmlonreply'] = 'خ ت م ل ئۇچۇرىغا جاۋاپ قايتۇرغاندا';
$labels['htmlonreplyandforward'] = 'خ ت م ل ئۇچۇرىغا جاۋاپ قايتۇرغاندا ياكى يەتكۈزگەندە';
$labels['htmlsignature'] = 'خ ت م ل ئىمزا';
$labels['showemail'] = 'ئېلىخەت ئادىرسىنى ئىسمى بىلەن كۆرسىتىش';
$labels['previewpane'] = 'ئالدىن كۆرۈش تاختىسىنى كۆرسىتىش';
$labels['skin'] = 'ئۇلىنىش ئېغىزى تېرىسى';
$labels['logoutclear'] = 'چېكىنگەندە ئەخلەت چېلىكىنى قۇرۇقداش';
$labels['logoutcompact'] = 'چېكىنگەندە كىلىش ساندۇقىنى ئىخچاملاش';
$labels['uisettings'] = 'ئىشلەتكۈچى ئۇلىنىش ئېغىزى';
$labels['serversettings'] = 'مۇلازىمېتىر تەڭشىكى';
$labels['mailboxview'] = 'خەت ساندۇقى كۆرۈنۈشى';
$labels['mdnrequests'] = 'تېلىخەت قايتۇرۇش تەلىپىگە بىنائەن';
$labels['askuser'] = 'مەندىن سوراڭ';
$labels['autosend'] = 'تېلخەت ئەۋەتىش';
$labels['autosendknown'] = 'تېلخەتنى مېنىڭ تۇنۇشلىرىمغا ئەۋەتىڭ، بولمىسا مەندىن سوراڭ';
$labels['autosendknownignore'] = 'تېلخەتنى مېنىڭ تۇنۇشلىرىمغا ئەۋەتىڭ، بولمىسا كارىڭىز بولمىسۇن';
$labels['autosendtrusted'] = 'تېلىخەتنى ئىشەنچلىك ئەۋەتكۈچىلەرگە ئەۋەتىڭ، بولمىسا مەندىن سوراڭ';
$labels['autosendtrustedignore'] = 'تېلخەتنى ئىشەنچلىك ئەۋەتكۈچىلەرگە ئەۋەتىڭ، بولمىسا كارىڭىز بولمىسۇن';
$labels['ignorerequest'] = 'تەلەپكە كارىڭىز بولمىسۇن';
$labels['readwhendeleted'] = 'خەتنى ئۆچۈرگەندە ئۇقۇغانلىق بەلگىسىنى قۇيۇش';
$labels['flagfordeletion'] = 'خەتنى ئۆچۈرۋەتكەندىن كۆرە ئۆچۈرۈلۈش بەلگىسىنى قۇيۇش';
$labels['skipdeleted'] = 'ئۆچۈرۋەتكەن ئۇچۇرلارنى كۆرسەتمەڭ';
$labels['deletealways'] = 'ئۇچۇرلارنى ئەخلەت چېلىكىگە يۆتكەش مەغلۇپ بولسا، ئۇلارنى ئۆچۈرۈڭ';
$labels['deletejunk'] = 'ئەخلەت چېلىكىدىكى ئۇچۇرلارنى بىۋاستە ئۆچۈرۋېتىڭ';
$labels['showremoteimages'] = 'يىراقتىكى ئەسكەرتىش رەسىملىرىنى كۆرسىتىش';
$labels['allowremoteresources'] = 'يىراقتىكى مەنبەلەرگە ئىجازەت بېرىش(رەسىم، ئۇسلۇب)';
$labels['fromknownsenders'] = 'تۇنۇش ئەۋەتكۈچىلەردىن';
$labels['fromtrustedsenders'] = 'ئىشەنچلىك ئەۋەتكۈچىلەردىن';
$labels['frommycontacts'] = 'تۇنۇشلىرىمدىن';
$labels['always'] = 'دائىم';
$labels['alwaysbutplain'] = 'دائىم، ئاددىي تېكىستقا جاۋاپ بەرگەندىن باشقا';
$labels['showinlineimages'] = 'خەتكە قىستۇرۇلغان رەسىملەرنى ئاستىدا كۆرسىتىڭ';
$labels['autosavedraft'] = 'قوليازمىنى ئاپتۇماتىك ساقلاڭ';
$labels['everynminutes'] = 'ھەر n$ مىنۇت(لار)دا';
$labels['refreshinterval'] = 'يېڭىلاش (يېڭى ئۇچۇرنى تەكشۈرۈش، قاتارلىق)';
$labels['never'] = 'ھەرگىز';
$labels['immediately'] = 'دەرھال';
$labels['messagesdisplaying'] = 'خەتلەرنى كۆرسىتىش';
$labels['messagescomposition'] = 'خەتلەرنى يېزىش';
$labels['mimeparamfolding'] = 'قىستۇرۇلغان ئىسىملار';
$labels['2231folding'] = 'پۈتۈن ر ف س 2231 (چاقماققۇش)';
$labels['miscfolding'] = 'ر ف س 2047/2231 (مىكروسوفىت Outlook)';
$labels['2047folding'] = 'پۈتۈن ر ف س 2047 (باشقا)';
$labels['force7bit'] = '8-بىتلىق خەتلەرگە MIME شىفىرىنى ئىشلىتىڭ';
$labels['savelocalstorage'] = "تور كۆرگۈچنىڭ يەرلىك بوشلۇقىغا ساقلاش (ۋاقىتلىق)";
$labels['advancedoptions'] = 'ئالاھىدە تاللانمىلار';
$labels['toggleadvancedoptions'] = 'ئالاھىدە تاللانمىلارنى بار-يوق قىلىش';
$labels['focusonnewmessage'] = 'تور كۆرگۈچنىڭ كۆزنىكىنى يېڭى خەتكە مەركەزلەشتۈرۈڭ';
$labels['checkallfolders'] = 'يېڭى ئۇچۇرنى ھەممە قىسقۇچلاردىن تەكشۈرۈش';
$labels['displaynext'] = 'ئۆچۈرۈش/چىقىرۋېتىشتىن كىيىن تىزىملىكنىڭ كىيىنكى قۇرىنى كۆرسىتىش';
$labels['defaultfont'] = 'خ ت م ل ئۇچۇرىنىڭ ئەسلىي خەت شەكلى';
$labels['mainoptions'] = 'ئاساسىي تاللانمىلار';
$labels['browseroptions'] = 'تور كۆرگۈچ تاللانمىلىرى';
$labels['section'] = 'بۆلەك';
$labels['maintenance'] = 'ئاسىراش';
$labels['newmessage'] = 'يېڭى خەت';
$labels['signatureoptions'] = 'ئىمزا تاللانمىلىرى';
$labels['whenreplying'] = 'جاۋاپ قايتۇرغاندا';
$labels['replyempty'] = 'ئەسلىدىكى خەتنى نەقىل كەلتۈرمەڭ';
$labels['replytopposting'] = 'نەقىلنىڭ ئۈستىدە يېڭى خەت يېزىش';
$labels['replytoppostingnoindent'] = 'نەقىلنىڭ ئۈستىدە يېڭى خەت يېزىش (بوش ئورۇن يوق)';
$labels['replybottomposting'] = 'نەقىلنىڭ ئاستىدا يېڭى خەت يېزىش';
$labels['replyremovesignature'] = 'جاۋاپ قايتۇرغاندا ئەسلىي ئىمزانى خەتتىن ئۆچۈرۋېتىش';
$labels['autoaddsignature'] = 'ئاپتۇماتىك ئىمزا قۇيۇش';
$labels['newmessageonly'] = 'يېڭى خەتكىلا';
$labels['replyandforwardonly'] = 'جاۋاپ قايتۇرۇش ۋە يەتكۈزۈشكىلا';
$labels['insertsignature'] = 'ئىمزا قۇيۇش';
$labels['sigbelow'] = 'ئىمزانى نەقىللىگەن ئۇچۇرنىڭ ئاستىغا قۇيۇش';
$labels['sigseparator'] = 'ئىمزالاردا ئۆلچەملىك ئايرىغۇچنى مەجبۇرى قۇيۇش';
$labels['automarkread'] = 'خەتكە ئۇقۇغان بەلگىسىنى قۇيۇش';
$labels['afternseconds'] = 'n$ سىكونتتىن كىيىن';
$labels['reqmdn'] = 'قايتۇرۇش تېلىخېتىنى دائىم تەلەپ قىلىش';
$labels['reqdsn'] = 'ئەۋەتىش ئەھۋالى ئۇقتۇرۇشىنى دائىم تەلەپ قىلىش';
$labels['replysamefolder'] = 'جاۋاپ خەتنى جاۋاپ قايتۇرۇلغان ئۇچۇر قىسقۇچىغا قۇيۇش';
$labels['defaultabook'] = 'سۈكۈتتىكى ئادىرىس دەپتىرى';
$labels['autocompletesingle'] = 'ئاپتۇماتىك پۈتكۈزۈشتە ئىككىنچى ئېلىخەت ئادىرىسلىرىنى تاشلاش';
$labels['listnamedisplay'] = 'تۇنۇشلارنى سۈپىتىدە تىزىش';
$labels['contactformmode'] = 'تۇنۇش جەدىۋېلى ھالىتى';
$labels['privatemode'] = 'شەخسىي (ئۆي)';
$labels['businessmode'] = 'سودا (خىزمەت)';
$labels['collectedaddresses'] = 'يىغىلغان ئادىرىسلار';
$labels['collectedrecipients'] = 'يىغىلغان تاپشۇرۋالغۇچىلار';
$labels['collectedrecipientsopt'] = 'ئەۋەتىلدىغان ئېلىخەتنىڭ تاپشۇرۋالغۇچىلىرىنى ساقلايدىغان ئورۇن';
$labels['collectedsendersopt'] = 'ئىشەنچلىك ئەۋەتكۈچىلەرنى ساقلاش';
$labels['trustedsenders'] = 'ئىشەنچلىك ئەۋەتكۈچىلەر';
$labels['spellcheckbeforesend'] = 'خەتنى ئەۋەتىشتىن بۇرۇن ئىملا تەكشۈرۈش';
$labels['spellcheckoptions'] = 'ئىملا تەكشۈرۈش تاللانمىلىرى';
$labels['spellcheckignoresyms'] = 'بەلگىلىك سۆزلەرنى ئۆتكۈزۋېتىش';
$labels['spellcheckignorenums'] = 'رەقەملىك سۆزلەرنى ئۆتكۈزۋېتىش';
$labels['spellcheckignorecaps'] = 'ھەممە ھەرىپ چوڭ يېزىلغان سۆزلەرنى ئۆتكۈزۋېتىش';
$labels['addtodict'] = 'لۇغەتكە قېتىش';
$labels['mailtoprotohandler'] = 'خەت ئەۋەتىش ئۈچۈن كىلىشىمنامە بىر-تەرەپ قىلغۇچنى تىزىملىتىش: ئۇلىنىشلار';
$labels['standardwindows'] = 'سەكرەلمىلەرنى ئۆلچەملىك كۆزنەك سۈپىتىدە بىر-تەرەپ قىلىش';
$labels['forwardmode'] = 'خەت يەتكۈزۈش';
$labels['inline'] = 'ئەسكەرتىش';
$labels['asattachment'] = 'قىستۇرما ھالەتتە';
$labels['replyallmode'] = '[ھەممىگە جاۋاپ] كۇنۇپكىسىنىڭ سۈكۈتتىكى ھەركىتى';
$labels['replyalldefault'] = 'ھەممىگە جاۋاپ قايتۇرۇش';
$labels['replyalllist'] = 'خەت ئەۋەتىش تىزىملىكىگىلا جاۋاپ قايتۇرۇش (تېپىلسا)';
$labels['allmessages'] = 'بارلىق خەتلەر';
$labels['olderxdays'] = 'x$ كۈندىن چوڭ';
$labels['folder'] = 'قىسقۇچ';
$labels['folders'] = 'قىسقۇچلار';
$labels['foldername'] = 'قىسقۇچ نامى';
$labels['subscribed'] = 'مۇشتەرى بولغان';
$labels['messagecount'] = 'خەتلەر';
$labels['create'] = 'قۇرۇش';
$labels['createfolder'] = 'يېڭى قىسقۇچ قۇرۇش';
$labels['managefolders'] = 'قىسقۇچلارنى باشقۇرۇش';
$labels['specialfolders'] = 'ئالاھىدە قىسقۇچلار';
$labels['properties'] = 'خاسلىقلار';
$labels['folderproperties'] = 'قىسقۇچ خاسلىقلىرى';
$labels['parentfolder'] = 'ئانا قىسقۇچ';
$labels['location'] = 'ئورۇن';
$labels['info'] = 'ئۇچۇر';
$labels['getfoldersize'] = 'بېسىپ قىسقۇچ چوڭلۇقىنى كۆرۈش';
$labels['changesubscription'] = 'بېسىپ مۇشتەرىلىكنى ئۆزگەرتىش';
$labels['foldertype'] = 'قىسقۇچ تۈرى';
$labels['personalfolder'] = 'شەخسىي قىسقۇچ';
$labels['otherfolder'] = 'باشقا ئىشلەتكۈچىنىڭ قىسقۇچى';
$labels['sharedfolder'] = 'ئاممىۋى قىسقۇچ';
$labels['findfolders'] = 'قىسقۇچلارنى تېپىش';
$labels['findcontacts'] = 'تۇنۇشلارنى تېپىش';
$labels['findmail'] = 'ئېلىخەت ئۇچۇرلىرىنى تېپىش';
$labels['namespace.personal'] = 'شەخسىي';
$labels['namespace.other'] = 'باشقا ئىشلەتكۈچىلەر';
$labels['namespace.shared'] = 'ھەمبەھىرلىگەن';
$labels['dualuselabel'] = 'پەقەتلا ئۆز-ئىچىگە ئالىدۇ';
$labels['dualusemail'] = 'ئۇچۇرلار';
$labels['dualusefolder'] = 'قىسقۇچلار';
$labels['generate'] = 'ھاسىل قىلىش';
$labels['encryptioncreatekey'] = 'يېڭى ئاچقۇچ جۈپى ھاسىل قىلىش';
$labels['openmailvelopesettings'] = 'خەت لىپاپىسى تەڭشەكلىرىنى ئېچىش';
$labels['encryptionprivkeysinmailvelope'] = 'سىزدە خەت لىپاپىسى ئاچقۇچ زەنجىرىدە ساقلانغان nr$ ماس كىلىدىغان شەخسىي ئاچقۇچلار بار:';
$labels['encryptionnoprivkeysinmailvelope'] = 'بۇ ئەۋەتكۈچىنىڭ سىزنىڭ خەت لىپاپىڭىزدا ساقلانغان PGP شەخسىي ئاچقۇچى يوق. شىفىرلانغان خەتنى قوزغىتىش ئۈچۈن بىرنى قۇرۇشنى خالامسىز؟';
$labels['encryption'] = 'شىفىرلاش';
$labels['mailvelopeoptions'] = 'خەت لىپاپىسى تاللانمىلىرى';
$labels['mailvelopemainkeyring'] = 'خەت لىپاپىسى ئاساسىي ئاچقۇچ زەنجىرىنى ئىشلىتىش';
$labels['mailvelopenotfound'] = 'خەت ئالاقىسى كېڭەيتمىسى تور كۆرگۈچىڭىزدە يوق/قاچىلانمىدى.';
$labels['sortby'] = 'رەتكە تىزىش';
$labels['sortasc'] = 'چوڭايغان بۇيىچە رەتكە تىزىش';
$labels['sortdesc'] = 'كىچىكلىگەن بۇيىچە رەتكە تىزىش';
$labels['undo'] = 'يېنىۋېلىش';
$labels['installedplugins'] = 'قاچىلانغان قوراللار';
$labels['plugin'] = 'قورال';
$labels['version'] = 'نەشىرى';
$labels['source'] = 'مەنبە';
$labels['destination'] = 'مەنزىل';
$labels['license'] = 'كىنىشكا';
$labels['support'] = 'ياردەمگە ئېرىشىڭ';
$labels['savedsearches'] = 'ساقلانغان ئىزدەشلەر';
$labels['dateformatY'] = 'ي ي ي ي';
$labels['dateformaty'] = 'ي ي';
$labels['dateformatm'] = 'ئا ئا';
$labels['dateformatd'] = 'ك ك';
$labels['dateformatj'] = 'ك';
$labels['dateformatn'] = 'ئا';
$labels['B'] = 'بايت';
$labels['KB'] = 'كىلوبايت';
$labels['MB'] = 'مېگابايىت';
$labels['GB'] = 'گىگابايىت';
$labels['unicode'] = 'ئۇنىكود';
$labels['english'] = 'ئىنگىلىزچە';
$labels['westerneuropean'] = 'غەربىي ياۋرۇپاچە';
$labels['easterneuropean'] = 'شەرقىي ياۋروپاچە';
$labels['southeasterneuropean'] = 'شەرقىي-جەنۇبىي ياۋرۇپاچە';
$labels['baltic'] = 'بالتىق';
$labels['cyrillic'] = 'قىرىلچە';
$labels['arabic'] = 'ئەرەپچە';
$labels['greek'] = 'گىرىكچە';
$labels['hebrew'] = 'ئىبرانىي';
$labels['turkish'] = 'تۈركچە';
$labels['nordic'] = 'شىمالىي ياۋرۇپاچە';
$labels['thai'] = 'تايلاندچە';
$labels['celtic'] = 'كېلتىك';
$labels['vietnamese'] = 'ۋېتنامچە';
$labels['japanese'] = 'ياپۇنچە';
$labels['korean'] = 'كورىيەچە';
$labels['chinese'] = 'خىتايچە';
$labels['arialabeltopnav'] = 'كۆزنەك باشقۇرۇش';
$labels['arialabeltasknav'] = 'ئەپ ۋەزىپىلىرى';
$labels['arialabeltoolbar'] = 'ئەپ قورال بالدىقى';
$labels['arialabellistnav'] = 'تىزىملىكنى كۆرسىتىش';
$labels['arialabelactivetask'] = 'جانلىق ۋەزىپە';
$labels['arialabelmessagessearchfilter'] = 'ئېلىخەت تىزىش سۈزگۈچى';
$labels['arialabelmailsearchform'] = 'ئېلىخەت ئۇچۇر ئىزدەش جەدىۋېلى';
$labels['arialabelcontactsearchform'] = 'تۇنۇشلارنى ئىزدەش جەدىۋېلى';
$labels['arialabelmailquicksearchbox'] = 'ئېلىخەت ئىزدەش كىرگۈزۈش';
$labels['arialabelquicksearchbox'] = 'ئىزدەش كىرگۈزگۈچ';
$labels['arialabelfoldersearchfilter'] = 'قىسقۇچ تىزىش سۈزگۈچى';
$labels['arialabelfoldersearchform'] = 'قىسقۇچ ئىزدەش جەدىۋېلى';
$labels['arialabelfolderlist'] = 'ئېلىخەت قىسقۇچىنى تاللاش';
$labels['arialabelmessagelist'] = 'ئېلىخەت خەتلىرىنى تىزىش';
$labels['arialabelmailpreviewframe'] = 'خەت ئالدىن كۆرگۈزگۈچ';
$labels['arialabelmailboxmenu'] = 'قىسقۇچ ھەركەت تىزىملىكى';
$labels['arialabellistselectmenu'] = 'تاللاش تىزىملىكىنى كۆرسىتىش';
$labels['arialabelthreadselectmenu'] = 'يىپلارنى كۆرسىتىش تىزىملىكى';
$labels['arialabelmessagelistoptions'] = 'خەت تىزىملىكىنى كۆرسىتىش ھەمدە تۈرگە ئايرىش تاللانمىلىرى';
$labels['arialabelmailimportdialog'] = 'خەت كىرگۈزۈش دېئالوگى';
$labels['arialabelmessagenav'] = 'خەت يولباشلاش';
$labels['arialabelmessagebody'] = 'خەت مەزمۇنى';
$labels['arialabelmessageactions'] = 'خەت ھەركىتى';
$labels['arialabelcontactquicksearch'] = 'تۇنۇشلارنى ئىزدەش جەدىۋېلى';
$labels['arialabelcontactsearchbox'] = 'تۇنۇش ئىزدەش كىرگۈزگۈچ';
$labels['arialabelmessageheaders'] = 'خەت باشلانمىلىرى';
$labels['arialabelforwardingoptions'] = 'يەتكۈزۈش تاللانمىلىرى';
$labels['arialabelreplyalloptions'] = 'ھەممىگە جاۋاپ قايتۇرۇش تاللانمىلىرى';
$labels['arialabelmoremessageactions'] = 'تېخىمۇ كۆپ خەت ھەركەتلىرى';
$labels['arialabelmorecontactactions'] = 'تېخىمۇ كۆپ تۇنۇش ھەركەتلىرى';
$labels['arialabelmarkmessagesas'] = 'تاللانغان خەتكە بەلگىسىنى قۇيۇش...';
$labels['arialabelcomposeoptions'] = 'يېزىش تاللانمىلىرى';
$labels['arialabelresponsesmenu'] = 'قاتلانغان ئىنكاس تىزىملىكى';
$labels['arialabelattachmentuploadform'] = 'قىستۇرما چىقىرىش جەدىۋېلى';
$labels['arialabelattachmentmenu'] = 'قىستۇرما تاللانمىلىرى';
$labels['arialabelmailtomenu'] = 'ئېلىخەت ئادىرىس تاللانمىلىرى';
$labels['arialabelattachmentpreview'] = 'قىستۇرما ئالدىن كۆرگۈزگۈچ';
$labels['ariasummarycomposecontacts'] = 'تاپشۇرۋالغۇچىلارنى تاللايدىغان توپلارنى ۋە تۇنۇشلارنى تىزىش';
$labels['arialabelcontactexportoptions'] = 'تۇنۇشلارنى چىقىرىش تاللانمىلىرى';
$labels['arialabelabookgroupoptions'] = 'ئادرىس دەپتىرى/توپ تاللانمىلىرى';
$labels['arialabelpreferencesform'] = 'مايىللىق جەدىۋېلى';
$labels['arialabelidentityeditfrom'] = 'كىملىك تەھرىرلەش جەدىۋېلى';
$labels['arialabelresponseeditfrom'] = 'ئىنكاس تەھرىرلەش جەدىۋېلى';
$labels['arialabelsearchterms'] = 'ئىزدەش ئاتالغۇلىرى';
$labels['arialabeldropactionmenu'] = 'سۆرەش ۋە تاشلاش ھەركەت تىزىملىكى';
$labels['arialabelheadersmenu'] = 'تاپشۇرۋالغۇچى (باشلانما) قۇشۇش تىزىملىكى';
$labels['arialabelimagetools'] = 'رەسىم قوراللىرى';
$labels['helplistnavigation'] = 'كۇنۇپكا تاختىسى يولباشلىغۇچىنى تىزىش';
$labels['helplistkeyboardnavigation'] = "يۇقىرى/تۆۋەن ئىستىرىلكا: قۇر يۆتكەشكە مەركەزلەشتۈرۈش/تاللاش
بوشلۇق: مەركەزلەشكەن قۇرنى تاللاش.
يۆتكەش+يۇقىرى/تۆۋەن: يۇقىرى/تۆۋەن قۇشۇمچە قۇرنى تاللاش.
كونتىرول+بوشلۇق: مەركەزلەشكەن قۇرنى تاللاش ياكى تاللىماسلىق.";
$labels['helplistkeyboardnavmessages'] = "ئىستىرىلكا ئوڭ/سول: خەت يىپىنى كېڭەيتىش/ئىخچاملاش (يىپ ھالىتىدە بولسا).
كىرىش: تاللانغان/مەركەزلەشكەن خەتنى ئېچىش.
ئۆچۈرۈش: تاللانغان خەتلەرنى ئەخلەت چېلىكىگە تاشلاش.";
$labels['helplistkeyboardnavcontacts'] = "كىرىش: تاللانغان/مەركەزلەنگەن تۇنۇشنى ئېچىش";
