<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Vcard Attachments plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['addvcardmsg'] = '添加 vCard 至地址簿中';
$labels['vcardsavefailed'] = '无法保存 vCard';
$labels['attachvcard'] = '附加 vCard';
$labels['vcardattached'] = '已附加 vCard 文件';
$labels['vcard'] = 'vCard';
$labels['forwardvcard'] = '转发 ';
$labels['contactsattached'] = '此消息附有 $num 个联系人。';
$labels['importedsuccessfully'] = '联系人已成功导入至地址簿。';
