<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'Un error ha occurrite.';
$messages['loginfailed']  = 'Apertura de session fallite.';
$messages['cookiesdisabled'] = 'Tu navigator non accepta cookies.';
$messages['sessionerror'] = 'Le session es invalide o ha expirate.';
$messages['cookiesmismatch'] = 'Cookie incorrecte detegite. Per favor rade le cookies de tu navigator.';
$messages['storageerror'] = 'Le connexion al servitor de immagazinage ha fallite.';
$messages['servererror'] = 'Error de servitor.';
$messages['servererrormsg'] = 'Error de sevitor: $msg';
$messages['accountlocked'] = 'Troppo de tentativas fallite de authentication. Reproba plus tarde.';
$messages['connerror'] = 'Error de connexion (impossibile attinger le servitor).';
$messages['dberror'] = 'Error de base de datos.';
$messages['dbconnerror'] = 'Non pote connecter al base de datos!';
$messages['windowopenerror'] = 'Le fenestra pop-up ha essite blocate.';
$messages['requesttimedout'] = 'Requesta expirate';
$messages['errorreadonly'] = 'Impossibile exequer le operation. Le dossier es in modo lectura sol.';
$messages['errornoperm'] = 'Impossibile exequer le operation. Permission refusate.';
$messages['erroroverquota'] = 'Impossibile exequer le operation. Nulle spatio libere sur disco.';
$messages['erroroverquotadelete'] = 'Nulle spatio libere sur disco. Preme SHIFT+DEL pro deler un message.';
$messages['invalidrequest'] = 'Requesta non valide. Le datos non ha essite salveguardate.';
$messages['invalidhost'] = 'Nomine de servitor non valide.';
$messages['nomessagesfound'] = 'Nulle message trovate in iste cassa postal.';
$messages['loggedout'] = 'Tu ha correctemente terminate le session. A revider!';
$messages['mailboxempty'] = 'Le cassa postal es vacue';
$messages['nomessages'] = 'Nulle message';
$messages['refreshing'] = 'Refrescante…';
$messages['loading'] = 'Cargante…';
$messages['uploading'] = 'Incargante un file…';
$messages['attaching'] = 'Annexa file…';
$messages['uploadingmany'] = 'Incargante files…';
$messages['loadingdata'] = 'Cargante datos…';
$messages['checkingmail'] = 'Verificante si il ha nove messages…';
$messages['sendingmessage'] = 'Inviante le message…';
$messages['messagesent'] = 'Message inviate con successo.';
$messages['savingmessage'] = 'Salveguardante le message…';
$messages['messagesaved'] = 'Message salveguardate in "Versiones provisori".';
$messages['successfullysaved'] = 'Salveguardate con successo.';
$messages['savingresponse'] = 'Salveguardante le texto del responsa…';
$messages['deleteresponseconfirm'] = 'Es tu secur de voler deler iste texto de responsa?';
$messages['nocontactselected'] = 'Tu non ha ancora seligite un contacto.';
$messages['addedsuccessfully'] = 'Le contacto ha essite addite al adressario.';
$messages['contactexists'] = 'Un contacto con le mesme adresse de e-mail jam existe.';
$messages['contactnameexists'] = 'Un contacto con le mesme nomine jam existe.';
$messages['blockedimages'] = 'Pro proteger tu vita private, le imagines a distantia es blocate in iste message.';
$messages['blockedresources'] = 'Pro proteger tu vita private, le ressources distante ha essite blocate.';
$messages['suspiciousemail'] = 'Iste message contine adresses de e-posta suspecte de esser fraudulente.';
$messages['bccemail'] = 'Le sequente message(s) contine destinatarios confidential (Bcc).';
$messages['bouncehint'] = 'Le message essera inviate sin modificationes, i.e., usante le texto, capites e destinatarios del original.';
$messages['encryptedmessage'] = 'Iste message ha essite cryptate e non pote esser monstrate.';
$messages['externalmessagedecryption'] = 'Isto es un message cryptate e pote esser decryptate con tu extension de navigator.';
$messages['nopubkeyfor'] = 'Nulle clave public valide trovate pro $email';
$messages['nopubkeyforsender'] = 'Nulle clave public valide ha essite trovate pro tu identitate de expeditor. Vole tu cryptar le message pro le destinatarios solmente?';
$messages['encryptnoattachments'] = 'Le annexos ja incargate non pote esser cryptate. Per favor re-adde los in le editor cryptographic.';
$messages['searchpubkeyservers'] = 'Vole tu cercar le claves mancante in le servitores de claves public?';
$messages['encryptpubkeysfound'] = 'Le sequente claves public ha essite trovate:';
$messages['keyservererror'] = 'Fallimento de obtener clave ab servitor de claves.';
$messages['keyimportsuccess'] = 'Le clave public $key ha essite correctemente importate in tu portaclaves.';
$messages['nocontactsfound'] = 'Nulle contacto trovate.';
$messages['contactnotfound'] = 'Le contacto requestate non ha essite trovate.';
$messages['contactsearchonly'] = 'Es necessari usar un formulario de recerca pro vider le contactos del adressario seligite.';
$messages['sendingfailed'] = 'Le invio del message ha fallite.';
$messages['senttooquickly'] = 'Per favor, attende $sec secunda(s) ante inviar iste message.';
$messages['errorsavingsent'] = 'Un error ha occurrite durante le salveguarda del message inviate.';
$messages['errorsaving'] = 'Un error ha occurrite durante le salveguarda.';
$messages['errormoving'] = 'Impossibile displaciar le message(s).';
$messages['errorcopying'] = 'Impossibile copiar le message(s).';
$messages['errordeleting'] = 'Impossibile deler le message(s).';
$messages['errormarking'] = 'Impossibile marcar le message(s).';
$messages['alerttitle'] = 'Attention';
$messages['confirmationtitle'] = 'Es tu secur…';
$messages['deletecontactconfirm']  = 'Es tu secur de voler deler le contacto(s) seligite?';
$messages['deletegroupconfirm']  = 'Es tu secur de voler deler le gruppo seligite?';
$messages['deletemessagesconfirm'] = 'Es tu secur de voler deler le message(s) seligite?';
$messages['deletefolderconfirm']  = 'Es tu secur de voler deler le dossier seligite?';
$messages['movefolderconfirm']  = 'Es tu secur de voler displaciar iste dossier?';
$messages['purgefolderconfirm']  = 'Es tu secur de voler deler tote le messages in iste dossier?';
$messages['contactdeleting'] = 'Delente contacto(s)…';
$messages['groupdeleting'] = 'Delente le gruppo…';
$messages['folderdeleting'] = 'Delente le dossier…';
$messages['foldermoving'] = 'Displaciante le dossier…';
$messages['foldersubscribing'] = 'Subscribente se al dossier…';
$messages['folderunsubscribing'] = 'Cancellante le subscription al dossier…';
$messages['formincomplete'] = 'Le formulario non ha essite totalmente completate.';
$messages['noemailwarning'] = 'Per favor, specifica un adresse de e-mail valide.';
$messages['nonamewarning']  = 'Per favor, specifica un nomine.';
$messages['nopagesizewarning'] = 'Per favor, specifica un dimension de pagina.';
$messages['nosenderwarning'] = 'Per favor, specifica le adresse de e-mail del expeditor.';
$messages['recipientsadded'] = 'Destinatario(s) correctemente addite.';
$messages['norecipientwarning'] = 'Per favor, specifica al minus un destinatario.';
$messages['disclosedrecipwarning'] = 'Tote le destinatarios videra le adresses de e-mail le unes del alteres. Pro evitar isto e proteger lor confidentialitate, usa le campo Bcc.';
$messages['disclosedreciptitle'] = 'Il ha troppo de destinatarios public';
$messages['nosubjectwarning']  = 'Le campo "Subjecto" es vacue. Vole tu specificar un subjecto ora?';
$messages['nosubjecttitle']  = 'Sin subjecto';
$messages['nobodywarning'] = 'Inviar iste message sin texto?';
$messages['notsentwarning'] = 'Le message non ha essite inviate e ha modificationes non salveguardate. Abandonar le modificationes?';
$messages['restoresavedcomposedata'] = 'Un message anteriormente componite ma non inviate ha essite trovate.\n\nSubjecto: $subject\nSalveguardate: $date\n\nVole tu restaurar iste message?';
$messages['nosearchname'] = 'Per favor, specifica le nomine o adresse de e-mail de un contacto.';
$messages['notuploadedwarning'] = 'Non tote le annexos ha ancora essite incargate. Per favor, attende o cancella le incargamento.';
$messages['searchsuccessful'] = '$nr messages trovate.';
$messages['contactsearchsuccessful'] = '$nr contactos trovate.';
$messages['searchnomatch'] = 'Le recerca non ha producite resultatos.';
$messages['searching'] = 'Cercante…';
$messages['checking'] = 'Verificante…';
$messages['stillsearching'] = 'Continuante le recerca…';
$messages['nospellerrors'] = 'Nulle error de orthographia trovate.';
$messages['folderdeleted'] = 'Le dossier ha essite delite.';
$messages['foldersubscribed'] = 'Le subscription al dossier ha succedite.';
$messages['folderunsubscribed'] = 'Le subscription al dossier ha essite cancellate.';
$messages['folderpurged'] = 'Le dossier ha essite vacuate.';
$messages['folderexpunged'] = 'Le dossier ha essite compactate.';
$messages['deletedsuccessfully'] = 'Delite con successo.';
$messages['converting'] = 'Removente le formatation…';
$messages['messageopenerror'] = 'Impossibile cargar le message ab le servitor.';
$messages['filelinkerror'] = 'Le annexation del file ha fallite.';
$messages['fileuploaderror'] = 'Incargamento de file falleva.';
$messages['csvfilemismatch'] = 'Le importation de plure files CSV con differente campos non es supportate.';
$messages['filesizeerror'] = 'Le file incargate excede le dimension maxime de $size.';
$messages['filecounterror'] = 'Tu pote incargar al maximo $count files insimul.';
$messages['msgsizeerror'] = 'Le annexation de un file ha fallite. Le dimension maxime de un message ($size) ha essite excedite.';
$messages['msgsizeerrorfwd'] = 'Le dimension maxime de un message ($size) ha essite excedite. $num message(s) non ha essite annexate.';
$messages['copysuccess'] = '$nr contactos ha essite copiate.';
$messages['movesuccess'] = '$nr contactos ha essite displaciate.';
$messages['copyerror'] = 'Impossibile copiar le contactos.';
$messages['moveerror'] = 'Impossibile displaciar le contactos.';
$messages['sourceisreadonly'] = 'Iste fonte de adresses es pro lectura solmente.';
$messages['errorsavingcontact'] = 'Impossibile salveguardar le adresse del contacto.';
$messages['movingmessage'] = 'Displaciante le message(s)…';
$messages['copyingmessage'] = 'Copiante le message(s)…';
$messages['copyingcontact'] = 'Copiante le contacto(s)…';
$messages['movingcontact'] = 'Displaciante le contacto(s)…';
$messages['deletingmessage'] = 'Delente le message(s)…';
$messages['markingmessage'] = 'Marcante le message(s)…';
$messages['addingmember'] = 'Addente contacto(s) al gruppo…';
$messages['removingmember'] = 'Removente contacto(s) del gruppo…';
$messages['receiptsent'] = 'Un confirmation de lectura ha essite inviate.';
$messages['errorsendingreceipt'] = 'Impossibile inviar le confirmation.';
$messages['deleteidentityconfirm'] = 'Es tu secur de voler deler iste identitate?';
$messages['nodeletelastidentity'] = 'Non es possibile deler iste identitate; illo es tu ultime.';
$messages['forbiddencharacter'] = 'Le nomine del dossier contine un character interdicte.';
$messages['selectimportfile'] = 'Per favor tu selige le file a incargar.';
$messages['addresswriterror'] = 'Le adressario seligite non permitte le scriptura.';
$messages['contactaddedtogroup'] = 'Le contactos ha essite addite a iste gruppo.';
$messages['contactremovedfromgroup'] = 'Le contactos ha essite removite de iste gruppo.';
$messages['nogroupassignmentschanged'] = 'Nulle assignation de gruppo ha essite cambiate.';
$messages['importwait'] = 'Importation in curso, un momento…';
$messages['importformaterror'] = 'Importation fallite. Le file incargate non es un file de datos de importation valide.';
$messages['importconfirm'] = '<b>$inserted contactos ha essite importate</b>';
$messages['importmessagesuccess'] = '$nr messages ha essite importate';
$messages['importmessageerror'] = 'Importation fallite. Le file incargate non es un file de cassa postal o message valide.';
$messages['opnotpermitted'] = 'Operation non permittite.';
$messages['nofromaddress'] = 'Le adresse de e-mail manca in le identitate seligite.';
$messages['editorwarning'] = 'Si tu cambia de typo de editor, le formato del texto pote esser perdite. Vole tu continuar?';
$messages['httpreceivedencrypterror'] = 'Un error fatal de configuration ha occurrite. Contacta immediatemente tu administrator.<b>Non es possibile inviar tu message.</b>';
$messages['smtpconnerror'] = 'Error SMTP ($code): Le connexion al servitor ha fallite.';
$messages['smtpautherror'] = 'Error SMTP ($code): Authentication fallite.';
$messages['smtpfromerror'] = 'Error SMTP ($code): Impossibile fixar le expeditor "$from" ($msg).';
$messages['smtptoerror'] = 'Error SMTP ($code): Impossibile adder le destinatario "$to" ($msg).';
$messages['smtprecipientserror'] = 'Error SMTP: Impossibile interpretar le lista de destinatarios.';
$messages['smtputf8error'] = 'Error de SMTP: Le servitor non supporta Unicode in le adresse de e-mail.';
$messages['smtpsizeerror'] = 'Error de SMTP: Le grandor del message excede le limite del servitor ($limit)';
$messages['smtperror'] = 'Error SMTP: $msg';
$messages['emailformaterror'] = 'Adresse de e-mail invalide: $email';
$messages['toomanyrecipients'] = 'Troppo de destinatarios. Reduce le numero de destinatarios a $max.';
$messages['maxgroupmembersreached'] = 'Le numero de membros del gruppo excede le maximo de $max.';
$messages['internalerror'] = 'Un error interne ha occurrite. Per favor, essaya lo de novo.';
$messages['contactdelerror'] = 'Impossibile deler le contacto(s).';
$messages['contactdeleted'] = 'Le contacto(s) ha essite delite.';
$messages['contactrestoreerror'] = 'Impossibile restaurar le contacto(s) delite.';
$messages['contactrestored'] = 'Le contacto(s) ha essite restaurate.';
$messages['groupdeleted'] = 'Le gruppo ha essite delite.';
$messages['grouprenamed'] = 'Le gruppo ha essite renominate.';
$messages['groupcreated'] = 'Le gruppo ha essite create.';
$messages['savedsearchdeleted'] = 'Le recerca salveguardate ha essite delite.';
$messages['savedsearchdeleteerror'] = 'Impossibile deler le recerca salveguardate.';
$messages['savedsearchcreated'] = 'Le recerca salveguardate ha essite create.';
$messages['savedsearchcreateerror'] = 'Impossibile crear le recerca salveguardate.';
$messages['messagedeleted'] = 'Le message(s) ha essite delite.';
$messages['messagemoved'] = 'Le message(s) ha essite displaciate.';
$messages['messagemovedtotrash'] = 'Le message(s) ha essite displaciate al corbe a papiro con successo.';
$messages['messagecopied'] = 'Le message(s) ha essite copiate.';
$messages['messagemarked'] = 'Le message(s) ha essite marcate.';
$messages['autocompletechars'] = 'Specifica al minus $min characteres pro autocompletion.';
$messages['autocompletemore'] = 'Plure entratas corresponde. Per favor, specifica plus characteres.';
$messages['namecannotbeempty'] = 'Le nomine non pote esser vacue.';
$messages['nametoolong'] = 'Le nomine es troppo longe.';
$messages['namedotforbidden'] = 'Le nomine del dossier non pote comenciar per un puncto.';
$messages['folderupdated'] = 'Le dossier ha essite actualisate.';
$messages['foldercreated'] = 'Le dossier ha essite create.';
$messages['invalidimageformat'] = 'Non es un formato de imagine valide.';
$messages['mispellingsfound'] = 'Errores de orthographia ha essite detegite in le message.';
$messages['parentnotwritable'] = 'Impossibile crear/displaciar le dossier in le dossier genitor seligite. Nulle permission de accesso.';
$messages['messagetoobig'] = 'Le parte del message es troppo grande pro tractar lo.';
$messages['attachmentvalidationerror'] = 'Iste annexo es suspecte perque su typo non corresponde al typo declarate in le message. Si tu non ha confidentia in le expeditor, tu non deberea aperir lo in le navigator perque illo pote haber contento nocive.<br/><br/><em>Expectate: $expected; trovate: $detected</em>';
$messages['noscriptwarning'] = 'Attention: Iste servicio webmail require JavaScript. Pro usar lo, per favor activa JavaScript in le configuration de tu navigator.';
$messages['messageissent'] = 'Le message ha jam essite inviate ma non ancora salveguardate. Vole tu salveguardar lo ora?';
$messages['errnotfound'] = 'File non trovate';
$messages['errnotfoundexplain'] = 'Le ressource requestate non ha essite trovate.';
$messages['errfailedrequest'] = 'Requesta fallite';
$messages['errauthorizationfailed'] = 'Autorisation fallite';
$messages['errunauthorizedexplain'] = 'Non poteva verificar que tu es autorisate a acceder a iste servicio.';
$messages['errrequestcheckfailed'] = 'Verification del requesta fallite';
$messages['errcsrfprotectionexplain'] = "Pro tu protection, le accesso a iste ressource ha essite securisate contra le falsification de requestas inter sitos (CSRF).\nSi tu vide isto, tu probabilemente non ha claudite session ante de quitar le application web.\n\nOra, un interaction human es necessari pro continuar.";
$messages['errcontactserveradmin'] = 'Per favor contacta le administrator de tu servitor.';
$messages['clicktoresumesession'] = 'Clicca hic pro continuar tu session anterior';
$messages['errcomposesession'] = 'Error del session de composition';
$messages['errcomposesessionexplain'] = 'Session de composition requestate non ha essite trovate.';
$messages['clicktocompose'] = 'Clicca hic pro componer un nove message';
$messages['nosupporterror'] = 'Iste function non es supportate per tu navigator web.';
$messages['siginserted'] = 'Signatura inserite con successo.';
$messages['responseinserted'] = 'Responsa inserite con successo.';
$messages['noresponsesavailable'] = 'Necun responsa disponibile';
$messages['listempty'] = 'Le lista es vacue.';
$messages['listusebutton'] = 'Usa le button Crear pro adder un nove entrata.';
$messages['keypaircreatesuccess'] = 'Un nove par de claves ha essite create pro $identity.';
$messages['emptyattachment'] = 'Iste annexo pare esser vacue.<br>Per favor, verifica lo presso le expeditor.';
$messages['oauthloginfailed'] = 'Le apertura de session con OAuth ha fallite. Per favor tenta lo de novo.';
