<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['tz:utc'] = 'UTC';
$labels['tz:africa'] = '非洲';
$labels['tz:africa:abidjan'] = '阿必尚';
$labels['tz:africa:accra'] = '阿克拉';
$labels['tz:africa:addis_ababa'] = '阿迪斯阿貝巴';
$labels['tz:africa:algiers'] = '阿爾及爾';
$labels['tz:africa:asmara'] = '阿斯馬拉';
$labels['tz:africa:bamako'] = '巴馬科';
$labels['tz:africa:bangui'] = '班基';
$labels['tz:africa:banjul'] = '班竹';
$labels['tz:africa:bissau'] = '比索';
$labels['tz:africa:blantyre'] = '布蘭岱';
$labels['tz:africa:brazzaville'] = '布拉薩市';
$labels['tz:africa:bujumbura'] = '布松布拉';
$labels['tz:africa:cairo'] = '開羅';
$labels['tz:africa:casablanca'] = '卡薩布蘭卡';
$labels['tz:africa:ceuta'] = '休達';
$labels['tz:africa:conakry'] = '科奈克里';
$labels['tz:africa:dakar'] = '達卡';
$labels['tz:africa:dar_es_salaam'] = '三蘭港';
$labels['tz:africa:djibouti'] = '吉布地';
$labels['tz:africa:douala'] = '杜阿拉';
$labels['tz:africa:el_aaiun'] = '阿尤恩';
$labels['tz:africa:freetown'] = '自由城';
$labels['tz:africa:gaborone'] = '嘉柏隆里';
$labels['tz:africa:harare'] = '哈拉雷';
$labels['tz:africa:johannesburg'] = '約翰尼斯堡';
$labels['tz:africa:juba'] = '朱巴';
$labels['tz:africa:kampala'] = '坎帕拉';
$labels['tz:africa:khartoum'] = '喀土木';
$labels['tz:africa:kigali'] = '吉佳利';
$labels['tz:africa:kinshasa'] = '金夏沙';
$labels['tz:africa:lagos'] = '拉哥斯';
$labels['tz:africa:libreville'] = '自由市';
$labels['tz:africa:lome'] = '洛美';
$labels['tz:africa:luanda'] = '羅安達';
$labels['tz:africa:lubumbashi'] = '盧本巴希';
$labels['tz:africa:lusaka'] = '路沙卡';
$labels['tz:africa:malabo'] = '馬拉博';
$labels['tz:africa:maputo'] = '馬布多';
$labels['tz:africa:maseru'] = '馬塞盧';
$labels['tz:africa:mbabane'] = '墨巴本';
$labels['tz:africa:mogadishu'] = '摩加迪休';
$labels['tz:africa:monrovia'] = '蒙羅維亞';
$labels['tz:africa:nairobi'] = '奈洛比';
$labels['tz:africa:ndjamena'] = '恩將納';
$labels['tz:africa:niamey'] = '尼阿美';
$labels['tz:africa:nouakchott'] = '諾克少';
$labels['tz:africa:ouagadougou'] = '瓦加杜古';
$labels['tz:africa:porto-novo'] = '新港';
$labels['tz:africa:sao_tome'] = '聖多美';
$labels['tz:africa:tripoli'] = '的黎波里';
$labels['tz:africa:tunis'] = '突尼斯';
$labels['tz:africa:windhoek'] = '溫荷克';
$labels['tz:america'] = '美洲';
$labels['tz:america:adak'] = '埃達克';
$labels['tz:america:anchorage'] = '安克拉治';
$labels['tz:america:anguilla'] = '安圭拉';
$labels['tz:america:antigua'] = '安地卡島';
$labels['tz:america:araguaina'] = '阿拉瓜伊納';
$labels['tz:america:argentina'] = '阿根廷';
$labels['tz:america:argentina:buenos_aires'] = '布宜諾斯艾利斯';
$labels['tz:america:argentina:catamarca'] = '卡塔馬卡';
$labels['tz:america:argentina:cordoba'] = '哥多華';
$labels['tz:america:argentina:jujuy'] = '胡胡伊';
$labels['tz:america:argentina:la_rioja'] = '拉里奧哈';
$labels['tz:america:argentina:mendoza'] = '門多薩';
$labels['tz:america:argentina:rio_gallegos'] = '里奧加耶戈斯';
$labels['tz:america:argentina:salta'] = '薩爾塔';
$labels['tz:america:argentina:san_juan'] = '聖胡安';
$labels['tz:america:argentina:san_luis'] = '聖路易';
$labels['tz:america:argentina:tucuman'] = '德圖庫曼';
$labels['tz:america:argentina:ushuaia'] = '烏蘇懷亞';
$labels['tz:america:aruba'] = '阿魯巴';
$labels['tz:america:asuncion'] = '亞松森';
$labels['tz:america:atikokan'] = '阿蒂科肯';
$labels['tz:america:bahia'] = '巴伊亞州';
$labels['tz:america:bahia_banderas'] = '班德拉斯灣';
$labels['tz:america:barbados'] = '巴貝多';
$labels['tz:america:belem'] = '貝倫區';
$labels['tz:america:belize'] = '貝里斯';
$labels['tz:america:blanc-sablon'] = '布朗薩布隆';
$labels['tz:america:boa_vista'] = '博阿維斯塔';
$labels['tz:america:bogota'] = '波哥大';
$labels['tz:america:boise'] = '波夕';
$labels['tz:america:cambridge_bay'] = '劍橋灣';
$labels['tz:america:campo_grande'] = '格蘭德營';
$labels['tz:america:cancun'] = '坎昆';
$labels['tz:america:caracas'] = '卡拉卡斯';
$labels['tz:america:cayenne'] = '開雲';
$labels['tz:america:cayman'] = '開曼群島';
$labels['tz:america:chicago'] = '芝加哥';
$labels['tz:america:chihuahua'] = '契瓦瓦';
$labels['tz:america:costa_rica'] = '哥斯大黎加';
$labels['tz:america:creston'] = '克雷斯頓';
$labels['tz:america:cuiaba'] = '庫亞巴';
$labels['tz:america:curacao'] = '古拉索';
$labels['tz:america:danmarkshavn'] = '丹麥港';
$labels['tz:america:dawson'] = '道森市';
$labels['tz:america:dawson_creek'] = '道森河市';
$labels['tz:america:denver'] = '丹佛市';
$labels['tz:america:detroit'] = '底特律';
$labels['tz:america:dominica'] = '多米尼加';
$labels['tz:america:edmonton'] = '艾德蒙頓';
$labels['tz:america:eirunepe'] = '埃魯內佩';
$labels['tz:america:el_salvador'] = '薩爾瓦多';
$labels['tz:america:fort_nelson'] = '納爾遜堡';
$labels['tz:america:fortaleza'] = '福塔萊薩';
$labels['tz:america:glace_bay'] = '格萊斯貝';
$labels['tz:america:godthab'] = '努克';
$labels['tz:america:goose_bay'] = '古斯貝';
$labels['tz:america:grand_turk'] = '大特克島';
$labels['tz:america:grenada'] = '格瑞那達';
$labels['tz:america:guadeloupe'] = '瓜德羅普';
$labels['tz:america:guatemala'] = '瓜地馬拉';
$labels['tz:america:guayaquil'] = '瓜亞基爾';
$labels['tz:america:guyana'] = '蓋亞那';
$labels['tz:america:halifax'] = '哈里法克斯';
$labels['tz:america:havana'] = '夏灣拿';
$labels['tz:america:hermosillo'] = '埃莫西約';
$labels['tz:america:indiana'] = '印第安納州';
$labels['tz:america:indiana:indianapolis'] = '印第安納波利斯';
$labels['tz:america:indiana:knox'] = '諾克斯';
$labels['tz:america:indiana:marengo'] = '馬倫哥';
$labels['tz:america:indiana:petersburg'] = '彼得斯堡';
$labels['tz:america:indiana:tell_city'] = '特爾城';
$labels['tz:america:indiana:vevay'] = '韋韋';
$labels['tz:america:indiana:vincennes'] = '文森';
$labels['tz:america:indiana:winamac'] = '威納馬克';
$labels['tz:america:inuvik'] = '因紐維克';
$labels['tz:america:iqaluit'] = '伊魁特';
$labels['tz:america:jamaica'] = '牙買加';
$labels['tz:america:juneau'] = '朱諾';
$labels['tz:america:kentucky'] = '肯塔基州';
$labels['tz:america:kentucky:louisville'] = '路易斯維爾';
$labels['tz:america:kentucky:monticello'] = '蒙蒂塞洛';
$labels['tz:america:kralendijk'] = '克拉倫代克';
$labels['tz:america:la_paz'] = '拉巴斯';
$labels['tz:america:lima'] = '利馬';
$labels['tz:america:los_angeles'] = '洛杉磯';
$labels['tz:america:lower_princes'] = '下太子';
$labels['tz:america:maceio'] = '馬塞約';
$labels['tz:america:managua'] = '馬拿瓜';
$labels['tz:america:manaus'] = '瑪瑙斯';
$labels['tz:america:marigot'] = '馬里戈';
$labels['tz:america:martinique'] = '馬丁尼克';
$labels['tz:america:matamoros'] = '馬塔莫羅斯';
$labels['tz:america:mazatlan'] = '馬薩特蘭';
$labels['tz:america:menominee'] = '梅諾米尼';
$labels['tz:america:merida'] = '美利達';
$labels['tz:america:metlakatla'] = '梅特拉卡特拉';
$labels['tz:america:mexico_city'] = '墨西哥城';
$labels['tz:america:miquelon'] = '密克隆';
$labels['tz:america:moncton'] = '蒙克頓';
$labels['tz:america:monterrey'] = '蒙特雷';
$labels['tz:america:montevideo'] = '蒙特維多';
$labels['tz:america:montserrat'] = '蒙哲臘';
$labels['tz:america:nassau'] = '拿索';
$labels['tz:america:new_york'] = '紐約';
$labels['tz:america:nipigon'] = '尼皮貢';
$labels['tz:america:nome'] = '諾米';
$labels['tz:america:noronha'] = '羅尼亞';
$labels['tz:america:north_dakota'] = '北達科他';
$labels['tz:america:north_dakota:beulah'] = '比尤拉';
$labels['tz:america:north_dakota:center'] = '森特';
$labels['tz:america:north_dakota:new_salem'] = '新薩勒姆';
$labels['tz:america:ojinaga'] = '奧希納加';
$labels['tz:america:panama'] = '巴拿馬';
$labels['tz:america:pangnirtung'] = '龐納唐';
$labels['tz:america:paramaribo'] = '巴拉馬利波';
$labels['tz:america:phoenix'] = '鳳凰城';
$labels['tz:america:port-au-prince'] = '太子港';
$labels['tz:america:port_of_spain'] = '西班牙港';
$labels['tz:america:porto_velho'] = '韋柳港';
$labels['tz:america:puerto_rico'] = '波多黎各';
$labels['tz:america:rainy_river'] = '雷尼河';
$labels['tz:america:rankin_inlet'] = '蘭金因萊特';
$labels['tz:america:recife'] = '李斯腓';
$labels['tz:america:regina'] = '利載拿';
$labels['tz:america:resolute'] = '瑞瑟魯特';
$labels['tz:america:rio_branco'] = '里約布蘭科';
$labels['tz:america:santarem'] = '聖塔倫';
$labels['tz:america:santiago'] = '聖地亞哥';
$labels['tz:america:santo_domingo'] = '聖多明哥';
$labels['tz:america:sao_paulo'] = '聖保羅';
$labels['tz:america:scoresbysund'] = '斯科斯比松';
$labels['tz:america:sitka'] = '矽地卡';
$labels['tz:america:st_barthelemy'] = '聖巴泰勒米';
$labels['tz:america:st_johns'] = "聖約翰斯";
$labels['tz:america:st_kitts'] = '聖基茨島';
$labels['tz:america:st_lucia'] = '聖盧西亞';
$labels['tz:america:st_thomas'] = '聖湯瑪士';
$labels['tz:america:st_vincent'] = '聖文森';
$labels['tz:america:swift_current'] = '斯威夫特卡倫特';
$labels['tz:america:tegucigalpa'] = '特古西加爾巴';
$labels['tz:america:thule'] = '圖勒';
$labels['tz:america:thunder_bay'] = '雷霆灣';
$labels['tz:america:tijuana'] = '提華納';
$labels['tz:america:toronto'] = '多倫多';
$labels['tz:america:tortola'] = '托爾托拉島';
$labels['tz:america:vancouver'] = '溫哥華';
$labels['tz:america:whitehorse'] = '白馬市';
$labels['tz:america:winnipeg'] = '溫尼辟';
$labels['tz:america:yakutat'] = '溫尼辟';
$labels['tz:america:yellowknife'] = '黃刀鎮';
$labels['tz:antarctica'] = '南極洲';
$labels['tz:antarctica:casey'] = '凱西站';
$labels['tz:antarctica:davis'] = '戴維斯站';
$labels['tz:antarctica:dumontdurville'] = "迪蒙·迪維爾站";
$labels['tz:antarctica:macquarie'] = '麥格理站';
$labels['tz:antarctica:mawson'] = '莫森站';
$labels['tz:antarctica:mcmurdo'] = '麥克默多站';
$labels['tz:antarctica:palmer'] = '帕爾默';
$labels['tz:antarctica:rothera'] = '羅瑟拉站';
$labels['tz:antarctica:syowa'] = '昭和基地';
$labels['tz:antarctica:troll'] = '特洛站';
$labels['tz:antarctica:vostok'] = '沃斯托克站';
$labels['tz:arctic'] = '北極';
$labels['tz:arctic:longyearbyen'] = '隆雅市';
$labels['tz:asia'] = '亞洲';
$labels['tz:asia:aden'] = '亞丁';
$labels['tz:asia:almaty'] = '阿拉木圖';
$labels['tz:asia:amman'] = '安曼';
$labels['tz:asia:anadyr'] = '阿那底';
$labels['tz:asia:aqtau'] = '阿克套';
$labels['tz:asia:aqtobe'] = '阿克托比';
$labels['tz:asia:ashgabat'] = '阿什哈巴德';
$labels['tz:asia:atyrau'] = '阿特勞';
$labels['tz:asia:baghdad'] = '巴格達';
$labels['tz:asia:bahrain'] = '巴林';
$labels['tz:asia:baku'] = '巴庫';
$labels['tz:asia:bangkok'] = '曼谷';
$labels['tz:asia:barnaul'] = '巴爾瑙爾';
$labels['tz:asia:beirut'] = '貝魯特';
$labels['tz:asia:bishkek'] = '比什凱克';
$labels['tz:asia:brunei'] = '汶萊';
$labels['tz:asia:chita'] = '赤塔';
$labels['tz:asia:choibalsan'] = '喬巴山';
$labels['tz:asia:colombo'] = '科倫坡';
$labels['tz:asia:damascus'] = '大馬士革';
$labels['tz:asia:dhaka'] = '達卡';
$labels['tz:asia:dili'] = '帝力';
$labels['tz:asia:dubai'] = '杜拜';
$labels['tz:asia:dushanbe'] = '杜尚別';
$labels['tz:asia:famagusta'] = '法馬古斯塔';
$labels['tz:asia:gaza'] = '加薩';
$labels['tz:asia:hebron'] = '希伯崙';
$labels['tz:asia:ho_chi_minh'] = '胡志明市';
$labels['tz:asia:hong_kong'] = '香港';
$labels['tz:asia:hovd'] = '科布多';
$labels['tz:asia:irkutsk'] = '伊爾庫次克';
$labels['tz:asia:jakarta'] = '耶加達';
$labels['tz:asia:jayapura'] = '查亞普拉';
$labels['tz:asia:jerusalem'] = '耶路撒冷';
$labels['tz:asia:kabul'] = '喀布爾';
$labels['tz:asia:kamchatka'] = '堪察加';
$labels['tz:asia:karachi'] = '卡拉奇';
$labels['tz:asia:kathmandu'] = '加德滿都';
$labels['tz:asia:khandyga'] = '肯德瓦';
$labels['tz:asia:kolkata'] = '加爾各答';
$labels['tz:asia:krasnoyarsk'] = '克拉斯諾雅斯克';
$labels['tz:asia:kuala_lumpur'] = '吉隆坡';
$labels['tz:asia:kuching'] = '古晉';
$labels['tz:asia:kuwait'] = '科威特';
$labels['tz:asia:macau'] = '澳門';
$labels['tz:asia:magadan'] = '馬加丹';
$labels['tz:asia:makassar'] = '望加錫';
$labels['tz:asia:manila'] = '馬尼拉';
$labels['tz:asia:muscat'] = '馬斯喀特';
$labels['tz:asia:nicosia'] = '尼科西亞';
$labels['tz:asia:novokuznetsk'] = '新庫斯內次';
$labels['tz:asia:novosibirsk'] = '新西伯利亞';
$labels['tz:asia:omsk'] = '鄂木斯克';
$labels['tz:asia:oral'] = '烏拉爾';
$labels['tz:asia:phnom_penh'] = '金邊';
$labels['tz:asia:pontianak'] = '坤甸';
$labels['tz:asia:pyongyang'] = '平壤';
$labels['tz:asia:qatar'] = '卡塔爾';
$labels['tz:asia:qyzylorda'] = '克孜勒奧爾達';
$labels['tz:asia:riyadh'] = '利雅得';
$labels['tz:asia:sakhalin'] = '庫頁島';
$labels['tz:asia:samarkand'] = '撒馬爾罕';
$labels['tz:asia:seoul'] = '首爾';
$labels['tz:asia:shanghai'] = '上海';
$labels['tz:asia:singapore'] = '新加坡';
$labels['tz:asia:srednekolymsk'] = '中科雷姆斯克';
$labels['tz:asia:taipei'] = '台北';
$labels['tz:asia:tashkent'] = '塔什干';
$labels['tz:asia:tbilisi'] = '第比利斯';
$labels['tz:asia:tehran'] = '德黑蘭';
$labels['tz:asia:thimphu'] = '廷布';
$labels['tz:asia:tokyo'] = '東京';
$labels['tz:asia:tomsk'] = '托木斯克';
$labels['tz:asia:ulaanbaatar'] = '烏蘭巴托';
$labels['tz:asia:urumqi'] = '烏魯木齊';
$labels['tz:asia:ust-nera'] = '烏斯季涅拉';
$labels['tz:asia:vientiane'] = '永珍';
$labels['tz:asia:vladivostok'] = '海參崴';
$labels['tz:asia:yakutsk'] = '雅庫茨克';
$labels['tz:asia:yangon'] = '仰光';
$labels['tz:asia:yekaterinburg'] = '葉卡捷琳堡';
$labels['tz:asia:yerevan'] = '葉里溫';
$labels['tz:atlantic'] = '大西洋';
$labels['tz:atlantic:azores'] = '亞速群島';
$labels['tz:atlantic:bermuda'] = '百慕達';
$labels['tz:atlantic:canary'] = '加那利群島';
$labels['tz:atlantic:cape_verde'] = '維德角';
$labels['tz:atlantic:faroe'] = '法羅群島';
$labels['tz:atlantic:madeira'] = '馬德拉';
$labels['tz:atlantic:reykjavik'] = '雷克雅未克';
$labels['tz:atlantic:south_georgia'] = '南喬治亞島';
$labels['tz:atlantic:st_helena'] = '聖赫倫那島';
$labels['tz:atlantic:stanley'] = '史坦利';
$labels['tz:australia'] = '澳洲';
$labels['tz:australia:adelaide'] = '亞德萊德';
$labels['tz:australia:brisbane'] = '布里斯本';
$labels['tz:australia:broken_hill'] = '布羅肯希爾';
$labels['tz:australia:currie'] = '克黎';
$labels['tz:australia:darwin'] = '達爾文';
$labels['tz:australia:eucla'] = '尤克拉';
$labels['tz:australia:hobart'] = '荷伯特';
$labels['tz:australia:lindeman'] = '利達民';
$labels['tz:australia:lord_howe'] = '豪勳爵島';
$labels['tz:australia:melbourne'] = '墨爾本';
$labels['tz:australia:perth'] = '珀斯';
$labels['tz:australia:sydney'] = '雪梨';
$labels['tz:europe'] = '歐洲';
$labels['tz:europe:amsterdam'] = '阿姆斯特丹';
$labels['tz:europe:andorra'] = '安道爾';
$labels['tz:europe:astrakhan'] = '阿斯特拉罕';
$labels['tz:europe:athens'] = '雅典';
$labels['tz:europe:belgrade'] = '貝爾格萊德';
$labels['tz:europe:berlin'] = '柏林';
$labels['tz:europe:bratislava'] = '布拉迪斯拉發';
$labels['tz:europe:brussels'] = '布魯塞爾';
$labels['tz:europe:bucharest'] = '布加勒斯特';
$labels['tz:europe:budapest'] = '布達佩斯';
$labels['tz:europe:busingen'] = '布辛根';
$labels['tz:europe:chisinau'] = '基施紐';
$labels['tz:europe:copenhagen'] = '哥本哈根';
$labels['tz:europe:dublin'] = '都柏林';
$labels['tz:europe:gibraltar'] = '直布羅陀';
$labels['tz:europe:guernsey'] = '耿西島';
$labels['tz:europe:helsinki'] = '赫爾辛基';
$labels['tz:europe:isle_of_man'] = '曼島';
$labels['tz:europe:istanbul'] = '伊斯坦堡';
$labels['tz:europe:jersey'] = '耿西島';
$labels['tz:europe:kaliningrad'] = '加里寧格勒';
$labels['tz:europe:kiev'] = '基輔';
$labels['tz:europe:kirov'] = '基洛夫';
$labels['tz:europe:lisbon'] = '里斯本';
$labels['tz:europe:ljubljana'] = '盧布爾雅那';
$labels['tz:europe:london'] = '倫敦';
$labels['tz:europe:luxembourg'] = '盧森堡';
$labels['tz:europe:madrid'] = '馬德里';
$labels['tz:europe:malta'] = '馬爾他';
$labels['tz:europe:mariehamn'] = '瑪麗港';
$labels['tz:europe:minsk'] = '明斯克';
$labels['tz:europe:monaco'] = '摩納哥';
$labels['tz:europe:moscow'] = '莫斯科';
$labels['tz:europe:oslo'] = '奧斯陸';
$labels['tz:europe:paris'] = '巴黎';
$labels['tz:europe:podgorica'] = '波德里查';
$labels['tz:europe:prague'] = '布拉格';
$labels['tz:europe:riga'] = '里加';
$labels['tz:europe:rome'] = '羅馬';
$labels['tz:europe:samara'] = '薩馬拉';
$labels['tz:europe:san_marino'] = '聖馬力諾';
$labels['tz:europe:sarajevo'] = '薩拉熱窩';
$labels['tz:europe:saratov'] = '薩拉托夫';
$labels['tz:europe:simferopol'] = '辛菲洛普';
$labels['tz:europe:skopje'] = '史高比耶';
$labels['tz:europe:sofia'] = '索菲亞';
$labels['tz:europe:stockholm'] = '斯德哥爾摩';
$labels['tz:europe:tallinn'] = '塔林';
$labels['tz:europe:tirane'] = '地拉那';
$labels['tz:europe:ulyanovsk'] = '烏里揚諾夫斯克';
$labels['tz:europe:uzhgorod'] = '烏日霍羅德';
$labels['tz:europe:vaduz'] = '華杜茲';
$labels['tz:europe:vatican'] = '梵蒂岡';
$labels['tz:europe:vienna'] = '維也納';
$labels['tz:europe:vilnius'] = '維爾紐斯';
$labels['tz:europe:volgograd'] = '伏爾加格勒';
$labels['tz:europe:warsaw'] = '華沙';
$labels['tz:europe:zagreb'] = '薩格勒布';
$labels['tz:europe:zaporozhye'] = '札波羅結';
$labels['tz:europe:zurich'] = '蘇黎世';
$labels['tz:indian'] = '印度洋';
$labels['tz:indian:antananarivo'] = '安塔那那列佛';
$labels['tz:indian:chagos'] = '查戈斯群島';
$labels['tz:indian:christmas'] = '聖誕節島';
$labels['tz:indian:cocos'] = '科科斯群島';
$labels['tz:indian:comoro'] = '葛摩';
$labels['tz:indian:kerguelen'] = '凱爾蓋朗群島';
$labels['tz:indian:mahe'] = '馬埃島';
$labels['tz:indian:maldives'] = '馬爾地夫';
$labels['tz:indian:mauritius'] = '模里西斯';
$labels['tz:indian:mayotte'] = '馬約特';
$labels['tz:indian:reunion'] = '留尼旺';
$labels['tz:pacific'] = '太平洋';
$labels['tz:pacific:apia'] = '阿皮亞';
$labels['tz:pacific:auckland'] = '奧克蘭';
$labels['tz:pacific:bougainville'] = '布干維爾島';
$labels['tz:pacific:chatham'] = '查塔姆';
$labels['tz:pacific:chuuk'] = '楚克';
$labels['tz:pacific:easter'] = '復活節島';
$labels['tz:pacific:efate'] = '埃法特島';
$labels['tz:pacific:enderbury'] = '恩德伯里島';
$labels['tz:pacific:fakaofo'] = '法考福環礁';
$labels['tz:pacific:fiji'] = '斐濟';
$labels['tz:pacific:funafuti'] = '富納富提';
$labels['tz:pacific:galapagos'] = '科隆群島';
$labels['tz:pacific:gambier'] = '甘比爾群島';
$labels['tz:pacific:guadalcanal'] = '瓜達康納爾島';
$labels['tz:pacific:guam'] = '關島';
$labels['tz:pacific:honolulu'] = '檀香山';
$labels['tz:pacific:johnston'] = '強斯頓環礁';
$labels['tz:pacific:kiritimati'] = '聖誕島';
$labels['tz:pacific:kosrae'] = '科斯雷';
$labels['tz:pacific:kwajalein'] = '瓜加林環礁';
$labels['tz:pacific:majuro'] = '馬久羅';
$labels['tz:pacific:marquesas'] = '馬克薩斯群島';
$labels['tz:pacific:midway'] = '中途島';
$labels['tz:pacific:nauru'] = '瑙魯';
$labels['tz:pacific:niue'] = '紐埃';
$labels['tz:pacific:norfolk'] = '諾福克島';
$labels['tz:pacific:noumea'] = '諾美亞';
$labels['tz:pacific:pago_pago'] = '巴哥巴哥';
$labels['tz:pacific:palau'] = '帛琉';
$labels['tz:pacific:pitcairn'] = '皮特肯群島';
$labels['tz:pacific:pohnpei'] = '澎貝島';
$labels['tz:pacific:port_moresby'] = '莫爾茲比港';
$labels['tz:pacific:rarotonga'] = '拉羅湯加島';
$labels['tz:pacific:saipan'] = '塞班島';
$labels['tz:pacific:tahiti'] = '大溪地';
$labels['tz:pacific:tarawa'] = '塔拉瓦環礁';
$labels['tz:pacific:tongatapu'] = '湯加塔布島';
$labels['tz:pacific:wake'] = '威克島';
$labels['tz:pacific:wallis'] = '沃利斯群島';
