<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = '$product වෙත පිළිගනිමු';
$labels['username'] = 'පරිශීලක නාමය';
$labels['password'] = 'මුරපදය';
$labels['server'] = 'පද්ධතිය';
$labels['login'] = 'පිවිසුම';
$labels['logout'] = 'පිටවීම';
$labels['mail'] = 'විද්‍යුත් තැපැල';
$labels['settings'] = 'සැකසුම්';
$labels['addressbook'] = 'ලිපින පොත';
$labels['inbox'] = 'එනලිපි';
$labels['drafts'] = 'කටු සටහන්';
$labels['sent'] = 'යැවූ';
$labels['trash'] = 'ඉවතලන බඳුන';
$labels['junk'] = 'සුන්බුන්';
$labels['subject'] = 'මාතෘකාව';
$labels['from'] = 'වෙතින්';
$labels['sender'] = 'යවන්නා';
$labels['to'] = 'වෙත';
$labels['cc'] = 'Cc';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'පිළිතුරු සඳහා';
$labels['date'] = 'දිනය';
$labels['size'] = 'ප්‍රමාණය';
$labels['priority'] = 'ප්‍රමුඛත්වය';
$labels['organization'] = 'සංවිධානය';
$labels['mailboxlist'] = 'බහාලුම්';
$labels['messagesfromto'] = '$from වෙතින් $to වෙත පණිවිඩ $count';
$labels['messagenrof'] = 'පණිවිඩ $count න් $nr';
$labels['copy'] = 'පිටපත් කරන්න';
$labels['move'] = 'ගෙනයන්න';
$labels['moveto'] = 'ගෙන යන්න...';
$labels['download'] = 'බාගත කරන්න';
$labels['filename'] = 'ගොනුවේ නම';
$labels['filesize'] = 'ගොනුවේ ප්‍රමාණය';
$labels['addtoaddressbook'] = 'ලිපින පොතට එක් කරන්න';
$labels['sun'] = 'ඉ';
$labels['mon'] = 'ස';
$labels['tue'] = 'අ';
$labels['wed'] = 'බ';
$labels['thu'] = 'බ්‍ර';
$labels['fri'] = 'සි';
$labels['sat'] = 'සෙ';
$labels['sunday'] = 'ඉරිදා';
$labels['monday'] = 'සඳුදා';
$labels['tuesday'] = 'අඟහරුවාදා';
$labels['wednesday'] = 'බදාදා';
$labels['thursday'] = 'බ්‍රහස්පතින්දා';
$labels['friday'] = 'සිකුරාදා';
$labels['saturday'] = 'සෙනසුරාදා';
$labels['jan'] = 'ජන';
$labels['feb'] = 'පෙබ';
$labels['mar'] = 'මාර්';
$labels['apr'] = 'අප්‍රේ';
$labels['may'] = 'මැයි';
$labels['jun'] = 'ජූනි';
$labels['jul'] = 'ජූලි';
$labels['aug'] = 'අගෝ';
$labels['sep'] = 'සැප්';
$labels['oct'] = 'ඔක්';
$labels['nov'] = 'නොවැ';
$labels['dec'] = 'දෙසැ';
$labels['longjan'] = 'ජනවාරි';
$labels['longfeb'] = 'පෙබරවාරි';
$labels['longmar'] = 'මාර්තු';
$labels['longapr'] = 'අප්‍රේල්';
$labels['longmay'] = 'මැයි';
$labels['longjun'] = 'ජූනි';
$labels['longjul'] = 'ජූලි';
$labels['longaug'] = 'අගෝස්තු';
$labels['longsep'] = 'සැප්තැම්බර්';
$labels['longoct'] = 'ඔක්තෝම්බර්';
$labels['longnov'] = 'නොවැම්බර්';
$labels['longdec'] = 'දෙසැම්බර්';
$labels['today'] = 'අද';
$labels['checkmail'] = 'අඵත් පණිවිඩ සඳහා පිරික්සීම';
$labels['compose'] = 'පණිවිඩයක් සෑදීම';
$labels['writenewmessage'] = 'අඵත් පණිවිඩයක්';
$labels['reply'] = 'පිළිතුරු දෙන්න';
$labels['replytomessage'] = 'පණිවිඩයට පිළිතුරු';
$labels['replytoallmessage'] = 'එවන්නාට සහ සැමට පිළිතුරු';
$labels['forward'] = 'ඉදිරියට';
$labels['forwardmessage'] = 'පණිවිඩය ඉදිරියට';
$labels['deletemessage'] = 'පණිවිඩය මකන්න';
$labels['movemessagetotrash'] = 'පණිවිඩය ලටපට වෙත ගෙන යන්න';
$labels['printmessage'] = 'මෙම පණිවිඩය මුද්‍රණය කරන්න';
$labels['previousmessage'] = 'කලින් පණිවිඩය පෙන්නන්න';
$labels['firstmessage'] = 'පළමුවන පණිවිඩය පෙන්නන්න';
$labels['nextmessage'] = 'මීළඟ පණිවිඩය පෙන්නන්න';
$labels['lastmessage'] = 'අවසාන පණිවිඩය පෙන්නන්න';
$labels['backtolist'] = 'නැවතත් පණිවිඩ ලැයිස්තුවට';
$labels['viewsource'] = 'මූලාශ්‍රය පෙන්වන්න';
$labels['mark'] = 'සලකුණු කරන්න';
$labels['markmessages'] = 'පණිවිඩ සලකුණු කරන්න';
$labels['markread'] = 'කියවු ලෙස';
$labels['markunread'] = 'නොකියවු ලෙස';
$labels['moreactions'] = 'තවත් ක්‍රියා...';
$labels['more'] = 'තවත්';
$labels['back'] = 'ආපසු';
$labels['options'] = 'විකල්ප';
$labels['select'] = 'තෝරන්න';
$labels['all'] = 'සියල්ල';
$labels['none'] = 'කිසිවක් නැත';
$labels['currpage'] = 'දැනට ඇති පිටුව';
$labels['isread'] = 'කියවන්න';
$labels['unread'] = 'නොකියවූ';
$labels['deleted'] = 'මකා දැමූ';
$labels['filter'] = 'පෙරන්න';
$labels['list'] = 'ලැයිස්තුව';
$labels['expand-all'] = 'සියල්ල දිගහරින්න';
$labels['collapse-all'] = 'සියල්ල හකුළන්න';
$labels['fromto'] = 'වෙතින්/වෙත';
$labels['attachment'] = 'ඇමුණුම';
$labels['nonesort'] = 'කිසිවක් නැත';
$labels['sentdate'] = 'යැවූ දිනය';
$labels['arrival'] = 'ලගාවූ දිනය';
$labels['asc'] = 'ආරෝහණ';
$labels['desc'] = 'අවරෝහණ';
$labels['layoutlist'] = 'ලැයිස්තුව';
$labels['folderactions'] = 'බහාලුම් ක්‍රියා...';
$labels['compact'] = 'සංයුක්ත';
$labels['empty'] = 'හිස්';
$labels['unknown'] = 'නොදනී';
$labels['unlimited'] = 'අසීමිත';
$labels['quicksearch'] = 'ඉක්මන් සෙවුම';
$labels['resetsearch'] = 'සෙවුම යලි පිහිටවීම';
$labels['msgtext'] = 'සම්පූර්ණ පණිවිඩය';
$labels['openinextwin'] = 'නව කවුළුවක විවෘත කරන්න';
$labels['sendmessage'] = 'පණිවිඩය යවන්න';
$labels['savemessage'] = 'කටු සටහනක් ලෙස සුරකින්න';
$labels['addattachment'] = 'ගොනුවක් අමුණන්න';
$labels['charset'] = 'අකුරැ කට්ටලය';
$labels['editortype'] = 'සම්පාදන ආකාරය';
$labels['returnreceipt'] = 'නැවත ලබන්නා';
$labels['recipient'] = 'ලබන්නා';
$labels['checkspelling'] = 'අක්‍ෂර වින්‍යාසය පරික්‍ෂාකරන්න';
$labels['resumeediting'] = 'සම්පාදන නැවත ඇරඹීම';
$labels['revertto'] = 'ආපසු ඒම';
$labels['attach'] = 'අමුණන්න';
$labels['attachments'] = 'ඇමුණුම්';
$labels['upload'] = 'ඇතුල් කරීම';
$labels['close'] = 'වසන්න';
$labels['low'] = 'අඩු';
$labels['lowest'] = 'අඩුම';
$labels['normal'] = 'සාමාන්‍ය';
$labels['high'] = 'ඉහළ';
$labels['highest'] = 'ඉහළම';
$labels['nosubject'] = '(මාතෘකාව නොමැත)';
$labels['showimages'] = 'රූප පෙන්වන්න';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'පැහැදිලි අකුරු';
$labels['addcc'] = 'Cc එක් කරන්න';
$labels['addbcc'] = 'Bcc එක් කරන්න';
$labels['addreplyto'] = '\'පිළිතුරු සඳහා\' එක් කරන්න';
$labels['mdnrequest'] = 'මෙම පණිවුඩය එවන්නා ඔබ එය කියවු බව අසයි. එය දැන්වීමට ඔබ කැමතිද?';
$labels['receiptread'] = 'ලැබීම් ලදුපත (කියවීම)';
$labels['yourmessage'] = 'මෙය ඔබගේ පණිවුඩයේ ලැබීම් ලදුපතයි';
$labels['receiptnote'] = 'සටහන: ලැබීම් ලදුපත මගින් මෙම පණිවුඩය කියවූ බව හෝ තේරුම් ගත් බව ගම්‍ය නොවේ. පණිවුඩය ලබන්නාට පෙන්නුම් කල බවටට සාක්ෂියක් පමණි';
$labels['name'] = 'ප්‍රදර්ශනය වන නම';
$labels['firstname'] = 'මුල් නම';
$labels['surname'] = 'අවසන් නම';
$labels['nickname'] = 'සුරතල් නම';
$labels['jobtitle'] = 'රැකියා තනතුර';
$labels['department'] = 'දෙපාර්තමේන්තුව';
$labels['gender'] = 'ස්ත්‍රි/පුරුෂ භාවය';
$labels['email'] = 'විද්‍යුත් තැපෑල';
$labels['phone'] = 'දුරකථනය';
$labels['address'] = 'ලිපිනය';
$labels['locality'] = 'නගරය';
$labels['region'] = 'ප්‍රාන්තය/පළාත';
$labels['country'] = 'රට';
$labels['birthday'] = 'උපන්දිනය';
$labels['anniversary'] = 'සංවත්සරය';
$labels['website'] = 'වෙබ් අඩවිය';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'සටහන්';
$labels['male'] = 'පුරුෂ';
$labels['female'] = 'ස්ත්‍රී';
$labels['manager'] = 'කළමණාකරු';
$labels['assistant'] = 'සහායක';
$labels['search'] = 'සොයන්න';
$labels['advanced'] = 'සංකීර්ණ‍';
$labels['other'] = 'වෙනත්';
$labels['typehome'] = 'නිවස';
$labels['typework'] = 'රක්ෂාව';
$labels['typeother'] = 'වෙනත්';
$labels['typemobile'] = 'ජංගම';
$labels['typemain'] = 'ප්‍රධාන';
$labels['typehomefax'] = 'ගෘහස්ථ ෆැක්ස්';
$labels['typepager'] = 'පේජරය';
$labels['typevideo'] = 'වීඩියෝ';
$labels['typeassistant'] = 'සහායක';
$labels['typeblog'] = 'බ්ලොග්';
$labels['typeprofile'] = 'පැතිකඩ';
$labels['editcontact'] = 'ලිපිනය වෙනස් කිරීම';
$labels['contacts'] = 'සබඳතා';
$labels['personalinfo'] = 'පුද්ගලික තොරතුරු';
$labels['edit'] = 'සංස්කරණය';
$labels['cancel'] = 'අවලංගු කරන්න';
$labels['save'] = 'සුරකින්න';
$labels['delete'] = 'මකන්න';
$labels['rename'] = 'නම වෙනස් කරන්න';
$labels['addphoto'] = 'එක් කරන්න';
$labels['deletecontact'] = 'තෝරාගත් ලිපින මකාදමන්න';
$labels['composeto'] = 'පනිවුඩයක් සෑදීම';
$labels['contactsfromto'] = '$from ගෙන් $to ලිපින $count';
$labels['print'] = 'මුද්‍රණය කරන්න';
$labels['export'] = 'අපනයනය';
$labels['previouspage'] = 'පෙර පිටුව පෙන්වන්න';
$labels['firstpage'] = 'පළමුවන පිටුව පෙන්වන්න';
$labels['nextpage'] = 'මීළඟ පිටුව පෙන්වන්න';
$labels['lastpage'] = 'අවසාන පිටුව පෙන්වන්න';
$labels['group'] = 'කණ්ඩායම';
$labels['groups'] = 'කණ්ඩායම්';
$labels['personaladrbook'] = 'පුද්ගලික ලිපිනය';
$labels['import'] = 'ආනයනය කරන්න';
$labels['done'] = 'අවසානයි';
$labels['settingsfor'] = 'සඳහා සැකසුම්';
$labels['about'] = 'පිළිබඳ';
$labels['preferences'] = 'අභිමතය';
$labels['userpreferences'] = 'පරිශීලක අභිමතය';
$labels['editpreferences'] = 'පරිශීලක අභිමතය වෙනස් කිරීම්';
$labels['identities'] = 'අනන්‍යතාවන්';
$labels['preferhtml'] = 'HTML විදහා පෙන්වීම';
$labels['htmlmessage'] = 'HTML පණිවිඩය';
$labels['prettydate'] = 'සුරුබුහුටි දින';
$labels['setdefault'] = 'පළමු තත්වයට';
$labels['autodetect'] = 'ස්වයංක්‍රීය';
$labels['language'] = 'භාෂාව';
$labels['timezone'] = 'කාල කලාපය';
$labels['signature'] = 'අත්සන';
$labels['dstactive'] = 'දිවා එළිය ඉතිරි කිරීම';
$labels['htmleditor'] = 'HTML පණිවිඩයක් සෑදීම';
$labels['htmlsignature'] = 'HTML අත්සන';
$labels['previewpane'] = 'පූර්වදර්ශන කොටස පෙන්නන්න';
$labels['uisettings'] = 'පරිශීලක අතුරුමුහුණත';
$labels['askuser'] = 'මගෙන් විමසන්න';
$labels['always'] = 'සැමවිට';
$labels['autosavedraft'] = 'ස්වයංක්‍රීයව කටු සටහන සුරකින්න';
$labels['never'] = 'කිසි විටෙකත් නැති';
$labels['immediately'] = 'හැකි ඉක්මනින්';
$labels['2231folding'] = 'Full RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Full RFC 2047 (වෙනත්)';
$labels['section'] = 'අංශය';
$labels['maintenance'] = 'නඩත්තු කිරීම';
$labels['newmessage'] = 'අලුත් පණිවිඩයක්';
$labels['autoaddsignature'] = 'ස්වයංක්‍රීයව අත්සන ඇතුලත් කරන්න';
$labels['newmessageonly'] = 'අලුත් පණිවිඩය පමණක්';
$labels['insertsignature'] = 'අත්සන ඇතුලත් කරන්න';
$labels['afternseconds'] = 'තත්පර $nකට පසු';
$labels['spellcheckignoresyms'] = 'සලකුණු සහිත වචන නොසලකා හරින්න';
$labels['spellcheckignorenums'] = 'අංක සහිත වචන නොසලකා හරින්න';
$labels['addtodict'] = 'ශබ්ද කෝෂයට එක් කරන්න';
$labels['allmessages'] = 'සියලු පණිවිඩ';
$labels['folder'] = 'බහාලුම';
$labels['folders'] = 'බහාලුම්';
$labels['foldername'] = 'බහාලුමේ නම';
$labels['subscribed'] = 'සාමාජික';
$labels['messagecount'] = 'පණිවිඩ';
$labels['create'] = 'තනන්න';
$labels['createfolder'] = 'නව බහාලුමක් තනන්න';
$labels['managefolders'] = 'බහාලුම් කළමනාකරණය කරන්න';
$labels['specialfolders'] = 'විශේෂ බහාලුම්';
$labels['properties'] = 'වත්කම්';
$labels['folderproperties'] = 'බහාලුමේ වත්කම්';
$labels['location'] = 'ස්ථානය';
$labels['info'] = 'තොරතුරු';
$labels['foldertype'] = 'බහාලුම් වර්ගය';
$labels['personalfolder'] = 'පුද්ගලික බහාලුම';
$labels['sharedfolder'] = 'පොදු බහාලුම';
$labels['sortby'] = 'වර්ග කරන්න';
$labels['sortasc'] = 'ආරෝහණ වර්ග කිරීම';
$labels['sortdesc'] = 'අවරෝහණ වර්ග කිරීම';
$labels['plugin'] = 'ප්ලගිනය';
$labels['version'] = 'අනුවාදය';
$labels['source'] = 'මූලාශ්‍රය';
$labels['license'] = 'බලපත්‍රය';
$labels['support'] = 'සහය ලබාගන්න';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'යුනිකේත';
$labels['english'] = 'ඉංග්‍රීසි';
$labels['westerneuropean'] = 'බටහිර යුරෝපීය';
$labels['baltic'] = 'බෝල්ටික්';
$labels['arabic'] = 'අරාබි';
$labels['greek'] = 'ග්‍රීක';
$labels['hebrew'] = 'හීබෲ';
$labels['turkish'] = 'තුර්කි';
$labels['nordic'] = 'නොර්ඩික්';
$labels['thai'] = 'තායි';
$labels['celtic'] = 'සෙල්ටික්';
$labels['vietnamese'] = 'වියට්නාම';
$labels['japanese'] = 'ජපන්';
$labels['korean'] = 'කොරියානු';
$labels['chinese'] = 'චීන';
