<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sender'] = 'بھیجنے والا';
$labels['flagdeleted'] = 'ختم ہو گیا';
$labels['datetest'] = 'تاریخ';
$labels['vacation.subject'] = 'مضمون';
