<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Mark-As-Junk plugin        |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttonjunk'] = 'Wiadomość jest spamem.';
$labels['asjunk'] = 'Jako spam';
$labels['markasjunk'] = 'Oznacz jako spam';
$labels['buttonnotjunk'] = 'Wiadomość nie jest spamem';
$labels['asnotjunk'] = 'Jako nie-spam';
$labels['markasnotjunk'] = 'Oznacz jako nie-spam';
$labels['notjunk'] = 'Nie-spam';
$messages['reportedasjunk'] = 'Pomyślnie oznaczono jako spam';
$messages['reportedasnotjunk'] = 'Pomyślnie oznaczono jako nie spam';
