<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Compartindo';
$labels['myrights'] = 'Permisos de acceso';
$labels['username'] = 'Usuario:';
$labels['advanced'] = 'Modo avanzado';
$labels['add'] = 'Engadir';
$labels['newuser'] = 'Engadir entrada';
$labels['editperms'] = 'Editar permisos';
$labels['actions'] = 'Accións sobre os permisos de acceso...';
$labels['anyone'] = 'Todos os usuarios (calquera)';
$labels['anonymous'] = 'Invitados (anónimos)';
$labels['identifier'] = 'Identificador';
$labels['acll'] = 'Buscar';
$labels['aclr'] = 'Ler mensaxes';
$labels['acls'] = 'Manter estado Vista';
$labels['aclw'] = 'Escribir marcadores';
$labels['acli'] = 'Inserir (Copiar en)';
$labels['aclp'] = 'Enviar';
$labels['aclc'] = 'Crear subcartafoles';
$labels['aclk'] = 'Crear subcartafoles';
$labels['acld'] = 'Eliminar mensaxes';
$labels['aclt'] = 'Eliminar mensaxes';
$labels['acle'] = 'Suprimir';
$labels['aclx'] = 'Eliminar cartafol';
$labels['acla'] = 'Administrar';
$labels['acln'] = 'Crear anotacións para as mensaxes';
$labels['aclfull'] = 'Control total';
$labels['aclother'] = 'Outro';
$labels['aclread'] = 'Ler';
$labels['aclwrite'] = 'Escribir';
$labels['acldelete'] = 'Eliminar';
$labels['shortacll'] = 'Buscar';
$labels['shortaclr'] = 'Ler';
$labels['shortacls'] = 'Manter';
$labels['shortaclw'] = 'Escribir';
$labels['shortacli'] = 'Inserir';
$labels['shortaclp'] = 'Enviar';
$labels['shortaclc'] = 'Crear';
$labels['shortaclk'] = 'Crear';
$labels['shortacld'] = 'Eliminar';
$labels['shortaclt'] = 'Eliminar';
$labels['shortacle'] = 'Suprimir';
$labels['shortaclx'] = 'Eliminar cartafol';
$labels['shortacla'] = 'Administrar';
$labels['shortacln'] = 'Crear anotación';
$labels['shortaclother'] = 'Outro';
$labels['shortaclread'] = 'Ler';
$labels['shortaclwrite'] = 'Escribir';
$labels['shortacldelete'] = 'Eliminar';
$labels['longacll'] = 'O cartafol é visible nas listas e é posible subscribirse a el';
$labels['longaclr'] = 'Pódese abrir o cartafol para a súa lectura';
$labels['longacls'] = 'Pódese cambiar o marcador de Vista';
$labels['longaclw'] = 'Pódense cambiar os marcadores e as palabras clave agás Vista e Eliminada';
$labels['longacli'] = 'Pódense escribir ou copiar as mensaxes neste cartafol';
$labels['longaclp'] = 'Pódense enviar as mensaxes a este cartafol';
$labels['longaclc'] = 'Pódense crear cartafoles (ou cambiarlle o nome) directamente baixo este cartafol';
$labels['longaclk'] = 'Pódense crear cartafoles (ou cambiarlle o nome) directamente baixo este cartafol';
$labels['longacld'] = 'Pódense cambiar o marcador Eliminar das mensaxes';
$labels['longaclt'] = 'Pódense cambiar o marcador Eliminar das mensaxes';
$labels['longacle'] = 'Pódense suprimir as mensaxes';
$labels['longaclx'] = 'Pódese eliminar o cartafol ou cambiarlle o nome';
$labels['longacla'] = 'Pódense cambiar os permisos de acceso ao cartafol';
$labels['longacln'] = 'Pódense cambiar os metadatos compartidos (anotacións) das mensaxes';
$labels['longaclfull'] = 'Control total, incluída a administración de cartafoles';
$labels['longaclread'] = 'Pódese abrir o cartafol para a súa lectura';
$labels['longaclwrite'] = 'Pódense marcar, escribir ou copiar as mensaxes no cartafol';
$labels['longacldelete'] = 'Pódense eliminar as mensaxes';
$labels['longaclother'] = 'Outros permisos de acceso';
$labels['ariasummaryacltable'] = 'Lista de permisos de acceso';
$labels['arialabelaclactions'] = 'Amosar accións';
$labels['arialabelaclform'] = 'Formulario de permisos de acceso';
$messages['deleting'] = 'Eliminando permisos de acceso...';
$messages['saving'] = 'Gardando permisos de acceso...';
$messages['updatesuccess'] = 'Permisos de acceso cambiados correctamente';
$messages['deletesuccess'] = 'Permisos de acceso eliminados correctamente';
$messages['createsuccess'] = 'Permisos de acceso engadidos correctamente';
$messages['updateerror'] = 'Non é posible actualizar os permisos de acceso';
$messages['deleteerror'] = 'Non é posible eliminar os permisos de acceso';
$messages['createerror'] = 'Non é posible engadir os permisos de acceso';
$messages['deleteconfirm'] = 'Seguro/a que queres eliminar os permisos de acceso do(s) usuario(s) seleccionado(s)?';
$messages['norights'] = 'Non se especificaron permisos!';
$messages['nouser'] = 'Non se especificou o nome de usuario!';
