<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'Noko gjekk feil.';
$messages['loginfailed']  = 'Feil ved innlogging.';
$messages['cookiesdisabled'] = 'Nettlesaren din tillet ikkje informasjonskapslar (cookies).';
$messages['sessionerror'] = 'Økta di er ugyldig eller har gått ut på tid.';
$messages['storageerror'] = 'Tilkoplinga til lagringstenaren vart mislukka.';
$messages['servererror'] = 'Tenarfeil.';
$messages['servererrormsg'] = 'Tenarfeil: $msg';
$messages['dberror'] = 'Databasefeil!';
$messages['requesttimedout'] = 'Førespurnaden fekk tidsavbrot';
$messages['errorreadonly'] = 'Klarte ikkje utføra handlinga. Mappa kan berre lesast.';
$messages['errornoperm'] = 'Klarte ikkje utføra handlinga. Nekta tilgang.';
$messages['invalidrequest'] = 'Eg forstår ingen ting! Ingen data lagra.';
$messages['invalidhost'] = 'Ugyldig tenarnamn.';
$messages['nomessagesfound'] = 'Ingen meldingar i denne postkassa.';
$messages['refreshing'] = 'Oppdaterer …';
$messages['loading'] = 'Hentar …';
$messages['uploading'] = 'Lastar opp fil …';
$messages['uploadingmany'] = 'Lastar opp filer …';
$messages['loadingdata'] = 'Hentar data …';
$messages['checkingmail'] = 'Ser etter nye meldingar …';
$messages['sendingmessage'] = 'Sender melding …';
$messages['messagesent'] = 'Meldinga vart sendt.';
$messages['savingmessage'] = 'Lagrar melding …';
$messages['messagesaved'] = 'Melding lagra som kladd.';
$messages['successfullysaved'] = 'Meldinga vart lagra.';
$messages['addedsuccessfully'] = 'Kontakta vart lagt til i adresseboka.';
$messages['contactnameexists'] = 'Det finst allereie en kontakt med dette namnet.';
$messages['blockedimages'] = 'Av omsyn til personvernet ditt er eksterne bilete blokkerte i denne meldinga.';
$messages['encryptedmessage'] = 'Dette er ei kryptert melding og kan ikkje visast. Orsak!';
$messages['nocontactsfound'] = 'Fann ingen kontaktar.';
$messages['contactnotfound'] = 'Fann ikkje kontakten du såg etter.';
$messages['sendingfailed'] = 'Klarte ikkje senda meldinga.';
$messages['senttooquickly'] = 'Du må venta $sec sekund for å senda meldinga.';
$messages['errormoving'] = 'Klarte ikkje flytte meldinga(r).';
$messages['errorcopying'] = 'Klarte ikkje kopiera meldinga(r).';
$messages['errordeleting'] = 'Klarte ikkje sletta meldinga(r).';
$messages['errormarking'] = 'Klarte ikkje markera meldinga(r).';
$messages['deletecontactconfirm']  = 'Sletta kontakt(ar)?';
$messages['deletegroupconfirm']  = 'Vil du sletta den valde gruppa?';
$messages['deletemessagesconfirm'] = 'Sletta melding(ar)?';
$messages['deletefolderconfirm']  = 'Sletta mappa?';
$messages['purgefolderconfirm']  = 'Sletta alle meldingane i denne mappa?';
$messages['contactdeleting'] = 'Slettar kontakt(ar) …';
$messages['groupdeleting'] = 'Slettar gruppe …';
$messages['folderdeleting'] = 'Slettar mappe …';
$messages['foldermoving'] = 'Flyttar mappe …';
$messages['foldersubscribing'] = 'Abonnerer på mappe …';
$messages['folderunsubscribing'] = 'Avsluttar mappeabonnement …';
$messages['formincomplete'] = 'Skjemaet var ikkje fullstendig fylt ut.';
$messages['noemailwarning'] = 'Skriv ei gyldig e-postadresse.';
$messages['nonamewarning']  = 'Skriv eit namn.';
$messages['nopagesizewarning'] = 'Oppgje sidestorleik.';
$messages['norecipientwarning'] = 'Skriv minst ein mottakar.';
$messages['nosubjectwarning']  = 'Emnefeltet er tomt. Vil du skriva eitt emne no?';
$messages['nobodywarning'] = 'Senda meldinga utan tekst?';
$messages['nosearchname'] = 'Skriv kontaktnamn eller epostadresse.';
$messages['notuploadedwarning'] = 'Ikkje alle vedlegga er ferdig opplasta enno. Vent litt til, eller avbryt opplastinga.';
$messages['searchsuccessful'] = 'Fann $nr meldingar.';
$messages['contactsearchsuccessful'] = '$nr kontaktar funne.';
$messages['searchnomatch'] = 'Søket fann ingenting.';
$messages['searching'] = 'Søkjer …';
$messages['checking'] = 'Sjekkar …';
$messages['nospellerrors'] = 'Fann ingen skrivefeil.';
$messages['folderdeleted'] = 'Mappe sletta.';
$messages['foldersubscribed'] = 'Abonnerte på mappa.';
$messages['folderunsubscribed'] = 'Avslutta mappeabonnement.';
$messages['deletedsuccessfully'] = 'Sletta.';
$messages['converting'] = 'Fjernar formatering frå meldinga …';
$messages['messageopenerror'] = 'Klarte ikkje lasta meldinga frå tenaren.';
$messages['fileuploaderror'] = 'Filopplasting feila.';
$messages['filesizeerror'] = 'Fila du lasta opp, er større enn største tillatne filstorleik, $size.';
$messages['sourceisreadonly'] = 'Denne adressekjelda er berre lesbar.';
$messages['errorsavingcontact'] = 'Klarte ikkje lagra kontaktadressa.';
$messages['movingmessage'] = 'Flyttar melding(ar) …';
$messages['copyingmessage'] = 'Kopierer melding(ar) …';
$messages['copyingcontact'] = 'Kopierer kontakt(ar) …';
$messages['deletingmessage'] = 'Slettar melding(ar) …';
$messages['markingmessage'] = 'Merkar melding(ar) …';
$messages['addingmember'] = 'Legg til kontakt(ar) i gruppa …';
$messages['removingmember'] = 'Fjernar kontakt(ar) frå gruppa …';
$messages['receiptsent'] = 'Har sendt lesekvittering.';
$messages['errorsendingreceipt'] = 'Klarte ikkje senda lesekvittering.';
$messages['deleteidentityconfirm'] = 'Vil du sletta denne identiteten?';
$messages['nodeletelastidentity'] = 'Du kan ikkje sletta denne identiteten, det er den siste.';
$messages['forbiddencharacter'] = 'Mappenamn inneheld eit teikn som ikkje er tillate.';
$messages['selectimportfile'] = 'Vel ei fil til å lasta opp.';
$messages['addresswriterror'] = 'Denne adresseboka kan ikkje skrivast til.';
$messages['contactaddedtogroup'] = 'La kontaktane til denne gruppa.';
$messages['contactremovedfromgroup'] = 'Tok vekk kontaktane frå denne gruppa.';
$messages['nogroupassignmentschanged'] = 'Endra ikkje gruppetilordningane.';
$messages['importwait'] = 'Importerer, vent …';
$messages['importformaterror'] = 'Importering feila. Den opplasta fila er i feil format.';
$messages['importconfirm'] = '<b>Importerte $inserted kontaktar</b>';
$messages['opnotpermitted'] = 'Ulovleg operasjon.';
$messages['httpreceivedencrypterror'] = 'En uopprettelig feil oppstod knytta til innstillingane. Kontakt systemansvarleg umiddelbart. <b>Meldinga kunne ikkje sendast.</b>';
$messages['smtpconnerror'] = 'SMTP-feil ($code): Tilkopling til tenar feila.';
$messages['smtpautherror'] = 'SMTP-feil ($code): Autentisering feila.';
$messages['smtpfromerror'] = 'SMTP-feil ($code): Klarte ikkje å angje sendar «$from» ($msg).';
$messages['smtptoerror'] = 'SMTP-feil ($code): Klarte ikkje å leggja til mottakar «$to» ($msg).';
$messages['smtprecipientserror'] = 'SMTP-feil: Klarte ikkje tolka mottakarlista.';
$messages['smtperror'] = 'SMTP-feil: $msg';
$messages['toomanyrecipients'] = 'For mange mottakarar. Senk talet til $max.';
$messages['maxgroupmembersreached'] = 'Ei gruppe kan ikkje ha fleire enn $max medlemmer.';
$messages['contactdelerror'] = 'Klarte ikkje sletta kontakt(ar).';
$messages['contactdeleted'] = 'Kontakt(ar) sletta utan feil.';
$messages['contactrestoreerror'] = 'Klarte ikkje gjenoppretta kontakt(ar).';
$messages['contactrestored'] = 'Kontakt(ar) gjennomretta utan feil.';
$messages['groupdeleted'] = 'Gruppa er sletta.';
$messages['grouprenamed'] = 'Gruppa har bytta namn.';
$messages['groupcreated'] = 'Gruppa er oppretta.';
$messages['savedsearchdeleted'] = 'Lagra søk er sletta.';
$messages['savedsearchdeleteerror'] = 'Klarte ikkje sletta lagra søk.';
$messages['savedsearchcreated'] = 'Oppretta lagra søk.';
$messages['savedsearchcreateerror'] = 'Klarte ikkje laga lagra søk.';
$messages['messagedeleted'] = 'Melding(ar) vart sletta.';
$messages['messagemoved'] = 'Melding(ar) vart flytta.';
$messages['messagecopied'] = 'Melding(ar) vart kopiert.';
$messages['messagemarked'] = 'Melding(ar) vart merka.';
$messages['autocompletechars'] = 'Skriv minst $min teikn for autofullføring.';
$messages['autocompletemore'] = 'Flere like oppføringar vart funne. Skriv fleire tegn.';
$messages['namecannotbeempty'] = 'Namn kan ikkje vera tomt.';
$messages['nametoolong'] = 'Namnet er for langt.';
$messages['folderupdated'] = 'Mappa er oppdatert.';
$messages['foldercreated'] = 'Mappa er oppretta.';
$messages['invalidimageformat'] = 'Ikke et gyldig bileteformat.';
$messages['mispellingsfound'] = 'Fann stavefeil i meldinga.';
$messages['parentnotwritable'] = 'Klarte ikkje laga/flytte mappa i vald overordna mappe. Ingen tilgangsrettar.';
$messages['messagetoobig'] = 'Meldingsdelen er for stor til å prosesserast.';
$messages['noscriptwarning'] = 'NB: Denne webmail-klienten krev JavaScript. Skru på JavaScript i nettlesaren din for å kunna bruka klienten.';
