<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = 'স্বাগতম';
$labels['username'] = 'গ্রাহক নাম (username)';
$labels['password'] = 'গোপোন শব্দ (password)';
$labels['server'] = 'সারভার';
$labels['login'] = 'প্রবেশ';
$labels['logout'] = 'প্রস্থান';
$labels['mail'] = 'ই-মেইল';
$labels['settings'] = 'ব্যাক্তিগত খুটিনাটি';
$labels['addressbook'] = 'ঠিকানার বই';
$labels['inbox'] = 'প্রধান বাক্স';
$labels['drafts'] = 'খসড়া';
$labels['sent'] = 'প্রেরিত(পাঠানো মেইল)';
$labels['trash'] = 'ডাস্টবিন';
$labels['junk'] = 'আজেবাজে মেইল';
$labels['subject'] = 'বিষয়';
$labels['from'] = 'প্রেরক';
$labels['sender'] = 'প্রেরক';
$labels['to'] = 'প্রাপক';
$labels['cc'] = 'অনুলিপির ঠিকানা';
$labels['bcc'] = 'নাজানিয়ে অনুলিপির ঠিকানা';
$labels['replyto'] = 'উত্তর পাঠানোর ঠিকানা';
$labels['date'] = 'তারিখ';
$labels['size'] = 'সাইজ';
$labels['priority'] = 'গুরুত্ব';
$labels['organization'] = 'কোম্পানি';
$labels['mailboxlist'] = 'ফোল্ডার/মেইলবক্স';
$labels['messagesfromto'] = '$count মেইলের মধ্যে, $from হতে $to দেখানো হচ্ছে';
$labels['messagenrof'] = '$nr #মেইল/চিঠি , $count এর মধ্যে';
$labels['copy'] = 'অনুলিপির ঠিকানা';
$labels['move'] = 'স্থানান্তর';
$labels['moveto'] = 'সরিয়ে ফেলুন..';
$labels['download'] = 'ডাউনলোড';
$labels['open'] = 'খোলা';
$labels['showattachment'] = 'দেখানো';
$labels['filename'] = 'ফাইলের নাম';
$labels['filesize'] = 'ফাইলের সাইজ';
$labels['addtoaddressbook'] = 'ঠিকানার বইতে ঢুকান';
$labels['sun'] = 'রবি';
$labels['mon'] = 'সোম';
$labels['tue'] = 'মঙ্গল';
$labels['wed'] = 'বুধ';
$labels['thu'] = 'বৃহ:';
$labels['fri'] = 'শুক্র';
$labels['sat'] = 'শনি';
$labels['sunday'] = 'রবিবার';
$labels['monday'] = 'সোমবার';
$labels['tuesday'] = 'মঙ্গলবার';
$labels['wednesday'] = 'বুধবার';
$labels['thursday'] = 'বৃহস্পতিবার';
$labels['friday'] = 'শুক্রবার';
$labels['saturday'] = 'শনিবার';
$labels['jan'] = 'জানুয়ারি';
$labels['feb'] = 'ফেব্রুয়ারি';
$labels['mar'] = 'মার্চ';
$labels['apr'] = 'এপ্রিল';
$labels['may'] = 'মে';
$labels['jun'] = 'জুন';
$labels['jul'] = 'জুলাই';
$labels['aug'] = 'আগস্ট';
$labels['sep'] = 'সেপ্তেমবার';
$labels['oct'] = 'অষ্টবার';
$labels['nov'] = 'নবেমবার';
$labels['dec'] = 'দিশেমবার';
$labels['longjan'] = 'জানুয়ারি';
$labels['longfeb'] = 'ফেব্রুয়ারি';
$labels['longmar'] = 'মার্চ';
$labels['longapr'] = 'এপ্রিল';
$labels['longmay'] = 'মে';
$labels['longjun'] = 'জুন';
$labels['longjul'] = 'জুলাই';
$labels['longaug'] = 'আগস্ট';
$labels['longsep'] = 'সেপ্তেমবার (September)';
$labels['longoct'] = 'অষ্টবার (October)';
$labels['longnov'] = 'নবেমবার (November)';
$labels['longdec'] = 'দিশেমবার (December)';
$labels['today'] = 'আজকে';
$labels['checkmail'] = 'দেখুন নতুন কোনো মেইল/চিঠি এলো কিনা';
$labels['compose'] = 'নতুন মেইল/চিঠি লিখুন';
$labels['writenewmessage'] = 'নতুন মেইল/চিঠি লিখুন';
$labels['reply'] = 'জবাব';
$labels['replytomessage'] = 'শুধু প্রেরকের কাছে উত্তর পাঠান';
$labels['replytoallmessage'] = 'প্রেরক ও এই চিঠির অন্যান্য প্রাপকদের কাছে উত্তর পাঠান';
$labels['forwardmessage'] = 'মেইল/চিঠি এগিয়ে দিন';
$labels['deletemessage'] = 'মেইল/চিঠি ছিড়ে ফেলুন';
$labels['movemessagetotrash'] = 'মেইল/চিঠি ডাস্টবিনে ফেলুন';
$labels['printmessage'] = 'মেইল/চিঠি প্রিন্ট করুন';
$labels['previousmessage'] = 'আগের মেইল/চিঠিটি দেখুন';
$labels['firstmessage'] = 'প্রথম মেইল/চিঠিটি দেখুন';
$labels['nextmessage'] = 'পরের মেইল/চিঠিটি দেখুন';
$labels['lastmessage'] = 'শেষ মেইল/চিঠিটি দেখুন';
$labels['backtolist'] = 'মেইল/চিঠির তালিকায় ফিরে যান';
$labels['viewsource'] = 'মূল উৎসদেখুন';
$labels['mark'] = 'দাগানো';
$labels['markmessages'] = 'মেইল/চিঠি (গুলো)';
$labels['markread'] = 'পড়া শেষ (read)';
$labels['markunread'] = 'নাদেখা (unread)';
$labels['markflagged'] = 'দাগানো (flagged)';
$labels['markunflagged'] = 'দাগহীন (unflagged)';
$labels['more'] = 'আরো';
$labels['first'] = 'প্রথম';
$labels['last'] = 'শেষ';
$labels['previous'] = 'পূর্ববর্তী';
$labels['next'] = 'পরবর্তী';
$labels['select'] = 'বেছেনিন';
$labels['all'] = 'সবগুলো';
$labels['none'] = 'কোনোটাই না';
$labels['isread'] = 'পড়';
$labels['unread'] = 'নাদেখা (unread)';
$labels['flagged'] = 'দাগানো (flagged)';
$labels['unanswered'] = 'উত্তর না দেওয়া গুলো';
$labels['filter'] = 'ছাকনি';
$labels['list'] = 'তালিকা';
$labels['nonesort'] = 'কোনোটাই না';
$labels['layoutlist'] = 'তালিকা';
$labels['compact'] = 'টাইটকরুন';
$labels['empty'] = 'খালিকরুন';
$labels['quota'] = 'ডিস্ক এ খালি যায়গা';
$labels['unknown'] = 'অজানা';
$labels['unlimited'] = 'সীমাহীন';
$labels['quicksearch'] = 'ঝটকরে খোজা';
$labels['resetsearch'] = 'নতুনকরে খুজুন';
$labels['openinextwin'] = 'নতুন উইন্ডো তে দেখুন';
$labels['sendmessage'] = 'এখুনি মেইল / চিঠিটি পাঠান';
$labels['savemessage'] = 'খসড়া হিসাবে জমা করে রাখুন';
$labels['addattachment'] = 'একটা ফাইল জুড়ে দিন চিঠির সাথে';
$labels['charset'] = 'Charset';
$labels['editortype'] = 'Editor type';
$labels['returnreceipt'] = 'ফিরতি রসিদ';
$labels['checkspelling'] = 'Check spelling';
$labels['resumeediting'] = 'Resume editing';
$labels['revertto'] = 'Revert to';
$labels['attachments'] = 'জুড়ে দেওয়া ফাইল (Attachments)';
$labels['upload'] = 'উঠায় দেন';
$labels['close'] = 'বন্ধ করুন';
$labels['low'] = 'Low';
$labels['lowest'] = 'Lowest';
$labels['normal'] = 'Normal';
$labels['high'] = 'High';
$labels['highest'] = 'Highest';
$labels['nosubject'] = '(বিষয়হীন)';
$labels['showimages'] = 'ছবি দেখান';
$labels['alwaysshow'] = 'সবসময় $sender এর কাছে থেকে পাওয়া ছবিগুলো দেখানো হোক';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'খালি লেখা দেখুন';
$labels['savesentmessagein'] = 'পাঠানো চিঠি/মেইল জমা করুন >>';
$labels['dontsave'] = 'জমিয়ে রাখা লাগবে না';
$labels['maxuploadsize'] = 'ফাইল উঠানোর সর্বোচ্চ সাইজ $size';
$labels['addcc'] = 'অনুলিপির ঠিকানা ঢুকান';
$labels['addbcc'] = 'নাজানিয়ে অনুলিপির ঠিকানা ঢুকান';
$labels['addreplyto'] = 'উত্তর পাঠানোর ঠিকানা ঢুকান';
$labels['mdnrequest'] = 'প্রাপক আপনার কাছে মেইল/চিঠিটা যে পেয়েছেন তার ফিরতি রসিদ চেয়েছেন। আপনি কি ফিরতি রসিদ টা পাঠাবেন?';
$labels['receiptread'] = 'মেইল/চিঠি যে পেয়েছেন তার ফিরতি রসিদ';
$labels['yourmessage'] = 'নিচে রয়েছে আপনার চিঠিটা যে প্রাপক পেয়েছেন তার রসিদ';
$labels['receiptnote'] = 'এই রসিদ খালি এতটুকু প্রমান করে যে প্রাপক চিঠিটি পেয়েছেন। কিন্তু তিনি ঠিকমতো পড়তে পেরেছেন কিনা অথবা তিনি পড়ে বুঝতে পেরেছেন কিনা তার কোনো প্রমান নেই।';
$labels['name'] = 'নাম';
$labels['firstname'] = 'নামের প্রথমাংশ';
$labels['surname'] = 'নামের শেষাংশ';
$labels['email'] = 'ই-মেইল/চিঠি';
$labels['editcontact'] = 'একটা ঠিকানা বদলান';
$labels['edit'] = 'বদলান';
$labels['cancel'] = 'বাতিল';
$labels['save'] = 'জমা দিন';
$labels['delete'] = 'ফেলে দিন';
$labels['deletecontact'] = 'বেছে নেওয়া ঠিকানা গুলো ফেলে দিন';
$labels['composeto'] = 'চিঠি পাঠাবেন কার কাছে?';
$labels['contactsfromto'] = '$count ঠিকানার মধ্যে $from থেকে $to টা';
$labels['print'] = 'প্রিন্ট করুন';
$labels['export'] = 'রপ্তানি করুন';
$labels['exportvcards'] = 'রপ্তানি করুন vCard আকারে';
$labels['previouspage'] = 'আগের গুলো দেখান';
$labels['firstpage'] = 'প্রথম গুলো দেখান';
$labels['nextpage'] = 'পরের গুলো দেখান';
$labels['lastpage'] = 'শেষের গুলো দেখান';
$labels['groups'] = 'গ্রুপ';
$labels['personaladrbook'] = 'নিজের ঠিকানা';
$labels['import'] = 'আমদানি করুন';
$labels['importcontacts'] = 'ঠিকানা আমদানি করুন';
$labels['importreplace'] = 'পুরো ঠিকানার বইটি খালি করে নতুন ঠিকানা গুলো ভরুন';
$labels['done'] = 'শেষ';
$labels['settingsfor'] = 'খুটিনাটি';
$labels['preferences'] = 'পছন্দ';
$labels['userpreferences'] = 'গ্রাহক পছন্দ';
$labels['editpreferences'] = 'গ্রাহক পছন্দ বদলান';
$labels['identities'] = 'পরিচিতি';
$labels['preferhtml'] = 'HTML এ দেখি';
$labels['htmlmessage'] = 'HTML মেইল/চিঠি';
$labels['prettydate'] = 'তারিখ ভালো করে দেখা যাবে';
$labels['setdefault'] = 'এইটাই আসল';
$labels['autodetect'] = 'কম্পুটার নিজেনিজি বেছে নেবে';
$labels['language'] = 'ভাষা';
$labels['timezone'] = 'সময়ভিত্তিক এলাকা';
$labels['pagesize'] = 'প্রতি পৃষ্ঠায় লাইন সংখ্যা';
$labels['signature'] = 'স্বাক্ষর';
$labels['dstactive'] = 'Daylight saving time';
$labels['htmleditor'] = 'HTML এ মেইল/চিঠি লিখুন';
$labels['htmlsignature'] = 'HTML এ স্বাক্ষর';
$labels['previewpane'] = 'ছোটোকরে দেখার জায়গা';
$labels['skin'] = 'মেইলবক্স এর পুরোটার চেহারা';
$labels['logoutclear'] = 'বেরহবার সময় ডাস্টবিন অটোমেটিক খালি হবে';
$labels['logoutcompact'] = 'বেরহবার সময় প্রধান বাক্স অটোমেটিক টাইট হবে';
$labels['uisettings'] = 'কম্পুটারের চেহারা';
$labels['serversettings'] = 'সারভার এর খুটিনাটি';
$labels['mailboxview'] = 'মেইলবক্স দেখার কায়দা';
$labels['mdnrequests'] = 'প্রেরক নোটিশ পাঠালে কি করা হবে?';
$labels['askuser'] = 'আমি গ্রাহক, আমাকে জিজ্ঞাসা করুন';
$labels['autosend'] = 'কম্পুটার নিজেনিজি ফিরতি নোটিশ পাঠায় দেবে';
$labels['readwhendeleted'] = 'ফেলে দেবার সময় মেইল/চিঠি পড়া হয়ে গেছে হিসাবে ধরে নেওয়া হবে';
$labels['flagfordeletion'] = 'একেবারেই ফেলে না দিয়ে মেইল/চিঠি গুলোকে দাগিয়ে রাখুন ফেলে দেবার জন্যে';
$labels['skipdeleted'] = 'ফেলে দেওয়া মেইল/চিঠি দেখানোর দরকার নেই';
$labels['showremoteimages'] = 'মেইলে অন্য ওয়েবসাইট থেকে আসা ছবি থাকলে তা দেখা যাবে';
$labels['fromknownsenders'] = 'পরিচিত প্রেরক এর ক্ষেত্রে';
$labels['always'] = 'সবসময়';
$labels['showinlineimages'] = 'মেইলের সাথে জোড়া লাগানো ছবি, মেইলের নিচে দেখা যাবে';
$labels['autosavedraft'] = 'নিজেনিজি খসড়া জমা হয়ে যাবে';
$labels['everynminutes'] = 'প্রতি $n মিনিটে';
$labels['never'] = 'কখোনোই না';
$labels['messagesdisplaying'] = 'মেইল/চিঠি দেখা যাচ্ছে';
$labels['messagescomposition'] = 'মেইল/চিঠি লেখা হচ্ছে';
$labels['mimeparamfolding'] = 'জুড়ে দেওয়া জিনিষের নাম';
$labels['2231folding'] = 'Full RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Full RFC 2047 (other)';
$labels['advancedoptions'] = 'জটিল বিষয়';
$labels['focusonnewmessage'] = 'নতুন মেইল এলেই তা হাইলাইট হয়ে যাবে';
$labels['checkallfolders'] = 'সবগুলো মেইলবক্সে নতুন চিঠি খোজা হবে';
$labels['folder'] = 'ফোল্ডার/মেইলবক্স';
$labels['folders'] = 'ফোল্ডার/মেইলবক্স';
$labels['foldername'] = 'ফোল্ডার/মেইলবক্স এর নাম';
$labels['subscribed'] = 'গ্রহনকারি';
$labels['messagecount'] = 'মেইল/চিঠি';
$labels['create'] = 'প্রস্তুত করুন';
$labels['createfolder'] = 'নতুন ফোল্ডার / মেইলবক্স প্রস্তুত করুন';
$labels['managefolders'] = 'ফোল্ডার/মেইলবক্স গুলো কে গুছান';
$labels['specialfolders'] = 'বিশেষ ফোল্ডার/মেইলবক্স';
$labels['sortby'] = 'সাজান';
$labels['sortasc'] = 'কম থেকে বেশি হিসাবে সাজান';
$labels['sortdesc'] = 'বেশি থেকে কম হিসাবে সাজান';
$labels['B'] = 'বাইট';
$labels['KB'] = 'কিলোবাইট';
$labels['MB'] = 'মেগাবাইট';
$labels['GB'] = 'গিগাবাইট';
