<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Diskouez kemennoù ar merdeer evit kemennadennoù nevez';
$labels['desktop'] = 'Diskouez kemennoù ar burev evit kemennadennoù nevez';
$labels['sound'] = 'Seniñ ar son pa kemennadenn nevez';
$labels['test'] = 'Taol-arnod';
$labels['title'] = 'Kemennadenn nevez !';
$labels['body'] = 'Resevet ho p\'eus ur postel nevez';
$labels['testbody'] = 'An dra se a zo un taol arnod kemenn';
$labels['desktopdisabled'] = 'Diweredekaet eo kemennoù ar burev en ho merdeer.';
$labels['desktopunsupported'] = 'N\'eo ket skoret kemennoù ar burev gant ho merdeer.';
$labels['desktoptimeout'] = 'Serr burev kemen';
