<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

// This is a list of CSV column names specified in CSV file header
// These must be original texts used in Outlook/Thunderbird exported csv files
// Encoding UTF-8

$map = [];

// MS Outlook 2010
$map['Anniversary'] = 'anniversary';
$map['Assistant\'s Name'] = 'assistant';
$map['Assistant\'s Phone'] = 'phone:assistant';
$map['Birthday'] = 'birthday';
$map['Business City'] = 'locality:work';
$map['Business Country/Region'] = 'country:work';
$map['Business Fax'] = 'phone:workfax';
$map['Business Phone'] = 'phone:work';
$map['Business Phone 2'] = 'phone:work2';
$map['Business Postal Code'] = 'zipcode:work';
$map['Business State'] = 'region:work';
$map['Business Street'] = 'street:work';
$map['Car Phone'] = 'phone:car';
$map['Categories'] = 'groups';
$map['Company'] = 'organization';
$map['Department'] = 'department';
$map['E-mail Address'] = 'email:other';
$map['E-mail 2 Address'] = 'email:other';
$map['E-mail 3 Address'] = 'email:other';
$map['First Name'] = 'firstname';
$map['Gender'] = 'gender';
$map['Home City'] = 'locality:home';
$map['Home Country/Region'] = 'country:home';
$map['Home Fax'] = 'phone:homefax';
$map['Home Phone'] = 'phone:home';
$map['Home Phone 2'] = 'phone:home2';
$map['Home Postal Code'] = 'zipcode:home';
$map['Home State'] = 'region:home';
$map['Home Street'] = 'street:home';
$map['Job Title'] = 'jobtitle';
$map['Last Name'] = 'surname';
$map['Manager\'s Name'] = 'manager';
$map['Middle Name'] = 'middlename';
$map['Mobile Phone'] = 'phone:mobile';
$map['Notes'] = 'notes';
$map['Other City'] = 'locality:other';
$map['Other Country/Region'] = 'country:other';
$map['Other Fax'] = 'phone:other';
$map['Other Phone'] = 'phone:other';
$map['Other Postal Code'] = 'zipcode:other';
$map['Other State'] = 'region:other';
$map['Other Street'] = 'street:other';
$map['Pager'] = 'phone:pager';
$map['Primary Phone'] = 'phone:main';
$map['Spouse'] = 'spouse';
$map['Suffix'] = 'suffix';
$map['Title'] = 'prefix';
$map['Web Page'] = 'website:homepage';

// Thunderbird
$map['Birth Day'] = 'birthday-d';
$map['Birth Month'] = 'birthday-m';
$map['Birth Year'] = 'birthday-y';
$map['Display Name'] = 'name';
$map['Fax Number'] = 'phone:homefax';
$map['Home Address'] = 'street:home';
$map['Home Country'] = 'country:home';
$map['Home ZipCode'] = 'zipcode:home';
$map['Mobile Number'] = 'phone:mobile';
$map['Nickname'] = 'nickname';
$map['Organization'] = 'organization';
$map['Pager Number'] = 'phone:pager';
$map['Primary Email'] = 'email:home';
$map['Secondary Email'] = 'email:other';
$map['Web Page 1'] = 'website:homepage';
$map['Web Page 2'] = 'website:other';
$map['Work Phone'] = 'phone:work';
$map['Work Address'] = 'street:work';
$map['Work Country'] = 'country:work';
$map['Work ZipCode'] = 'zipcode:work';

// Atmail
$map['Date of Birth'] = 'birthday';
$map['Email'] = 'email:home';
$map['Home Mobile'] = 'phone:mobile';
$map['Home Zip'] = 'zipcode:home';
$map['Info'] = 'notes';
$map['User Photo'] = 'photo';
$map['URL'] = 'website:homepage';
$map['Work City'] = 'locality:work';
$map['Work Company'] = 'organization';
$map['Work Dept'] = 'department';
$map['Work Fax'] = 'phone:workfax';
$map['Work Mobile'] = 'phone:other';
$map['Work State'] = 'region:work';
$map['Work Title'] = 'jobtitle';
$map['Work Zip'] = 'zipcode:work';
$map['Group'] = 'groups';

// GMail
$map['Groups'] = 'groups';
$map['Group Membership'] = 'groups';
$map['Given Name'] = 'firstname';
$map['Additional Name'] = 'middlename';
$map['Family Name'] = 'surname';
$map['Name'] = 'name';
$map['Name Prefix'] = 'prefix';
$map['Name Suffix'] = 'suffix';

// Roundcube fields
$map['Email Home'] = 'email:home';
$map['Email Work'] = 'email:work';
$map['Email Other'] = 'email:other';
$map['Phone Video'] = 'phone:video';
$map['Maiden Name'] = 'maidenname';
$map['IM Aim'] = 'im:aim';
$map['IM Icq'] = 'im:icq';
$map['IM Jabber'] = 'im:jabber';
$map['IM Msn'] = 'im:msn';
$map['IM Skype'] = 'im:skype';
$map['IM Yahoo'] = 'im:yahoo';
$map['Website Blog'] = 'website:blog';
$map['Website Home Page'] = 'website:homepage';
$map['Website Other'] = 'website:other';
$map['Website Profile'] = 'website:profile';
$map['Website Work'] = 'website:work';
