<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['tz:utc'] = 'کاتی گەردوونیی ھاوھەنگاو';
$labels['tz:africa'] = 'ئەفریقا';
$labels['tz:africa:abidjan'] = 'ئابەجان';
$labels['tz:africa:accra'] = 'ئاکرا';
$labels['tz:africa:addis_ababa'] = 'ئەدیس ئەبابا';
$labels['tz:africa:algiers'] = 'جەزائیر';
$labels['tz:africa:asmara'] = 'ئەسمەرە';
$labels['tz:africa:bamako'] = 'باماکۆ';
$labels['tz:africa:bangui'] = 'بانگوئی';
$labels['tz:africa:banjul'] = 'بانجول';
$labels['tz:africa:bissau'] = 'بیساو';
$labels['tz:africa:blantyre'] = 'بلانتیر';
$labels['tz:africa:brazzaville'] = 'برازاڤیل';
$labels['tz:africa:bujumbura'] = 'بوجومبورە';
$labels['tz:africa:cairo'] = 'قاهیرە';
$labels['tz:africa:casablanca'] = 'کازابلانکا';
$labels['tz:africa:ceuta'] = 'کوتا';
$labels['tz:africa:conakry'] = 'کۆناکری';
$labels['tz:africa:dakar'] = 'داکار';
$labels['tz:africa:dar_es_salaam'] = 'دار ئەلسەلام';
$labels['tz:africa:djibouti'] = 'جیبووتی';
$labels['tz:africa:douala'] = 'دوالا';
$labels['tz:africa:el_aaiun'] = 'ئەلعیون';
$labels['tz:africa:freetown'] = 'فریتاون';
$labels['tz:africa:gaborone'] = 'گابۆرۆن';
$labels['tz:africa:harare'] = 'ھەرارێ';
$labels['tz:africa:johannesburg'] = 'جۆهانسبێرگ';
$labels['tz:africa:juba'] = 'جوبا';
$labels['tz:africa:kampala'] = 'کەمپالا';
$labels['tz:africa:khartoum'] = 'خەرتوم';
$labels['tz:africa:kigali'] = 'کوگالی';
$labels['tz:africa:kinshasa'] = 'کنشاسا';
$labels['tz:africa:lagos'] = 'لاگۆس';
$labels['tz:africa:libreville'] = 'لیبرێڤیل';
$labels['tz:africa:lome'] = 'لۆمێ';
$labels['tz:africa:luanda'] = 'لواندا';
$labels['tz:africa:lubumbashi'] = 'لوبومباشی';
$labels['tz:africa:lusaka'] = 'لوساکا';
$labels['tz:africa:malabo'] = 'مالابۆ';
$labels['tz:africa:maputo'] = 'ماپوتۆ';
$labels['tz:africa:maseru'] = 'مازروو';
$labels['tz:africa:mbabane'] = 'ئمبەبانێی';
$labels['tz:africa:mogadishu'] = 'مۆگادیشو';
$labels['tz:africa:monrovia'] = 'مۆنرۆڤیا';
$labels['tz:africa:nairobi'] = 'نایرۆبی';
$labels['tz:africa:ndjamena'] = 'ئنجامینا';
$labels['tz:africa:niamey'] = 'نیامی';
$labels['tz:africa:nouakchott'] = 'نواکشۆت';
$labels['tz:africa:ouagadougou'] = 'ئۆئاگادۆگۆ';
$labels['tz:africa:porto-novo'] = 'پۆرتۆ نۆڤۆ';
$labels['tz:africa:sao_tome'] = 'ساوتۆمێی';
$labels['tz:africa:tripoli'] = 'تریپۆلی';
$labels['tz:africa:tunis'] = 'توونس';
$labels['tz:africa:windhoek'] = 'ویندهوک';
$labels['tz:america'] = 'ئەمریکا';
$labels['tz:america:adak'] = 'ئەیداک';
$labels['tz:america:anchorage'] = 'ئەنکورج';
$labels['tz:america:anguilla'] = 'ئەنگویلا';
$labels['tz:america:antigua'] = 'ئەنتیگا';
$labels['tz:america:araguaina'] = 'ئەرەگوینا';
$labels['tz:america:argentina'] = 'ئەرژەنتین';
$labels['tz:america:argentina:buenos_aires'] = 'بوێنس ئایریس';
$labels['tz:america:argentina:catamarca'] = 'کاتامارکا';
$labels['tz:america:argentina:cordoba'] = 'کۆردوبا';
$labels['tz:america:argentina:jujuy'] = 'هوهوی';
$labels['tz:america:argentina:la_rioja'] = 'لا ڕیۆفا';
$labels['tz:america:argentina:mendoza'] = 'میندۆزا';
$labels['tz:america:argentina:rio_gallegos'] = 'ڕیۆ گاشێفۆس';
$labels['tz:america:argentina:salta'] = 'سەڵتا';
$labels['tz:america:argentina:san_juan'] = 'سان هوان';
$labels['tz:america:argentina:san_luis'] = 'سان لویس';
$labels['tz:america:argentina:tucuman'] = 'توکومان';
$labels['tz:america:argentina:ushuaia'] = 'ئوسوایا';
$labels['tz:america:aruba'] = 'ئەروبا';
$labels['tz:america:asuncion'] = 'ئەسنتیۆن';
$labels['tz:america:atikokan'] = 'ئەتیکۆکان';
$labels['tz:america:bahia'] = 'بەهیە';
$labels['tz:america:bahia_banderas'] = 'بەهیە بەندێراس';
$labels['tz:america:barbados'] = 'باربادۆس';
$labels['tz:america:belem'] = 'بێلوم';
$labels['tz:america:belize'] = 'بڵیز';
$labels['tz:america:blanc-sablon'] = 'بلانک سابلۆن';
$labels['tz:america:boa_vista'] = 'بۆوا ڤیستا';
$labels['tz:america:bogota'] = 'بۆگۆتا';
$labels['tz:america:boise'] = 'بۆیس';
$labels['tz:america:cambridge_bay'] = 'کامبریدج بەی';
$labels['tz:america:campo_grande'] = 'کامپۆ گراندێی';
$labels['tz:america:cancun'] = 'کانکون';
$labels['tz:america:caracas'] = 'کراکەس';
$labels['tz:america:cayenne'] = 'کاین';
$labels['tz:america:cayman'] = 'کەیمن';
$labels['tz:america:chicago'] = 'شیکاگۆ';
$labels['tz:america:chihuahua'] = 'چیواوا';
$labels['tz:america:costa_rica'] = 'کۆستاریکا';
$labels['tz:america:creston'] = 'کرێستۆن';
$labels['tz:america:cuiaba'] = 'کویبا';
$labels['tz:america:curacao'] = 'کوراساو';
$labels['tz:america:danmarkshavn'] = 'دانمارکشاڤن';
$labels['tz:america:dawson'] = 'دۆسن';
$labels['tz:america:dawson_creek'] = 'دۆسن کریک';
$labels['tz:america:denver'] = 'دێنڤەر';
$labels['tz:america:detroit'] = 'دیترۆیت';
$labels['tz:america:dominica'] = 'دۆمینیکا';
$labels['tz:america:edmonton'] = 'ئێدمنتن';
$labels['tz:america:eirunepe'] = 'ئێرنپی';
$labels['tz:america:el_salvador'] = 'ئێل سلڤادۆر';
$labels['tz:america:fort_nelson'] = 'فۆرت نیڵسن';
$labels['tz:america:fortaleza'] = 'فۆرتالێزا';
$labels['tz:america:glace_bay'] = 'گلەیس بەی';
$labels['tz:america:godthab'] = 'گۆدهاب';
$labels['tz:america:goose_bay'] = 'گووس بەی';
$labels['tz:america:grand_turk'] = 'گراند تورک';
$labels['tz:america:grenada'] = 'گرنادا';
$labels['tz:america:guadeloupe'] = 'گوادالوپ';
$labels['tz:america:guatemala'] = 'گواتیمالا';
$labels['tz:america:guayaquil'] = 'گوایەکیل';
$labels['tz:america:guyana'] = 'گوایا';
$labels['tz:america:halifax'] = 'هاڵیفاکس';
$labels['tz:america:havana'] = 'هاڤانا';
$labels['tz:america:hermosillo'] = 'ئێرمۆسیۆ';
$labels['tz:america:indiana'] = 'ئیندیانا';
$labels['tz:america:indiana:indianapolis'] = 'ئیندیانا پۆلیس';
$labels['tz:america:indiana:knox'] = 'نۆکس';
$labels['tz:america:indiana:marengo'] = 'مەرێنگۆ';
$labels['tz:america:indiana:petersburg'] = 'پیتەرسبێرگ';
$labels['tz:america:indiana:tell_city'] = 'تێڵ سیتی';
$labels['tz:america:indiana:vevay'] = 'ڤیڤای';
$labels['tz:america:indiana:vincennes'] = 'ڤانسێن';
$labels['tz:america:indiana:winamac'] = 'ویناماک';
$labels['tz:america:inuvik'] = 'ئینوڤیک';
$labels['tz:america:iqaluit'] = 'ئیکالویت';
$labels['tz:america:jamaica'] = 'جامایکا';
$labels['tz:america:juneau'] = 'جونۆو';
$labels['tz:america:kentucky'] = 'کەنتاکی';
$labels['tz:america:kentucky:louisville'] = 'لویس ڤیڵ';
$labels['tz:america:kentucky:monticello'] = 'مۆنتیچێلۆ';
$labels['tz:america:kralendijk'] = 'کرالندیجک';
$labels['tz:america:la_paz'] = 'لاپاز';
$labels['tz:america:lima'] = 'لیما';
$labels['tz:america:los_angeles'] = 'لۆس ئەنجلس';
$labels['tz:america:lower_princes'] = 'لاوەر پرینسس';
$labels['tz:america:maceio'] = 'مەسێۆ';
$labels['tz:america:managua'] = 'ماناگوا';
$labels['tz:america:manaus'] = 'ماناوس';
$labels['tz:america:marigot'] = 'ماریگۆ';
$labels['tz:america:martinique'] = 'مارتنیک';
$labels['tz:america:matamoros'] = 'مەتامۆرۆس';
$labels['tz:america:mazatlan'] = 'مەزاتلان';
$labels['tz:america:menominee'] = 'مەنامنی';
$labels['tz:america:merida'] = 'مێریدا';
$labels['tz:america:metlakatla'] = 'مەتلاکەتلا';
$labels['tz:america:mexico_city'] = 'مەکسیکۆ سیتی';
$labels['tz:america:miquelon'] = 'مکەڵان';
$labels['tz:america:moncton'] = 'مۆنکتن';
$labels['tz:america:monterrey'] = 'مۆنترای';
$labels['tz:america:montevideo'] = 'مۆنتێڤیدیۆ';
$labels['tz:america:montserrat'] = 'مۆنسێرات';
$labels['tz:america:nassau'] = 'ناساو';
$labels['tz:america:new_york'] = 'نیویۆرک';
$labels['tz:america:nipigon'] = 'نیپیگۆن';
$labels['tz:america:nome'] = 'نۆم';
$labels['tz:america:noronha'] = 'نۆرۆنها';
$labels['tz:america:north_dakota'] = 'داکۆتای باکوور';
$labels['tz:america:north_dakota:beulah'] = 'بیوڵا';
$labels['tz:america:north_dakota:center'] = 'سەنتەر';
$labels['tz:america:north_dakota:new_salem'] = 'نیو سەیلم';
$labels['tz:america:ojinaga'] = 'ئۆهیناگا';
$labels['tz:america:panama'] = 'پاناما';
$labels['tz:america:pangnirtung'] = 'پانیرتەنگ';
$labels['tz:america:paramaribo'] = 'پاراماریبۆ';
$labels['tz:america:phoenix'] = 'فینیکس';
$labels['tz:america:port-au-prince'] = 'پۆرتۆ پرینس';
$labels['tz:america:port_of_spain'] = 'پۆرت ئۆف سپەین';
$labels['tz:america:porto_velho'] = 'پۆرتۆ ڤێلۆ';
$labels['tz:america:puerto_rico'] = 'پۆرتۆ ڕیکۆ';
$labels['tz:america:rainy_river'] = 'ڕەینی ڕیڤەر';
$labels['tz:america:rankin_inlet'] = 'ڕانکین ئینلێت';
$labels['tz:america:recife'] = 'ڕەسیفی';
$labels['tz:america:regina'] = 'ڕەجینا';
$labels['tz:america:resolute'] = 'ڕێزلوت';
$labels['tz:america:rio_branco'] = 'ڕیۆ برانکۆ';
$labels['tz:america:santarem'] = 'سەنتاریم';
$labels['tz:america:santiago'] = 'سانتیاگۆ';
$labels['tz:america:santo_domingo'] = 'سانتۆ دۆمینگۆ';
$labels['tz:america:sao_paulo'] = 'ساوپاولۆ';
$labels['tz:america:scoresbysund'] = 'سکۆرس بایسەند';
$labels['tz:america:sitka'] = 'سیتکا';
$labels['tz:america:st_barthelemy'] = 'سەینت بارتێلێمی';
$labels['tz:america:st_johns'] = "سەینت جۆنس";
$labels['tz:america:st_kitts'] = 'سەینت کیتس';
$labels['tz:america:st_lucia'] = 'سەینت لوشیا';
$labels['tz:america:st_thomas'] = 'سەینت تۆماس';
$labels['tz:america:st_vincent'] = 'سەینت ڤینسنت';
$labels['tz:america:swift_current'] = 'سویفت کەڕێنت';
$labels['tz:america:tegucigalpa'] = 'تەیگوسیگالپا';
$labels['tz:america:thule'] = 'تولی';
$labels['tz:america:thunder_bay'] = 'سەندەربەی';
$labels['tz:america:tijuana'] = 'تیوانا';
$labels['tz:america:toronto'] = 'تۆرۆنتۆ';
$labels['tz:america:tortola'] = 'تۆرتۆلا';
$labels['tz:america:vancouver'] = 'ڤانکۆڤەر';
$labels['tz:america:whitehorse'] = 'وایت هۆرس';
$labels['tz:america:winnipeg'] = 'وینپیگ';
$labels['tz:america:yakutat'] = 'یاکوتات';
$labels['tz:america:yellowknife'] = 'یەلۆنایف';
$labels['tz:antarctica'] = 'ئەنتارکتیکا';
$labels['tz:antarctica:casey'] = 'کاسی';
$labels['tz:antarctica:davis'] = 'دەیڤس';
$labels['tz:antarctica:dumontdurville'] = "دومۆنت دڤیل";
$labels['tz:antarctica:macquarie'] = 'مۆکۆری';
$labels['tz:antarctica:mawson'] = 'ماوسن';
$labels['tz:antarctica:mcmurdo'] = 'مەکموردۆ';
$labels['tz:antarctica:palmer'] = 'پاڵمەر';
$labels['tz:antarctica:rothera'] = 'ڕۆزێرا';
$labels['tz:antarctica:syowa'] = 'سیوا';
$labels['tz:antarctica:troll'] = 'ترۆڵ';
$labels['tz:antarctica:vostok'] = 'ڤۆستۆک';
$labels['tz:arctic'] = 'ئارکتیک';
$labels['tz:arctic:longyearbyen'] = 'لۆنیەربێن';
$labels['tz:asia'] = 'ئاسیا';
$labels['tz:asia:aden'] = 'عەدەن';
$labels['tz:asia:almaty'] = 'ئەلماتی';
$labels['tz:asia:amman'] = 'عەمان';
$labels['tz:asia:anadyr'] = 'ئەنادر';
$labels['tz:asia:aqtau'] = 'ئەکتاو';
$labels['tz:asia:aqtobe'] = 'ئەکتۆبی';
$labels['tz:asia:ashgabat'] = 'ئاشگەبات';
$labels['tz:asia:atyrau'] = 'ئەتیراو';
$labels['tz:asia:baghdad'] = 'بەغداد';
$labels['tz:asia:bahrain'] = 'بەحرەین';
$labels['tz:asia:baku'] = 'باکو';
$labels['tz:asia:bangkok'] = 'بانگۆک';
$labels['tz:asia:barnaul'] = 'بارناڵ';
$labels['tz:asia:beirut'] = 'بەیروت';
$labels['tz:asia:bishkek'] = 'بوشکەک';
$labels['tz:asia:brunei'] = 'برونای';
$labels['tz:asia:chita'] = 'چیتا';
$labels['tz:asia:choibalsan'] = 'چۆیباڵسان';
$labels['tz:asia:colombo'] = 'کۆڵۆمبۆ';
$labels['tz:asia:damascus'] = 'دەماسکوس';
$labels['tz:asia:dhaka'] = 'دەکا';
$labels['tz:asia:dili'] = 'دیڵی';
$labels['tz:asia:dubai'] = 'دوبەی';
$labels['tz:asia:dushanbe'] = 'دوشانبێی';
$labels['tz:asia:famagusta'] = 'فاماگوستا';
$labels['tz:asia:gaza'] = 'غەزە';
$labels['tz:asia:hebron'] = 'هیبرۆن';
$labels['tz:asia:ho_chi_minh'] = 'هۆ چی مین';
$labels['tz:asia:hong_kong'] = 'هۆنگ کۆنگ';
$labels['tz:asia:hovd'] = 'هۆڤد';
$labels['tz:asia:irkutsk'] = 'ئیرکوتسکە';
$labels['tz:asia:jakarta'] = 'جاکەرتا';
$labels['tz:asia:jayapura'] = 'جایاپورا';
$labels['tz:asia:jerusalem'] = 'ئورشەلیم';
$labels['tz:asia:kabul'] = 'کابوول';
$labels['tz:asia:kamchatka'] = 'کامچاتکە';
$labels['tz:asia:karachi'] = 'کەرەچی';
$labels['tz:asia:kathmandu'] = 'کەتماندوو';
$labels['tz:asia:khandyga'] = 'هاندیگا';
$labels['tz:asia:kolkata'] = 'کەلکەتە';
$labels['tz:asia:krasnoyarsk'] = 'کرازنیاسک';
$labels['tz:asia:kuala_lumpur'] = 'کوالا لامپور';
$labels['tz:asia:kuching'] = 'کوچینگ';
$labels['tz:asia:kuwait'] = 'کوەیت';
$labels['tz:asia:macau'] = 'ماکاو';
$labels['tz:asia:magadan'] = 'ماگەدان';
$labels['tz:asia:makassar'] = 'مەکاسەر';
$labels['tz:asia:manila'] = 'مەنێڵا';
$labels['tz:asia:muscat'] = 'مەسقەت';
$labels['tz:asia:nicosia'] = 'نیکۆسیا';
$labels['tz:asia:novokuznetsk'] = 'نۆڤۆکوتزنێسک';
$labels['tz:asia:novosibirsk'] = 'نۆڤاسبرسک';
$labels['tz:asia:omsk'] = 'ئۆمسک';
$labels['tz:asia:oral'] = 'ئۆراڵ';
$labels['tz:asia:phnom_penh'] = 'پنۆم پێن';
$labels['tz:asia:pontianak'] = 'پۆنتیاناک';
$labels['tz:asia:pyongyang'] = 'پیۆنگ یانگ';
$labels['tz:asia:qatar'] = 'قەتەر';
$labels['tz:asia:qyzylorda'] = 'کیزیلۆردا';
$labels['tz:asia:riyadh'] = 'ڕیاز';
$labels['tz:asia:sakhalin'] = 'سەخالین';
$labels['tz:asia:samarkand'] = 'سەمەرقەند';
$labels['tz:asia:seoul'] = 'سیئۆل';
$labels['tz:asia:shanghai'] = 'شەنگەهای';
$labels['tz:asia:singapore'] = 'سەنگافورە';
$labels['tz:asia:srednekolymsk'] = 'سریدنکۆلیمسک';
$labels['tz:asia:taipei'] = 'تایپێ';
$labels['tz:asia:tashkent'] = 'تاشکەند';
$labels['tz:asia:tbilisi'] = 'تەبلیس';
$labels['tz:asia:tehran'] = 'تاران';
$labels['tz:asia:thimphu'] = 'تیمفوو';
$labels['tz:asia:tokyo'] = 'تۆکیۆ';
$labels['tz:asia:tomsk'] = 'تۆمسک';
$labels['tz:asia:ulaanbaatar'] = 'ئولانباتۆر';
$labels['tz:asia:urumqi'] = 'ئورومچی';
$labels['tz:asia:ust-nera'] = 'ئوست نێرا';
$labels['tz:asia:vientiane'] = 'ڤیێنتیان';
$labels['tz:asia:vladivostok'] = 'ڤلادیڤۆستۆک';
$labels['tz:asia:yakutsk'] = 'یاکوتسک';
$labels['tz:asia:yangon'] = 'یانگۆن';
$labels['tz:asia:yekaterinburg'] = 'یەکاترینبۆرگ';
$labels['tz:asia:yerevan'] = 'یەریڤان';
$labels['tz:atlantic'] = 'ئەتڵەسی';
$labels['tz:atlantic:azores'] = 'دوورگەکانی ئەزوور';
$labels['tz:atlantic:bermuda'] = 'بەرمۆدە';
$labels['tz:atlantic:canary'] = 'کەناری';
$labels['tz:atlantic:cape_verde'] = 'کەیپڤەرد';
$labels['tz:atlantic:faroe'] = 'دوورگەکانی فارۆ';
$labels['tz:atlantic:madeira'] = 'دوورگەکانی مادیرا';
$labels['tz:atlantic:reykjavik'] = 'ڕێکیاڤیک';
$labels['tz:atlantic:south_georgia'] = 'باشووری جۆرجیا';
$labels['tz:atlantic:st_helena'] = 'سەینت هێلینا';
$labels['tz:atlantic:stanley'] = 'ستانلی';
$labels['tz:australia'] = 'ئوسترالیا';
$labels['tz:australia:adelaide'] = 'ئەدێلاید';
$labels['tz:australia:brisbane'] = 'بریزبێن';
$labels['tz:australia:broken_hill'] = 'بڕۆکن هیڵ';
$labels['tz:australia:currie'] = 'کوری';
$labels['tz:australia:darwin'] = 'داروین';
$labels['tz:australia:eucla'] = 'یۆکلا';
$labels['tz:australia:hobart'] = 'هۆبارت';
$labels['tz:australia:lindeman'] = 'لیندەمان';
$labels['tz:australia:lord_howe'] = 'لۆرد هاو';
$labels['tz:australia:melbourne'] = 'مێلبۆرن';
$labels['tz:australia:perth'] = 'پێرس';
$labels['tz:australia:sydney'] = 'سیدنی';
$labels['tz:europe'] = 'ئەوروپا';
$labels['tz:europe:amsterdam'] = 'ئەمستردام';
$labels['tz:europe:andorra'] = 'ئەندۆرا';
$labels['tz:europe:astrakhan'] = 'ئەستراخان';
$labels['tz:europe:athens'] = 'ئەسینا';
$labels['tz:europe:belgrade'] = 'بێلگراد';
$labels['tz:europe:berlin'] = 'بەرلین';
$labels['tz:europe:bratislava'] = 'براتسیلاڤا';
$labels['tz:europe:brussels'] = 'برۆکسل';
$labels['tz:europe:bucharest'] = 'بوخارێست';
$labels['tz:europe:budapest'] = 'بوداپێست';
$labels['tz:europe:busingen'] = 'بۆزینگن';
$labels['tz:europe:chisinau'] = 'کیشیناو';
$labels['tz:europe:copenhagen'] = 'کۆپنهاگن';
$labels['tz:europe:dublin'] = 'دوبلین';
$labels['tz:europe:gibraltar'] = 'گیبرالتار';
$labels['tz:europe:guernsey'] = 'گەرنزی';
$labels['tz:europe:helsinki'] = 'ھێلسینکی';
$labels['tz:europe:isle_of_man'] = 'دوورگەی مان';
$labels['tz:europe:istanbul'] = 'ئیستانبوڵ';
$labels['tz:europe:jersey'] = 'جێرزی';
$labels['tz:europe:kaliningrad'] = 'کالینینگراد';
$labels['tz:europe:kiev'] = 'کیڤ';
$labels['tz:europe:kirov'] = 'کیرۆڤ';
$labels['tz:europe:lisbon'] = 'لیسبۆن';
$labels['tz:europe:ljubljana'] = 'لیوبلیانا';
$labels['tz:europe:london'] = 'لەندەن';
$labels['tz:europe:luxembourg'] = 'لوکسمبۆرگ';
$labels['tz:europe:madrid'] = 'مەدرید';
$labels['tz:europe:malta'] = 'ماڵتا';
$labels['tz:europe:mariehamn'] = 'ماریهام';
$labels['tz:europe:minsk'] = 'مینسک';
$labels['tz:europe:monaco'] = 'مۆناکۆ';
$labels['tz:europe:moscow'] = 'مۆسکۆ';
$labels['tz:europe:oslo'] = 'ئۆسلۆ';
$labels['tz:europe:paris'] = 'پاریس';
$labels['tz:europe:podgorica'] = 'پۆدگۆریتسا';
$labels['tz:europe:prague'] = 'پراگ';
$labels['tz:europe:riga'] = 'ڕیگا';
$labels['tz:europe:rome'] = 'ڕۆما';
$labels['tz:europe:samara'] = 'سەمارا';
$labels['tz:europe:san_marino'] = 'سان مارینۆ';
$labels['tz:europe:sarajevo'] = 'سارایێڤۆ';
$labels['tz:europe:saratov'] = 'ساراتۆڤ';
$labels['tz:europe:simferopol'] = 'سیمفرۆپۆڵ';
$labels['tz:europe:skopje'] = 'سکۆپیە';
$labels['tz:europe:sofia'] = 'سۆفیا';
$labels['tz:europe:stockholm'] = 'ستۆکهۆڵم';
$labels['tz:europe:tallinn'] = 'تاڵین';
$labels['tz:europe:tirane'] = 'تیرانا';
$labels['tz:europe:ulyanovsk'] = 'ئولیانۆڤسک';
$labels['tz:europe:uzhgorod'] = 'ئۆژهورود';
$labels['tz:europe:vaduz'] = 'ڤادوتس';
$labels['tz:europe:vatican'] = 'ڤاتیکان';
$labels['tz:europe:vienna'] = 'ڤیەنا';
$labels['tz:europe:vilnius'] = 'ڤیلنیوس';
$labels['tz:europe:volgograd'] = 'ڤۆڵگۆگراد';
$labels['tz:europe:warsaw'] = 'وارشۆ';
$labels['tz:europe:zagreb'] = 'زاگرێب';
$labels['tz:europe:zaporozhye'] = 'زاپرۆژیا';
$labels['tz:europe:zurich'] = 'زوریخ';
$labels['tz:indian'] = 'ھیندستان';
$labels['tz:indian:antananarivo'] = 'ئانتاناناریڤۆ';
$labels['tz:indian:chagos'] = 'چاگۆس';
$labels['tz:indian:christmas'] = 'کریسمس';
$labels['tz:indian:cocos'] = 'دوورگەکانی کۆکۆس';
$labels['tz:indian:comoro'] = 'دوورگەکانی قەمەر';
$labels['tz:indian:kerguelen'] = 'کەرگولەن';
$labels['tz:indian:mahe'] = 'ماهی';
$labels['tz:indian:maldives'] = 'ماڵدیڤ';
$labels['tz:indian:mauritius'] = 'مۆریس';
$labels['tz:indian:mayotte'] = 'مایۆت';
$labels['tz:indian:reunion'] = 'ڕیۆنیۆن';
$labels['tz:pacific'] = 'هێمن';
$labels['tz:pacific:apia'] = 'ئاپیا';
$labels['tz:pacific:auckland'] = 'ئۆکلاند';
$labels['tz:pacific:bougainville'] = 'بۆگنویڵ';
$labels['tz:pacific:chatham'] = 'چاتەم';
$labels['tz:pacific:chuuk'] = 'چوک';
$labels['tz:pacific:easter'] = 'ئیستەر';
$labels['tz:pacific:efate'] = 'ئافات';
$labels['tz:pacific:enderbury'] = 'ئەندەربۆری';
$labels['tz:pacific:fakaofo'] = 'فاکاوفو';
$labels['tz:pacific:fiji'] = 'فیجی';
$labels['tz:pacific:funafuti'] = 'فونافوتی';
$labels['tz:pacific:galapagos'] = 'دوورگەکانی گالاپاگۆس';
$labels['tz:pacific:gambier'] = 'گامبیر';
$labels['tz:pacific:guadalcanal'] = 'گوادال کەناڵ';
$labels['tz:pacific:guam'] = 'گوام';
$labels['tz:pacific:honolulu'] = 'هۆنولولو';
$labels['tz:pacific:johnston'] = 'جۆنستۆن';
$labels['tz:pacific:kiritimati'] = 'کیریتیماتی';
$labels['tz:pacific:kosrae'] = 'کۆسرای';
$labels['tz:pacific:kwajalein'] = 'کواجالین';
$labels['tz:pacific:majuro'] = 'ماجورۆ';
$labels['tz:pacific:marquesas'] = 'مارکێز';
$labels['tz:pacific:midway'] = 'میدوەی';
$labels['tz:pacific:nauru'] = 'نائووروو';
$labels['tz:pacific:niue'] = 'نیووەی';
$labels['tz:pacific:norfolk'] = 'نۆرفۆڵک';
$labels['tz:pacific:noumea'] = 'نۆمیا';
$labels['tz:pacific:pago_pago'] = 'پاگۆ پاگۆ';
$labels['tz:pacific:palau'] = 'پالاو';
$labels['tz:pacific:pitcairn'] = 'پیتکارن';
$labels['tz:pacific:pohnpei'] = 'پۆنپی';
$labels['tz:pacific:port_moresby'] = 'پۆرت مۆرسبی';
$labels['tz:pacific:rarotonga'] = 'ڕارۆتۆنگا';
$labels['tz:pacific:saipan'] = 'سایپان';
$labels['tz:pacific:tahiti'] = 'تاھیتی';
$labels['tz:pacific:tarawa'] = 'تاراوە';
$labels['tz:pacific:tongatapu'] = 'تۆنگاتاپو';
$labels['tz:pacific:wake'] = 'وەیک';
$labels['tz:pacific:wallis'] = 'واڵیس';
