<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail MarkdownEditor plugin      |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['editor_icon_alt'] = 'Edytor Markdown';
$labels['editor_button_title'] = 'Utwórz wiadomość w Markdown, która zostanie wysłana w HTMLu';
$labels['toolbar_button_quit'] = 'Powrót do edytora zwykłego tekstu';
$labels['toolbar_button_help'] = 'Otwórz dokumentację składni Markdown w nowym oknie';
$labels['toolbar_button_preview'] = 'Podgląd HTML tak jak zostanie wysałany';
$labels['toolbar_button_bold'] = 'Pogrubienie';
$labels['toolbar_button_italic'] = 'Kursywa';
$labels['toolbar_button_strike'] = 'Przekreślenie';
$labels['toolbar_button_h1'] = 'Nagłówek 1';
$labels['toolbar_button_h2'] = 'Nagłówek 2';
$labels['toolbar_button_h3'] = 'Nagłówek 3';
$labels['toolbar_button_h4'] = 'Nagłówek 4';
$labels['toolbar_button_h5'] = 'Nagłówek 5';
$labels['toolbar_button_h6'] = 'Nagłówek 6';
$labels['toolbar_button_blockquote'] = 'Blok cytatu';
$labels['toolbar_button_unordered_list'] = 'List nienumerowana';
$labels['toolbar_button_ordered_list'] = 'Lista numerowana';
$labels['toolbar_button_link'] = 'Łącze';
$labels['toolbar_button_image'] = 'Obrazek';
$labels['toolbar_button_undo'] = 'Cofnij';
$labels['toolbar_button_redo'] = 'Powtórz';
