<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Mark-As-Junk plugin        |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttonjunk'] = '這是垃圾郵件';
$labels['asjunk'] = '為垃圾郵件';
$labels['markasjunk'] = '標示為垃圾郵件';
$labels['buttonnotjunk'] = '這不是垃圾郵件';
$labels['asnotjunk'] = '為非垃圾郵件';
$labels['markasnotjunk'] = '標示為非垃圾郵件';
$labels['notjunk'] = '非垃圾郵件';
$messages['reportedasjunk'] = '已回報為垃圾郵件';
$messages['reportedasnotjunk'] = '已回報為非垃圾郵件';
