<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Шүүлтүүр';
$labels['managefilters'] = 'Ирэх мэйлийн шүүлтүүр зохицуулах';
$labels['filtername'] = 'Шүүх нэр';
$labels['newfilter'] = 'Шинэ шүүлтүүр';
$labels['filteradd'] = 'Шүүлтүүр нэмэх';
$labels['filterdel'] = 'Шүүлтүүр устгах';
$labels['moveup'] = 'Дээш зөөх';
$labels['movedown'] = 'Доош зөөх';
$labels['filterallof'] = 'Дараах дүрмүүдтэй бүгдтэй нь таарч байна';
$labels['filteranyof'] = 'дараах дүрмүүдтэй таарч байна';
$labels['filterany'] = 'бүх зурвас';
$labels['filtercontains'] = 'агуулсан';
$labels['filternotcontains'] = 'агуулаагүй';
$labels['filteris'] = 'тэнцүү';
$labels['filterisnot'] = 'нь тэнцүү биш';
$labels['filterexists'] = 'байна';
$labels['filternotexists'] = 'байхгүй';
$labels['filtermatches'] = 'таарсан';
$labels['filternotmatches'] = 'таараагүй';
$labels['filterregex'] = 'хайлтад таарсан';
$labels['filternotregex'] = 'хайлт таараагүй';
$labels['filterunder'] = 'доор';
$labels['addrule'] = 'Дүрэм нэмэх';
$labels['delrule'] = 'Дүрэм устгах';
$labels['messagemoveto'] = 'Захиа зөөх';
$labels['messageredirect'] = 'Захиаг дамжуулах';
$labels['messagecopyto'] = 'Захиа хуулж явуулах';
$labels['messagesendcopy'] = 'Захианы хуулбарыг илгээх';
$labels['messagereply'] = 'Захианд хариулах';
$labels['messagedelete'] = 'Захиа устгах';
$labels['del'] = 'Устгах';
$labels['sender'] = 'Илгээгч';
$labels['flagread'] = 'Унших';
$labels['datetest'] = 'Огноо';
$labels['spamtestequals'] = 'тэнцүү';
$labels['spamtestnotequals'] = 'нь тэнцүү биш';
$labels['vacation.subject'] = 'Гарчиг';
