<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Сподели';
$labels['myrights'] = 'Право на пристап';
$labels['username'] = 'Корисник';
$labels['advanced'] = 'Напредно ниво';
$labels['add'] = 'Додај';
$labels['newuser'] = 'Додади запис';
$labels['editperms'] = 'Уреди одобрение';
$labels['actions'] = 'Правото на пристапување';
$labels['anyone'] = 'Сите корисници (секој)';
$labels['anonymous'] = 'Гости (анонимен)';
$labels['identifier'] = 'Идентификатор';
$labels['acll'] = 'Пронајди';
$labels['aclr'] = 'Прочитај пораките';
$labels['acls'] = 'Задржи статус прегледано';
$labels['aclw'] = 'Напиши знамиња';
$labels['acli'] = 'Вметни (копирај)';
$labels['aclp'] = 'Објави';
$labels['aclc'] = 'Создај подпапка';
$labels['aclk'] = 'Креирај подпапка';
$labels['acld'] = 'Избриши пораки ';
$labels['aclt'] = 'Избриши пораки';
$labels['acle'] = 'Испразни ';
$labels['aclx'] = 'Избриши папка ';
$labels['acla'] = 'Управувај ';
$labels['acln'] = 'Коментирај пораки ';
$labels['aclfull'] = 'Целосна контрола ';
$labels['aclother'] = 'Друго ';
$labels['aclread'] = 'Читај ';
$labels['aclwrite'] = 'Пишувај ';
$labels['acldelete'] = 'Бришај ';
$labels['shortacll'] = 'Пребарувај ';
$labels['shortaclr'] = 'Чита';
$labels['shortacls'] = 'Задржи';
$labels['shortaclw'] = 'Пишивај';
$labels['shortacli'] = 'Внеси ';
$labels['shortaclp'] = 'Постирај';
$labels['shortaclc'] = 'Креирај ';
$labels['shortaclk'] = 'Создај';
$labels['shortacld'] = 'Избриши ';
$labels['shortaclt'] = 'Избриши';
$labels['shortacle'] = 'Избриши трајно ';
$labels['shortaclx'] = 'Бришај папка ';
$labels['shortacla'] = 'Управувај ';
$labels['shortacln'] = 'Дај коментар ';
$labels['shortaclother'] = 'Друго ';
$labels['shortaclread'] = 'Читај';
$labels['shortaclwrite'] = 'Пичувај';
$labels['shortacldelete'] = 'Избриши';
$labels['longacll'] = 'Папката е видлива на листите и може да се претплати на неа ';
$labels['longaclr'] = 'Папката може да се отвори за читање ';
$labels['longacls'] = 'Знамето за прегледани пораки може да се смени ';
$labels['longaclw'] = 'Знамињата за пораки и клучните зборови може да се сменат, освен прегледани и избришани';
$labels['longacli'] = 'Пораките можат да се впишаат или ископираат во папката ';
$labels['longaclp'] = 'Пораки може да бидат објавени во оваа папка';
$labels['longaclc'] = 'Папките може да се креираат (или преименуваат) директно под оваа папка ';
$labels['longaclk'] = 'Папките може да се креираат (или преименуваат) директно под оваа папка ';
$labels['longacld'] = 'Знамето за избришани пораки може да се смени';
$labels['longaclt'] = 'Знамето за избришани пораки може да се смени';
$labels['longacle'] = 'Пораките може трајно да се избришаат ';
$labels['longaclx'] = 'Папката може да се избрише или преименува ';
$labels['longacla'] = 'Правата за пристап кон папката може да бидат променети ';
$labels['longacln'] = 'Метадата (прибелешки) на споделени пораки може да се промени ';
$labels['longaclfull'] = 'Целосна контрола вклучувајќи и администрација на папка ';
$labels['longaclread'] = 'Папката може да биде отворена за читање ';
$labels['longaclwrite'] = 'Пораките може да бидат штиклирани, запишани или копирани во папката ';
$labels['longacldelete'] = 'Пораките може да бидат избришани ';
$labels['longaclother'] = 'Други правила за пристап ';
$labels['ariasummaryacltable'] = 'Листа од правила за пристап ';
$labels['arialabelaclactions'] = 'Листа на акции ';
$labels['arialabelaclform'] = 'Форма за правила на пристап ';
$messages['deleting'] = 'Бришење на правата за пристап ';
$messages['saving'] = 'Зачувување на правата за пристап ';
$messages['updatesuccess'] = 'Успешно променети правила на пристап ';
$messages['deletesuccess'] = 'Успешно избришани правила на пристап';
$messages['createsuccess'] = 'Успешно додадени правила на пристап';
$messages['updateerror'] = 'Не може да се ажурират правата за пристап';
$messages['deleteerror'] = 'Не може да се избришаат правата за пристап';
$messages['createerror'] = 'Не може да се додадат правата за пристап';
$messages['deleteconfirm'] = 'Дали сте сигурни дека сакате да ги тргнете правата за пристап на избраниот корисник(ци)? ';
$messages['norights'] = 'Нема наведени права! ';
$messages['nouser'] = 'Нема неведено корисничко име! ';
