<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = 'Selamat datang di $product';
$labels['username'] = 'Username';
$labels['password'] = 'Password';
$labels['server'] = 'Server';
$labels['login'] = 'Masuk';
$labels['oauthlogin'] = 'Log masuk dengan $provider';
$labels['menu'] = 'Menu';
$labels['logout'] = 'Keluar';
$labels['mail'] = 'E-Mail';
$labels['settings'] = 'Pengaturan';
$labels['addressbook'] = 'Buku Alamat';
$labels['darkmode'] = 'Mode gelap';
$labels['lightmode'] = 'Mode terang';
$labels['inbox'] = 'Kotak Masuk';
$labels['drafts'] = 'Konsep';
$labels['sent'] = 'Terkirim';
$labels['trash'] = 'Surat Terhapus';
$labels['junk'] = 'Sampah';
$labels['show_real_foldernames'] = 'Tampilkan nama asli untuk folder spesial';
$labels['subject'] = 'Judul';
$labels['from'] = 'Pengirim';
$labels['sender'] = 'Pengirim';
$labels['to'] = 'Penerima';
$labels['cc'] = 'Lampiran';
$labels['bcc'] = 'Lampiran tersembunyi';
$labels['replyto'] = 'Balas kepada';
$labels['followupto'] = 'Surat Tindak Lanjut Untuk';
$labels['date'] = 'Tanggal';
$labels['size'] = 'Ukuran';
$labels['priority'] = 'Prioritas';
$labels['organization'] = 'Organisasi';
$labels['readstatus'] = 'Status Terbaca';
$labels['listoptions'] = 'Daftar Pilihan...';
$labels['listoptionstitle'] = 'Opsi daftar';
$labels['mailboxlist'] = 'Semua Folder';
$labels['messagesfromto'] = 'Pesan dari $from sampai $to dari total $count';
$labels['threadsfromto'] = 'Untaian dari $from sampai $to dari total $count';
$labels['messagenrof'] = 'Pesan $nr dari total $count';
$labels['fromtoshort'] = '$from - $to dari total $count';
$labels['copy'] = 'Salin';
$labels['move'] = 'Pindahkan';
$labels['moveto'] = 'Pindahkan ke...';
$labels['copyto'] = 'Salin ke...';
$labels['download'] = 'Unduh';
$labels['open'] = 'Buka';
$labels['showattachment'] = 'Tampilkan';
$labels['showanyway'] = 'Tampilkan saja';
$labels['filename'] = 'Nama berkas';
$labels['filesize'] = 'Ukuran berkas';
$labels['addtoaddressbook'] = 'Tambah ke buku alamat';
$labels['sun'] = 'Min';
$labels['mon'] = 'Sen';
$labels['tue'] = 'Sel';
$labels['wed'] = 'Rab';
$labels['thu'] = 'Kam';
$labels['fri'] = 'Jum';
$labels['sat'] = 'Sab';
$labels['sunday'] = 'Minggu';
$labels['monday'] = 'Senin';
$labels['tuesday'] = 'Selasa';
$labels['wednesday'] = 'Rabu';
$labels['thursday'] = 'Kamis';
$labels['friday'] = 'Jumat';
$labels['saturday'] = 'Sabtu';
$labels['jan'] = 'Jan';
$labels['feb'] = 'Feb';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Apr';
$labels['may'] = 'Mei';
$labels['jun'] = 'Jun';
$labels['jul'] = 'Jul';
$labels['aug'] = 'Ags';
$labels['sep'] = 'Sep';
$labels['oct'] = 'Okt';
$labels['nov'] = 'Nov';
$labels['dec'] = 'Des';
$labels['longjan'] = 'Januari';
$labels['longfeb'] = 'Februari';
$labels['longmar'] = 'Maret';
$labels['longapr'] = 'April';
$labels['longmay'] = 'Mei';
$labels['longjun'] = 'Juni';
$labels['longjul'] = 'Juli';
$labels['longaug'] = 'Agustus';
$labels['longsep'] = 'Spetember';
$labels['longoct'] = 'Oktober';
$labels['longnov'] = 'November';
$labels['longdec'] = 'Desember';
$labels['today'] = 'Hari ini';
$labels['refresh'] = 'Segarkan';
$labels['checkmail'] = 'Periksa pesan baru';
$labels['compose'] = 'Tulis sebuah pesan';
$labels['writenewmessage'] = 'Buat pesan baru';
$labels['reply'] = 'Balas';
$labels['replytomessage'] = 'Balas ke pengirim';
$labels['replytoallmessage'] = 'Balas ke pengirim dan yang lain';
$labels['replyall'] = 'Balas ke semua';
$labels['replylist'] = 'Balas ke milis';
$labels['forward'] = 'Teruskan';
$labels['forwardinline'] = 'Teruskan bersama surat';
$labels['forwardattachment'] = 'Teruskan sebagai sisipan';
$labels['forwardmessage'] = 'Teruskan pesan';
$labels['bouncemsg'] = 'Kirim ulang (bounce)';
$labels['bounce'] = 'Kirim ulang';
$labels['deletemessage'] = 'Hapus pesan';
$labels['undeletemessage'] = 'Batal hapus pesan';
$labels['movemessagetotrash'] = 'Pindahkan pesan ke tong sampah';
$labels['printmessage'] = 'Cetak pesan ini';
$labels['previousmessage'] = 'Perlihatkan pesan sebelumnya';
$labels['firstmessage'] = 'Perlihatkan pesan pertama';
$labels['nextmessage'] = 'Perlihatkan pesan berikutnya';
$labels['lastmessage'] = 'Perlihatkan pesan terakhir';
$labels['backtolist'] = 'Kembali ke daftar pesan';
$labels['viewsource'] = 'Perlihatkan kode sumber';
$labels['mark'] = 'Tandai';
$labels['markmessages'] = 'Tandai Pesan';
$labels['markread'] = 'Terbaca';
$labels['markunread'] = 'Belum Terbaca';
$labels['markflagged'] = 'Sudah ditandai';
$labels['markunflagged'] = 'Belum ditandai';
$labels['markundeleted'] = 'Sebagai tidak dihapus';
$labels['markasread'] = 'Tandai sebagai telah dibaca';
$labels['markasunread'] = 'Tandai sebagai belum dibaca';
$labels['markasflagged'] = 'Jadikan ditandai';
$labels['markasunflagged'] = 'Jadikan tidak ditandai';
$labels['moreactions'] = 'Tindakan lain..';
$labels['markallread'] = 'Tandai semua telah dibaca';
$labels['folders-cur'] = 'Hanya pilih folder';
$labels['folders-sub'] = 'Pilih folder dan subfoldernya';
$labels['folders-all'] = 'Semua folder';
$labels['more'] = 'Berikutnya';
$labels['back'] = 'Kembali';
$labels['options'] = 'Pilihan';
$labels['composeoptions'] = 'Opsi penyusunan pesan';
$labels['optionsandattachments'] = 'Opsi dan lampiran';
$labels['actions'] = 'Tindakan';
$labels['first'] = 'Pertama';
$labels['last'] = 'Terakhir';
$labels['previous'] = 'Sebelumnya';
$labels['next'] = 'Selanjutnya';
$labels['select'] = 'Pilih';
$labels['selection'] = 'Pemilihan';
$labels['all'] = 'Semua';
$labels['none'] = 'Tidak ada';
$labels['currpage'] = 'Halaman sekarang';
$labels['isread'] = 'Baca';
$labels['unread'] = 'Belum terbaca';
$labels['flagged'] = 'Ditandai';
$labels['unflagged'] = 'Tidak ditandai';
$labels['unanswered'] = 'Belum terjawab';
$labels['withattachment'] = 'Dengan lampiran';
$labels['deleted'] = 'Terhapus';
$labels['undeleted'] = 'Tidak terhapus';
$labels['replied'] = 'Sudah dibalas';
$labels['forwarded'] = 'Diteruskan';
$labels['invert'] = 'Sebaliknya';
$labels['filter'] = 'Penyaringan';
$labels['list'] = 'Daftar';
$labels['threads'] = 'Untaian';
$labels['expand-all'] = 'Bentangkan Semua';
$labels['expand-unread'] = 'Bentangkan yang Belum Terbaca';
$labels['collapse-all'] = 'Lipat Semua';
$labels['threaded'] = 'Teruntai';
$labels['showunread'] = 'Tampilkan pesan yang belum dibaca';
$labels['autoexpand_threads'] = 'Bentangkan pesan teruntai';
$labels['do_expand'] = 'semua untaian';
$labels['expand_only_unread'] = 'hanya pesan yang belum terbaca';
$labels['fromto'] = 'Pengirim/Penerima';
$labels['flag'] = 'Bendera';
$labels['attachment'] = 'Lampiran';
$labels['nonesort'] = 'Tidak ada';
$labels['sentdate'] = 'Tanggal kirim';
$labels['arrival'] = 'Tanggal masuk';
$labels['asc'] = 'menaik';
$labels['desc'] = 'menurun';
$labels['listcolumns'] = 'Perlihatkan kolom';
$labels['listsorting'] = 'Mengurutkan kolom';
$labels['listorder'] = 'Mengurutkan susunan';
$labels['listmode'] = 'Perlihatkan mode tinjauan';
$labels['lmode'] = 'Mode daftar';
$labels['layout'] = 'Tata Letak';
$labels['layoutwidescreen'] = 'Layar Lebar';
$labels['layoutdesktop'] = 'Desktop';
$labels['layoutlist'] = 'Daftar';
$labels['layoutwidescreendesc'] = 'Layar lebar (tilikan 3 kolom)';
$labels['layoutdesktopdesc'] = 'Desktop (daftar lebar dan pratinjau surat di bawah)';
$labels['layoutlistdesc'] = 'Daftar (tanpa pratinjau surat)';
$labels['folderactions'] = 'Tindakan pada folder...';
$labels['compact'] = 'Rampingkan';
$labels['empty'] = 'Kosong';
$labels['importmessages'] = 'Impor pesan';
$labels['mailimportdesc'] = 'Anda dapat mengunggah surat memakai berkas dalam format <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> atau <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a>.';
$labels['quota'] = 'Penggunaan ruang';
$labels['unknown'] = 'Tidak dikenal';
$labels['unlimited'] = 'Tidak terbatas';
$labels['quotatype'] = 'Tipe kuota';
$labels['quotatotal'] = 'Batas';
$labels['quotaused'] = 'Dipakai';
$labels['quotastorage'] = 'Ruang disk';
$labels['quotamessage'] = 'Cacah pesan';
$labels['quicksearch'] = 'Pencarian cepat';
$labels['resetsearch'] = 'Atur ulang pencarian';
$labels['searchmod'] = 'Peubah pencarian';
$labels['msgtext'] = 'Seluruh pesan';
$labels['body'] = 'Badan';
$labels['type'] = 'Tipe';
$labels['namex'] = 'Nama';
$labels['searchscope'] = 'Jangkauan';
$labels['currentfolder'] = 'Folder sekarang';
$labels['subfolders'] = 'Ini adalah subfolder';
$labels['allfolders'] = 'Semua folder';
$labels['searchinterval-1W'] = 'lebih dari seminggu';
$labels['searchinterval-1M'] = 'lebih dari sebulan';
$labels['searchinterval-1Y'] = 'lebih dari setahun';
$labels['searchinterval1W'] = 'kurang dari seminggu';
$labels['searchinterval1M'] = 'kurang dari sebulan';
$labels['searchinterval1Y'] = 'kurang dari setahun';
$labels['openinextwin'] = 'Buka dalam jendela baru';
$labels['emlsave'] = 'Unduh (.eml)';
$labels['changeformattext'] = 'Tampilkan dalam format text biasa';
$labels['changeformathtml'] = 'Tampilkan dalam format HTML';
$labels['editasnew'] = 'Sunting sebagai pesan baru';
$labels['send'] = 'Kirim';
$labels['sendmessage'] = 'Kirim pesan';
$labels['savemessage'] = 'Simpan sebagai konsep';
$labels['addattachment'] = 'Sisipkan sebuah berkas';
$labels['charset'] = 'Set karakter';
$labels['editortype'] = 'Tipe penyunting';
$labels['returnreceipt'] = 'Tanda terima kembali';
$labels['dsn'] = 'Pemberitahuan status terkirim';
$labels['mailreplyintro'] = 'Pada $date, $sender menulis:';
$labels['originalmessage'] = 'Pesan Asli';
$labels['selectimage'] = 'Pilih gambar';
$labels['addimage'] = 'Tambah gambar';
$labels['selectmedia'] = 'Pilih film';
$labels['addmedia'] = 'Tambah film';
$labels['encrypt'] = 'Enkripsi';
$labels['encryptmessage'] = 'Enkripsi pesan';
$labels['encryptmessagemailvelope'] = 'Enkripsi pesan dengan Mailvelope';
$labels['importpubkeys'] = 'Impor kunci publik';
$labels['encryptedsendialog'] = 'Mengirim pesan terenkripsi';
$labels['keyid'] = 'ID Kunci';
$labels['keylength'] = 'Bit';
$labels['keyexpired'] = 'Kedaluarsa';
$labels['keyrevoked'] = 'Dicabut';
$labels['bccinstead'] = 'Gunakan Bcc';
$labels['insert'] = 'Sisipkan';
$labels['recipient'] = 'Penerima';
$labels['editidents'] = 'Ubah identitas';
$labels['spellcheck'] = 'Ejaan';
$labels['checkspelling'] = 'Pemeriksaan ejaan';
$labels['resumeediting'] = 'Lanjutkan menyunting';
$labels['revertto'] = 'Kembalikan ke';
$labels['restore'] = 'Kembalikan';
$labels['restoremessage'] = 'Kembalikan pesan ?';
$labels['ignore'] = 'Abaikan';
$labels['responses'] = 'Respon';
$labels['insertresponse'] = 'Masukkan respon';
$labels['manageresponses'] = 'Atur respon';
$labels['newresponse'] = 'Buat respon baru';
$labels['addresponse'] = 'Tambah respon';
$labels['editresponse'] = 'Ubah respon';
$labels['editresponses'] = 'Ubah respon';
$labels['responsename'] = 'Nama';
$labels['responsetext'] = 'Teks Respon';
$labels['attach'] = 'Lampirkan';
$labels['attachments'] = 'Sisipan';
$labels['upload'] = 'Unggah';
$labels['uploadprogress'] = '$percent ($current dari $total)';
$labels['close'] = 'Tutup';
$labels['messageoptions'] = 'Pilihan pesan...';
$labels['togglecomposeoptions'] = 'Jungkitkan opsi penyusunan';
$labels['attachmentrename'] = 'Ubah nama lampiran';
$labels['low'] = 'Rendah';
$labels['lowest'] = 'Paling Rendah';
$labels['normal'] = 'Normal';
$labels['high'] = 'Tinggi';
$labels['highest'] = 'Paling tinggi';
$labels['nosubject'] = '(tanpa judul)';
$labels['showimages'] = 'Tampilkan gambar';
$labels['alwaysshow'] = 'Selalu tampilkan gambar dari $sender';
$labels['isdraft'] = 'Ini adalah konsep surat.';
$labels['andnmore'] = '$nr lagi...';
$labels['togglemoreheaders'] = 'Tampilkan kepala pesan lebih lanjut';
$labels['togglefullheaders'] = 'Beralih kepala pesan penuh';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Teks murni';
$labels['savesentmessagein'] = 'Simpan pesan terkirim di';
$labels['dontsave'] = 'Jangan disimpan';
$labels['maxuploadsize'] = 'Ukuran file maksimal adalah $size';
$labels['addcc'] = 'Tambah Cc';
$labels['addbcc'] = 'Tambah Bcc';
$labels['addreplyto'] = 'Tambah Balas Ke';
$labels['addfollowupto'] = 'Tambahkan Tindak-Lanjut-Ke';
$labels['mdnrequest'] = 'Pengirim pesan ini telah meminta untuk diberitahu ketika Anda membaca pesan ini. Apakah anda ingin memberitahu pengirim?';
$labels['receiptread'] = 'Tanda Terima (baca)';
$labels['yourmessage'] = 'Ini adalah Tanda Terima untuk pesan Anda';
$labels['receiptnote'] = 'Catatan: Tanda Terima ini hanya mengesahkan bahwa pesan telah diperlihatkan pada komputer penerima. Tidak ada jaminan bahwa penerima telah membaca atau mengerti isi pesan.';
$labels['name'] = 'Nama yang ditampilkan';
$labels['firstname'] = 'Nama depan';
$labels['surname'] = 'Nama belakang';
$labels['middlename'] = 'Nama tengah';
$labels['nameprefix'] = 'awalan';
$labels['namesuffix'] = 'sisipan';
$labels['nickname'] = 'nama panggilan';
$labels['jobtitle'] = 'Jabatan';
$labels['department'] = 'Departemen';
$labels['gender'] = 'Jenis kelamin';
$labels['maidenname'] = 'Nama asli';
$labels['email'] = 'E-Mail';
$labels['phone'] = 'Telepon';
$labels['address'] = 'Alamat';
$labels['street'] = 'Jalan';
$labels['locality'] = 'Kota';
$labels['zipcode'] = 'Kode pos';
$labels['region'] = 'Provinsi';
$labels['country'] = 'Negara';
$labels['birthday'] = 'Tanggal lahir';
$labels['anniversary'] = 'Hari jadi';
$labels['website'] = 'Laman web';
$labels['instantmessenger'] = 'IM';
$labels['notes'] = 'Catatan';
$labels['male'] = 'pria';
$labels['female'] = 'wanita';
$labels['manager'] = 'Menejer';
$labels['assistant'] = 'Asisten';
$labels['spouse'] = 'Suami/Istri';
$labels['allfields'] = 'Semua isian';
$labels['search'] = 'Cari';
$labels['searchresult'] = 'Hasil pencarian';
$labels['advsearch'] = 'Pencarian Lebih Lanjut';
$labels['advanced'] = 'Tingkat lanjut';
$labels['other'] = 'Lainnya';
$labels['printcontact'] = 'Cetak kontak';
$labels['qrcode'] = 'Kode QR';
$labels['typehome'] = 'Rumah';
$labels['typework'] = 'Kantor';
$labels['typeother'] = 'Lainnya';
$labels['typemobile'] = 'HP';
$labels['typemain'] = 'Utama';
$labels['typehomefax'] = 'Faks Rumah';
$labels['typeworkfax'] = 'Faks Kantor';
$labels['typecar'] = 'Mobil';
$labels['typepager'] = 'Pejer';
$labels['typevideo'] = 'Video';
$labels['typeassistant'] = 'Asisten';
$labels['typehomepage'] = 'Laman Web';
$labels['typeblog'] = 'Blog';
$labels['typeprofile'] = 'Profil';
$labels['addfield'] = 'Tambah kolom isian';
$labels['addcontact'] = 'Tambah kontak';
$labels['editcontact'] = 'Ubah kontak';
$labels['contacts'] = 'Daftar kontak';
$labels['contactproperties'] = 'Properti kontak';
$labels['contactnameandorg'] = 'Nama dan Organisasi';
$labels['personalinfo'] = 'Informasi pribadi';
$labels['personal'] = 'Pribadi';
$labels['contactphoto'] = 'Foto kontak';
$labels['edit'] = 'Ubah';
$labels['cancel'] = 'Batal';
$labels['save'] = 'Simpan';
$labels['delete'] = 'Hapus';
$labels['discard'] = 'Buang';
$labels['ok'] = 'OK';
$labels['rename'] = 'Ganti nama';
$labels['addphoto'] = 'Tambah';
$labels['replacephoto'] = 'Ganti';
$labels['uploadphoto'] = 'Unggah foto';
$labels['newcontact'] = 'Buat kontak baru';
$labels['deletecontact'] = 'Hapus kontak terpilih';
$labels['composeto'] = 'Tulis surat kepada';
$labels['contactsfromto'] = 'Kontak $from sampai $to dari total $count';
$labels['print'] = 'Cetak';
$labels['export'] = 'Ekspor';
$labels['exportall'] = 'Ekspor semua';
$labels['exportsel'] = 'Ekspor pilihan';
$labels['exportvcards'] = 'Ekspor kontak dalam format vCard';
$labels['newgroup'] = 'Buat grup baru';
$labels['addgroup'] = 'Tambah grup';
$labels['grouprename'] = 'Ganti nama grup';
$labels['groupdelete'] = 'Hapus grup';
$labels['groupremoveselected'] = 'Hapus kontak terpilih dari grup';
$labels['uponelevel'] = 'Naik satu tingkat';
$labels['previouspage'] = 'Perlihatkan himpunan sebelumnya';
$labels['firstpage'] = 'Perlihatkan himpunan pertama';
$labels['nextpage'] = 'Perlihatkan himpunan selanjutnya';
$labels['lastpage'] = 'Perlihatkan himpunan terakhir';
$labels['group'] = 'Kelompok';
$labels['groups'] = 'Kelompok';
$labels['listgroup'] = 'Daftar anggota grup';
$labels['personaladrbook'] = 'Alamat pribadi';
$labels['searchsave'] = 'Simpan pencarian';
$labels['searchdelete'] = 'Hapus pencarian';
$labels['import'] = 'Impor';
$labels['importcontacts'] = 'Impor kontak';
$labels['importfromfile'] = 'Impor dari berkas';
$labels['importtarget'] = 'Tambah kontak ke';
$labels['importreplace'] = 'Ganti seluruh buku alamat';
$labels['importgroups'] = 'Impor pengaturan grup';
$labels['importgroupsall'] = 'Semua (buat grup jika diperlukan)';
$labels['importgroupsexisting'] = 'Hanya untuk grup yang telah ada';
$labels['done'] = 'Selesai';
$labels['settingsfor'] = 'Pengaturan untuk';
$labels['about'] = 'Informasi program';
$labels['preferences'] = 'Pilihan';
$labels['userpreferences'] = 'Pilihan pengguna';
$labels['editpreferences'] = 'Ubah pilihan pengguna';
$labels['identities'] = 'Identitas';
$labels['manageidentities'] = 'Kelola identitas';
$labels['newidentity'] = 'Buat identitas baru';
$labels['addidentity'] = 'Tambah identitas';
$labels['editidentity'] = 'Sunting identitas';
$labels['identityencryption'] = 'Enkripsi';
$labels['preferhtml'] = 'Lebih suka HTML';
$labels['defaultcharset'] = 'Default Character';
$labels['htmlmessage'] = 'Pesan HTML';
$labels['messagepart'] = 'Bagian';
$labels['digitalsig'] = 'Tanda tangan digital';
$labels['dateformat'] = 'Format tanggal';
$labels['timeformat'] = 'Format waktu';
$labels['prettydate'] = 'Tanggal Cantik';
$labels['setdefault'] = 'Pengaturan Awal';
$labels['autodetect'] = 'Otomatis';
$labels['language'] = 'Bahasa';
$labels['timezone'] = 'Daerah Waktu';
$labels['pagesize'] = 'Baris per halaman';
$labels['signature'] = 'Tanda tangan';
$labels['dstactive'] = 'Waktu Musim Panas';
$labels['showinextwin'] = 'Buka pesan di jendela baru';
$labels['composeextwin'] = 'Buat pesan di jendela baru';
$labels['htmleditor'] = 'Tulis pesan HTML';
$labels['htmlonreply'] = 'balasan untuk pesan HTML saja';
$labels['htmlonreplyandforward'] = 'ketika meneruskan atau membalas pesan HTML';
$labels['htmlsignature'] = 'Tandatangan HTML';
$labels['showemail'] = 'Tampilkan alamat email dengan nama';
$labels['previewpane'] = 'Unjuk pratinjau';
$labels['skin'] = 'Tampilan antarmuka';
$labels['logoutclear'] = 'Bersihkan Tong Sampah saat keluar';
$labels['logoutcompact'] = 'Mampatkan Kotak Masuk saat keluar';
$labels['uisettings'] = 'Antarmuka pengguna';
$labels['serversettings'] = 'Pengaturan Server';
$labels['mailboxview'] = 'Tampilan Kotak Surat';
$labels['mdnrequests'] = 'Sedang dimintakan tanda terima kembali';
$labels['askuser'] = 'tanya pengguna';
$labels['autosend'] = 'kirim otomatis';
$labels['autosendknown'] = 'kirim tanda terima kepada kontak saya, selain itu tanyai saya';
$labels['autosendknownignore'] = 'kirim tanda terima kepada kontak saya, selain acuhkan';
$labels['ignorerequest'] = 'abaikan permintaan';
$labels['readwhendeleted'] = 'Tandai pesan sebagai terbaca saat dihapus';
$labels['flagfordeletion'] = 'Tandai pesan untuk penghapusan daripada dihapus';
$labels['skipdeleted'] = 'Jangan tampilkan pesan terhapus';
$labels['deletealways'] = 'Jika gagal memindakan ke tempat sampah, langsung hapus';
$labels['deletejunk'] = 'Langsung hapus pesan di kotak sampah';
$labels['showremoteimages'] = 'Tampilkan remote inline images';
$labels['fromknownsenders'] = 'dari pengirim yang dikenal';
$labels['always'] = 'selalu';
$labels['alwaysbutplain'] = 'selalu, kecuali saat membalas ke teks polos';
$labels['showinlineimages'] = 'Tampilkan gambar terlampir dibawah pesan';
$labels['autosavedraft'] = 'Otomatis menyimpan konsep';
$labels['everynminutes'] = 'setiap $n menit';
$labels['refreshinterval'] = 'Refresh (memeriksa pesan baru, dsb)';
$labels['never'] = 'tidak pernah';
$labels['immediately'] = 'secepatnya';
$labels['messagesdisplaying'] = 'Penampilan Pesan';
$labels['messagescomposition'] = 'Pengaturan Pesan';
$labels['mimeparamfolding'] = 'Nama lampiran';
$labels['2231folding'] = 'Full RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Full RFC 2047 (other)';
$labels['force7bit'] = 'Gunakan MIME encoding untuk karakter 8-bit';
$labels['savelocalstorage'] = "Simpan dalam penyimpanan lokal peramban (secara sementara)";
$labels['advancedoptions'] = 'Pilihan lanjut';
$labels['toggleadvancedoptions'] = 'Jungkitkan opsi tingkat lanjut';
$labels['focusonnewmessage'] = 'Pusatkan jendela broswer saat ada pesan baru';
$labels['checkallfolders'] = 'Periksa semua folder untuk pesan baru';
$labels['displaynext'] = 'Tampilkan entri daftar selanjutnya setelah menghapus/memindah';
$labels['defaultfont'] = 'Huruf standar untuk pesan HTML';
$labels['mainoptions'] = 'Pilihan Utama';
$labels['browseroptions'] = 'Pilihan peramban web';
$labels['section'] = 'Bagian';
$labels['maintenance'] = 'Perbaikan';
$labels['newmessage'] = 'Pesan baru';
$labels['signatureoptions'] = 'Opsi tanda tangan';
$labels['whenreplying'] = 'Ketika membalas';
$labels['replyempty'] = 'jangan kutip pesan asli';
$labels['replytopposting'] = 'Tulis pesan baru diatas pesan asli';
$labels['replytoppostingnoindent'] = 'mulai pesan baru di atas tanda kutip (tanpa indentasi)';
$labels['replybottomposting'] = 'Tulis pesan baru dibawah pesan asli';
$labels['replyremovesignature'] = 'ketika membalas pesan hapus tanda tangan dari pesan';
$labels['autoaddsignature'] = 'Otomatis tambahkan tanda tangan';
$labels['newmessageonly'] = 'Hanya untuk pesan baru';
$labels['replyandforwardonly'] = 'Hanya untuk dijawab dan diteruskan';
$labels['insertsignature'] = 'Isi tanda tangan';
$labels['sigbelow'] = 'Tempatkan tanda tangan di bawah pesan yang dikutip';
$labels['sigseparator'] = 'Paksakan pemisah standar dalam tanda tangan';
$labels['afternseconds'] = 'setelah $n detik';
$labels['reqmdn'] = 'Selalu meminta tanda terima kembali';
$labels['reqdsn'] = 'Selalu meminta pemberitahuan status terkirim';
$labels['replysamefolder'] = 'Taruh balasan di folder yang sama dengan pesan yang dibalas';
$labels['defaultabook'] = 'Buku alamat utama';
$labels['autocompletesingle'] = 'Lewatkan alamat email alternatif pada pelengkapan otomatis';
$labels['listnamedisplay'] = 'Daftar kontak sebagai';
$labels['spellcheckbeforesend'] = 'Periksa ejaan sebelum mengirimkan pesan';
$labels['spellcheckoptions'] = 'Pilihan Ejaan';
$labels['spellcheckignoresyms'] = 'Abaikan kata-kata yang bersimbol';
$labels['spellcheckignorenums'] = 'Abaikan kata-kata yang bernomor';
$labels['spellcheckignorecaps'] = 'Abaikan kata-kata dengan huruf besar semua';
$labels['addtodict'] = 'Tambahkan ke kamus';
$labels['mailtoprotohandler'] = 'Daftarkan pengampu protokol untuk link mailto:';
$labels['standardwindows'] = 'Kelola popup sebagai standar window';
$labels['forwardmode'] = 'Meneruskan pesan';
$labels['inline'] = 'dalam surat';
$labels['asattachment'] = 'sebagai sisipan';
$labels['replyallmode'] = 'Aksi dasar dari tombol [Jawab semua]';
$labels['replyalldefault'] = 'jawab ke semua';
$labels['replyalllist'] = 'jawab hanya ke daftar alamat email (jika ditemukan)';
$labels['allmessages'] = 'semua pesan';
$labels['folder'] = 'Folder';
$labels['folders'] = 'Semua Folder';
$labels['foldername'] = 'Nama folder';
$labels['subscribed'] = 'Subscribed';
$labels['messagecount'] = 'Pesan-pesan';
$labels['create'] = 'Buat';
$labels['createfolder'] = 'Buat folder baru';
$labels['managefolders'] = 'Atur folder';
$labels['specialfolders'] = 'Folder Khusus';
$labels['properties'] = 'Atribut';
$labels['folderproperties'] = 'Atribut folder';
$labels['parentfolder'] = 'Folder induk';
$labels['location'] = 'Lokasi';
$labels['info'] = 'Informasi';
$labels['getfoldersize'] = 'Klik untuk mendapatkan ukuran folder';
$labels['changesubscription'] = 'Klik untuk mengubah langganan';
$labels['foldertype'] = 'Jenis folder';
$labels['personalfolder'] = 'Folder pribadi';
$labels['otherfolder'] = 'Folder pengguna lain';
$labels['sharedfolder'] = 'Folder publik';
$labels['findfolders'] = 'Cari folder';
$labels['namespace.personal'] = 'Pribadi';
$labels['namespace.other'] = 'Pengguna lain';
$labels['namespace.shared'] = 'Bersama';
$labels['encryptioncreatekey'] = 'Buat pasangan kunci baru';
$labels['encryption'] = 'Enkripsi';
$labels['sortby'] = 'Urut berdasarkan';
$labels['sortasc'] = 'Urut menaik';
$labels['sortdesc'] = 'Urut menurun';
$labels['undo'] = 'Batalkan';
$labels['installedplugins'] = 'Plugin terpasang';
$labels['plugin'] = 'Pengaya';
$labels['version'] = 'Versi';
$labels['source'] = 'Sumber';
$labels['license'] = 'Lisensi';
$labels['support'] = 'Dukungan';
$labels['dateformatY'] = 'YYYY';
$labels['dateformaty'] = 'YY';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Inggris';
$labels['westerneuropean'] = 'Eropa Barat';
$labels['easterneuropean'] = 'Eropa Timur';
$labels['southeasterneuropean'] = 'Eropa Tenggara';
$labels['baltic'] = 'Balkan';
$labels['cyrillic'] = 'Rusia';
$labels['arabic'] = 'Arab';
$labels['greek'] = 'Yunani';
$labels['hebrew'] = 'Yahudi';
$labels['turkish'] = 'Turki';
$labels['nordic'] = 'Nordik';
$labels['thai'] = 'Thailand';
$labels['celtic'] = 'Keltik';
$labels['vietnamese'] = 'Vietnam';
$labels['japanese'] = 'Jepang';
$labels['korean'] = 'Korea';
$labels['chinese'] = 'Cina';
$labels['arialabeltopnav'] = 'Kendali jendela';
$labels['arialabeltasknav'] = 'Tugas aplikasi';
$labels['arialabeltoolbar'] = 'Bilah alat aplikasi';
$labels['arialabelactivetask'] = 'Tugas aktif';
$labels['arialabelmessagessearchfilter'] = 'Penyaring senarai surel';
$labels['arialabelmailsearchform'] = 'Formulir pencarian pesan surel';
$labels['arialabelcontactsearchform'] = 'Formulir pencarian kontak';
$labels['arialabelmailquicksearchbox'] = 'Masukan pencarian surel';
$labels['arialabelquicksearchbox'] = 'Masukan pencarian';
$labels['arialabelfoldersearchfilter'] = 'Penyaring senarai folder';
$labels['arialabelfoldersearchform'] = 'Formulir pencarian folder';
$labels['arialabelfolderlist'] = 'Pilihan folder surel';
$labels['arialabelmessagelist'] = 'Daftar Pesan Surel';
$labels['arialabelmailpreviewframe'] = 'Pratinjau pesan';
$labels['arialabelmailboxmenu'] = 'Menu aksi folder';
$labels['arialabellistselectmenu'] = 'Menu pemilihan senarai';
$labels['arialabelthreadselectmenu'] = 'Menu daftar thread';
$labels['arialabelmessagelistoptions'] = 'Opsi penampilan dan pengurutan senarai pesan';
$labels['arialabelmailimportdialog'] = 'Dialog impor pesan';
$labels['arialabelmessagenav'] = 'Navigasi pesan';
$labels['arialabelmessagebody'] = 'Tubuh Pesan';
$labels['arialabelmessageactions'] = 'Aksi pesan';
$labels['arialabelcontactquicksearch'] = 'Formulir pencarian kontak';
$labels['arialabelcontactsearchbox'] = 'Masukan pencarian kontak';
$labels['arialabelmessageheaders'] = 'Kepala pesan';
$labels['arialabelforwardingoptions'] = 'Opsi penerusan';
$labels['arialabelreplyalloptions'] = 'Opsi balas-ke-semua';
$labels['arialabelmoremessageactions'] = 'Aksi pesan lainnya';
$labels['arialabelmarkmessagesas'] = 'Tandai pesan yang dipilih sebagai...';
$labels['arialabelcomposeoptions'] = 'Opsi penyusunan pesan';
$labels['arialabelresponsesmenu'] = 'Menu respon siap pakai';
$labels['arialabelattachmentuploadform'] = 'Formulir pengunggahan lampiran';
$labels['arialabelattachmentpreview'] = 'Pratinjau lampiran';
$labels['ariasummarycomposecontacts'] = 'Daftar kontak dan grup untuk dipilih sebagai penerima';
$labels['arialabelcontactexportoptions'] = 'Opsi ekspor kontak';
$labels['arialabelabookgroupoptions'] = 'Opsi buku alamat/grup';
$labels['arialabelpreferencesform'] = 'Formulir preferensi';
$labels['arialabelidentityeditfrom'] = 'Formulir sunting identitas';
$labels['arialabelresponseeditfrom'] = 'Formulir sunting respon';
$labels['arialabelsearchterms'] = 'Istilah pencarian';
$labels['helplistnavigation'] = 'Navigasi papan tik senarai';
$labels['helplistkeyboardnavigation'] = "Panah turun/naik: Pindah baris fokus/pilihan
Spasi: Pilih baris yang terfokus.
Shift + turun/naik: Pilih baris tambahan di atas/bawah.
Ctrl + Spasi: Tambahkan baris terfokus ke pilihan/hapus dari pilihan.";
$labels['helplistkeyboardnavmessages'] = "Panah kanan/kiri: kembangkan/mampatkan thread pesan (hanya dalam mode thread).
Enter: Buka pesan yang dipilih/difokuskan.
Delete: Pindahkan pesan yang dipilih ke Tong Sampah.";
$labels['helplistkeyboardnavcontacts'] = "Enter: Buka kontak yang dipilih/terfokus.";
