<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = 'Tervetuloa $product -käyttäjäksi';
$labels['username'] = 'Käyttäjätunnus';
$labels['password'] = 'Salasana';
$labels['server'] = 'Palvelin';
$labels['login'] = 'Kirjaudu';
$labels['oauthlogin'] = 'Kirjaudu palveluntarjoajan $provider avulla';
$labels['menu'] = 'Valikko';
$labels['logout'] = 'Kirjaudu ulos';
$labels['mail'] = 'Sähköposti';
$labels['settings'] = 'Asetukset';
$labels['addressbook'] = 'Osoitekirja';
$labels['darkmode'] = 'Tumma tila';
$labels['lightmode'] = 'Vaalea tila';
$labels['inbox'] = 'Saapuneet';
$labels['drafts'] = 'Luonnokset';
$labels['sent'] = 'Lähetetyt';
$labels['trash'] = 'Roskakori';
$labels['junk'] = 'Roskaposti';
$labels['show_real_foldernames'] = 'Näytä erikoiskansioiden oikeat nimet';
$labels['subject'] = 'Aihe';
$labels['from'] = 'Lähettäjä';
$labels['sender'] = 'Lähettäjä';
$labels['to'] = 'Vastaanottaja';
$labels['cc'] = 'Kopio';
$labels['bcc'] = 'Piilokopio';
$labels['replyto'] = 'Vastaus osoitteeseen';
$labels['followupto'] = 'Keskustelunsiirto';
$labels['date'] = 'Päiväys';
$labels['size'] = 'Koko';
$labels['priority'] = 'Tärkeys';
$labels['organization'] = 'Organisaatio';
$labels['readstatus'] = 'Luettu';
$labels['listoptions'] = 'Listaa valinnat...';
$labels['listoptionstitle'] = 'Listavalinnat';
$labels['mailboxlist'] = 'Kansiot';
$labels['messagesfromto'] = 'Viestit $from-$to/$count';
$labels['threadsfromto'] = 'Viestiketjut $from-$to/$count';
$labels['messagenrof'] = 'Viesti $nr/$count';
$labels['fromtoshort'] = '$from - $to (yhteensä $count)';
$labels['copy'] = 'Kopioi';
$labels['move'] = 'Siirrä';
$labels['moveto'] = 'siirrä kansioon...';
$labels['copyto'] = 'Kopioi...';
$labels['download'] = 'lataa';
$labels['open'] = 'Avaa';
$labels['showattachment'] = 'Näytä';
$labels['showanyway'] = 'Näytä silti';
$labels['filename'] = 'Tiedoston nimi';
$labels['filesize'] = 'Tiedoston koko';
$labels['addtoaddressbook'] = 'Lisää osoitekirjaan';
$labels['sun'] = 'Su';
$labels['mon'] = 'Ma';
$labels['tue'] = 'Ti';
$labels['wed'] = 'Ke';
$labels['thu'] = 'To';
$labels['fri'] = 'Pe';
$labels['sat'] = 'La';
$labels['sunday'] = 'Sunnuntai';
$labels['monday'] = 'Maanantai';
$labels['tuesday'] = 'Tiistai';
$labels['wednesday'] = 'Keskiviikko';
$labels['thursday'] = 'Torstai';
$labels['friday'] = 'Perjantai';
$labels['saturday'] = 'Lauantai';
$labels['jan'] = 'Tammi';
$labels['feb'] = 'Helmi';
$labels['mar'] = 'Maalis';
$labels['apr'] = 'Huhti';
$labels['may'] = 'Touko';
$labels['jun'] = 'Kesä';
$labels['jul'] = 'Heinä';
$labels['aug'] = 'Elo';
$labels['sep'] = 'Syys';
$labels['oct'] = 'Loka';
$labels['nov'] = 'Marras';
$labels['dec'] = 'Joulu';
$labels['longjan'] = 'Tammikuu';
$labels['longfeb'] = 'Helmikuu';
$labels['longmar'] = 'Maaliskuu';
$labels['longapr'] = 'Huhtikuu';
$labels['longmay'] = 'Touko';
$labels['longjun'] = 'Kesäkuu';
$labels['longjul'] = 'Heinäkuu';
$labels['longaug'] = 'Elokuu';
$labels['longsep'] = 'Syyskuu';
$labels['longoct'] = 'Lokakuu';
$labels['longnov'] = 'Marraskuu';
$labels['longdec'] = 'Joulukuu';
$labels['today'] = 'Tänään';
$labels['refresh'] = 'Päivitä';
$labels['checkmail'] = 'Tarkista saapuneet viestit';
$labels['compose'] = 'Viestin kirjoitus';
$labels['writenewmessage'] = 'Kirjoita uusi viesti';
$labels['reply'] = 'Vastaa';
$labels['replytomessage'] = 'Vastaa viestiin';
$labels['replytoallmessage'] = 'Vastaa kaikille';
$labels['replyall'] = 'Vastaa kaikille';
$labels['replylist'] = 'Vastaa listalle';
$labels['forward'] = 'Välitä eteenpäin';
$labels['forwardinline'] = 'Välitä viesti';
$labels['forwardattachment'] = 'Välitä viesti liitteenä';
$labels['forwardmessage'] = 'Välitä viesti';
$labels['bouncemsg'] = 'Lähetä edelleen (bounce)';
$labels['bounce'] = 'Lähetä edelleen';
$labels['deletemessage'] = 'Poista viesti';
$labels['undeletemessage'] = 'Kumoa viestin poisto';
$labels['movemessagetotrash'] = 'Siirrä viesti roskakoriin';
$labels['printmessage'] = 'Tulosta viesti';
$labels['previousmessage'] = 'Näytä edellinen viesti';
$labels['firstmessage'] = 'Näytä ensimmäinen viesti';
$labels['nextmessage'] = 'Näytä edellinen viesti';
$labels['lastmessage'] = 'Näytä viimeinen viesti';
$labels['backtolist'] = 'Takaisin viesteihin';
$labels['viewsource'] = 'Näytä lähdekoodi';
$labels['mark'] = 'Merkitse';
$labels['markmessages'] = 'Merkitse viestit';
$labels['markread'] = 'Luetuksi';
$labels['markunread'] = 'Lukemattomaksi';
$labels['markflagged'] = 'Korostetuksi';
$labels['markunflagged'] = 'Korostamattomaksi';
$labels['markundeleted'] = 'Poistamattomaksi';
$labels['markasread'] = 'Merkitse luetuksi';
$labels['markasunread'] = 'Merkitse lukemattomaksi';
$labels['markasflagged'] = 'Merkitse korostetuksi';
$labels['markasunflagged'] = 'Merkitse korostamattomaksi';
$labels['moreactions'] = 'Lisää toimintoja...';
$labels['markallread'] = 'Merkitse kaikki luetuiksi';
$labels['folders-cur'] = 'Vain valittu kansio';
$labels['folders-sub'] = 'Valittu kansio ja alikansiot';
$labels['folders-all'] = 'Kaikki kansiot';
$labels['more'] = 'Lisää';
$labels['back'] = 'Takaisin';
$labels['options'] = 'Asetukset';
$labels['composeoptions'] = 'Kirjoitusasetukset';
$labels['optionsandattachments'] = 'Asetukset ja liitteet';
$labels['actions'] = 'Toiminnot';
$labels['first'] = 'Ensimmäinen';
$labels['last'] = 'Viimeinen';
$labels['previous'] = 'Edellinen';
$labels['next'] = 'Seuraava';
$labels['select'] = 'Valitse';
$labels['selection'] = 'Valinta';
$labels['all'] = 'Kaikki';
$labels['none'] = 'Ei mikään';
$labels['currpage'] = 'Nykyinen sivu';
$labels['isread'] = 'Luettu';
$labels['unread'] = 'Lukemattomat';
$labels['flagged'] = 'Korostettu';
$labels['unflagged'] = 'Ei merkitty';
$labels['unanswered'] = 'Vastaamaton';
$labels['withattachment'] = 'Liitteen kera';
$labels['deleted'] = 'Poistettu';
$labels['undeleted'] = 'Ei poistettu';
$labels['replied'] = 'Vastattu';
$labels['forwarded'] = 'Välitetty';
$labels['invert'] = 'Käännä';
$labels['filter'] = 'Suodin';
$labels['list'] = 'Listaus';
$labels['threads'] = 'Viestiketjut';
$labels['expand-all'] = 'Laajenna kaikki';
$labels['expand-unread'] = 'Laajenna lukemattomat';
$labels['collapse-all'] = 'Kutista kaikki';
$labels['threaded'] = 'Säikeet';
$labels['showunread'] = 'Näytä lukemattomat viestit';
$labels['autoexpand_threads'] = 'Laajenna viestiketjut automaattisesti';
$labels['do_expand'] = 'kaikki viestiketjut';
$labels['expand_only_unread'] = 'vain ne joissa lukemattomia viestejä';
$labels['fromto'] = 'Lähettäjä/Vastaanottaja';
$labels['flag'] = 'Merkitse';
$labels['attachment'] = 'Liite';
$labels['nonesort'] = 'Ei mikään';
$labels['sentdate'] = 'Lähetysaika';
$labels['arrival'] = 'Saapumisaika';
$labels['asc'] = 'nouseva';
$labels['desc'] = 'laskeva';
$labels['listcolumns'] = 'Näkyvät kentät';
$labels['listsorting'] = 'Lajittelu kenttä';
$labels['listorder'] = 'Lajittelu järjestys';
$labels['listmode'] = 'Listausnäkymä';
$labels['lmode'] = 'Listaustapa';
$labels['layout'] = 'Asettelu';
$labels['layoutwidescreen'] = 'Laajakuva';
$labels['layoutdesktop'] = 'Työpöytä';
$labels['layoutlist'] = 'Listaus';
$labels['layoutwidescreendesc'] = 'Laajakuva (3 kolumnin näkymä)';
$labels['layoutdesktopdesc'] = 'Työpöytä (laaja lista ja esikatselu)';
$labels['layoutlistdesc'] = 'Lista (ei esikatselua)';
$labels['folderactions'] = 'Kansiotoiminnot...';
$labels['compact'] = 'Tiivistä';
$labels['empty'] = 'Tyhjennä';
$labels['importmessages'] = 'Tuo viestejä';
$labels['mailimportdesc'] = 'Voit lisätä sähköpostia tiedostoissa käyttäen <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a>- tai <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a>-muotoa.';
$labels['mailimportzip'] = 'Useat tiedostot on mahdollista pakata zip-arkistoihin.';
$labels['quota'] = 'Levytila';
$labels['unknown'] = 'tuntematon';
$labels['unlimited'] = 'rajoittamaton';
$labels['quotatype'] = 'Kiintiön tyyppi';
$labels['quotatotal'] = 'Raja';
$labels['quotaused'] = 'Käytetty';
$labels['quotastorage'] = 'Levytila';
$labels['quotamessage'] = 'Viestien määrä';
$labels['shortheaderdate'] = '$date';
$labels['shortheaderto'] = 'Vastaanottajalle $to, $date';
$labels['shortheaderfrom'] = 'Lähettäjältä $from, $date';
$labels['quicksearch'] = 'Pikahaku';
$labels['searchplaceholder'] = 'Hae...';
$labels['resetsearch'] = 'Nollaa haku';
$labels['searchmod'] = 'Hakukriteerit';
$labels['msgtext'] = 'Koko viesti';
$labels['body'] = 'Runko';
$labels['type'] = 'Tyyppi';
$labels['namex'] = 'Nimi';
$labels['searchscope'] = 'Rajaus';
$labels['currentfolder'] = 'Nykyinen kansio';
$labels['subfolders'] = 'Nykyinen kansio ja sen alikansiot';
$labels['allfolders'] = 'Kaikki kansiot';
$labels['searchinterval-1W'] = 'viikkoa vanhempi';
$labels['searchinterval-1M'] = 'kuukautta vanhempi';
$labels['searchinterval-1Y'] = 'vuotta vanhempi';
$labels['searchinterval1W'] = 'viikkoa uudempi';
$labels['searchinterval1M'] = 'kuukautta uudempi';
$labels['searchinterval1Y'] = 'vuotta uudempi';
$labels['openinextwin'] = 'Avaa uudessa ikkunassa';
$labels['emlsave'] = 'Tallenna (.eml)';
$labels['changeformattext'] = 'Näytä raakatekstimuodossa';
$labels['changeformathtml'] = 'Näytä HTML-muodossa';
$labels['editasnew'] = 'Muokkaa uutena';
$labels['send'] = 'Lähetä';
$labels['sendmessage'] = 'Lähetä viesti';
$labels['savemessage'] = 'Tallenna tämä luonnos';
$labels['addattachment'] = 'Liitetiedosto';
$labels['charset'] = 'Merkistö';
$labels['editortype'] = 'Editorin tyyppi';
$labels['returnreceipt'] = 'Perillesaapumisilmoitus';
$labels['dsn'] = 'Toimituksen tilailmoitus';
$labels['keepformatting'] = 'Säilytä muotoilu';
$labels['mailreplyintro'] = '$sender kirjoitti $date:';
$labels['originalmessage'] = 'Alkuperäinen viesti';
$labels['selectimage'] = 'Valitse kuva';
$labels['addimage'] = 'Lisää kuva';
$labels['selectmedia'] = 'Valitse elokuva';
$labels['addmedia'] = 'Lisää elokuva';
$labels['encrypt'] = 'Salaa';
$labels['encryptmessage'] = 'Salaa viesti';
$labels['encryptmessagemailvelope'] = 'Salaa viesti Mailvelopella';
$labels['importpubkeys'] = 'Tuo julkiset avaimet';
$labels['encryptedsendialog'] = 'Lähetetään salattua viestiä';
$labels['encryptandsign'] = 'Salaa ja allekirjoita';
$labels['keyid'] = 'Avaimen tunniste';
$labels['keylength'] = 'Bittiä';
$labels['keyexpired'] = 'Vanhentunut';
$labels['keyrevoked'] = 'Kumottu';
$labels['bccinstead'] = 'Käytä Piilokopiota';
$labels['insert'] = 'Lisää';
$labels['insertcontact'] = 'Lisää yhteystieto(ja)';
$labels['recipient'] = 'Vastaanottaja';
$labels['recipientedit'] = 'Vastaanottajan muokkaus';
$labels['editidents'] = 'Muokkaa identiteettejä';
$labels['spellcheck'] = 'Oikeinkirjoitus';
$labels['checkspelling'] = 'Tarkista oikeinkirjoitus';
$labels['resumeediting'] = 'Jatka muokkausta';
$labels['revertto'] = 'Muuta takaisin';
$labels['restore'] = 'Palauta';
$labels['restoremessage'] = 'Palautetaanko viesti?';
$labels['ignore'] = 'Jätä huomiotta';
$labels['responses'] = 'Vastaukset';
$labels['insertresponse'] = 'Lisää vastaus';
$labels['manageresponses'] = 'Hallitse vastauksia';
$labels['newresponse'] = 'Luo uusi vastaus';
$labels['addresponse'] = 'Lisää vastaus';
$labels['editresponse'] = 'Muokkaa vastausta';
$labels['editresponses'] = 'Muokkaa vastauksia';
$labels['responsename'] = 'Nimi';
$labels['responsetext'] = 'Vastausteksti';
$labels['attach'] = 'Liitä';
$labels['attachments'] = 'Liitetiedostot';
$labels['upload'] = 'Lisää';
$labels['uploadprogress'] = '$percent ($current/$total)';
$labels['close'] = 'Sulje';
$labels['messageoptions'] = 'Viestin asetukset...';
$labels['togglecomposeoptions'] = 'Vaihda kirjoitusvalintoja';
$labels['attachmentrename'] = 'Nimeä liite uudelleen';
$labels['low'] = 'Matala';
$labels['lowest'] = 'Matalin';
$labels['normal'] = 'Normaali';
$labels['high'] = 'Korkea';
$labels['highest'] = 'Korkein';
$labels['nosubject'] = '(ei aihetta)';
$labels['showimages'] = 'Näytä kuvat';
$labels['allow'] = 'Salli';
$labels['alwaysshow'] = 'Näytä aina lähettäjältä $sender saapuneet kuvat';
$labels['alwaysallow'] = 'Salli aina lähettäjältä $sender';
$labels['isdraft'] = 'Tämä on luonnosviesti.';
$labels['andnmore'] = '$nr lisää...';
$labels['details'] = 'Tiedot';
$labels['summary'] = 'Yhteenveto';
$labels['headers'] = 'Otsakkeet';
$labels['allheaders'] = 'Kaikki otsakkeet...';
$labels['togglemoreheaders'] = 'Näytä lisää viestiotsakkeita';
$labels['togglefullheaders'] = 'Viestin otsakkeet päällä/pois';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Tavallinen teksti';
$labels['savesentmessagein'] = 'Tallenna lähetetty viesti kansioon';
$labels['dontsave'] = 'Älä tallenna';
$labels['maxuploadsize'] = 'Suurin sallittu tiedostokoko on $size';
$labels['addcc'] = 'Lisää kopio';
$labels['addbcc'] = 'Lisää piilokopio';
$labels['addreplyto'] = 'Lisää vastausosoite';
$labels['addfollowupto'] = 'Lisää keskustelunsiirto';
$labels['sendreceipt'] = 'Lähetä lukukuittaus?';
$labels['mdnrequest'] = 'Viestin lähettäjä on pyytänyt kuittauksen siitä että olet lukenut viestin. Haluatko lähettää kuittauksen?';
$labels['receiptread'] = 'Lukukuittaus';
$labels['yourmessage'] = 'Tämä viesti on kuittaus lähettämällesi viestille';
$labels['receiptnote'] = 'Huom! Kuittaus tarkoittaa vain sitä, että viesti on avattu vastaanottajan tietokoneella. Se ei tarkoita että vastaanottaja on myös lukenut tai ymmärtänyt viestin.';
$labels['sendalwaysto'] = 'Lähetä aina lähettäjälle $email';
$labels['zoomin'] = 'Lähennä';
$labels['zoomout'] = 'Loitonna';
$labels['rotate'] = 'Käännä';
$labels['increaseimage'] = 'Suurenna kuvaa';
$labels['decreaseimage'] = 'Pienennä kuvaa';
$labels['rotateimage'] = 'Käännä kuvaa';
$labels['showtools'] = 'Näytä kuvatyökalut';
$labels['hidetools'] = 'Piilota kuvatyökalut';
$labels['name'] = 'Näkyvä nimi';
$labels['firstname'] = 'Etunimi';
$labels['surname'] = 'Sukunimi';
$labels['middlename'] = 'Toinen nimi';
$labels['nameprefix'] = 'Etuliite';
$labels['namesuffix'] = 'Jälkiliite';
$labels['nickname'] = 'Lempinimi';
$labels['jobtitle'] = 'Titteli';
$labels['department'] = 'Osasto';
$labels['gender'] = 'Sukupuoli';
$labels['maidenname'] = 'Tyttönimi';
$labels['email'] = 'Sähköposti';
$labels['phone'] = 'Puhelin';
$labels['address'] = 'Osoite';
$labels['street'] = 'Katu';
$labels['locality'] = 'Kaupunki';
$labels['zipcode'] = 'Postinumero';
$labels['region'] = 'Osavaltio tai lääni';
$labels['country'] = 'Maa';
$labels['birthday'] = 'Syntymäpäivä';
$labels['anniversary'] = 'Vuosipäivä';
$labels['website'] = 'Verkkosivu';
$labels['instantmessenger'] = 'Pikaviestin';
$labels['notes'] = 'Muistiinpanot';
$labels['male'] = 'mies';
$labels['female'] = 'nainen';
$labels['manager'] = 'Päällikkö';
$labels['assistant'] = 'Avustaja';
$labels['spouse'] = 'Puoliso';
$labels['allfields'] = 'Kaikki kentät';
$labels['search'] = 'Haku';
$labels['searchresult'] = 'Haun tulos';
$labels['advsearch'] = 'Tarkennettu haku';
$labels['advanced'] = 'Lisäasetukset';
$labels['other'] = 'Muu';
$labels['printcontact'] = 'Tulosta yhteystieto';
$labels['qrcode'] = 'QR-koodi';
$labels['typehome'] = 'Koti';
$labels['typework'] = 'Työ';
$labels['typeother'] = 'Muu';
$labels['typemobile'] = 'Matkapuhelin';
$labels['typemain'] = 'Oma';
$labels['typehomefax'] = 'Kotifaksi';
$labels['typeworkfax'] = 'Työfaksi';
$labels['typecar'] = 'Auto';
$labels['typepager'] = 'Hakulaite';
$labels['typevideo'] = 'Video';
$labels['typeassistant'] = 'Avustaja';
$labels['typehomepage'] = 'Kotisivu';
$labels['typeblog'] = 'Blogi';
$labels['typeprofile'] = 'Profiili';
$labels['addfield'] = 'Lisää kenttä...';
$labels['addcontact'] = 'Lisää yhteystieto';
$labels['editcontact'] = 'Muokkaa yhteystietoa';
$labels['contacts'] = 'Yhteystiedot';
$labels['contactproperties'] = 'Yhteystiedon ominaisuudet';
$labels['contactnameandorg'] = 'Nimi ja organisaatio';
$labels['personalinfo'] = 'Henkilökohtaiset tiedot';
$labels['personal'] = 'Henkilökohtainen';
$labels['contactphoto'] = 'Yhteyshenkilön kuva';
$labels['edit'] = 'Muokkaa';
$labels['cancel'] = 'Peruuta';
$labels['save'] = 'Tallenna';
$labels['delete'] = 'Poista';
$labels['discard'] = 'Hylkää';
$labels['continue'] = 'Jatka';
$labels['ok'] = 'OK';
$labels['rename'] = 'Nimeä uudelleen';
$labels['addphoto'] = 'Lisää';
$labels['replacephoto'] = 'Korvaa';
$labels['uploadphoto'] = 'Lähetä kuva';
$labels['choosefile'] = 'Valitse tiedosto...';
$labels['choosefiles'] = 'Valitse tiedostot...';
$labels['browse'] = 'Selaa';
$labels['newcontact'] = 'Luo uusi yhteystieto';
$labels['deletecontact'] = 'Poista valitut yhteystiedot';
$labels['composeto'] = 'Kirjoita viesti yhteystiedolle';
$labels['contactsfromto'] = 'Yhteystiedot $from-$to/$count';
$labels['print'] = 'Tulosta';
$labels['export'] = 'Vie';
$labels['exportall'] = 'Vie kaikki';
$labels['exportsel'] = 'Vie valitut';
$labels['exportvcards'] = 'Vie yhteystiedot vCard-muodossa';
$labels['newgroup'] = 'Luo uusi ryhmä';
$labels['addgroup'] = 'Lisää ryhmä';
$labels['grouprename'] = 'Nimeä ryhmä uudelleen';
$labels['groupdelete'] = 'Poista ryhmä';
$labels['groupassign'] = 'Aseta ryhmään...';
$labels['groupremove'] = 'Poista ryhmästä';
$labels['groupremoveselected'] = 'Poista valitut yhteystiedot ryhmästä';
$labels['uponelevel'] = 'Yksi taso ylös';
$labels['previouspage'] = 'Näytä edellinen luettelo';
$labels['firstpage'] = 'Näytä ensimmäinen luettelo';
$labels['nextpage'] = 'Näytä seuraava luettelo';
$labels['lastpage'] = 'Näytä viimeinen luettelo';
$labels['group'] = 'Ryhmä';
$labels['groups'] = 'Ryhmät';
$labels['listgroup'] = 'Listaa ryhmän jäsenet';
$labels['personaladrbook'] = 'Henkilökohtaiset osoitteet';
$labels['searchsave'] = 'Tallenna haku';
$labels['searchdelete'] = 'Poista haku';
$labels['import'] = 'Tuo';
$labels['importcontacts'] = 'Tuo yhteystiedot';
$labels['importfromfile'] = 'Tuo tiedostosta';
$labels['importtarget'] = 'Lisää yhteystiedot kohteeseen';
$labels['importreplace'] = 'Korvaa koko osoitekirja';
$labels['importgroups'] = 'Tuo ryhmämääritykset';
$labels['importgroupsall'] = 'Kaikki (luo ryhmät tarvittaessa)';
$labels['importgroupsexisting'] = 'Vain olemassa oleville ryhmille';
$labels['importdesc'] = 'Voit tuoda yhteystietoja olemassa olevasta osoitekirjasta.<br/>Tuetut muodot ovat <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> tai CSV.';
$labels['importmapdesc'] = 'Vahvista että kenttien kohdennus alla on oikein ennen CSV-materiaalin tuontia.';
$labels['fieldnotmapped'] = 'Kenttää ei kohdennettu (älä tuo)';
$labels['skipheader'] = 'Älä tuo ensimmäistä riviä (otsakkeet)';
$labels['done'] = 'Valmis';
$labels['settingsfor'] = 'Asetukset';
$labels['about'] = 'Tietoja';
$labels['preferences'] = 'Asetukset';
$labels['userpreferences'] = 'Käyttäjän asetukset';
$labels['editpreferences'] = 'Muokkaa käyttäjän asetuksia';
$labels['identities'] = 'Identiteetit';
$labels['manageidentities'] = 'Hallitse henkilöyksiä';
$labels['newidentity'] = 'Luo uusi henkilöys';
$labels['addidentity'] = 'Lisää henkilöys';
$labels['editidentity'] = 'Muokkaa henkilöyttä';
$labels['identityencryption'] = 'Salaus';
$labels['preferhtml'] = 'Käytä HTML:aa';
$labels['defaultcharset'] = 'Oletusmerkistökoodaus';
$labels['htmlmessage'] = 'HTML-viesti';
$labels['messagepart'] = 'Osa';
$labels['digitalsig'] = 'Digitaalinen allekirjoitus';
$labels['dateformat'] = 'Päiväyksen muoto';
$labels['timeformat'] = 'Ajan muoto';
$labels['prettydate'] = 'Nätit päiväykset';
$labels['setdefault'] = 'Aseta vakioksi';
$labels['autodetect'] = 'Automaattinen';
$labels['language'] = 'Kieli';
$labels['timezone'] = 'Aikavyöhyke';
$labels['pagesize'] = 'Rivejä sivulla';
$labels['signature'] = 'Allekirjoitus';
$labels['dstactive'] = 'Kesäaika';
$labels['showinextwin'] = 'Avaa viesti uudessa ikkunassa';
$labels['composeextwin'] = 'Lähetä viesti uudessa ikkunassa';
$labels['htmleditor'] = 'Kirjoita HTML-muodossa';
$labels['htmlonreply'] = 'Vain vastatessa HTML-viesteihin';
$labels['htmlonreplyandforward'] = 'välittäessä tai vastatessa HTML-viestiin';
$labels['htmlsignature'] = 'HTML-allekirjoitus';
$labels['showemail'] = 'Näytä sähköpostiosoite näyttönimen kanssa';
$labels['previewpane'] = 'Näytä esikatselulehti';
$labels['skin'] = 'Käyttöliittymän teema';
$labels['logoutclear'] = 'Tyhjennä roskakori kirjautuessa ulos';
$labels['logoutcompact'] = 'Tiivistä kansiot kirjautuessa ulos';
$labels['uisettings'] = 'Käyttöliittymä';
$labels['serversettings'] = 'Palvelinasetukset';
$labels['mailboxview'] = 'Postilaatikkonäkymä';
$labels['mdnrequests'] = 'Lähettäjän kuittaukset';
$labels['askuser'] = 'kysy käyttäjältä';
$labels['autosend'] = 'lähetä automaattisesti';
$labels['autosendknown'] = 'Lähetä kuittaus kontaktilistassa oleville, kysy muulloin';
$labels['autosendknownignore'] = 'Lähetä kuittaus vain kontaktilistassa oleville';
$labels['autosendtrusted'] = 'lähetä kuittaus luotetuille lähettäjille, kysy minulta muulloin';
$labels['autosendtrustedignore'] = 'lähetä kuittaus luotetuille lähettäjille, jätä muulloin huomiotta';
$labels['ignorerequest'] = 'Hylkää pyyntö';
$labels['readwhendeleted'] = 'Merkitse poistettavat viestit luetuiksi';
$labels['flagfordeletion'] = 'Poistamisen sijaan merkitse viestit poistettavaksi';
$labels['skipdeleted'] = 'Älä näytä poistettuja viestejä';
$labels['deletealways'] = 'Poista viestit, joiden siirtäminen roskakoriin epäonnistuu';
$labels['deletejunk'] = 'Poista roskapostiviestit suoraan';
$labels['showremoteimages'] = 'Näytä ulkopuoliset kuvat viestissä';
$labels['allowremoteresources'] = 'Salli ulkoiset lähteet (kuvat, tyylitiedostot)';
$labels['fromknownsenders'] = 'tunnetuilta lähettäjiltä';
$labels['fromtrustedsenders'] = 'tunnetuista lähettäjistä';
$labels['frommycontacts'] = 'yhteystiedoistani';
$labels['always'] = 'aina';
$labels['alwaysbutplain'] = 'aina, paitsi vastatessa "vain teksti"-viesteihin';
$labels['showinlineimages'] = 'Näytä liitekuvat viestin jälkeen';
$labels['autosavedraft'] = 'Tallenna luonnos automaattisesti';
$labels['everynminutes'] = 'joka $n. minuutti';
$labels['refreshinterval'] = 'Päivitä (tarkista uudet viestit jne.)';
$labels['never'] = 'ei koskaan';
$labels['immediately'] = 'välittömästi';
$labels['messagesdisplaying'] = 'Viestien näyttäminen';
$labels['messagescomposition'] = 'Viestien kirjoittaminen';
$labels['mimeparamfolding'] = 'Liitetiedostojen nimet';
$labels['2231folding'] = 'Täysin RFC 2231:n mukainen (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231:n mukainen (MS Outlook)';
$labels['2047folding'] = 'Täysin RFC 2047:n mukainen (muut)';
$labels['force7bit'] = 'Käytä MIME-koodausta 8-bittisille merkeille';
$labels['savelocalstorage'] = "Tallenna selaimen paikalliseen tallennustilaan (väliaikaisesti)";
$labels['advancedoptions'] = 'Lisäasetukset';
$labels['toggleadvancedoptions'] = 'Vaihda edistyneemmät valinnat';
$labels['focusonnewmessage'] = 'Tarkenna selainikkuna uuteen viestiin';
$labels['checkallfolders'] = 'Tarkista kaikki kansiot uusien viestien varalta';
$labels['displaynext'] = 'Näytä listalta seuraava poiston/siirron jälkeen';
$labels['defaultfont'] = 'HTML-viestin oletuskirjasin';
$labels['mainoptions'] = 'Pääasetukset';
$labels['browseroptions'] = 'Selainasetukset';
$labels['section'] = 'Kohta';
$labels['maintenance'] = 'Huolto';
$labels['newmessage'] = 'Uusi viesti';
$labels['signatureoptions'] = 'Allekirjoituksen asetukset';
$labels['whenreplying'] = 'Vastattaessa';
$labels['replyempty'] = 'älä lainaa alkuperäistä viestiä';
$labels['replytopposting'] = 'aloita uusi viesti alkuperäisen yläpuolelle';
$labels['replytoppostingnoindent'] = 'aloita uusi viesti lainauksen yläpuolella (ei sisennystä)';
$labels['replybottomposting'] = 'aloita uusi viesti alkuperäisen alapuolelle';
$labels['replyremovesignature'] = 'Vastattaessa poista alkuperäinen allekirjoitus viestistä';
$labels['autoaddsignature'] = 'Lisää allekirjoitus automaattisesti';
$labels['newmessageonly'] = 'vain uuteen viestiin';
$labels['replyandforwardonly'] = 'vain vastauksiin ja välityksiin';
$labels['insertsignature'] = 'Lisää allekirjoitus';
$labels['sigbelow'] = 'Aseta allekirjoitus lainatun viestin alapuolelle';
$labels['sigseparator'] = 'Pakota standardi erotin allekirjoituksissa';
$labels['automarkread'] = 'Merkitse viestit luetuiksi';
$labels['afternseconds'] = '$n sekunnin jälkeen';
$labels['reqmdn'] = 'Pyydä aina kuittausviestiä';
$labels['reqdsn'] = 'Pyydä aina toimituksen tilailmoitus';
$labels['replysamefolder'] = 'Laita vastaukseni samaan hakemistoon alkuperäisen viestin kanssa';
$labels['defaultabook'] = 'Oletusarvoinen osoitekirja';
$labels['autocompletesingle'] = 'Älä huomioi vaihtoehtoisia sähköpostiosoitteita automaattisessa täydennyksessä';
$labels['listnamedisplay'] = 'Listaa yhteystiedot';
$labels['contactformmode'] = 'Yhteydenottolomaketila';
$labels['privatemode'] = 'Yksityinen (Koti)';
$labels['businessmode'] = 'Työ';
$labels['collectedaddresses'] = 'Kerätyt osoitteet';
$labels['collectedrecipients'] = 'Kerätyt vastaanottajat';
$labels['collectedrecipientsopt'] = 'Säilytä lähtevien sähköpostien vastaanottajat';
$labels['collectedsendersopt'] = 'Säilytä luotetut lähettäjät';
$labels['trustedsenders'] = 'Luotetut lähettäjät';
$labels['spellcheckbeforesend'] = 'Tarkista oikeinkirjoitus ennen viestin lähetystä';
$labels['spellcheckoptions'] = 'Oikuluvun asetukset';
$labels['spellcheckignoresyms'] = 'Jätä huomiotta sanat, joissa on symboleja';
$labels['spellcheckignorenums'] = 'Jätä huomiotta sanat, joissa on numeroita';
$labels['spellcheckignorecaps'] = 'Jätä huomiotta sanat, joissa kaikki kirjaimet on isoja';
$labels['addtodict'] = 'Lisää sanakirjaan';
$labels['mailtoprotohandler'] = 'Rekisteröi mailto:-linkkien protokollakäsitteljä';
$labels['standardwindows'] = 'Käsittele popup-ikkunoita tavallisina ikkunoina';
$labels['forwardmode'] = 'Viestin välitys';
$labels['inline'] = 'rivissä';
$labels['asattachment'] = 'liitteenä';
$labels['replyallmode'] = 'Oletustoiminto [Vastaa kaikille]-painikkeelle';
$labels['replyalldefault'] = 'vastaa kaikille';
$labels['replyalllist'] = 'vastaa pelkälle postituslistalle (jos havaittu)';
$labels['allmessages'] = 'Kaikki viestit';
$labels['olderxdays'] = 'vanhempi kuin $x päivää';
$labels['folder'] = 'Kansio';
$labels['folders'] = 'Kansiot';
$labels['foldername'] = 'Kansion nimi';
$labels['subscribed'] = 'Näytetään';
$labels['messagecount'] = 'Viestejä';
$labels['create'] = 'Luo uusi';
$labels['createfolder'] = 'Luo uusi kansio';
$labels['managefolders'] = 'Kansioiden hallinta';
$labels['specialfolders'] = 'Erikoiskansiot';
$labels['properties'] = 'Ominaisuudet';
$labels['folderproperties'] = 'Kansion ominaisuudet';
$labels['parentfolder'] = 'Yläkansio';
$labels['location'] = 'Sijanti';
$labels['info'] = 'Tietoja';
$labels['getfoldersize'] = 'Napsauta saadaksesi kansion koon';
$labels['changesubscription'] = 'Klikkaa muuttaaksesi tilausta';
$labels['foldertype'] = 'Kansion tyyppi';
$labels['personalfolder'] = 'Yksityinen kansio';
$labels['otherfolder'] = 'Toisen käyttäjän kansio';
$labels['sharedfolder'] = 'Julkinen kansio';
$labels['findfolders'] = 'Etsi kansioita';
$labels['findcontacts'] = 'Etsi yhteystiedot';
$labels['findmail'] = 'Etsi viestit';
$labels['namespace.personal'] = 'Henkilökohtainen';
$labels['namespace.other'] = 'Muut käyttäjät';
$labels['namespace.shared'] = 'Jaettu';
$labels['dualuselabel'] = 'Voi sisältää vain';
$labels['dualusemail'] = 'viestit';
$labels['dualusefolder'] = 'kansiot';
$labels['generate'] = 'Luo';
$labels['encryptioncreatekey'] = 'Luo uusi avainpari';
$labels['openmailvelopesettings'] = 'Avaa Mailvelopen asetukset';
$labels['encryptionprivkeysinmailvelope'] = 'Sinulla on $nr täsmäävää yksityistä avainta tallennettuna Mailvelope-avainketjuusi:';
$labels['encryptionnoprivkeysinmailvelope'] = 'Tällä lähettäjäidentiteetillä ei vielä ole yksityistä PGP-avainta tallennettuna Mailvelope-laajennukseesi. Haluatko luoda avaimen mahdollistaaksesi salatun viestinnän?';
$labels['encryption'] = 'Salaus';
$labels['mailvelopeoptions'] = 'Mailvelopen valinnat';
$labels['mailvelopemainkeyring'] = 'Käytä Mailvelopen pääavainnippua';
$labels['mailvelopenotfound'] = 'Mailvelope-laajennusta ei ole otettu käyttöön tai asennettu selaimeesi.';
$labels['sortby'] = 'Järjestä';
$labels['sortasc'] = 'Järjestä nousevasti (a-ö)';
$labels['sortdesc'] = 'Järjestä laskevasti (ö-a)';
$labels['undo'] = 'Kumoa';
$labels['installedplugins'] = 'Asennetut lisäosat';
$labels['plugin'] = 'Liitännäinen';
$labels['version'] = 'Versio';
$labels['source'] = 'Lähde';
$labels['destination'] = 'Kohde';
$labels['license'] = 'Lisenssi';
$labels['skinauthor'] = 'Tekijältä $author';
$labels['support'] = 'Hanki tukea';
$labels['savedsearches'] = 'Tallennetut haut';
$labels['dateformatY'] = 'VVVV';
$labels['dateformaty'] = 'VV';
$labels['dateformatm'] = 'KK';
$labels['dateformatd'] = 'PP';
$labels['dateformatj'] = 'P';
$labels['dateformatn'] = 'K';
$labels['B'] = 't';
$labels['KB'] = 'Kt';
$labels['MB'] = 'Mt';
$labels['GB'] = 'Gt';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Englantilainen';
$labels['westerneuropean'] = 'Länsieurooppalainen';
$labels['easterneuropean'] = 'Itäeurooppalainen';
$labels['southeasterneuropean'] = 'Eteläeurooppalainen';
$labels['baltic'] = 'Balttilainen';
$labels['cyrillic'] = 'Kyrillinen';
$labels['arabic'] = 'Arabialainen';
$labels['greek'] = 'Kreikkalainen';
$labels['hebrew'] = 'Heprealainen';
$labels['turkish'] = 'Turkkilainen';
$labels['nordic'] = 'Pohjoismaalainen';
$labels['thai'] = 'Thaimaalainen';
$labels['celtic'] = 'Kelttiläinen';
$labels['vietnamese'] = 'Vietnamilainen';
$labels['japanese'] = 'Japanilainen';
$labels['korean'] = 'Korealainen';
$labels['chinese'] = 'Kiinalainen';
$labels['arialabeltopnav'] = 'Ikkunan hallinta';
$labels['arialabeltasknav'] = 'Sovelluksen tehtävät';
$labels['arialabeltoolbar'] = 'Sovelluksen työkalupalkki';
$labels['arialabellistnav'] = 'Listan navigointi';
$labels['arialabelactivetask'] = 'Aktiivinen tehtävä';
$labels['arialabelmessagessearchfilter'] = 'Sähköpostin listaussuodatin';
$labels['arialabelmailsearchform'] = 'Sähköpostiviestin hakulomake';
$labels['arialabelcontactsearchform'] = 'Yhteyshenkilöiden hakulomake';
$labels['arialabelmailquicksearchbox'] = 'Sähköpostihaun syöttö';
$labels['arialabelquicksearchbox'] = 'Haun syöttö';
$labels['arialabelfoldersearchfilter'] = 'Kansion listaussuodatin';
$labels['arialabelfoldersearchform'] = 'Kansion hakulomake';
$labels['arialabelfolderlist'] = 'Sähköpostin kansion valinta';
$labels['arialabelmessagelist'] = 'Sähköpostiviestien listaus';
$labels['arialabelmailpreviewframe'] = 'Viestin esikatselu';
$labels['arialabelmailboxmenu'] = 'Kansion toimintovalikko';
$labels['arialabellistselectmenu'] = 'Listaa valintavalikko';
$labels['arialabelthreadselectmenu'] = 'Keskusteluiden listausvalikko';
$labels['arialabelmessagelistoptions'] = 'Viestilista ja järjestelyvalinnat';
$labels['arialabelmailimportdialog'] = 'Viestintuonti';
$labels['arialabelmessagenav'] = 'Viestien navigointi';
$labels['arialabelmessagebody'] = 'Viestin runko';
$labels['arialabelmessageactions'] = 'Viestitoiminnot';
$labels['arialabelcontactquicksearch'] = 'Yhteyshenkilöiden hakulomake';
$labels['arialabelcontactsearchbox'] = 'Yhteyshenkilön hakusyöte';
$labels['arialabelmessageheaders'] = 'Viestin otsakkeet';
$labels['arialabelforwardingoptions'] = 'Uudelleenohjausvalinnat';
$labels['arialabelreplyalloptions'] = 'Vastaa kaikille -valinnat';
$labels['arialabelmoremessageactions'] = 'Lisää viestitoimintoja';
$labels['arialabelmorecontactactions'] = 'Lisää yhteystietotoimintoja';
$labels['arialabelmarkmessagesas'] = 'Merkitse valitut viestit...';
$labels['arialabelcomposeoptions'] = 'Kirjoitusvalinnat';
$labels['arialabelresponsesmenu'] = 'Valmiit vastaukset -valikko';
$labels['arialabelattachmentuploadform'] = 'Liitteen lähetyslomake';
$labels['arialabelattachmentmenu'] = 'Liitteiden asetukset';
$labels['arialabelmailtomenu'] = 'Sähköpostiosoitteen asetukset';
$labels['arialabelattachmentpreview'] = 'Liitteen esikatselu';
$labels['ariasummarycomposecontacts'] = 'Luettelo yhteyshenkilöistä ja ryhmistä, jotka voi valita vastaanottajaksi';
$labels['arialabelcontactexportoptions'] = 'Yhteyshenkilön vientivalinnat';
$labels['arialabelabookgroupoptions'] = 'Osoitekirjan/ryhmän valinnat';
$labels['arialabelpreferencesform'] = 'Asetukset -lomake';
$labels['arialabelidentityeditfrom'] = 'Henkilöyden muokkauslomake';
$labels['arialabelresponseeditfrom'] = 'Vastauksen muokkauslomake';
$labels['arialabelsearchterms'] = 'Hakuehdot';
$labels['arialabeldropactionmenu'] = 'Raahaa ja pudota toimintovalikko';
$labels['arialabelheadersmenu'] = 'Vastaanottajaotsakkeen lisäysvalikko';
$labels['arialabelimagetools'] = 'Kuvatyökalut';
$labels['helplistnavigation'] = 'Luetteloi näppäimistönavigointi';
$labels['helplistkeyboardnavigation'] = "Nuolet ylös/alas: Siirrä kohdistettua riviä/valintaa.
Välilyönti: Valitse kohdistettu rivi.
Shift + ylös/alas: Valitse lisää rivejä yläpuolelta/alapuolelta.
Ctrl + välilyönti: Lisää kohdistettu rivi valintaan/poista valinnasta.";
$labels['helplistkeyboardnavmessages'] = "Nuolinäppäimet oikealle/vasemmalle: Laajenna/kutista viestikeskustelut (vain keskustelu-tilassa).
Entteri/rivinvaihto: Avaa valittu/kohdistettu viesti.
Delete/poista: Siirrä valitut viestit roskakoriin.";
$labels['helplistkeyboardnavcontacts'] = "Enter: avaa valittu/kohdistettu yhteystieto.";
