<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Mostrar notificación cuando haya nuevos mensajes';
$labels['desktop'] = 'Mostrar notificación en escritorio cuando haya nuevos mensajes';
$labels['sound'] = 'Reproducir sonido cuando haya nuevos mensajes';
$labels['test'] = 'Prueba';
$labels['title'] = 'Correo nuevo!';
$labels['body'] = 'Has recibido correo nuevo';
$labels['testbody'] = 'Esta es una notificación de prueba';
$labels['desktopdisabled'] = 'Las notificaciones en escritorio están deshabilitadas en tu navegador';
$labels['desktopunsupported'] = 'Tu navegador no soporta notificaciones en escritorio';
$labels['desktoptimeout'] = 'Cerrar notificación de escritorio';
