<?php

/*
 +-----------------------------------------------------------------------+
 | localization/ru_RU/csv2vcard.inc                                      |
 |                                                                       |
 | Language file of the Roundcube Webmail client                         |
 | Copyright (C) 2005-2014, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Aleksander Machniak <alec@alec.pl>                            |
 +-----------------------------------------------------------------------+
*/
$map['День рождения'] = 'birthday-d';
$map['Месяц рождения'] = 'birthday-m';
$map['Год рождения'] = 'birthday-y';
$map['Отображаемое имя'] = 'name';
$map['Номер факса'] = 'phone:homefax';
$map['Адрес'] = 'street:home';
$map['Город'] = 'locality:home';
$map['Штат'] = 'region:home';
$map['Страна'] = 'country:home';
$map['Почтовый индекс'] = 'zipcode:home';
$map['Номер сотового телефона'] = 'phone:mobile';
$map['Псевдоним'] = 'nickname';
$map['Организация'] = 'organization';
$map['Номер пейджера'] = 'phone:pager';
$map['Адрес электронной почты'] = 'email:home';
$map['Альтернативный адрес электронной почты'] = 'email:other';
$map['Веб-страница 1'] = 'website:homepage';
$map['Веб-страница 2'] = 'website:other';
$map['Веб-страница'] = 'website:homepage';
$map['Заметки'] = 'notes';
$map['Рабочий телефон'] = 'phone:work';
$map['Адрес (раб.)'] = 'street:work';
$map['Страна (раб.)'] = 'country:work';
$map['Почтовый индекс (раб.)'] = 'zipcode:work';
$map['Фамилия'] = 'surname';
$map['Имя'] = 'firstname';
$map['Город (раб.)'] = 'locality:work';
$map['work_state_short'] = 'Штат (раб.)';
