<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Archivéieren';
$labels['buttontitle'] = 'Dëse Message archivéieren';
$labels['archived'] = 'Erfollegräich archivéiert';
$labels['archivedreload'] = 'Erfollegräich archivéiert. Lued d\'Säit nei fir déi neisten Archiv-Dossieren ze gesinn.';
$labels['archiveerror'] = 'Verschidde Messagë konnten net archivéiert ginn';
$labels['archivefolder'] = 'Archiv';
$labels['settingstitle'] = 'Archiv';
$labels['archivetype'] = 'Archiv dividéieren duerch';
$labels['archivetypeyear'] = 'Joer (z.B. Archiv/2013)';
$labels['archivetypemonth'] = 'Mount (z.B. Archiv/2013/06)';
$labels['archivetypetbmonth'] = 'Mount - Thunderbird kompatibel (z.B. Archiv/2012/2012-06)';
$labels['archivetypefolder'] = 'Original-Dossier';
$labels['archivetypefolderyear'] = 'Joer an den original Dossier (z.B. Archiv/2012/...)';
$labels['archivetypefoldermonth'] = 'Joer, Mount an den original Dossier (z.B. Archiv/2012/...)';
$labels['archivetypesender'] = 'Sender-E-Mail';
$labels['unkownsender'] = 'onbekannt';
