<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'ئارخىپ';
$labels['buttontitle'] = 'بۇ خەتنى ئارخىپلاش';
$labels['archived'] = 'مۇۋاپىقىيەتلىك ئارخىپلاندى';
$labels['archivedreload'] = 'مۇۋاپىقىيەتلىك ئارخىپلاندى. بەتنى قايتا يۈكلەش ئارقىلىق يېڭى ئارخىپ قىسقۇچىنى كۆرۈڭ.';
$labels['archiveerror'] = 'بەزى خەتلەرنى ئارخىپلىغىلى بولمىدى';
$labels['archivefolder'] = 'ئارخىپ';
$labels['settingstitle'] = 'ئارخىپ';
$labels['archivetype'] = 'ئارخىپنى ئايرىش';
$labels['archivetypeyear'] = 'يىل (مەسلەن: ئارخىپ/2012)';
$labels['archivetypemonth'] = 'ئاي (مەسلەن: ئارخىپ/2012/06)';
$labels['archivetypetbmonth'] = 'ئاي - چاقماققۇشقا ماس (مەسلەن: ئارخىپ/2012/2012-06)';
$labels['archivetypefolder'] = 'ئەسلىي قىسقۇچ';
$labels['archivetypefolderyear'] = 'يىل ھەمدە ئەسلىي قىسقۇچ (مەسلەن: ئارخىپ/2012/...)';
$labels['archivetypefoldermonth'] = 'يىل، ئاي ھەمدە ئەسلىي قىسقۇچ (مەسلەن: ئارخىپ/2012/06/...)';
$labels['archivetypesender'] = 'ئەۋەتكۈچى ئېلىخېتى';
$labels['unkownsender'] = 'ناتۇنۇش';
$labels['readonarchive'] = 'خەتكە ئارخىپتا ئۇقۇغانلىق بەلگىسىنى قۇيۇش';
