<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['tz:africa'] = 'إفريقيا';
$labels['tz:africa:abidjan'] = 'أبيدجان';
$labels['tz:africa:accra'] = 'آكرا';
$labels['tz:africa:addis_ababa'] = 'أديس أبيبا';
$labels['tz:africa:algiers'] = 'الجزائر';
$labels['tz:africa:asmara'] = 'أسمرا';
$labels['tz:africa:bamako'] = 'باماكو';
$labels['tz:africa:banjul'] = 'بنجول';
$labels['tz:africa:bissau'] = 'بيساو';
$labels['tz:africa:brazzaville'] = 'برازافيل';
$labels['tz:africa:cairo'] = 'القاهرة';
$labels['tz:africa:casablanca'] = 'الدار البيضاء';
$labels['tz:africa:ceuta'] = 'سبة';
$labels['tz:africa:conakry'] = 'كوناكري';
$labels['tz:africa:dakar'] = 'داكار';
$labels['tz:africa:dar_es_salaam'] = 'دار السلام';
$labels['tz:africa:djibouti'] = 'جيبوتي';
$labels['tz:africa:douala'] = 'دوالا';
$labels['tz:africa:el_aaiun'] = 'العيون';
$labels['tz:africa:harare'] = 'هراري';
$labels['tz:africa:johannesburg'] = 'جوهانسبورغ';
$labels['tz:africa:juba'] = 'جوبا';
$labels['tz:africa:kampala'] = 'كامبالا';
$labels['tz:africa:khartoum'] = 'الخرطوم';
$labels['tz:africa:kigali'] = 'كيغالي';
$labels['tz:africa:kinshasa'] = 'كينشاسا';
$labels['tz:africa:lagos'] = 'لاغوس';
$labels['tz:africa:libreville'] = 'لبير فيل';
$labels['tz:africa:lome'] = 'لومي';
$labels['tz:africa:luanda'] = 'لواندا';
$labels['tz:africa:lubumbashi'] = 'لوبومباشي';
$labels['tz:africa:lusaka'] = 'لوزاكا';
$labels['tz:africa:malabo'] = 'مالابو';
$labels['tz:africa:maputo'] = 'مابوتو';
$labels['tz:africa:mbabane'] = 'مبابان';
$labels['tz:africa:mogadishu'] = 'موغاديشيو';
$labels['tz:africa:monrovia'] = 'منروفيا';
$labels['tz:africa:nairobi'] = 'نايروبي';
$labels['tz:africa:ndjamena'] = 'نجامينا';
$labels['tz:africa:niamey'] = 'نيامي';
$labels['tz:africa:nouakchott'] = 'نواكشوط';
$labels['tz:africa:ouagadougou'] = 'واغادوغو';
$labels['tz:africa:tripoli'] = 'طرابلس';
$labels['tz:africa:tunis'] = 'تونس';
$labels['tz:america'] = 'أمريكا';
$labels['tz:america:anchorage'] = 'أونكوراج';
$labels['tz:america:halifax'] = 'هاليفاكس';
$labels['tz:america:indiana'] = 'الإنديانا';
$labels['tz:america:indiana:petersburg'] = 'بيترزبرغ';
$labels['tz:america:indiana:winamac'] = 'ويناماك';
$labels['tz:america:jamaica'] = 'جامايكا';
$labels['tz:america:kentucky'] = 'كانتوكي';
$labels['tz:america:la_paz'] = 'لاباز';
$labels['tz:america:lima'] = 'ليما';
$labels['tz:america:los_angeles'] = 'لوس أنجلس';
$labels['tz:america:manaus'] = 'ماناووس';
$labels['tz:america:martinique'] = 'مارتينيك';
$labels['tz:america:montevideo'] = 'مونتيفيديو';
$labels['tz:america:montserrat'] = 'مونسيراط';
$labels['tz:america:new_york'] = 'نيويورك';
$labels['tz:america:panama'] = 'بانما';
$labels['tz:america:paramaribo'] = 'باراماريبو';
$labels['tz:america:phoenix'] = 'فينيكس';
$labels['tz:america:port-au-prince'] = 'بور أو برانس';
$labels['tz:america:puerto_rico'] = 'بورتو ريكو';
$labels['tz:america:regina'] = 'ريجينا';
$labels['tz:america:santiago'] = 'سان تياغو';
$labels['tz:america:sao_paulo'] = 'ساو باولو';
$labels['tz:america:tijuana'] = 'تيخوانا';
$labels['tz:america:toronto'] = 'تورونطو';
$labels['tz:america:tortola'] = 'تورتولا';
$labels['tz:america:vancouver'] = 'فانكوفر';
$labels['tz:america:winnipeg'] = 'وينيباغ';
$labels['tz:antarctica:mawson'] = 'ماوسن';
$labels['tz:antarctica:palmer'] = 'بالمر';
$labels['tz:antarctica:troll'] = 'طرول';
$labels['tz:antarctica:vostok'] = 'فوسطوك';
$labels['tz:asia'] = 'آسيا';
$labels['tz:asia:aden'] = 'عدن';
$labels['tz:asia:amman'] = 'عمان';
$labels['tz:asia:baghdad'] = 'بغداد';
$labels['tz:asia:bahrain'] = 'البحرين';
$labels['tz:asia:bangkok'] = 'بانكوك';
$labels['tz:asia:beirut'] = 'بيروت';
$labels['tz:asia:brunei'] = 'بروناي';
$labels['tz:asia:colombo'] = 'كولومبو';
$labels['tz:asia:damascus'] = 'دمشق';
$labels['tz:asia:dubai'] = 'دبي';
$labels['tz:asia:famagusta'] = 'فاماغوستا';
$labels['tz:asia:gaza'] = 'غزة';
$labels['tz:asia:hong_kong'] = 'هونغ كونغ';
$labels['tz:asia:jakarta'] = 'جاكارتا';
$labels['tz:asia:jayapura'] = 'جايابورا';
$labels['tz:asia:kabul'] = 'كابل';
$labels['tz:asia:karachi'] = 'كراتشي';
$labels['tz:asia:kolkata'] = 'كولكاتا';
$labels['tz:asia:kuala_lumpur'] = 'كوالالمبور';
$labels['tz:asia:kuwait'] = 'الكويت';
$labels['tz:asia:macau'] = 'ماكاو';
$labels['tz:asia:manila'] = 'مانيلا';
$labels['tz:asia:muscat'] = 'مسقط';
$labels['tz:asia:nicosia'] = 'نيقوسيا';
$labels['tz:asia:qatar'] = 'قطر';
$labels['tz:asia:riyadh'] = 'الرياض';
$labels['tz:asia:samarkand'] = 'سمرقند';
$labels['tz:asia:shanghai'] = 'شانغهاي';
$labels['tz:asia:singapore'] = 'سانغفورة';
$labels['tz:asia:taipei'] = 'تاي باي';
$labels['tz:asia:tehran'] = 'طهران';
$labels['tz:asia:tokyo'] = 'طوكيو';
$labels['tz:asia:vladivostok'] = 'فلاديفوسطوك';
$labels['tz:atlantic:reykjavik'] = 'ريكيافيك';
$labels['tz:australia'] = 'أستراليا';
$labels['tz:australia:melbourne'] = 'ميلبورن';
$labels['tz:australia:sydney'] = 'سيدني';
$labels['tz:europe'] = 'أوروبا';
$labels['tz:europe:amsterdam'] = 'أمستيردام';
$labels['tz:europe:andorra'] = 'أندورا';
$labels['tz:europe:athens'] = 'أثينا';
$labels['tz:europe:belgrade'] = 'بلغراد';
$labels['tz:europe:berlin'] = 'برلين';
$labels['tz:europe:bratislava'] = 'براتيسلافا';
$labels['tz:europe:brussels'] = 'بروكسل';
$labels['tz:europe:bucharest'] = 'بوخاريست';
$labels['tz:europe:budapest'] = 'بودابست';
$labels['tz:europe:dublin'] = 'دوبلين';
$labels['tz:europe:gibraltar'] = 'جبل طارق';
$labels['tz:europe:helsinki'] = 'هيلسينكي';
$labels['tz:europe:istanbul'] = 'إسطنبول';
$labels['tz:europe:kiev'] = 'كييف';
$labels['tz:europe:lisbon'] = 'لشبونة';
$labels['tz:europe:london'] = 'لندن';
$labels['tz:europe:luxembourg'] = 'اللوكسومبورغ';
$labels['tz:europe:madrid'] = 'مادريد';
$labels['tz:europe:malta'] = 'مالطا';
$labels['tz:europe:monaco'] = 'موناكو';
$labels['tz:europe:moscow'] = 'موسكو';
$labels['tz:europe:oslo'] = 'أوسلو';
$labels['tz:europe:paris'] = 'باريس';
$labels['tz:europe:rome'] = 'روما';
$labels['tz:europe:sarajevo'] = 'ساراييفو';
$labels['tz:europe:vatican'] = 'الفاتيكان';
$labels['tz:europe:vienna'] = 'فيينا';
$labels['tz:europe:warsaw'] = 'فارسوفيا';
$labels['tz:europe:zagreb'] = 'زاغرب';
$labels['tz:pacific:midway'] = 'ميدواي';
$labels['tz:pacific:tahiti'] = 'تاهيتي';
