<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'เกิดข้อผิดพลาดบางประการ!';
$messages['loginfailed']  = 'ไม่สามารถเข้าสู่ระบบได้';
$messages['cookiesdisabled'] = 'Browser ของคุณไม่ได้เปิดการใช้งาน Cookie ไว้';
$messages['sessionerror'] = 'Your session is invalid or expired';
$messages['storageerror'] = 'ไม่สามารถติดต่อ IMAP Server ได้';
$messages['servererror'] = 'เกิดข้อผิดพลาดเกี่ยวกับเซิร์ฟเวอร์';
$messages['dberror'] = 'เกิดข้อผิดพลาดเกี่ยวกับฐานข้อมูล';
$messages['invalidhost'] = 'ชื่อเซิร์ฟเวอร์ไม่ถูกต้อง';
$messages['nomessagesfound'] = 'ไม่มีจดหมายในกล่องจดหมายนี้';
$messages['refreshing'] = 'กำลังรีเฟรช...';
$messages['loading'] = 'Loading...';
$messages['uploading'] = 'กำลังอัพโหลดไฟล์...';
$messages['uploadingmany'] = 'กำลังอัพโหลดไฟล์...';
$messages['loadingdata'] = 'กำลังโหลดข้อมูล...';
$messages['checkingmail'] = 'กำลังเช็คจดหมายใหม่...';
$messages['sendingmessage'] = 'กำลังส่งจดหมาย...';
$messages['messagesent'] = 'จดหมายถูกส่งเรียบร้อยแล้ว';
$messages['savingmessage'] = 'กำลังบันทึกจดหมาย...';
$messages['messagesaved'] = 'จดหมายถูกบันทึกเป็นจดหมายร่าง';
$messages['successfullysaved'] = 'บันทึกเรียบร้อยแล้ว';
$messages['addedsuccessfully'] = 'รายชื่อถูกบันทึกเรียบร้อยแล้ว';
$messages['blockedimages'] = 'เพื่อปกป้องความส่วนตัว รูปจากภายนอกในจดหมายนี้จะถูกปิดบังไว้';
$messages['encryptedmessage'] = 'จดหมายถูกเข้ารหัสไม่สามารถแสดงผลได้';
$messages['nocontactsfound'] = 'ไม่พบรายชื่อที่ค้นหา';
$messages['contactnotfound'] = 'ไม่พบรายชื่อที่ค้นหา';
$messages['sendingfailed'] = 'การส่งจดหมายล้มเหลว';
$messages['errormoving'] = 'ไม่สามารถย้ายจดหมายได้';
$messages['errordeleting'] = 'ไม่สามารถลบจดหมายได้';
$messages['deletecontactconfirm']  = 'คุณมั่นใจที่ต้องการลบรายชื่อที่เลือกใช่หรือไม่?';
$messages['deletemessagesconfirm'] = 'คุณมั่นใจที่ต้องการลบจดหมายที่เลือกใช่หรือไม่?';
$messages['deletefolderconfirm']  = 'คุณมั่นใจที่ต้องการลบแฟ้มนี้หรือไม่?';
$messages['purgefolderconfirm']  = 'คุณมั่นใจที่ต้องการลบจดหมายทั้งหมดในแฟ้มนี้ใช่หรือไม่?';
$messages['contactdeleting'] = 'กำลังลบรายชื่อผู้ติดต่อ...';
$messages['groupdeleting'] = 'กำลังลบกลุ่ม...';
$messages['folderdeleting'] = 'กำลังลบโฟลเดอร์...';
$messages['foldermoving'] = 'กำลังย้ายโฟลเดอร์...';
$messages['formincomplete'] = 'ฟอร์มยังไม่ครบถ้วนสมบูรณ์';
$messages['noemailwarning'] = 'โปรดใส่อีเมล์ให้ถูกต้อง';
$messages['nonamewarning']  = 'โปรดใส่ชื่อ';
$messages['nopagesizewarning'] = 'โปรดใส่จำนวนหน้า';
$messages['norecipientwarning'] = 'โปรดใส่ผู้รับอย่างน้อย 1 ชื่อ';
$messages['nosubjectwarning']  = 'หัวจดหมายว่างเปล่า คุณต้องการใส่หัวจดหมายเดี๋ยวนี้หรือไม่?';
$messages['nobodywarning'] = 'คุณต้องการส่งจดหมายโดยไม่มีข้อความใช่หรือไม่?';
$messages['nosearchname'] = 'โปรดใสชื่อหรืออีเมล์';
$messages['searchsuccessful'] = 'พบจดหมายจำนวน $nr ฉบับ';
$messages['searchnomatch'] = 'การค้นหาไม่พบ';
$messages['searching'] = 'กำลังค้นหา...';
$messages['checking'] = 'กำลังตรวจสอบ...';
$messages['nospellerrors'] = 'ไม่พบคำที่สะกดผิด';
$messages['folderdeleted'] = 'ลบแฟ้มเสร็จสมบูรณ์';
$messages['deletedsuccessfully'] = 'ลบเสร็จสมบูรณ์';
$messages['converting'] = 'นำเอาหารจัดรูปแบบในจดหมายออก...';
$messages['messageopenerror'] = 'ไม่สามารถอ่านจดหมายจาก Server ได้';
$messages['fileuploaderror'] = 'การอัพโหลดล้มเหลว';
$messages['filesizeerror'] = 'ไฟล์มีขนาดใหญ่เกิน $size';
$messages['sourceisreadonly'] = 'จดหมายนี้เป็นแบบอ่านอย่างเดียว';
$messages['errorsavingcontact'] = 'ไม่สามารถบันทึกรายชื่อได้';
$messages['movingmessage'] = 'กำลังย้ายข้อความ...';
$messages['copyingmessage'] = 'กำลังคัดลอกข้อความ...';
$messages['copyingcontact'] = 'กำลังคัดลอกรายชื่อผู้ติดต่อ...';
$messages['deletingmessage'] = 'กำลังลบข้อความ...';
$messages['importwait'] = 'กำลังนำเข้าข้อมูล, โปรดรอสักครู่';
