<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Կիսվել';
$labels['myrights'] = 'Մուտքի իրավունքներ';
$labels['username'] = 'Օգտատեր`';
$labels['advanced'] = 'Առաջադեմ ռեժիմ';
$labels['add'] = 'Ավելացնել';
$labels['newuser'] = 'Ավելացնել գրառում';
$labels['editperms'] = 'Խմբագրել թույլտվությունները';
$labels['actions'] = 'Մուտքի իրավունքների գործողություններ…';
$labels['anyone'] = 'Բոլոր օգտվողները (ցանկացած)';
$labels['anonymous'] = 'Հյուրերը (անանուն)';
$labels['identifier'] = 'Նկարագրիչ';
$labels['acll'] = 'Փնտրում';
$labels['aclr'] = 'Կարդալ հաղորդագրությունները';
$labels['acls'] = 'Պահպանել դիտման կարգավիճակը';
$labels['aclw'] = 'Գրառման նշումներ';
$labels['acli'] = 'Ներդնել (Պատճենել ներս)';
$labels['aclp'] = 'Հրապարակել';
$labels['aclc'] = 'Ստեղծել ենթապանակներ';
$labels['aclk'] = 'Ստեղծել ենթապանակներ';
$labels['acld'] = 'Ջնջել հաղորդագրությունները';
$labels['aclt'] = 'Ջնջել հաղորդագրությունները';
$labels['acle'] = 'Հեռացնել';
$labels['aclx'] = 'Ջնջել պանակը';
$labels['acla'] = 'Կառավարել';
$labels['acln'] = 'Ծանոթագրել հաղորդագրությունները';
$labels['aclfull'] = 'Լրիվ վերահսկում';
$labels['aclother'] = 'Այլ';
$labels['aclread'] = 'Կարդալ';
$labels['aclwrite'] = 'Գրել';
$labels['acldelete'] = 'Ջնջել';
$labels['shortacll'] = 'Փնտրում';
$labels['shortaclr'] = 'Կարդալ';
$labels['shortacls'] = 'Պահել';
$labels['shortaclw'] = 'Գրել';
$labels['shortacli'] = 'Ներդնել';
$labels['shortaclp'] = 'Հրապարակել';
$labels['shortaclc'] = 'Ստեղծել';
$labels['shortaclk'] = 'Ստեղծել';
$labels['shortacld'] = 'Ջնջել';
$labels['shortaclt'] = 'Ջնջել';
$labels['shortacle'] = 'Հեռացնել';
$labels['shortaclx'] = 'Պանակի ջնջում';
$labels['shortacla'] = 'Կառավարել';
$labels['shortacln'] = 'Ծանոթագրել';
$labels['shortaclother'] = 'Այլ';
$labels['shortaclread'] = 'Կարդալ';
$labels['shortaclwrite'] = 'Գրել';
$labels['shortacldelete'] = 'Ջնջել';
$labels['longacll'] = 'Պանակը երևում է ցուցակներում և նրան հնարավոր է բաժանորդագրվել';
$labels['longaclr'] = 'Պանակը կարող է բացվել ընթերցման համար';
$labels['longacls'] = 'Տեսված հաղորդագրությունների նշումը կարող է փոփոխվել';
$labels['longaclw'] = 'Հաղորդագրությունների նշումները և հիմնաբառերը կարող են փոփոխվել, բացառությամբ Տեսած և Ջնջված նշումների';
$labels['longacli'] = 'Հաղորդագրությունները կարող են գրվել և պատճենվել պանակի մեջ';
$labels['longaclp'] = 'Հաղորդագրությունները կարող են հրապարակվել այս պանակում';
$labels['longaclc'] = 'Պանակները կարող են ստեղծվել (կամ վերանվանվել) այս պանակում';
$labels['longaclk'] = 'Պանակները կարող են ստեղծվել (կամ վերանվանվել) այս պանակում';
$labels['longacld'] = 'Հաղորդագրությունների Ջնջել նշումը կարող է փոփոխվել';
$labels['longaclt'] = 'Հաղորդագրությունների Ջնջել նշումը կարող է փոփոխվել';
$labels['longacle'] = 'Հաղորդագրությունները կարող են հեռացվել';
$labels['longaclx'] = 'Պանակը կարող է ջնջվել կամ վերանվանվել';
$labels['longacla'] = 'Պանակի մուտքի իրավունքները կարող են փոփոխվել';
$labels['longacln'] = 'Հաղորդագրությունների բաշխված տվյալները (ծանոթագրությունները) կարող են փոփոխվել';
$labels['longaclfull'] = 'Լրիվ վերահսկում ներառյալ պանակների կառավարումը';
$labels['longaclread'] = 'Պանակը կարող է բացվել ընթերցման համար';
$labels['longaclwrite'] = 'Հաղորդագրությունները կարող են նշվել, ստեղծվել և պատճենվել այս պանակում';
$labels['longacldelete'] = 'Հաղորդագրությունները կարող են ջնջվել';
$labels['longaclother'] = 'Մուտքի այլ իրավունքները';
$labels['ariasummaryacltable'] = 'Մուտքի իրավունքների ցուցակը';
$labels['arialabelaclactions'] = 'Գործողությունների ցուցակը';
$labels['arialabelaclform'] = 'Մուտքի իրավունքների բլանկ';
$messages['deleting'] = 'Ջնջվում են մուտքի իրավունքները…';
$messages['saving'] = 'Պահպանվում են մուտքի իրավունքները…';
$messages['updatesuccess'] = 'Մուտքի իրավունքները բարեհաջող փոփոխվեցին։';
$messages['deletesuccess'] = 'Մուտքի իրավունքները բարեհաջող ջնջվեցին։';
$messages['createsuccess'] = 'Մուտքի իրավունքները բարեհաջող ավելացվեցվին։';
$messages['updateerror'] = 'Մուտքի իրավունքների թարմացումը անջատել';
$messages['deleteerror'] = 'Մուտքի իրավունքները ջնջումը ձախողվեց։';
$messages['createerror'] = 'Մուտքի իրավունքները ավելացումը ձախողվեց։';
$messages['deleteconfirm'] = 'Դուք վստա՞հ էք, որ ցանկանում եք նշված օգտվողներին զրկել մուտքի իրավունքներից։';
$messages['norights'] = 'Ոչ մի իրավունք չի՛ նշվել։';
$messages['nouser'] = 'Օգտվողի անունը չի՛ նշվել։';
