<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Parzûn';
$labels['filtername'] = 'Navê parzûnê';
$labels['newfilter'] = 'Parzûna nû';
$labels['filteradd'] = 'Parzûnê tevlî bike';
$labels['filterdel'] = 'Parzûnê jê bibe';
$labels['actions'] = 'Çalakî';
$labels['moveup'] = 'Bilivîne jor';
$labels['movedown'] = 'Bilivîne jêr';
$labels['filterany'] = 'hemû peyam';
$labels['filtercontains'] = 'dihewîne';
$labels['filternotcontains'] = 'nahebîne';
$labels['filteris'] = 'weke';
$labels['filterisnot'] = 'ne weke';
$labels['filterexists'] = 'heye';
$labels['filternotexists'] = 'tune ye';
$labels['filterunder'] = 'bin';
$labels['filterover'] = 'ser';
$labels['mime'] = 'MIME:';
$labels['mimepart'] = 'Beşa MIME:';
$labels['mime-message'] = 'peyam';
$labels['mime-type'] = 'cûre';
$labels['messagemoveto'] = 'Peyamê bilivîne bo';
$labels['messageredirect'] = 'Peyamê vegerîne';
$labels['messagecopyto'] = 'Peyamê jê bigire bo';
$labels['messagesendcopy'] = 'Jêbirina peyamê bişîne bo';
$labels['messagereply'] = 'Bi peyamekê bibersivîne';
$labels['messagedelete'] = 'Peyamê jê bibe';
$labels['add'] = 'Tevlî bike';
$labels['del'] = 'Jê bibe';
$labels['sender'] = 'Şander';
$labels['vacationaddr'] = 'Navnîşanên e-nameyê min';
$labels['vacationsubject'] = 'Mijara peyamê:';
$labels['days'] = 'roj';
$labels['seconds'] = 'çirke';
$labels['enable'] = 'Veke/Bigire';
$labels['active'] = 'çalak';
$labels['none'] = 'ne yek';
$labels['fromfile'] = 'ji pelê';
$labels['filterdisabled'] = 'Parzûn neçalak e';
$labels['countisgreaterthan'] = 'jimar mezintir e ji';
$labels['countisgreaterthanequal'] = 'jimar weke yan jî mezintir e ji';
$labels['countislessthan'] = 'jimar kêmtir e ji';
$labels['countequals'] = 'hejmar weke ';
$labels['countnotequals'] = 'hejmar ne weke';
$labels['flagread'] = 'Xwendî';
$labels['flagdeleted'] = 'Jêbirî';
$labels['flaganswered'] = 'Nebersivandî';
$labels['flagflagged'] = 'Bialakirî';
$labels['flagdraft'] = 'Reşnivîs';
$labels['headerfromstart'] = 'ji destpêkê';
$labels['varlength'] = 'Dirêjahî';
$labels['notify'] = 'Agahiyê bişîne';
$labels['notifyimportance'] = 'Girîng:';
$labels['notifyimportancelow'] = 'nizm';
$labels['notifyimportancenormal'] = 'normal';
$labels['notifyimportancehigh'] = 'bilind';
$labels['notifymethodmailto'] = 'Email';
$labels['notifymethodtel'] = 'Telefon';
$labels['notifymethodsms'] = 'SMS';
$labels['filtercreate'] = 'Parzingek çêke';
$labels['nextstep'] = 'Gava pêşde';
$labels['...'] = '...';
$labels['currdate'] = 'Dîroka niha';
$labels['datetest'] = 'Dîrok';
$labels['year'] = 'sal';
$labels['month'] = 'meh';
$labels['day'] = 'roj';
$labels['date'] = 'dîrok (ssss-mm--rr)';
$labels['julian'] = 'dîrok (julian)';
$labels['hour'] = 'saet';
$labels['minute'] = 'xulek';
$labels['second'] = 'saniye';
$labels['time'] = 'dem (ss:dd:ss)';
$labels['iso8601'] = 'dem (ISO8601)';
$labels['zone'] = 'qada demê';
$labels['weekday'] = 'rojên hefteyê (0-6)';
$labels['advancedopts'] = 'Vebijêrkên pêşketî';
$labels['address'] = 'navnîşan';
$labels['text'] = 'nivîs';
$labels['contenttype'] = 'cûreya naverokê';
$labels['modtype'] = 'cûre';
$labels['allparts'] = 'hemû';
$labels['user'] = 'bikarhêner';
$labels['detail'] = 'detay';
$labels['spamtestequals'] = 'weke';
$labels['spamtestnotequals'] = 'ne weke';
$labels['vacation.reply'] = 'Peyamê bibersivîne';
$labels['vacation.advanced'] = 'Sazkariyên pêşketî';
$labels['vacation.subject'] = 'Mijar';
$labels['vacation.start'] = 'Dema destpêkê';
$labels['vacation.end'] = 'Dema bidawîbûnê';
$labels['vacation.status'] = 'Rewş';
$labels['vacation.on'] = 'Vekirî';
$labels['vacation.off'] = 'Vemirî';
$labels['vacation.saving'] = 'Dane tê tomarkirin...';
$labels['vacation.keep'] = 'Bihêle';
$labels['forward.on'] = 'Vekirî';
$labels['forward.off'] = 'Vemirî';
$labels['forward.status'] = 'Rewş:';
$labels['forward.saving'] = 'Dane tê tomarkirin...';
$labels['message'] = 'Peyam';
