<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Дељење';
$labels['myrights'] = 'Права приступа';
$labels['username'] = 'Корисник:';
$labels['advanced'] = 'Напредни режим';
$labels['add'] = 'Додај';
$labels['newuser'] = 'Додај унос';
$labels['editperms'] = 'Уреди дозволе';
$labels['actions'] = 'Радње права приступа...';
$labels['anyone'] = 'Сви корисници (било ко)';
$labels['anonymous'] = 'Гости (анонимно)';
$labels['identifier'] = 'Идентификатор';
$labels['acll'] = 'Потражи';
$labels['aclr'] = 'Прочитане поруке';
$labels['acls'] = 'Очувај стање прегледаности';
$labels['acli'] = 'Убаци (копирај у)';
$labels['aclc'] = 'Направи потфасцикле';
$labels['aclk'] = 'Направи потфасцикле';
$labels['acld'] = 'Обриши поруке';
$labels['aclt'] = 'Обриши поруке';
$labels['aclx'] = 'Обриши фасциклу';
$labels['acla'] = 'Администрирај';
$labels['aclfull'] = 'Пуна контрола';
$labels['aclother'] = 'Друго';
$labels['aclread'] = 'Читање';
$labels['aclwrite'] = 'Упис';
$labels['acldelete'] = 'Обриши';
$labels['shortacll'] = 'Потражи';
$labels['shortaclr'] = 'Прочитана';
$labels['shortacls'] = 'Задржи';
$labels['shortaclw'] = 'Пиши';
$labels['shortacli'] = 'Убаци';
$labels['shortaclc'] = 'Направи';
$labels['shortaclk'] = 'Направи';
$labels['shortacld'] = 'Обриши';
$labels['shortaclt'] = 'Обриши';
$labels['shortacla'] = 'Администрирај';
$labels['shortaclother'] = 'Друго';
$labels['shortaclread'] = 'Читање';
$labels['shortaclwrite'] = 'Упис';
$labels['shortacldelete'] = 'Брисање';
