<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'एक त्रुटि पाई गई !';
$messages['loginfailed']  = 'लॉगिन नहीं हो पाया';
$messages['cookiesdisabled'] = 'आपका ब्राऊसर कुकी स्वीकार नहीं कर रहा है';
$messages['sessionerror'] = 'सत्र समाप्त या अवैद्य';
$messages['storageerror'] = 'आईमैप (IMAP) सर्वर से सम्पर्क नहीं हो पाया';
$messages['servererror'] = 'सर्वर त्रुटि';
$messages['dberror'] = 'डाटाबेस त्रुटि!';
$messages['windowopenerror'] = 'पॉपप विंडो अवरुद्ध किया गया था !';
$messages['requesttimedout'] = 'अनुरोध का समय समाप्त';
$messages['errorreadonly'] = 'कार्य करने में असमर्थ । फ़ोल्डर केवल पढ़ने के लिए है।';
$messages['nomessagesfound'] = 'इस मेलबॉक्स में कोई मेल नहीं है';
$messages['loading'] = 'लोड हो रहा है';
$messages['loadingdata'] = 'डाटा लोड हो रहा है...';
$messages['checkingmail'] = 'क्या नया मेल है?...';
$messages['sendingmessage'] = 'मेल भेजा जा रहा है...';
$messages['messagesent'] = 'मेल भेजा गया है';
$messages['savingmessage'] = 'मेल सहेजा जा रहा है...';
$messages['messagesaved'] = 'मेल ड्राफ़्ट फोल्डर में जमा हो रहा है';
$messages['successfullysaved'] = 'सहेजा गया है';
$messages['addedsuccessfully'] = 'पता खाते में पता जोडा गया है';
$messages['blockedimages'] = 'आप के प्राईवेसी के लिये और स्पैम से बचने के लिये इस मेल में सदूर चित्र नहीं दिखाये गये हैं।';
$messages['encryptedmessage'] = 'माफ़ कीजिये, यह मेल कूट रूप में है, इस कारण दिखाया नहीं जा सकता।';
$messages['nocontactsfound'] = 'कोई पता नहीं मिला';
$messages['sendingfailed'] = 'मेल नहीं भिज पाया';
$messages['errormoving'] = 'मेल खिस्का नहीं';
$messages['errordeleting'] = 'मेल मिटा नहीं';
$messages['deletecontactconfirm']  = 'चुने गये पते को सचमुच मिटाना है ?';
$messages['deletemessagesconfirm'] = 'चुने गये मेल को सचमुच मिटाना है ?';
$messages['deletefolderconfirm']  = 'फ़ोल्डर को सचमुच मिटाऐं ?';
$messages['purgefolderconfirm']  = 'फ़ोल्डर में पडे सारे मेल को सचमुच मिटाना है?';
$messages['formincomplete'] = 'फ़ॉर्म पूरी तरह से भरा नहीं';
$messages['noemailwarning'] = 'वैद्य मेल पता भरें';
$messages['nonamewarning']  = 'नाम भरें';
$messages['nopagesizewarning'] = 'पन्ना माप भरें';
$messages['norecipientwarning'] = 'कम-से-कम एक पाने वाले का पता भरें';
$messages['nosubjectwarning']  = 'मेल का कोई विशय नहीं बताया गया है। क्या आप विशय डालना चाहते हैं ?';
$messages['nobodywarning'] = 'बिना कुछ लिखे मेल भेजें?';
$messages['nosearchname'] = 'पता या पते का नाम भरें';
$messages['searchsuccessful'] = '$nr मेल मिले';
$messages['searchnomatch'] = 'खोज असफ़ल';
$messages['searching'] = 'खोजा रहे हैं...';
$messages['checking'] = 'चाँचा चा रहा है...';
$messages['nospellerrors'] = 'कोई स्पैलिंग गलती नहीं मिली';
$messages['folderdeleted'] = 'फ़ोल्डर मिट गया';
$messages['deletedsuccessfully'] = 'मिट गया';
$messages['converting'] = 'मेल से फ़ॉर्मैटिंग निकाला जा रहा है...';
$messages['messageopenerror'] = 'सर्वर से मेल लोड नहीं हो पाया';
$messages['fileuploaderror'] = 'फ़ाईल अपलोड नहीं हो पाया';
$messages['filesizeerror'] = 'अपलोड के लिये फ़ाईल हद $size से बड़ा है';
