<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['welcome'] = 'Bem-vindo ao $product';
$labels['username'] = 'Utilizador';
$labels['password'] = 'Senha';
$labels['server'] = 'Servidor';
$labels['login'] = 'Entrar';
$labels['oauthlogin'] = 'Iniciar sessão com $provider';
$labels['menu'] = 'Menu';
$labels['logout'] = 'Sair';
$labels['mail'] = 'Mensagens';
$labels['settings'] = 'Definições';
$labels['addressbook'] = 'Contactos';
$labels['darkmode'] = 'Modo escuro';
$labels['lightmode'] = 'Modo claro';
$labels['inbox'] = 'A receber';
$labels['drafts'] = 'Rascunhos';
$labels['sent'] = 'Enviados';
$labels['trash'] = 'Reciclagem';
$labels['junk'] = 'Spam';
$labels['show_real_foldernames'] = 'Mostrar nomes reais para as pastas especiais';
$labels['subject'] = 'Assunto';
$labels['from'] = 'De';
$labels['sender'] = 'Remetente';
$labels['to'] = 'Para';
$labels['cc'] = 'Cc';
$labels['bcc'] = 'Bcc';
$labels['replyto'] = 'Responder a';
$labels['followupto'] = 'No seguimento de';
$labels['date'] = 'Data';
$labels['size'] = 'Tamanho';
$labels['priority'] = 'Prioridade';
$labels['organization'] = 'Entidade';
$labels['readstatus'] = 'Estado de leitura';
$labels['listoptions'] = 'Lista de opções...';
$labels['listoptionstitle'] = 'Opções de lista';
$labels['mailboxlist'] = 'Pastas';
$labels['messagesfromto'] = 'Mensagens de $from a $to de $count';
$labels['threadsfromto'] = 'Tópicos de $from a $to de $count';
$labels['messagenrof'] = 'Mensagem $nr de $count';
$labels['fromtoshort'] = '$from – $to de $count';
$labels['copy'] = 'Copiar';
$labels['move'] = 'Mover';
$labels['moveto'] = 'Mover para...';
$labels['copyto'] = 'Copiar para...';
$labels['download'] = 'Descarregar';
$labels['open'] = 'Abrir';
$labels['showattachment'] = 'Mostrar';
$labels['showanyway'] = 'Mostrar na mesma';
$labels['filename'] = 'Nome do ficheiro';
$labels['filesize'] = 'Tamanho do ficheiro';
$labels['addtoaddressbook'] = 'Adicionar à lista de contactos';
$labels['sun'] = 'Dom';
$labels['mon'] = 'Seg';
$labels['tue'] = 'Ter';
$labels['wed'] = 'Qua';
$labels['thu'] = 'Qui';
$labels['fri'] = 'Sex';
$labels['sat'] = 'Sáb';
$labels['sunday'] = 'Domingo';
$labels['monday'] = 'Segunda-feira';
$labels['tuesday'] = 'Terça-feira';
$labels['wednesday'] = 'Quarta-feira';
$labels['thursday'] = 'Quinta-feira';
$labels['friday'] = 'Sexta-feira';
$labels['saturday'] = 'Sábado';
$labels['jan'] = 'Jan';
$labels['feb'] = 'Fev';
$labels['mar'] = 'Mar';
$labels['apr'] = 'Abr';
$labels['may'] = 'Maio';
$labels['jun'] = 'Jun';
$labels['jul'] = 'Jul';
$labels['aug'] = 'Ago';
$labels['sep'] = 'Set';
$labels['oct'] = 'Out';
$labels['nov'] = 'Nov';
$labels['dec'] = 'Dez';
$labels['longjan'] = 'Janeiro';
$labels['longfeb'] = 'Fevereiro';
$labels['longmar'] = 'Março';
$labels['longapr'] = 'Abril';
$labels['longmay'] = 'Maio';
$labels['longjun'] = 'Junho';
$labels['longjul'] = 'Julho';
$labels['longaug'] = 'Agosto';
$labels['longsep'] = 'Setembro';
$labels['longoct'] = 'Outubro';
$labels['longnov'] = 'Novembro';
$labels['longdec'] = 'Dezembro';
$labels['today'] = 'Hoje';
$labels['refresh'] = 'Atualizar';
$labels['checkmail'] = 'Verificar por novas mensagens';
$labels['compose'] = 'Nova mensagem';
$labels['writenewmessage'] = 'Criar mensagem';
$labels['reply'] = 'Responder';
$labels['replytomessage'] = 'Responder';
$labels['replytoallmessage'] = 'Responder a lista ou ao remetente e todos os destinatários';
$labels['replyall'] = 'Responder a todos';
$labels['replylist'] = 'Responder à lista';
$labels['forward'] = 'Reencaminhar';
$labels['forwardinline'] = 'Reencaminhar no texto';
$labels['forwardattachment'] = 'Reencaminhar como anexo';
$labels['forwardmessage'] = 'Reencaminhar';
$labels['bouncemsg'] = 'Reenviar (devolver)';
$labels['bounce'] = 'Reenviar';
$labels['deletemessage'] = 'Eliminar';
$labels['undeletemessage'] = 'Restaurar mensagem';
$labels['movemessagetotrash'] = 'Mover para reciclagem';
$labels['printmessage'] = 'Imprimir';
$labels['previousmessage'] = 'Mensagem anterior';
$labels['firstmessage'] = 'Primeira mensagem';
$labels['nextmessage'] = 'Próxima mensagem';
$labels['lastmessage'] = 'Última mensagem';
$labels['backtolist'] = 'Voltar';
$labels['viewsource'] = 'Mostrar código fonte';
$labels['mark'] = 'Marcar';
$labels['markmessages'] = 'Marcar mensagens';
$labels['markread'] = 'Como lida(s)';
$labels['markunread'] = 'Como não lida(s)';
$labels['markflagged'] = 'Com sinalização';
$labels['markunflagged'] = 'Como sem sinalização';
$labels['markundeleted'] = 'Como não eliminado';
$labels['markasread'] = 'Marcar como lida';
$labels['markasunread'] = 'Marcar como não lida';
$labels['markasflagged'] = 'Marcar como sinalizada';
$labels['markasunflagged'] = 'Marcar como não sinalizada';
$labels['moreactions'] = 'Mais ações...';
$labels['markallread'] = 'Marcar todas como Lidas';
$labels['folders-cur'] = 'Apenas pasta selecionada';
$labels['folders-sub'] = 'Pasta selecionada e respetivas subpastas';
$labels['folders-all'] = 'Todas as pastas';
$labels['more'] = 'Mais';
$labels['back'] = 'Voltar';
$labels['options'] = 'Opções';
$labels['composeoptions'] = 'Opções de composição';
$labels['optionsandattachments'] = 'Opções e anexos';
$labels['actions'] = 'Ações';
$labels['first'] = 'Primeiro';
$labels['last'] = 'Último';
$labels['previous'] = 'Anterior';
$labels['next'] = 'Seguinte';
$labels['select'] = 'Selecionar';
$labels['selection'] = 'Selecção';
$labels['all'] = 'Todas';
$labels['none'] = 'Nenhum';
$labels['currpage'] = 'Página atual';
$labels['isread'] = 'Ler';
$labels['unread'] = 'Não lidas';
$labels['flagged'] = 'Sinalizadas';
$labels['unflagged'] = 'Não sinalizado';
$labels['unanswered'] = 'Não respondidas';
$labels['withattachment'] = 'Com anexo';
$labels['deleted'] = 'Eliminadas';
$labels['undeleted'] = 'Não eliminada';
$labels['replied'] = 'Respondido';
$labels['forwarded'] = 'Reencaminhado';
$labels['invert'] = 'Inverter seleção';
$labels['filter'] = 'Filtro';
$labels['list'] = 'Em lista';
$labels['threads'] = 'Tópicos';
$labels['expand-all'] = 'Expandir tudo';
$labels['expand-unread'] = 'Expandir não lidas';
$labels['collapse-all'] = 'Recolher tudo';
$labels['threaded'] = 'Por tópicos';
$labels['showunread'] = 'Mostrar mensagens não lidas';
$labels['autoexpand_threads'] = 'Expandir tópicos das mensagens';
$labels['do_expand'] = 'todos os tópicos';
$labels['expand_only_unread'] = 'só com mensagens não lidas';
$labels['fromto'] = 'De/Para';
$labels['flag'] = 'Sinalizar';
$labels['attachment'] = 'Anexo';
$labels['nonesort'] = 'Nenhum';
$labels['sentdate'] = 'Data de envio';
$labels['arrival'] = 'Data de receção';
$labels['asc'] = 'crescente';
$labels['desc'] = 'decrescente';
$labels['listcolumns'] = 'Lista de colunas';
$labels['listsorting'] = 'Ordenar por';
$labels['listorder'] = 'Ordenação';
$labels['listmode'] = 'Modo de visualização';
$labels['lmode'] = 'Modo de lista';
$labels['layout'] = 'Modelo';
$labels['layoutwidescreen'] = 'Panorâmico';
$labels['layoutdesktop'] = 'Área de Trabalho';
$labels['layoutlist'] = 'Lista';
$labels['layoutwidescreendesc'] = 'Widescreen (vista de 3 colunas)';
$labels['layoutdesktopdesc'] = 'Área de trabalho (lista ampla e pré-visualização da mensagem abaixo)';
$labels['layoutlistdesc'] = 'Lista (sem pré-visualização da mensagem)';
$labels['folderactions'] = 'Ações para pastas...';
$labels['compact'] = 'Compactar';
$labels['empty'] = 'Esvaziar';
$labels['importmessages'] = 'Importar mensagens';
$labels['mailimportdesc'] = 'Pode carregar emails usando ficheiros no formato <a href="https://en.wikipedia.org/wiki/Email#Message_format">MIME</a> ou <a href="https://en.wikipedia.org/wiki/Mbox">Mbox</a>.';
$labels['mailimportzip'] = 'Vários ficheiros podem ser compactados em arquivos zip.';
$labels['quota'] = 'Espaço utilizado';
$labels['unknown'] = 'desconhecido';
$labels['unlimited'] = 'ilimitado';
$labels['quotatype'] = 'Tipo de cota';
$labels['quotatotal'] = 'Limite';
$labels['quotaused'] = 'Usado';
$labels['quotastorage'] = 'Espaço em disco';
$labels['quotamessage'] = 'Número de mensagens';
$labels['shortheaderdate'] = 'Em $date';
$labels['shortheaderto'] = 'Para $to em $date';
$labels['shortheaderfrom'] = 'De $from em $date
';
$labels['quicksearch'] = 'Pesquisa rápida';
$labels['searchplaceholder'] = 'Pesquisar...';
$labels['resetsearch'] = 'Limpar pesquisa';
$labels['searchmod'] = 'Modificadores de pesquisa';
$labels['msgtext'] = 'Mensagem completa';
$labels['body'] = 'Corpo';
$labels['type'] = 'Tipo';
$labels['namex'] = 'Nome';
$labels['searchscope'] = 'Âmbito';
$labels['currentfolder'] = 'Pasta atual';
$labels['subfolders'] = 'Esta pasta e subpastas';
$labels['allfolders'] = 'Todas as pastas';
$labels['searchinterval-1W'] = 'Com mais de uma semana';
$labels['searchinterval-1M'] = 'Com mais de um mês';
$labels['searchinterval-1Y'] = 'Com mais de um ano';
$labels['searchinterval1W'] = 'Com menos de uma semana';
$labels['searchinterval1M'] = 'Com menos de um mês';
$labels['searchinterval1Y'] = 'Com menos de um ano';
$labels['infolder'] = 'Pasta: $folder';
$labels['currentaddressbook'] = 'Livro de endereços atual';
$labels['alladdressbooks'] = 'Todos os livros de endereços';
$labels['openinextwin'] = 'Abrir numa nova janela';
$labels['emlsave'] = 'Descarregar (formato .eml)';
$labels['changeformattext'] = 'Mostrar em formato de texto simples';
$labels['changeformathtml'] = 'Mostrar em formato HTML';
$labels['editasnew'] = 'Editar como nova';
$labels['send'] = 'Enviar';
$labels['sendmessage'] = 'Enviar';
$labels['savemessage'] = 'Guardar como rascunho';
$labels['addattachment'] = 'Adicionar anexo';
$labels['charset'] = 'Charset';
$labels['editortype'] = 'Tipo de editor';
$labels['returnreceipt'] = 'Recibo de leitura';
$labels['dsn'] = 'Recibo de entrega';
$labels['keepformatting'] = 'Manter formatação';
$labels['mailreplyintro'] = 'A $date, $sender escreveu:';
$labels['originalmessage'] = 'Mensagem original';
$labels['selectimage'] = 'Selecionar imagem';
$labels['addimage'] = 'Adicionar imagem';
$labels['selectmedia'] = 'Selecionar filme';
$labels['addmedia'] = 'Adicionar filme';
$labels['encrypt'] = 'Encriptar';
$labels['encryptmessage'] = 'Encriptar mensagem';
$labels['encryptmessagemailvelope'] = 'Encriptar mensagem com Mailvelope';
$labels['importpubkeys'] = 'Importar chaves públicas';
$labels['encryptedsendialog'] = 'A enviar mensagem encriptada';
$labels['encryptandsign'] = 'Encriptar e assinar';
$labels['keyid'] = 'ID da chave';
$labels['keylength'] = 'Bits';
$labels['keyexpired'] = 'Expirada';
$labels['keyrevoked'] = 'Revogada';
$labels['bccinstead'] = 'Usar Bcc';
$labels['addheader'] = 'Adicionar campo (Cc, Bcc...)';
$labels['insert'] = 'Inserir';
$labels['insertcontact'] = 'Inserir contacto(s)';
$labels['recipient'] = 'Destinatário';
$labels['recipientedit'] = 'Editar destinatário';
$labels['editidents'] = 'Editar entidades';
$labels['spellcheck'] = 'Ortografia';
$labels['checkspelling'] = 'Verificar ortografia';
$labels['resumeediting'] = 'Continuar edição';
$labels['revertto'] = 'Reverter para';
$labels['restore'] = 'Restaurar';
$labels['restoremessage'] = 'Restaurar mensagem?';
$labels['ignore'] = 'Ignorar';
$labels['responses'] = 'Respostas';
$labels['insertresponse'] = 'Insira uma resposta';
$labels['manageresponses'] = 'Gerir respostas';
$labels['newresponse'] = 'Criar nova resposta';
$labels['addresponse'] = 'Adicionar resposta';
$labels['editresponse'] = 'Editar resposta';
$labels['editresponses'] = 'Editar respostas';
$labels['responsename'] = 'Nome';
$labels['responsetext'] = 'Texto da resposta';
$labels['attach'] = 'Anexar';
$labels['attachments'] = 'Anexos';
$labels['upload'] = 'Carregar';
$labels['uploadprogress'] = '$percent ($current de $total)';
$labels['close'] = 'Fechar';
$labels['messageoptions'] = 'Opções de mensagens...';
$labels['togglecomposeoptions'] = 'Alternar opções de composição';
$labels['attachmentrename'] = 'Renomear anexo';
$labels['low'] = 'Baixa';
$labels['lowest'] = 'Muito baixa';
$labels['normal'] = 'Normal';
$labels['high'] = 'Alta';
$labels['highest'] = 'Muito alta';
$labels['nosubject'] = '(sem assunto)';
$labels['showimages'] = 'Mostrar imagens';
$labels['allow'] = 'Permitir';
$labels['alwaysshow'] = 'Mostrar sempre as imagens de $sender';
$labels['alwaysallow'] = 'Permitir sempre de $sender';
$labels['isdraft'] = 'Esta é uma mensagem de rascunho.';
$labels['andnmore'] = '$nr mais...';
$labels['details'] = 'Detalhes';
$labels['summary'] = 'Resumo';
$labels['headers'] = 'Cabeçalhos';
$labels['allheaders'] = 'Todos os cabeçalhos';
$labels['togglemoreheaders'] = 'Mostrar cabeçalhos adicionais da mensagem';
$labels['togglefullheaders'] = 'Mostrar cabeçalho original da mensagem';
$labels['htmltoggle'] = 'HTML';
$labels['plaintoggle'] = 'Texto simples';
$labels['savesentmessagein'] = 'Guardar mensagem enviada em';
$labels['dontsave'] = 'não guardar';
$labels['maxuploadsize'] = 'Tamanho máximo permitido do ficheiro é $size';
$labels['addcc'] = 'Adicionar Cc';
$labels['addbcc'] = 'Adicionar Bcc';
$labels['addreplyto'] = 'Adicionar Responder a';
$labels['addfollowupto'] = 'Adicionar No seguimento de';
$labels['sendreceipt'] = 'Enviar recibo de leitura?';
$labels['mdnrequest'] = 'O remetente desta mensagem pediu para ser notificado quando esta mensagem fosse lida. Deseja enviar uma notificação?';
$labels['receiptread'] = 'Recibo de leitura';
$labels['yourmessage'] = 'Isto é um recibo de leitura da sua mensagem';
$labels['receiptnote'] = 'Nota: este recibo apenas indica que a mensagem foi aberta pelo destinatário. Não garante que a mensagem foi lida ou compreendida.';
$labels['sendalwaysto'] = 'Enviar sempre para $email';
$labels['zoomin'] = 'Ampliar';
$labels['zoomout'] = 'Reduzir';
$labels['rotate'] = 'Rodar';
$labels['increaseimage'] = 'Aumentar tamanho da imagem';
$labels['decreaseimage'] = 'Reduzir tamanho da imagem';
$labels['rotateimage'] = 'Rodar imagem';
$labels['showtools'] = 'Mostrar ferramentas de imagem';
$labels['hidetools'] = 'Ocultar ferramentas de imagem';
$labels['name'] = 'Nome exibido';
$labels['firstname'] = 'Primeiro nome';
$labels['surname'] = 'Apelido';
$labels['middlename'] = 'Outros nomes';
$labels['nameprefix'] = 'Título';
$labels['namesuffix'] = 'Sufixo';
$labels['nickname'] = 'Pseudónimo';
$labels['jobtitle'] = 'Cargo';
$labels['department'] = 'Departamento';
$labels['gender'] = 'Género';
$labels['maidenname'] = 'Nome solteiro';
$labels['email'] = 'Email';
$labels['phone'] = 'Telefone';
$labels['address'] = 'Endereço';
$labels['street'] = 'Rua';
$labels['locality'] = 'Cidade';
$labels['zipcode'] = 'Código postal';
$labels['region'] = 'Concelho';
$labels['country'] = 'País';
$labels['birthday'] = 'Data de nascimento';
$labels['anniversary'] = 'Aniversário';
$labels['website'] = 'Página web';
$labels['instantmessenger'] = 'Endereço IM';
$labels['notes'] = 'Notas';
$labels['male'] = 'masculino';
$labels['female'] = 'feminino';
$labels['nonbinary'] = 'não binário';
$labels['othergender'] = 'outro';
$labels['manager'] = 'Gestor';
$labels['assistant'] = 'Assistente';
$labels['spouse'] = 'Cônjuge';
$labels['allfields'] = 'Todos os campos';
$labels['search'] = 'Pesquisar';
$labels['searchresult'] = 'Resultado da pesquisa';
$labels['advsearch'] = 'Pesquisa avançada';
$labels['advanced'] = 'Pesquisa avançada';
$labels['other'] = 'Outro';
$labels['printcontact'] = 'Imprimir contacto';
$labels['qrcode'] = 'Código QR';
$labels['typehome'] = 'Casa';
$labels['typework'] = 'Trabalho';
$labels['typeother'] = 'Outro';
$labels['typemobile'] = 'Telemóvel';
$labels['typemain'] = 'Principal';
$labels['typehomefax'] = 'Fax da residência';
$labels['typeworkfax'] = 'Fax da empresa';
$labels['typecar'] = 'Carro';
$labels['typepager'] = 'Pager';
$labels['typevideo'] = 'Vídeo';
$labels['typeassistant'] = 'Assistente';
$labels['typehomepage'] = 'Página Inicial';
$labels['typeblog'] = 'Blogue';
$labels['typeprofile'] = 'Perfil';
$labels['addfield'] = 'Adicionar campo...';
$labels['addcontact'] = 'Adicionar contacto';
$labels['editcontact'] = 'Editar contacto';
$labels['contacts'] = 'Contactos';
$labels['contactproperties'] = 'Dados do contacto';
$labels['contactnameandorg'] = 'Nome da Organização';
$labels['personalinfo'] = 'Informação pessoal';
$labels['personal'] = 'Pessoal';
$labels['contactphoto'] = 'Foto do contacto';
$labels['edit'] = 'Editar';
$labels['cancel'] = 'Cancelar';
$labels['save'] = 'Guardar';
$labels['delete'] = 'Eliminar';
$labels['discard'] = 'Rejeitar';
$labels['continue'] = 'Continuar';
$labels['ok'] = 'OK';
$labels['rename'] = 'Renomear';
$labels['addphoto'] = 'Adicionar';
$labels['replacephoto'] = 'Substituir';
$labels['uploadphoto'] = 'Carregar foto';
$labels['choosefile'] = 'Escolher ficheiro...';
$labels['choosefiles'] = 'Escolher ficheiros...';
$labels['browse'] = 'Procurar';
$labels['newcontact'] = 'Criar novo contacto';
$labels['deletecontact'] = 'Eliminar contacto(s) selecionado(s)';
$labels['composeto'] = 'Nova mensagem para';
$labels['contactsfromto'] = 'Contactos $from - $to de $count';
$labels['print'] = 'Imprimir';
$labels['export'] = 'Exportar';
$labels['exportall'] = 'Exportar todos';
$labels['exportsel'] = 'Exportar selecionados';
$labels['exportvcards'] = 'Exportar contactos no formato vCard';
$labels['newgroup'] = 'Criar novo grupo';
$labels['addgroup'] = 'Adicionar grupo';
$labels['grouprename'] = 'Renomear grupo';
$labels['groupdelete'] = 'Eliminar grupo';
$labels['groupassign'] = 'Atribuir a grupo...';
$labels['groupremove'] = 'Remover do grupo';
$labels['groupremoveselected'] = 'Remover o(s) contacto(s) selecionado(s) do grupo';
$labels['uponelevel'] = 'Um nível acima';
$labels['previouspage'] = 'Página anterior';
$labels['firstpage'] = 'Primeira página';
$labels['nextpage'] = 'Página seguinte';
$labels['lastpage'] = 'Última página';
$labels['group'] = 'Grupo';
$labels['groups'] = 'Grupos';
$labels['listgroup'] = 'Lista de membros do grupo';
$labels['personaladrbook'] = 'Endereços pessoais';
$labels['searchsave'] = 'Guardar pesquisa';
$labels['searchdelete'] = 'Eliminar pesquisa';
$labels['import'] = 'Importar';
$labels['importcontacts'] = 'Importar contactos';
$labels['importfromfile'] = 'Importar do ficheiro';
$labels['importtarget'] = 'Adicionar contactos a';
$labels['importreplace'] = 'Substituir todo o livro de endereços.';
$labels['importgroups'] = 'Importar atribuições de grupo';
$labels['importgroupsall'] = 'Todos (criar grupos se necessário)';
$labels['importgroupsexisting'] = 'Apenas para grupos existentes';
$labels['importdesc'] = 'Pode carregar contactos de um livro de endereços existente.<br/>Actualmente, suportamos a importação de endereços no formato de dados <a href="https://en.wikipedia.org/wiki/VCard">vCard</a> ou CSV (separados por vírgulas).';
$labels['importmapdesc'] = 'Confirme se a informação de mapeamento dos campos abaixo estão corretas antes de prosseguir com a importação de dados CSV (separado por vírgula).';
$labels['fieldnotmapped'] = 'Campo não mapeado (não importar)';
$labels['skipheader'] = 'Não importar a primeira linha (cabeçalhos)';
$labels['done'] = 'Concluído';
$labels['birth_day'] = 'Dia de aniversário';
$labels['birth_month'] = 'Mês de aniversário';
$labels['birth_year'] = 'Ano de aniversário';
$labels['settingsfor'] = 'Configurações para';
$labels['about'] = 'Acerca';
$labels['preferences'] = 'Preferências';
$labels['userpreferences'] = 'Preferências do utilizador';
$labels['editpreferences'] = 'Editar preferências do utilizador';
$labels['identities'] = 'Identidades';
$labels['manageidentities'] = 'Gerir identidades';
$labels['newidentity'] = 'Criar nova identidade';
$labels['addidentity'] = 'Adicionar identidade';
$labels['editidentity'] = 'Editar identidade';
$labels['identityencryption'] = 'Encriptação';
$labels['preferhtml'] = 'Mostrar mensagens em HTML';
$labels['defaultcharset'] = 'Conjunto de caracteres predefinido';
$labels['htmlmessage'] = 'Mensagem em HTML';
$labels['messagepart'] = 'Parte';
$labels['digitalsig'] = 'Assinatura digital';
$labels['dateformat'] = 'Formato da data';
$labels['timeformat'] = 'Formato da hora';
$labels['prettydate'] = 'Formatar datas';
$labels['setdefault'] = 'Marcar como predefinido';
$labels['autodetect'] = 'Auto';
$labels['language'] = 'Idioma';
$labels['timezone'] = 'Fuso horário';
$labels['pagesize'] = 'Linhas por página';
$labels['signature'] = 'Assinatura';
$labels['dstactive'] = 'Horário de verão';
$labels['showinextwin'] = 'Abrir mensagem numa nova janela';
$labels['composeextwin'] = 'Compor numa nova janela';
$labels['htmleditor'] = 'Escrever mensagens em HTML';
$labels['htmlonreply'] = 'apenas em resposta a mensagens HTML';
$labels['htmlonreplyandforward'] = 'no reencaminhamento ou resposta de mensagem em HTML';
$labels['htmlsignature'] = 'Assinatura em HTML';
$labels['showemail'] = 'Mostrar endereço de email com o nome a exibir';
$labels['previewpane'] = 'Mostrar pré-visualização';
$labels['skin'] = 'Visual da interface';
$labels['logoutclear'] = 'Esvaziar reciclagem ao sair';
$labels['logoutcompact'] = 'Compactar Caixa de entrada ao sair';
$labels['uisettings'] = 'Interface do utilizador';
$labels['serversettings'] = 'Definições do servidor';
$labels['mailboxview'] = 'Visualização da Caixa de entrada';
$labels['mdnrequests'] = 'Enviar notificações';
$labels['askuser'] = 'perguntar';
$labels['autosend'] = 'enviar recibo de leitura';
$labels['autosendknown'] = 'enviar recibo de leitura apenas para os meus contactos';
$labels['autosendknownignore'] = 'enviar recibo para os meus contactos, caso contrário, ignorar';
$labels['autosendtrusted'] = 'enviar recibo para remetentes confiáveis, caso contrário, pergunte-me';
$labels['autosendtrustedignore'] = 'enviar recibo para remetentes confiáveis, caso contrário, ignorar';
$labels['ignorerequest'] = 'ignorar pedido';
$labels['readwhendeleted'] = 'Marcar a mensagem como lida, ao eliminar';
$labels['flagfordeletion'] = 'Marcar a mensagem para eliminação em vez de a eliminar';
$labels['skipdeleted'] = 'Não mostrar mensagens eliminadas';
$labels['deletealways'] = 'Se ao mover mensagens para a reciclagem falhar, eliminá-las';
$labels['deletejunk'] = 'Eliminar diretamente as mensagens no Spam';
$labels['showremoteimages'] = 'Mostrar imagens externas';
$labels['allowremoteresources'] = 'Permitir recursos remotos (imagens, estilos)';
$labels['fromknownsenders'] = 'de remetentes conhecidos';
$labels['fromtrustedsenders'] = 'de remetentes confiáveis';
$labels['frommycontacts'] = 'dos meus contactos';
$labels['always'] = 'sempre';
$labels['alwaysbutplain'] = 'sempre, exceto quando responder a texto simples';
$labels['showinlineimages'] = 'Mostrar imagens anexadas abaixo da mensagem';
$labels['autosavedraft'] = 'Guardar rascunho automaticamente';
$labels['everynminutes'] = 'a cada $n minuto(s)';
$labels['refreshinterval'] = 'Atualizar (verificar por novas mensagens, etc.)';
$labels['never'] = 'nunca';
$labels['immediately'] = 'imediatamente';
$labels['messagesdisplaying'] = 'Visualização de mensagens';
$labels['messagescomposition'] = 'Composição de mensagens';
$labels['mimeparamfolding'] = 'Nome dos anexos';
$labels['2231folding'] = 'Total RFC 2231 (Thunderbird)';
$labels['miscfolding'] = 'RFC 2047/2231 (MS Outlook)';
$labels['2047folding'] = 'Total RFC 2047 (outro)';
$labels['force7bit'] = 'Usar codificação MIME para caracteres de 8 bits';
$labels['savelocalstorage'] = "Guardado no armazenamento local do navegador (temporariamente)";
$labels['advancedoptions'] = 'Opções avançadas';
$labels['toggleadvancedoptions'] = 'Alternar opções de avançadas';
$labels['focusonnewmessage'] = 'Ativar a janela do navegador na nova mensagem';
$labels['checkallfolders'] = 'Verificar por novas mensagens em todas as pastas';
$labels['displaynext'] = 'Mostrar próxima entrada da lista após eliminar/mover';
$labels['defaultfont'] = 'Tipo de letra padrão para mensagens HTML';
$labels['mainoptions'] = 'Opções';
$labels['browseroptions'] = 'Opções do browser';
$labels['section'] = 'Secção';
$labels['maintenance'] = 'Manutenção';
$labels['newmessage'] = 'Nova mensagem';
$labels['signatureoptions'] = 'Opções de assinatura';
$labels['whenreplying'] = 'Ao responder';
$labels['replyempty'] = 'Não incluir a mensagem original';
$labels['replytopposting'] = 'iniciar mensagem acima da original';
$labels['replytoppostingnoindent'] = 'Iniciar nova mensagem acima das citações (sem recuo)';
$labels['replybottomposting'] = 'iniciar mensagem abaixo da original';
$labels['replyremovesignature'] = 'Ao responder, remover a assinatura original da mensagem';
$labels['autoaddsignature'] = 'Adicionar assinatura automaticamente';
$labels['newmessageonly'] = 'apenas em novas mensagens';
$labels['replyandforwardonly'] = 'apenas em respostas e reenvios';
$labels['insertsignature'] = 'Inserir assinatura';
$labels['sigbelow'] = 'Colocar assinatura abaixo da mensagem citada';
$labels['sigseparator'] = 'Forçar separador padrão nas assinaturas';
$labels['automarkread'] = 'Marcar mensagens como lidas';
$labels['afternseconds'] = 'após $n segundos';
$labels['reqmdn'] = 'Pedir sempre um recibo de leitura';
$labels['reqdsn'] = 'Pedir sempre um recibo de entrega';
$labels['alwayskeepformatting'] = 'Manter sempre a formatação original do texto';
$labels['replysamefolder'] = 'Guardar respostas na mesma pasta da mensagem original';
$labels['defaultabook'] = 'Livro de endereços padrão';
$labels['autocompletesingle'] = 'Ignorar endereços de email alternativos no preenchimento automático';
$labels['listnamedisplay'] = 'Listar contactos como';
$labels['contactformmode'] = 'Modo de formulário do contacto';
$labels['privatemode'] = 'Privado (Casa)';
$labels['businessmode'] = 'Empresarial (Trabalho)';
$labels['collectedaddresses'] = 'Endereços recolhidos';
$labels['collectedrecipients'] = 'Destinatários recolhidos';
$labels['collectedrecipientsopt'] = 'Armazenar destinatários de email em';
$labels['collectedsendersopt'] = 'Armazenar remetentes de confiança em';
$labels['trustedsenders'] = 'Remetentes de confiança';
$labels['spellcheckbeforesend'] = 'Verificar ortografia antes de enviar a mensagem';
$labels['spellcheckoptions'] = 'Opções de verificação ortográfica';
$labels['spellcheckignoresyms'] = 'Ignorar palavras com símbolos';
$labels['spellcheckignorenums'] = 'Ignorar palavras com números';
$labels['spellcheckignorecaps'] = 'Ignorar palavras em maiúsculas';
$labels['addtodict'] = 'Adicionar ao dicionário';
$labels['editoroptions'] = 'Opções do Editor';
$labels['enableautolink'] = 'Converter automaticamente URLs válidos em hiperligações';
$labels['mailtoprotohandler'] = 'Registar manipulador de protocolo para mailto: links';
$labels['standardwindows'] = 'Lidar com popups como janelas padrão';
$labels['forwardmode'] = 'Reencaminhamento de mensagens';
$labels['inline'] = 'em linha';
$labels['asattachment'] = 'como anexo';
$labels['replyallmode'] = 'Ação predefinida do botão [Responder a todos]';
$labels['replyalldefault'] = 'responder a todos';
$labels['replyalllist'] = 'responder só à lista de discussão (se identificada)';
$labels['allmessages'] = 'todas as mensagens';
$labels['olderxdays'] = 'com mais de $x dias';
$labels['folder'] = 'Pasta';
$labels['folders'] = 'Pastas';
$labels['foldername'] = 'Nome da pasta';
$labels['subscribed'] = 'Subscrita';
$labels['messagecount'] = 'Mensagens';
$labels['create'] = 'Criar';
$labels['createfolder'] = 'Criar pasta';
$labels['managefolders'] = 'Gerir pastas';
$labels['specialfolders'] = 'Pastas especiais (predefinidas)';
$labels['properties'] = 'Propriedades';
$labels['folderproperties'] = 'Propriedades da pasta';
$labels['parentfolder'] = 'Pasta de origem';
$labels['location'] = 'Localização';
$labels['info'] = 'Informação';
$labels['getfoldersize'] = 'Clique para obter o tamanho da pasta';
$labels['changesubscription'] = 'Clique para alterar a subscrição';
$labels['foldertype'] = 'Tipo de pasta';
$labels['personalfolder'] = 'Pasta privada';
$labels['otherfolder'] = 'Outro tipo de pasta';
$labels['sharedfolder'] = 'Pasta pública';
$labels['findfolders'] = 'Localizar pastas';
$labels['findcontacts'] = 'Encontrar contactos';
$labels['findmail'] = 'Encontrar mensagens de correio';
$labels['namespace.personal'] = 'Pessoal';
$labels['namespace.other'] = 'Outros utilizadores';
$labels['namespace.shared'] = 'Partilhado';
$labels['dualuselabel'] = 'Apenas pode conter';
$labels['dualusemail'] = 'mensagens';
$labels['dualusefolder'] = 'pastas';
$labels['generate'] = 'Gerar';
$labels['encryptioncreatekey'] = 'Criar um novo par de chaves';
$labels['openmailvelopesettings'] = 'Abrir configurações do Mailvelope';
$labels['encryptionprivkeysinmailvelope'] = 'Tem $nr correspondências de chaves privadas armazenadas no porta-chaves do seu Mailvelope:';
$labels['encryptionnoprivkeysinmailvelope'] = 'Esta identidade do remetente ainda não possui uma chave PGP privada armazenada na sua extensão Mailvelope. Gostaria de criar uma para ativar a mensagem encriptada?';
$labels['encryption'] = 'Encriptação';
$labels['mailvelopeoptions'] = 'Opções do Mailvelope';
$labels['mailvelopemainkeyring'] = 'Usar porta-chaves principal do Mailvelope';
$labels['mailvelopenotfound'] = 'A extensão do Mailvelope não está activada/instalada no seu navegador.';
$labels['mailvelopeenable'] = 'Ativar';
$labels['sortby'] = 'Ordenar por';
$labels['sortasc'] = 'Ordenação crescente';
$labels['sortdesc'] = 'Ordenação decrescente';
$labels['undo'] = 'Anular';
$labels['installedplugins'] = 'Plugins instalados';
$labels['plugin'] = 'Plugin';
$labels['version'] = 'Versão';
$labels['source'] = 'Fonte';
$labels['destination'] = 'Destino';
$labels['license'] = 'Licença';
$labels['skinauthor'] = 'por $author';
$labels['support'] = 'Obter suporte';
$labels['savedsearches'] = 'Pesquisas guardadas';
$labels['dateformatY'] = 'AAAA';
$labels['dateformaty'] = 'AA';
$labels['dateformatm'] = 'MM';
$labels['dateformatd'] = 'DD';
$labels['dateformatj'] = 'D';
$labels['dateformatn'] = 'M';
$labels['B'] = 'B';
$labels['KB'] = 'KB';
$labels['MB'] = 'MB';
$labels['GB'] = 'GB';
$labels['unicode'] = 'Unicode';
$labels['english'] = 'Inglês';
$labels['westerneuropean'] = 'Europa Ocidental';
$labels['easterneuropean'] = 'Europa Leste';
$labels['southeasterneuropean'] = 'Sudeste Europeu';
$labels['baltic'] = 'Báltico';
$labels['cyrillic'] = 'Cirílico';
$labels['arabic'] = 'Árabe';
$labels['greek'] = 'Grego';
$labels['hebrew'] = 'Hebraico';
$labels['turkish'] = 'Turno';
$labels['nordic'] = 'Nórdico';
$labels['thai'] = 'Tailandês';
$labels['celtic'] = 'Céltico';
$labels['vietnamese'] = 'Vietnamita';
$labels['japanese'] = 'Japonês';
$labels['korean'] = 'Coreano';
$labels['chinese'] = 'Chinês';
$labels['arialabeltopnav'] = 'Controlo de janela';
$labels['arialabeltasknav'] = 'Tarefas da aplicação';
$labels['arialabeltoolbar'] = 'Barra de ferramentas da aplicação';
$labels['arialabellistnav'] = 'Navegação na lista';
$labels['arialabelactivetask'] = 'Tarefa ativa';
$labels['arialabelmessagessearchfilter'] = 'Filtro da listagem de email';
$labels['arialabelmailsearchform'] = 'Formulário de pesquisa email';
$labels['arialabelcontactsearchform'] = 'Formulário de pesquisa de contactos';
$labels['arialabelmailquicksearchbox'] = 'Entrada da pesquisa de email';
$labels['arialabelquicksearchbox'] = 'Entrada da pesquisa';
$labels['arialabelfoldersearchfilter'] = 'Lista de filtro de pasta';
$labels['arialabelfoldersearchform'] = 'Formulário de pesquisa de pasta';
$labels['arialabelfolderlist'] = 'Seleção de pasta de email';
$labels['arialabelmessagelist'] = 'Listagem de mensagens de email';
$labels['arialabelmailpreviewframe'] = 'Pré-visualizar mensagem';
$labels['arialabelmailboxmenu'] = 'Menu de ações de pasta';
$labels['arialabellistselectmenu'] = 'Menu de seleção de lista';
$labels['arialabelthreadselectmenu'] = 'Menu de listagem de tópicos';
$labels['arialabelmessagelistoptions'] = 'Visualização da lista de mensagens e opções de ordenação';
$labels['arialabelmailimportdialog'] = 'Janela de importação de mensagens';
$labels['arialabelmessagenav'] = 'Navegação nas mensagens';
$labels['arialabelmessagebody'] = 'Corpo da mensagem';
$labels['arialabelmessageactions'] = 'Ações de mensagem';
$labels['arialabelcontactquicksearch'] = 'Formulário de pesquisa de contactos';
$labels['arialabelcontactsearchbox'] = 'Entrada da pesquisa de contacto';
$labels['arialabelmessageheaders'] = 'Cabeçalhos da mensagem';
$labels['arialabelforwardingoptions'] = 'Opções de reencaminhamento';
$labels['arialabelreplyalloptions'] = 'Opções de responder a todos';
$labels['arialabelmoremessageactions'] = 'Mais ações de mensagens';
$labels['arialabelmorecontactactions'] = 'Mais ações do contacto';
$labels['arialabelmarkmessagesas'] = 'Marcar mensagens selecionadas como...';
$labels['arialabelcomposeoptions'] = 'Opções de composição';
$labels['arialabelresponsesmenu'] = 'Menu de respostas tipo';
$labels['arialabelattachmentuploadform'] = 'Formulário de envio de anexos';
$labels['arialabelattachmentmenu'] = 'Opções de anexos';
$labels['arialabelmailtomenu'] = 'Opções de endereço de email';
$labels['arialabelattachmentpreview'] = 'Pré-visualização de anexos';
$labels['ariasummarycomposecontacts'] = 'Lista de contactos e grupos para selecionar como destinatários';
$labels['arialabelcontactexportoptions'] = 'Opções de exportação de contacto';
$labels['arialabelabookgroupoptions'] = 'Opções do livro de endereços/grupos';
$labels['arialabelpreferencesform'] = 'Formulário de preferências';
$labels['arialabelidentityeditfrom'] = 'Formulário de edição de identidade';
$labels['arialabelresponseeditfrom'] = 'Formulário de edição de resposta';
$labels['arialabelsearchterms'] = 'Termos de pesquisa';
$labels['arialabeldropactionmenu'] = 'Menu de ação Arrastar e Largar';
$labels['arialabelheadersmenu'] = 'Destinatário (cabeçalho) a adicionar menu';
$labels['arialabelimagetools'] = 'Ferramentas de imagem';
$labels['helplistnavigation'] = 'Lista de teclas de navegação';
$labels['helplistkeyboardnavigation'] = "Setas cima/baixo: Move linha de realce/seleção.
Espaço: Seleciona linha realçada.
Shift + cima/baixo: Seleciona linha adicional acima/abaixo.
Ctrl + Espaço: Adiciona linha realçada à seleção/remove da seleção.";
$labels['helplistkeyboardnavmessages'] = "Setas direita/esquerda: Expande/recolhe tópicos de mensagens (só no modo de tópicos).
Enter: Abre a mensagem selecionada/realçada.
Delete: Move as mensagens selecionadas para a Reciclagem.";
$labels['helplistkeyboardnavcontacts'] = "Enter: Abre o contacto selecionado/realçado. ";
