<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'بىر خاتالىق كۆرۈلدى!';
$messages['loginfailed']  = 'كىرىش مەغلۇپ بولدى.';
$messages['cookiesdisabled'] = 'سىزنىڭ تور كۆرگۈچىڭىز پىچىنىلەرنى قوللىمايدۇ.';
$messages['sessionerror'] = 'سىزنىڭ باسقۇچىڭىز ئىناۋەتسىز ياكى ۋاقتى ئۆتتى.';
$messages['cookiesmismatch'] = 'پىچىنە ماس كەلمەسلىك بايقالدى. تور كۆرگۈچىڭىزنىڭ پىچىنىلىرىنى تازلاڭ.';
$messages['storageerror'] = 'ساقلاش مۇلازىمېتىرىغا ئۇلىنىش مەغلۇپ بولدى.';
$messages['servererror'] = 'مۇلازىمېتىر خاتالىقى!';
$messages['servererrormsg'] = 'مۇلازىمېتىر خاتالىقى: msg$';
$messages['accountlocked'] = 'بەك كۆپ كىرىش مەغلۇبى. كىيىنرەك سىناپ بېقىڭ.';
$messages['connerror'] = 'ئۇلىنىش خاتالىقى (مۇلازىمېتىرغا يەتكىلى بولمىدى)!';
$messages['dberror'] = 'سانلىق مەلۇمات ئامبىرى خاتالىقى!';
$messages['dbconnerror'] = 'سانلىق مەلۇمات ئامبىرىغا ئۇلىغىلى بولمىدى!';
$messages['windowopenerror'] = 'سەكرەپ چىقىش كۆزنىكى مەنئي قىلىندى!';
$messages['requesttimedout'] = 'تەلەپ ۋاقتى ئۆتتى';
$messages['errorreadonly'] = 'ۋەزىپىنى ئورۇندىغىلى بولمىدى. قىسقۇچ بولسا ئوقۇشقىلا-بولىدىغان.';
$messages['errornoperm'] = 'ۋەزىپىنى ئورۇندىغىلى بولمىدى. ئىجازەت بېرىلمىدى.';
$messages['erroroverquota'] = 'ۋەزىپىنى ئورۇندىغىلى بولمىدى. بىكار دىسكا بوشلۇقى يوق.';
$messages['erroroverquotadelete'] = 'بىكار دىسكا بوشلۇقى قالمىدى. SHIFT+DEL نى بېسىپ بىر خەتنى ئۆچۈرۈڭ.';
$messages['invalidrequest'] = 'ئىناۋەتسىز تەلەپ! ھېچقانداق ئۇچۇر ساقلانمىدى.';
$messages['invalidhost'] = 'ئىناۋەتسىز مۇلازىمېتىر نامى.';
$messages['nomessagesfound'] = 'بۇ ئېلىخەت ساندۇقىدا ھېچقانداق خەت يوق.';
$messages['loggedout'] = 'سىز بۇ باسقۇچنى مۇۋاپىقىيەتلىك ئاخىرلاشتۇردىڭىز. خەيىر-خوش!';
$messages['mailboxempty'] = 'خەت ساندۇقى قۇرۇق';
$messages['nomessages'] = 'ئۇچۇر يوق';
$messages['refreshing'] = 'يېڭىلاۋاتىدۇ...';
$messages['loading'] = 'يۈكلەۋاتىدۇ...';
$messages['uploading'] = 'ھۆججەت چىقىرىۋاتىدۇ...';
$messages['attaching'] = 'ھۆججەت قىستۇرۋاتىدۇ...';
$messages['uploadingmany'] = 'ھۆججەتلەرنى چىقىرىۋاتىدۇ...';
$messages['loadingdata'] = 'ئۇچۇرلارنى يۈكلەۋاتىدۇ...';
$messages['checkingmail'] = 'يېڭى ئۇچۇرلارنى تەكشۈرىۋاتىدۇ...';
$messages['sendingmessage'] = 'خەتنى ئەۋەتىۋاتىدۇ...';
$messages['messagesent'] = 'خەت مۇۋاپىقىيەتلىك ئەۋەتىلدى';
$messages['savingmessage'] = 'خەتنى ساقلاۋاتىدۇ...';
$messages['messagesaved'] = 'خەت قوليازما قىسقۇچىغا ساقلاندى.';
$messages['successfullysaved'] = 'مۇۋاپىقىيەتلىك ساقلاندى.';
$messages['savingresponse'] = 'ئىنكاس تىكىستىنى ساقلاۋاتىدۇ...';
$messages['deleteresponseconfirm'] = 'بۇ ئىنكاس تېكىستىنى راستىنلا ئۆچۈرەمسىز؟';
$messages['nocontactselected'] = 'سىز تېخى بىرەر تۇنۇش تاللىمىدىڭىز.';
$messages['addedsuccessfully'] = 'تۇنۇش ئادىرىس دەپتىرىگە مۇۋاپىقىيەتلىك قېتىلدى.';
$messages['contactexists'] = 'ئوخشاش ئېلىخەت ئادىرىستىكى تۇنۇش مەۋجۇت.';
$messages['contactnameexists'] = 'ئوخشاش ئىسىملىك تۇنۇش مەۋجۇت.';
$messages['blockedimages'] = 'مەخپىيەتلىكىڭىزنى قوغداش ئۈچۈن، يىراق-مەنبەلىك رەسىملەر بۇ خەتتە مەنئىي قىلىندى.';
$messages['blockedresources'] = 'مەخپىيەتلىكىڭىزنى قوغداش ئۈچۈن يىراق مەنبەلەر مەنئىي قىلىندى.';
$messages['suspiciousemail'] = 'بۇ خەت ئالدامچىلىققا مۇناسىۋەتلىك گۇمانلىق ئېلخەت ئادىرسىنى ئۆز-ئىچىگە ئالغان.';
$messages['bccemail'] = 'يەتكۈزۈلگەن خەت(لەر) مەخپىي تاپشۇرۋالغۇچىلارنى ئۆز-ئىچىگە ئالىدۇ(ب چ چ).';
$messages['bouncehint'] = 'بۇ خەت ھېچقانداق ئۆزگەرتمەي ئەۋەتىلدۇ، مەسلەن: ئەسلىدىكى مەزمۇن، باشلانما ھەمدە تاپشۇرۋالغۇچىلار بىلەن.';
$messages['encryptedmessage'] = 'بۇ بىر شىفىرلانغان خەت شۇڭا كۆرسەتكىلى بولمايدۇ. كەچۈرۈڭ!';
$messages['externalmessagedecryption'] = 'بۇ بىر شىفىرلانغان خەت بۇلۇپ، تور كۆرگۈچنىڭ كېڭەيتىلمىسى بىلەن شىفىرسىزلىغىلى بۇلىدۇ.';
$messages['nopubkeyfor'] = 'بۇ email$ ئۈچۈن ئاممىۋىي ئاچقۇچ تېپىلمىدى';
$messages['nopubkeyforsender'] = 'سىزنىڭ ئەۋەتكۈچى كىملىكىڭىزگە ماس ئاممىۋىي ئاچقۇچ تېپىلمىدى. سىز بۇ خەتنى تاپشۇرۋالغۇچىلار ئۈچۈنلا شىفىرلامسىز؟';
$messages['encryptnoattachments'] = 'ئاللىبۇرۇن چىقىرىلغان قىستۇرمىلارنى شىفىرلىغىلى بولمايدۇ. ئۇلارنى شىفىرلاش تەھرىرىدە قايتا قۇشۇڭ.';
$messages['searchpubkeyservers'] = 'سىز بۇ كەم قالغان ئاچقۇچلار ئۈچۈن ئاممىۋىي ئاچقۇچ مۇلازىمېتىرلىرىنى ئىزدەمسىز؟';
$messages['encryptpubkeysfound'] = 'تۆۋەندىكى ئاممىۋىي ئاچقۇچ تېپىلدى:';
$messages['keyservererror'] = 'ئاچقۇچ مۇلازىمېتىردىن ئاچقۇچقا ئېرىشكىلى بولمىدى.';
$messages['keyimportsuccess'] = 'ئاممىۋىي ئاچقۇچ key$ سىزنىڭ ئاچقۇچ چەمبىرىكىڭىزگە مۇۋاپىقىيەتلىك كىرگۈزۈلدى.';
$messages['nocontactsfound'] = 'ھېچقانداق تۇنۇش تېپىلمىدى.';
$messages['contactnotfound'] = 'تەلەپ قىلىنغان تۇنۇش تېپىلمىدى.';
$messages['contactsearchonly'] = 'سىز تاللانغان ئادىرس دەپتىرىدىن تۇنۇشلارنى كۆرۈش ئۈچۈن ئىزدەش جەدىۋېلىنى ئىشلىتىشىڭىز لازىم.';
$messages['sendingfailed'] = 'خەتنى ئەۋەتىش مەغلۇپ بولدى.';
$messages['senttooquickly'] = 'بۇ خەتنى ئەۋەتىشتىن بۇرۇن sec$ سىكونت(لار) ساقلاڭ.';
$messages['errorsavingsent'] = 'ئەۋەتىلگەن خەتنى ساقلاۋاتقاندا بىر خاتالىق كۆرۈلدى.';
$messages['errorsaving'] = 'ساقلاۋاتقاندا بىر خاتالىق كۆرۈلدى.';
$messages['errormoving'] = 'بۇ خەت(لەر)نى يۆتكىگىلى بولمىدى.';
$messages['errorcopying'] = 'بۇ خەت(لەر)نى كۆچۈرگىلى بولمىدى.';
$messages['errordeleting'] = 'بۇ خەت(لەر)نى ئۆچۈرگىلى بولمىدى.';
$messages['errormarking'] = 'بۇ خەت(لەر)گە بەلگە قويغىلى بولمىدى.';
$messages['alerttitle'] = 'دىققەت';
$messages['confirmationtitle'] = 'جەزىملەشتۈرەمسىز...';
$messages['deletecontactconfirm']  = 'سىز تاللانغان تۇنۇش(لار)نى راستىنلا ئۆچۈرمەكچىمۇ؟';
$messages['deletegroupconfirm']  = 'سىز تاللانغان توپنى راستىنلا ئۆچۈرمەكچىمۇ؟';
$messages['deletemessagesconfirm'] = 'سىز تاللانغان خەت(لەر)نى راستىنلا ئۆچۈرمەكچىمۇ؟';
$messages['deletefolderconfirm']  = 'بۇ قىسقۇچنى راستىنلا ئۆچۈرەمسىز؟';
$messages['movefolderconfirm']  = 'سىز بۇ قىسقۇچنى راستىنلا يۆتكەمسىز؟';
$messages['purgefolderconfirm']  = 'سىز بۇ قىسقۇچتىكى بارلىق خەتلەرنى راستىنلا ئۆچۈرمەكچىمۇ؟';
$messages['contactdeleting'] = 'تۇنۇش(لار)نى ئۆچۈرىۋاتىدۇ...';
$messages['groupdeleting'] = 'توپنى ئۆچۈرىۋاتىدۇ...';
$messages['folderdeleting'] = 'قىسقۇچنى ئۆچۈرىۋاتىدۇ...';
$messages['foldermoving'] = 'قىسقۇچنى يۆتكەۋاتىدۇ...';
$messages['foldersubscribing'] = 'قىسقۇچقا مۇشتەرى بۇلىۋاتىدۇ...';
$messages['folderunsubscribing'] = 'قىسقۇچقا مۇشتەرى بولمايۋاتىدۇ...';
$messages['formincomplete'] = 'بۇ جەدىۋەل تۇلۇق تولدۇرۇلمىدى.';
$messages['noemailwarning'] = 'بىر ئىناۋەتلىك ئېلىخەت ئادىرسىنى كىرگۈزۈڭ.';
$messages['nonamewarning']  = 'بىر ئىسىم كىرگۈزۈڭ.';
$messages['nopagesizewarning'] = 'بەت چوڭلۇقىنى كىرگۈزۈڭ.';
$messages['nosenderwarning'] = 'ئەۋەتكۈچى ئېلىخەت ئادىرسىنى كىرگۈزۈڭ.';
$messages['recipientsadded'] = 'تاپشۇرۋالغۇچى(لار) مۇۋاپىقىيەتلىك قۇشۇلدى.';
$messages['norecipientwarning'] = 'ئەڭ كەمدە بىر تاپشۇرۋالغۇچى كىرگۈزۈڭ.';
$messages['disclosedreciptitle'] = 'بەك كۆپ ئاممىۋىي تاپشۇرۋالغۇچىلار';
$messages['nosubjectwarning']  = '"تېما" كاتەكچىسى قۇرۇق. بىرنى كىرگۈزۈشنى خالامسىز؟';
$messages['nosubjecttitle']  = 'تېما يوق';
$messages['nobodywarning'] = 'بۇ ئۇچۇرنى مەزمۇنسىز ئەۋەتەمسىز؟';
$messages['notsentwarning'] = 'بۇ خەت ئەۋەتىلمىدى ھەمدە ساقلانمىغان ئۆزگىرىشلەر بار. ئۆزگەرتىشلەرنى تاشلىۋېتەمسىز؟';
$messages['restoresavedcomposedata'] = 'بىر-پارچە ئىلگىرى يېزىلغان لىكىن ئەۋەتىلمىگەن خەت تېپىلدى. تېما: subject$ ساقلانغان: date$ سىز بۇ خەتنى ئەسلىگە قايتۇرامسىز؟';
$messages['nosearchname'] = 'بىرەر تۇنۇش ئىسمى ياكى ئېلىخەت ئادىرسىنى كىرگۈزۈڭ.';
$messages['notuploadedwarning'] = 'تېخى ھەممە قىستۇرمىلار چىقىرىپ بولۇنمىدى. ساقلاڭ ياكى چىقىرىشنى ئەمەلدىن قالدۇرۇڭ.';
$messages['searchsuccessful'] = 'nr$ خەتلەر تېپىلدى.';
$messages['contactsearchsuccessful'] = 'nr$ تۇنۇشلار تېپىلدى.';
$messages['searchnomatch'] = 'ئىزدەشكە ھېچنىمە ماس كەلمىدى.';
$messages['searching'] = 'ئىزدەۋاتىدۇ...';
$messages['checking'] = 'تەكشۈرۋاتىدۇ...';
$messages['stillsearching'] = 'تېخىچە ئىزدەۋاتىدۇ...';
$messages['nospellerrors'] = 'ھېچقانداق ئىملا خاتالىقى تېپىلمىدى.';
$messages['folderdeleted'] = 'قىسقۇچ مۇۋاپىقىيەتلىك ئۆچۈرۈلدى.';
$messages['foldersubscribed'] = 'قىسقۇچ مۇۋاپىقىيەتلىك مۇشتەرى بولۇندى.';
$messages['folderunsubscribed'] = 'قىسقۇچ مۇۋاپىقىيەتلىك مۇشتەرى بولۇنمىدى.';
$messages['folderpurged'] = 'قىسقۇچ مۇۋاپىقىيەتلىك قۇرۇقدالدى.';
$messages['folderexpunged'] = 'قىسقۇچ مۇۋاپىقىيەتلىك ئىخچاملاندى.';
$messages['deletedsuccessfully'] = 'مۇۋاپىقىيەتلىك ئۆچۈرۈلدى.';
$messages['converting'] = 'فورمات ئۆچۈرۈلۋاتىدۇ...';
$messages['messageopenerror'] = 'خەتنى مۇلازىمېتىردىن يۈكلىيەلمىدى.';
$messages['filelinkerror'] = 'ھۆججەت قىستۇرۇش مەغلۇپ بولدى.';
$messages['fileuploaderror'] = 'ھۆججەت چىقىرىش مەغلۇپ بولدى.';
$messages['csvfilemismatch'] = 'ئوخشىمىغان كاتەكچىلىك كۆپلىگەن CSV ھۆججىتىنى كىرگۈزۈش قۇبۇل قىلىنمايدۇ.';
$messages['filesizeerror'] = 'چىقارغان ھۆججەت چوڭلۇقى ئەڭ چوڭ بوشلۇق size$ دىن ئېشىپ كەتتى.';
$messages['filecounterror'] = 'سىز ئەڭ كۆپ بولغاندا count$ ھۆججەتلەرنى چىقىرالايسىز.';
$messages['msgsizeerror'] = 'ھۆججەت قىستۇرۇش مەغلۇپ بولدى. خەتنىڭ چوڭلۇقى ئەڭ يۇقىرى ئۆلچەمدىن( size$) ئېشىپ كەتتى.';
$messages['msgsizeerrorfwd'] = 'خەتنىڭ چوڭلۇقى ئۆلچەمدىن (size$) ئېشىپ كەتتى. num$ خەت(لەر) قىستۇرۇلمىدى.';
$messages['copysuccess'] = 'nr$ تۇنۇشلار مۇۋاپىقىيەتلىك كۆچۈرۈلدى.';
$messages['movesuccess'] = 'nr$ تۇنۇشلار مۇۋاپىقىيەتلىك يۆتكەلدى.';
$messages['copyerror'] = 'ھېچقانداق تۇنۇشنى كۆچۈرگىلى بولمىدى.';
$messages['moveerror'] = 'ھېچقانداق تۇنۇشنى يۆتكىگىلى بولمىدى.';
$messages['sourceisreadonly'] = 'بۇ ئادىرىس مەنبەسى بولسا ئۇقۇشقىلا-بولىدىغان.';
$messages['errorsavingcontact'] = 'بۇ تۇنۇش ئادىرسىنى ساقلىغىلى بولمىدى.';
$messages['movingmessage'] = 'خەت(لەر)نى يۆتكەۋاتىدۇ...';
$messages['copyingmessage'] = 'خەت(لەر)نى كۆچۈرۈۋاتىدۇ...';
$messages['copyingcontact'] = 'تۇنۇش(لار)نى كۆچۈرۈۋاتىدۇ...';
$messages['movingcontact'] = 'تۇنۇش(لار)نى يۆتكەۋاتىدۇ...';
$messages['deletingmessage'] = 'خەت(لەر)نى ئۆچۈرىۋاتىدۇ...';
$messages['markingmessage'] = 'خەت(لەر)گە بەلگە قۇيىۋاتىدۇ...';
$messages['addingmember'] = 'تۇنۇش(لار)نى بۇ توپقا قۇشۇۋاتىدۇ...';
$messages['removingmember'] = 'تۇنۇش(لار)نى بۇ توپتىن چىقىرىۋاتىدۇ...';
$messages['receiptsent'] = 'بىر ئۇقۇغانلىق تېلخېتى مۇۋاپىقىيەتلىك ئەۋەتىلدى.';
$messages['errorsendingreceipt'] = 'بۇ تېلىخەتنى ئەۋەتكىلى بولمىدى.';
$messages['deleteidentityconfirm'] = 'سىز بۇ كىملىكنى راستىنلا ئۆچۈرمەكچىمۇ؟';
$messages['nodeletelastidentity'] = 'سىز بۇ كىملىكنى ئۆچۈرسىڭىز بولمايدۇ، بۇ ئەڭ ئاخىرقىسى.';
$messages['forbiddencharacter'] = 'قىسقۇچ ئىسمى مەنئىي قىلىنغان ھەرىپنى ئۆز-ئىچىگە ئالىدۇ.';
$messages['selectimportfile'] = 'بىرەر ھۆججەتنى تاللاپ چىقىرىڭ.';
$messages['addresswriterror'] = 'تاللانغان ئادىرىس دەپتىرىگە يازغىلى بولمايدۇ.';
$messages['contactaddedtogroup'] = 'تۇنۇشلار بۇ توپقا مۇۋاپىقىيەتلىك قېتىلدى.';
$messages['contactremovedfromgroup'] = 'تۇنۇشلار بۇ توپتىن مۇۋاپىقىيەتلىك چىقىرىلدى.';
$messages['nogroupassignmentschanged'] = 'ھېچقانداق توپ تاپشۇرۇقى ئۆزگەرتىلمىدى.';
$messages['importwait'] = 'كىرگۈزىۋاتىدۇ، بىردەم ساقلاڭ...';
$messages['importformaterror'] = 'كىرگۈزۈش مەغلۇپ بولدى! چىقىرىلغان ھۆججەتنىڭ تىپى ئىناۋەتلىك ئەمەس.';
$messages['importconfirm'] = '<b>inserted$ تۇنۇشلار مۇۋاپىقىيەتلىك كىرگۈزۈلدى </b>';
$messages['importmessagesuccess'] = 'nr$ خەتلەر مۇۋاپىقىيەتلىك كىرگۈزۈلدى';
$messages['importmessageerror'] = 'كىرگۈزۈش مەغلۇپ بولدى! چىقىرىلغان ھۆججەت ئىناۋەتلىك ئېلىخەت ياكى خەت ھۆججىتى ئەمەس.';
$messages['opnotpermitted'] = 'مەشخۇلاتقا ئىجازەت بېرىلمىدى!';
$messages['nofromaddress'] = 'تاللانغان كىملىكنىڭ ئېلىخەت ئادىرسى يوق.';
$messages['editorwarning'] = 'تەھرىرلىگۈچ تۈرىنى ئۆزگەرتىش تېكىست فورماتىنىڭ يوقىلىشىنى كەلتۈرۈپ چىقىرىشى مۇمكىن. سىز داۋاملاشتۇرامسىز؟';
$messages['httpreceivedencrypterror'] = 'بىر ئېغىر تەڭشەش خاتالىقى كۆرۈلدى. دەرھال باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ. <b>سىزنىڭ خېتىڭىزنى ئەۋەتكىلى بولمىدى. </b>';
$messages['smtpconnerror'] = 'SMTP خاتالىقى (code$): مۇلازىمېتىرغا ئۇلىنىش مەغلۇپ بولدى.';
$messages['smtpautherror'] = 'SMTP خاتالىقى (code$): كىملىكىنى دەلىللەش مەغلۇپ بولدى.';
$messages['smtpfromerror'] = 'SMTP خاتالىقى (code$): ئەۋەتكۈچىنى "from$" بېكىتىش مەغلۇپ بولدى (msg$).';
$messages['smtptoerror'] = 'SMTP خاتالىقى (code$): تاپشۇرۋالغۇچىنى "to$" قېتىش مەغلۇپ بولدى (msg$).';
$messages['smtprecipientserror'] = 'SMTP خاتالىقى : تاپشۇرۋالغۇچىلار تىزىملىكىنى يىشىەلمىدى.';
$messages['smtputf8error'] = 'SMTP خاتالىقى: مۇلازىمېتىر ئېلىخەت ئادىرسىدا ئۇنىكودنى قوللىمايدۇ.';
$messages['smtpsizeerror'] = 'SMTP خاتالىقى: خەتنىڭ چوڭلۇقى مۇلازىمېتىر چېكىدىن(limit$) ئېشىپ كەتتى.';
$messages['smtperror'] = 'SMTP خاتالىقى: msg$';
$messages['emailformaterror'] = 'ئىناۋەتسىز ئېلىخەت ئادىرسى: email$';
$messages['toomanyrecipients'] = 'تاپشۇرۋالغۇچىلار سانىنى max$ دىن تۆۋەنلىتىڭ.';
$messages['maxgroupmembersreached'] = 'توپ ئەزالىرىنىڭ سانى ئەڭ يۇقىرى ئۆلچەم max$ دىن ئېشىپ كەتتى.';
$messages['internalerror'] = 'ئىچكى خاتالىق كۆرۈلدى. قايتا سىناپ بېقىڭ.';
$messages['contactdelerror'] = 'تۇنۇش(لار)نى ئۆچۈرگىلى بولمىدى.';
$messages['contactdeleted'] = 'تۇنۇش(لار) مۇۋاپىقىيەتلىك ئۆچۈرۈلدى.';
$messages['contactrestoreerror'] = 'ئۆچۈرۈلگەن تۇنۇش(لار)نى ئەسلىگە قايتۇرغىلى بولمىدى.';
$messages['contactrestored'] = 'تۇنۇش(لار) مۇۋاپىقىيەتلىك ئەسلىگە كەلدى.';
$messages['groupdeleted'] = 'توپ مۇۋاپىقىيەتلىك ئۆچۈرۈلدى.';
$messages['grouprenamed'] = 'توپقا مۇۋاپىقىيەتلىك يېڭى ئسىىم قۇيۇلدى.';
$messages['groupcreated'] = 'توپ مۇۋاپىقىيەتلىك قۇرۇلدى.';
$messages['savedsearchdeleted'] = 'ساقلانغان ئىزدەشلەر مۇۋاپىقىيەتلىك ئۆچۈرۈلدى.';
$messages['savedsearchdeleteerror'] = 'ساقلانغان ئىزدەشلەرنى ئۆچۈرگىلى بولمىدى.';
$messages['savedsearchcreated'] = 'ساقلانغان ئىزدەش مۇۋاپىقىيەتلىك قۇرۇلدى.';
$messages['savedsearchcreateerror'] = 'ساقلانغان ئىزدەشنى قۇرغىلى بولمىدى.';
$messages['messagedeleted'] = 'خەت(لەر) مۇۋاپىقىيەتلىك ئۆچۈرۈلدى.';
$messages['messagemoved'] = 'خەت(لەر) مۇۋاپىقىيەتلىك يۆتكەلدى.';
$messages['messagemovedtotrash'] = 'خەت(لەر) ئەخلەت چېلىكىگە مۇۋاپىقىيەتلىك يۆتكەلدى.';
$messages['messagecopied'] = 'خەت(لەر) مۇۋاپىقىيەتلىك كۆچۈرۈلدى.';
$messages['messagemarked'] = 'خەت(لەر)گە مۇۋاپىقىيەتلىك بەلگە قۇيۇلدى.';
$messages['autocompletechars'] = 'ئاپتۇماتىك تولدۇرۇش ئۈچۈن ئەڭ كەم بولغاندا min$ ھەرىپ كىرگۈزۈڭ.';
$messages['autocompletemore'] = 'تېخىمۇ كۆپ ماس قۇرلار تېپىلدى. كۆپرەك ھەرىپلەرنى كىرگۈزۈڭ.';
$messages['namecannotbeempty'] = 'ئىسمى قۇرۇق بولسا بولمايدۇ.';
$messages['nametoolong'] = 'ئىسمى بەك ئۇزۇن.';
$messages['namedotforbidden'] = 'قىسقۇچ ئىسمى چىكىت بىلەن باشلانمايدۇ.';
$messages['folderupdated'] = 'قىسقۇچ مۇۋاپىقىيەتلىك يېڭىلاندى.';
$messages['foldercreated'] = 'قىسقۇچ مۇۋاپىقىيەتلىك قۇرۇلدى.';
$messages['invalidimageformat'] = 'ئىناۋەتلىك رەسىم فورماتى ئەمەس.';
$messages['mispellingsfound'] = 'خەتتە ئىملا خاتالىقى كۆرۈلدى.';
$messages['parentnotwritable'] = 'قىسقۇچنى تاللىغان ئانا قىسقۇچ ئىچىگە قۇرغىلى/يۆتكىگىلى بولمىدى. كىرىش ھوقوقى يوق.';
$messages['messagetoobig'] = 'ئۇچۇر قىسمى بىر-تەرەپ قىلىشقا بەك چوڭ.';
$messages['attachmentvalidationerror'] = 'قىستۇرما گۇمانلىق چۈنكى ئۇنىڭ تىپى خەتتە دىيىلگەن تىپقا ماس كەلمەيدۇ. ئەگەر سىز بۇ ئەۋەتكۈچىگە ئىشەنمىسىڭىز، ئۇنى بۇ تور كۆرگۈچتە ئاچماسلىقىڭىز لازىم چۈنكى ئۇ بەلكىم يامان-نىيەتلىك مەزمۇنلارنى ئۆز-ئىچىگە ئېلىشى مۇمكىن. <br/><br/><em>كۈتۈلگەن: expected$؛ تېپىلغان: detected$</em>';
$messages['noscriptwarning'] = 'ئاگاھلاندۇرۇش: بۇ تورخەت مۇلازىمېتى Javascript نى تەلەپ قىلىدۇ. ئىشلىتىش ئۈچۈن تور كۆرگۈچىڭىزدە Javascript نى بار قىلىڭ.';
$messages['messageissent'] = 'بۇ خەت ئاللىبۇرۇن ئەۋەتىلدى، لىكىن تېخى ساقلانمىدى. سىز ئۇنى ھازىر ساقلامسىز؟';
$messages['errnotfound'] = 'ھۆججەت تېپىلمىدى';
$messages['errnotfoundexplain'] = 'تەلەپ قىلىنغان بايلىق تېپىلمىدى!';
$messages['errfailedrequest'] = 'مەغلۇپ بولغان تەلەپ';
$messages['errauthorizationfailed'] = 'كىملىكىنى دەلىللەش مەغلۇپ بولدى';
$messages['errunauthorizedexplain'] = 'سىزنىڭ بۇ مۇلازىمەتكە ئېرىشىش ھوقوقىڭىزنىڭ بار-يوقلىقىنى دەلىللىگىلى بولمىدى!';
$messages['errrequestcheckfailed'] = 'تەلەپ تەكشۈرۈش مەغلۇپ بولدى';
$messages['errcsrfprotectionexplain'] = "سىزنى قوغداش ئۈچۈن، بۇ بايلىقنى ئىشلىتىش CSRF كە قارشى قوغدالدى. سىزنىڭ بۇنى كۆرۈشىڭىزدىكى سەۋەب سىز بۇ تور ئېپىدىن ئايرىلىشتىن بۇرۇن تېخى ئۇنىڭدىن چېكىنمىدىڭىز. داۋاملاشتۇرۇش ئۈچۈن ئادەم بىلەن ماسلىشىش كېرەك بولدى. ";
$messages['errcontactserveradmin'] = 'سىزنىڭ مۇلازىمېتىر باشقۇرغۇچىڭىز بىلەن ئالاقىلىشىڭ.';
$messages['clicktoresumesession'] = 'بۇ يەرنى بېسىپ ئالدىنقى باسقۇچنى ئەسلىگە كەلتۈرۈڭ';
$messages['errcomposesession'] = 'يېزىش باسقۇچى خاتالىقى';
$messages['errcomposesessionexplain'] = 'تەلەپ قىلىنغان يېزىش باسقۇچى تېپىلمىدى.';
$messages['clicktocompose'] = 'بۇ يەرنى بېسىپ يېڭى خەت قۇرۇڭ';
$messages['nosupporterror'] = 'سىزنىڭ تور كۆرگۈچىڭىز بۇ ئالاھىدىلىكنى قوللىمايدۇ.';
$messages['siginserted'] = 'ئىمزا مۇۋاپىقىيەتلىك كىرگۈزۈلدى.';
$messages['responseinserted'] = 'ئىنكاس مۇۋاپىقىيەتلىك كىرگۈزۈلدى.';
$messages['noresponsesavailable'] = 'ھېچقانداق ئىنكاس يوق';
$messages['listempty'] = 'بۇ تىزىملىك قۇرۇق';
$messages['listusebutton'] = 'يېڭى خاتىرە قېتىش ئۈچۈن قۇرۇش كۇنۇپكىسىنى بېسىڭ.';
$messages['keypaircreatesuccess'] = 'يېڭى ئاچقۇچ جۈپى identity$ ئۈچۈن مۇۋاپىقىيەتلىك قۇرۇلدى.';
$messages['emptyattachment'] = 'بۇ قىستۇرما قۇرۇقتەك قىلىدۇ. <br>بۇنى ئەۋەتكەن ئادەم بىلەن تەكشۈرۈڭ.';
$messages['oauthloginfailed'] = 'كىملىك دەلىللەش مەغلۇپ بولدى. قايتا سىناپ بېقىڭ.';
