<?php

/*
 +-----------------------------------------------------------------------+
 | language/pl_PL/csv2vcard.inc                                          |
 |                                                                       |
 | Language file of the Roundcube Webmail client                         |
 | Copyright (C) 2005-2012, The Roundcube Dev Team                       |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 |                                                                       |
 +-----------------------------------------------------------------------+
 | Author: Aleksander Machniak <alec@alec.pl>                            |
 +-----------------------------------------------------------------------+
*/
$map = array();
$map['Rocznica'] = 'anniversary';
$map['Asystent'] = 'assistant';
$map['Telefon asystenta'] = 'phone:assistant';
$map['Urodziny'] = 'birthday';
$map['Miasto (biuro)'] = 'locality:work';
$map['Kraj/region (biuro)'] = 'country:work';
$map['Faks służbowy'] = 'phone:workfax';
$map['Telefon służbowy'] = 'phone:work';
$map['Telefon służbowy 2'] = 'phone:work2';
$map['Kod pocztowy (biuro)'] = 'zipcode:work';
$map['Województwo (biuro)'] = 'region:work';
$map['Ulica (biuro)'] = 'street:work';
$map['Kategorie'] = 'groups';
$map['Firma'] = 'organization';
$map['Oddział'] = 'department';
$map['Adres e-mail'] = 'email:other';
$map['Imię'] = 'firstname';
$map['Płeć'] = 'gender';
$map['Miasto (dom)'] = 'locality:home';
$map['Kraj/region (dom)'] = 'country:home';
$map['Faks domowy'] = 'phone:homefax';
$map['Telefon domowy'] = 'phone:home';
$map['Home Phone 2'] = 'phone:home2';
$map['Kod pocztowy (dom)'] = 'zipcode:home';
$map['Województwo (dom)'] = 'region:home';
$map['Ulica (dom)'] = 'street:home';
$map['Stanowisko'] = 'jobtitle';
$map['Nazwisko'] = 'surname';
$map['Menadżer'] = 'manager';
$map['Drugie imię'] = 'middlename';
$map['Telefon komórkowy'] = 'phone:mobile';
$map['Notatki'] = 'notes';
$map['Pager'] = 'phone:pager';
$map['Telefon główny'] = 'phone:main';
$map['Tytuł'] = 'prefix';
$map['Osobista strona sieci Web'] = 'website:homepage';
$map['Przydomek'] = 'nickname';
