<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Archive plugin             |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['buttontext'] = 'Arxiv';
$labels['buttontitle'] = 'Mesajı arxivə göndər';
$labels['archived'] = 'Arxivə göndərildi';
$labels['archivedreload'] = 'Müvəffəqiyyətlə arxivləşdirildi. Yeni arxiv qovluqlarını görmək üçün səhifəni yeniləyin.';
$labels['archiveerror'] = 'Bəzi məktublar arxivləşdirilə bilinmirlər';
$labels['archivefolder'] = 'Arxiv';
$labels['settingstitle'] = 'Arxiv';
$labels['archivetype'] = 'Arxivi böl: ';
$labels['archivetypeyear'] = 'İl (məs. Arxiv/2012)';
$labels['archivetypemonth'] = 'Ay (məs. Arxiv/2012/06)';
$labels['archivetypefolder'] = 'Orijinal qovluq';
$labels['archivetypesender'] = 'Göndərənin E-Poçtu';
$labels['unkownsender'] = 'naməlum';
