<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = '新しいメッセージの通知をブラウザーに表示';
$labels['desktop'] = '新しいメッセージの通知をデスクトップに表示';
$labels['sound'] = '新しいメッセージが届くと音を再生';
$labels['test'] = 'テスト';
$labels['title'] = '新しい電子メールです!';
$labels['body'] = '新しいメッセージを受信しました。';
$labels['testbody'] = 'これはテストの通知です。';
$labels['desktopdisabled'] = 'ブラウザーでデスクトップ通知が無効になっています。';
$labels['desktopunsupported'] = 'ブラウザーがデスクトップ通知をサポートしていません。';
$labels['desktoptimeout'] = 'デスクトップ通知を閉じる';
