<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = 'Ndodhi një gabim!';
$messages['loginfailed']  = 'Hyrja dështoi.';
$messages['cookiesdisabled'] = 'Shfletuesi juaj s’i pranon cookie-t.';
$messages['sessionerror'] = 'Sesioni juaj është i pavlefshëm ose ka skaduar.';
$messages['cookiesmismatch'] = 'U pikas ngatërrim cookie-sh. Ju lutemi, pastroni cookie-t prej shfletuesit tuaj.';
$messages['storageerror'] = 'Lidhja me shërbyesin e depozitimit dështoi.';
$messages['servererror'] = 'Gabim Shërbyesi!';
$messages['servererrormsg'] = 'Gabim Shërbyesi: $msg';
$messages['accountlocked'] = 'Numër i madh përpjekjesh të dështuara për hyrje. Riprovoni më vonë.';
$messages['connerror'] = 'Gabim Lidhjeje (S’u arrit të kapej shërbyesi)!';
$messages['dberror'] = 'Gabim Baze të Dhënash!';
$messages['dbconnerror'] = 'S’arrihet të lidhet me bazën e të dhënave!';
$messages['windowopenerror'] = 'Dritarja flluskë u bllokua!';
$messages['requesttimedout'] = 'Kërkesës i mbaroi koha';
$messages['errorreadonly'] = 'S’arrihet të kryhet veprimi. Dosja është vetëm për lexim.';
$messages['errornoperm'] = 'S’arrihet të kryhet veprimi. Leje të mohuara.';
$messages['erroroverquota'] = 'S’arrihet të kryhet veprimi. S’ka hapësirë të lirë në disk.';
$messages['erroroverquotadelete'] = 'S’ka hapësirë të lirë në disk. Përdorni SHIFT+DEL që të fshini një mesazh.';
$messages['invalidrequest'] = 'Kërkesë e pavlefshme! S’u ruajt ndonjë e dhënë.';
$messages['invalidhost'] = 'Emër i pavlefshëm shërbyesi.';
$messages['nomessagesfound'] = 'S’u gjetën mesazhe në këtë kuti postare.';
$messages['loggedout'] = 'E përfunduat me sukses sesionin. Mirupafshim!';
$messages['mailboxempty'] = 'Kutia postare është e zbrazët';
$messages['nomessages'] = 'S’ka mesazhe';
$messages['refreshing'] = 'Po rifreskohet…';
$messages['loading'] = 'Po ngarkohet...';
$messages['uploading'] = 'Po ngarkohet kartelë…';
$messages['attaching'] = 'Po bashkëngjitet kartelë…';
$messages['uploadingmany'] = 'Po ngarkohen kartela…';
$messages['loadingdata'] = 'Po ngarkohen të dhëna...';
$messages['checkingmail'] = 'Po kontrollohet për mesazhe të rinj...';
$messages['sendingmessage'] = 'Po dërgohet mesazhi...';
$messages['messagesent'] = 'Mesazhi u dërgua me sukses.';
$messages['savingmessage'] = 'Po ruhet mesazhi...';
$messages['messagesaved'] = 'Mesazhi u ruajt te Skicat.';
$messages['successfullysaved'] = 'U ruajt me sukses.';
$messages['savingresponse'] = 'Po ruhet tekst përgjigjeje…';
$messages['deleteresponseconfirm'] = 'Doni vërtet të fshihet ky tekst përgjigjeje?';
$messages['nocontactselected'] = 'S’keni përzgjedhur ende ndonjë kontakt.';
$messages['addedsuccessfully'] = 'Kontakti u shtua me sukses në librin e adresave.';
$messages['contactexists'] = 'Ka tashmë një kontakt me të njëjtën adresë email.';
$messages['contactnameexists'] = 'Ka tashmë një kontakt me të njëjtin emër.';
$messages['blockedimages'] = 'Që të mbrohet privatësia juaj, figurat e largëta të këtij mesazhi janë bllokuar.';
$messages['blockedresources'] = 'Për mbrojtjen e privatësisë tuaj janë bllokuar burime të largët.';
$messages['suspiciousemail'] = 'Ky mesazh përmban adresa email të dyshimta që mund të jenë të rrejshme.';
$messages['bccemail'] = 'Mesazhi(et) e përcjella përmbajnë marrës të fshehtë (Bcc).';
$messages['bouncehint'] = 'Mesazhi do të dërgohet pa ndonjë ndryshim, d.m.th. duke përdorur lëndën, kryet dhe marrësit origjinalë.';
$messages['encryptedmessage'] = 'Ky është një mesazh i fshehtëzuar dhe s’mund të shfaqet. Na ndjeni!';
$messages['externalmessagedecryption'] = 'Ky është një mesazh i fshehtëzuar dhe mund të shfshehtëzohet me zgjerimin e shfletuesit tuaj.';
$messages['nopubkeyfor'] = 'S’u gjet kyç i vlefshëm publik për $email';
$messages['nopubkeyforsender'] = 'S’u gjet kyç i vlefshëm publik për identitetin e dërguesit tuaj. Doni të fshehtëzohet mesazhi vetëm për marrësit?';
$messages['encryptnoattachments'] = 'Bashkëngjitjet tashmë të ngarkuara s’mund të fshehtëzohen. Ju lutemi, rishtojini te përpunuesi i fshehtëzimeve.';
$messages['searchpubkeyservers'] = 'Doni të kërkohet në shërbyes publikë kyçesh për kyçin që mungon?';
$messages['encryptpubkeysfound'] = 'U gjetën kyçet publikë vijues:';
$messages['keyservererror'] = 'S\'u arrit të merret kyç që nga shërbyesi i kyçeve.';
$messages['keyimportsuccess'] = 'Kyçi publik $key u importua me sukses te vargu juaj i kyçeve.';
$messages['nocontactsfound'] = 'S’u gjetën kontakte.';
$messages['contactnotfound'] = 'S’u gjet kontakti i kërkuar.';
$messages['contactsearchonly'] = 'Duhet të përdorni një formular kërkimi që të shihni kontakte prej librit të përzgjedhur të adresave.';
$messages['sendingfailed'] = 'Dërgimi i mesazhit dështoi.';
$messages['senttooquickly'] = 'Ju lutemi, pritni $sec sekondë(a) përpara se të dërgohet ky mesazh.';
$messages['errorsavingsent'] = 'Ndodhi një gabim teksa ruhej mesazhi i dërguar.';
$messages['errorsaving'] = 'Ndodhi një gabim gjatë ruajtjes.';
$messages['errormoving'] = 'S’u lëviz dot mesazhi(et).';
$messages['errorcopying'] = 'S’u kopjua dot mesazhi(et).';
$messages['errordeleting'] = 'S’u fshi dot mesazhi(et).';
$messages['errormarking'] = 'S’iu vu dot shenjë mesazhit(eve).';
$messages['alerttitle'] = 'Kujdes';
$messages['confirmationtitle'] = 'Jeni i sigurt se…';
$messages['deletecontactconfirm']  = 'Doni vërtet të fshihet kontakti(et) i përzgjedhur?';
$messages['deletegroupconfirm']  = 'Doni vërtet të fshihet grupi i përzgjedhur?';
$messages['deletemessagesconfirm'] = 'Doni vërtet të fshihet mesazhi(et) i përzgjedhur?';
$messages['deletefolderconfirm']  = 'Doni vërtet të fshihet kjo dosje?';
$messages['movefolderconfirm']  = 'Doni vërtet të lëvizet kjo dosje?';
$messages['purgefolderconfirm']  = 'Doni vërtet të fshihen krejt mesazhet në këtë dosje?';
$messages['contactdeleting'] = 'Po fshihet kontakti(et)…';
$messages['groupdeleting'] = 'Po fshihet grupi…';
$messages['folderdeleting'] = 'Po fshihet dosja…';
$messages['foldermoving'] = 'Po lëvizet dosja…';
$messages['foldersubscribing'] = 'Po bëhet pajtimi te dosja…';
$messages['folderunsubscribing'] = 'Po hiqet pajtimi te dosja…';
$messages['formincomplete'] = 'Formulari s’u plotësua i tëri.';
$messages['noemailwarning'] = 'Ju lutemi, jepni një adresë email të vlefshme.';
$messages['nonamewarning']  = 'Ju lutemi, jepni një emër.';
$messages['nopagesizewarning'] = 'Ju lutemi, jepni një madhësi faqeje.';
$messages['nosenderwarning'] = 'Ju lutemi, jepni adresë email të dërguesit.';
$messages['recipientsadded'] = 'Marrësi(at) u shtuan me sukses.';
$messages['norecipientwarning'] = 'Ju lutemi, jepni të paktën një marrës.';
$messages['disclosedrecipwarning'] = 'Krejt pjesëmarrësit do të shohin adresat email të njëri-tjetrit. Për të parandaluar  këtë dhe mbrojtur privatësinë e tyre, mund të përdorni fushën Bcc.';
$messages['disclosedreciptitle'] = 'Shumë pjesëmarrës publikë';
$messages['nosubjectwarning']  = 'Fusha "Subjekt" është e zbrazët. Do të donit të jepnit një tani?';
$messages['nosubjecttitle']  = 'S’ka subjekt';
$messages['nobodywarning'] = 'Të dërgohet mesazhi pa tekst?';
$messages['notsentwarning'] = 'Mesazhi s’është dërguar dhe ka ndryshime të paruajtura. Doni të hidhen tej ndryshimet tuaja?';
$messages['restoresavedcomposedata'] = 'U gjet një mesazh i hartuar më parë, por i padërguar.\n\nSubjekt: $subject\nRuajtur më: $date\n\nDoni të rimerret ky mesazh?';
$messages['nosearchname'] = 'Ju lutemi, jepni emër kontakti ose adresë email.';
$messages['notuploadedwarning'] = 'S’janë ngarkuar ende krejt bashkëngjitjet. Ju lutemi, prisni ose anulojeni ngarkimin.';
$messages['searchsuccessful'] = 'U gjetën $nr mesazhe.';
$messages['contactsearchsuccessful'] = 'U gjetën $nr kontakte.';
$messages['searchnomatch'] = 'Kërkimi s’ktheu përputhje.';
$messages['searching'] = 'Po kërkohet…';
$messages['checking'] = 'Po kontrollohet…';
$messages['stillsearching'] = 'Ende në kërkim…';
$messages['nospellerrors'] = 'S’u gjetën gabime drejtshkrimi.';
$messages['folderdeleted'] = 'Dosja u fshi me sukses.';
$messages['foldersubscribed'] = 'Pajtimi te dosja u krye me sukses.';
$messages['folderunsubscribed'] = 'Pajtimi te dosja u hoq me sukses.';
$messages['folderpurged'] = 'Dosja u zbraz me sukses.';
$messages['folderexpunged'] = 'Dosja u ngjesh me sukses.';
$messages['deletedsuccessfully'] = 'U fshi me sukses.';
$messages['converting'] = 'Po i hiqet formatimi…';
$messages['messageopenerror'] = 'S’u ngarkuan dot mesazhe që nga shërbyesi.';
$messages['filelinkerror'] = 'Dështoi bashkëngjitja e kartelës.';
$messages['fileuploaderror'] = 'Dështoi ngarkimi i kartelës.';
$messages['csvfilemismatch'] = 'Nuk mbulohet importimi njëherësh i shumë kartelave CSV me fusha të ndryshme.';
$messages['filesizeerror'] = 'Kartela e ngarkuar e tejkalon madhësinë maksimum prej $size.';
$messages['filecounterror'] = 'Mund të ngarkoni e shumta $count kartela njëherësh.';
$messages['msgsizeerror'] = 'Dështoi bashkëngjitja e një kartele. Tejkalohej madhësi maksimum e një mesazhi ($size).';
$messages['msgsizeerrorfwd'] = 'U tejkalua madhësia maksimum për mesazhet ($size). S’u bashkëngjit(ën) $num mesazh(e).';
$messages['copysuccess'] = 'U kopjuan me sukses $nr kontakte.';
$messages['movesuccess'] = 'U lëvizën me sukses $nr kontakte.';
$messages['copyerror'] = 'S’u kopjua dot ndonjë kontakt.';
$messages['moveerror'] = 'S’u lëviz dot ndonjë kontakt.';
$messages['sourceisreadonly'] = 'Ky burim adrese është vetëm i lexueshëm.';
$messages['errorsavingcontact'] = 'S’u ruajt dot adresa e kontaktit.';
$messages['movingmessage'] = 'Po lëvizet mesazhi(et)...';
$messages['copyingmessage'] = 'Po kopjohet mesazhi(et)…';
$messages['copyingcontact'] = 'Po kopjohet kontakti(et)…';
$messages['movingcontact'] = 'Po lëvizet kontakti(et)…';
$messages['deletingmessage'] = 'Po fshihet mesazhi(et)…';
$messages['markingmessage'] = 'Po i vihet shenjë mesazhit(et)…';
$messages['addingmember'] = 'Po shtohet kontakti(et) te grupi…';
$messages['removingmember'] = 'Po hiqet kontakti(et) nga grupi…';
$messages['receiptsent'] = 'U dërgua me sukses dëftesë leximi.';
$messages['errorsendingreceipt'] = 'S’u dërgua dot dëftesa.';
$messages['deleteidentityconfirm'] = 'Doni vërtet të fshihet ky identitet?';
$messages['nodeletelastidentity'] = 'Këtë identitet s’mund ta fshini, është i fundit i juaji.';
$messages['forbiddencharacter'] = 'Emri i dosjes përmban një shenjë të ndaluar.';
$messages['selectimportfile'] = 'Ju lutemi, përzgjidhni kartelë për ngarkim.';
$messages['addresswriterror'] = 'Libri i adresave i përzgjedhur s’është i shkrueshëm.';
$messages['contactaddedtogroup'] = 'Kontaktet u shtuan me sukses te ky grup.';
$messages['contactremovedfromgroup'] = 'Kontaktet u hoqën me sukses nga ky grup.';
$messages['nogroupassignmentschanged'] = 'S’pati ndryshime në përshoqërime grupi.';
$messages['importwait'] = 'Po importohet, ju lutemi, prisni…';
$messages['importformaterror'] = 'Importimi dështoi! Kartela e ngarkuar s’është kartelë e vlefshme të dhënash importimi.';
$messages['importconfirm'] = '<b>U importuan me sukses $inserted kontakte</b>';
$messages['importconfirmskipped'] = '<b>U anashkaluan $skipped kontakte ekzistuese</b>';
$messages['importconfirminvalid'] = '<b>U anashkaluan $invalid kontakte të pavlefshme</b>';
$messages['importconfirmerrors'] = '<b>S’u arrit të importohen $errors kontakte të vlefshme</b>';
$messages['importmessagesuccess'] = 'U importuan me sukses $nr mesazhe';
$messages['importmessageerror'] = 'Importimi dështoi! Kartela e ngarkuar s’është kartelë e vlefshme mesazhi apo kutie postare';
$messages['opnotpermitted'] = 'Veprim i palejuar!';
$messages['nofromaddress'] = 'Në identitetin e përzgjedhur mungon adresë email.';
$messages['editorwarning'] = 'Këmbimi i llojit të përpunuesit mund të shkaktojë humbjen e formatimit të tekstit. Doni të vazhdohet?';
$messages['httpreceivedencrypterror'] = 'Ndodhi një gabim fatal formësimi. Lidhuni menjëherë me përgjegjësin tuaj. <b>Mesazhi juaj s’u dërgua dot.</b>';
$messages['smtpconnerror'] = 'Gabim SMTP ($code): Lidhja me shërbyesin dështoi.';
$messages['smtpautherror'] = 'Gabim SMTP ($code): Mirëfilltësimi dështoi.';
$messages['smtpfromerror'] = 'Gabim SMTP ($code): Dështoi rregullimi i dërguesit "$from" ($msg).';
$messages['smtptoerror'] = 'Gabim SMTP ($code): Dështoi shtimi i marrësit "$to" ($msg).';
$messages['smtprecipientserror'] = 'Gabim SMTP: S’arrihet të përtypet lista e marrësve.';
$messages['smtputf8error'] = 'Gabim SMTP: Shërbyesi nuk mbulon kodim Unikod në adresa email.';
$messages['smtpsizeerror'] = 'Gabim SMTP: Madhësia e mesazhit e tejkalon kufirin e shërbyesit ($limit)';
$messages['smtperror'] = 'Gabim SMTP: $msg';
$messages['emailformaterror'] = 'Adresë email e pavlefshme: $email';
$messages['toomanyrecipients'] = 'Shumë marrës. Zvogëloni numrin e marrësve deri në $max.';
$messages['maxgroupmembersreached'] = 'Numri i anëtarëve të grupit e tejkalon maksimumin prej $max.';
$messages['internalerror'] = 'Ndodhi një gabim i brendshëm. Ju lutemi, riprovoni.';
$messages['contactdelerror'] = 'S’u fshi dot kontakti(et).';
$messages['contactdeleted'] = 'Kontakti(et) u fshi me sukses.';
$messages['contactrestoreerror'] = 'S’u rikthye dot kontakti(et) i fshirë.';
$messages['contactrestored'] = 'Kontakti(et) u rikthye me sukses.';
$messages['groupdeleted'] = 'Grupi u fshi me sukses.';
$messages['grouprenamed'] = 'Grupi u riemërtua me sukses.';
$messages['groupcreated'] = 'Grupi u krijua me sukses.';
$messages['savedsearchdeleted'] = 'Kërkimi i ruajtur u fshi me sukses.';
$messages['savedsearchdeleteerror'] = 'S’u fshi dot kërkimi i ruajtur.';
$messages['savedsearchcreated'] = 'Kërkimi i ruajtur u krijua me sukses.';
$messages['savedsearchcreateerror'] = 'S’u krijua dot kërkimi i ruajtur.';
$messages['messagedeleted'] = 'Mesazhi(et) u fshi me sukses.';
$messages['messagemoved'] = 'Mesazhi(et) u lëviz me sukses.';
$messages['messagemovedtotrash'] = 'Mesazhi(et) u shpunë me sukses te Hedhurinat.';
$messages['messagecopied'] = 'Mesazhi(et) u kopjua me sukses.';
$messages['messagemarked'] = 'Mesazhi(et) iu vu shenjë me sukses.';
$messages['autocompletechars'] = 'Për vetëplotësim jepni të paktën $min shenjë.';
$messages['autocompletemore'] = 'U gjetën më tepër zëra me përputhje. Ju lutemi, shtypni më tepër shenja.';
$messages['namecannotbeempty'] = 'Emri s’mund të jetë i zbrazët.';
$messages['nametoolong'] = 'Emri është shumë i gjatë.';
$messages['namedotforbidden'] = 'Emri i dosjes s’mund të fillojë me një pikë.';
$messages['folderupdated'] = 'Dosja u përditësua me sukses.';
$messages['foldercreated'] = 'Dosja u krijua me sukses.';
$messages['invalidimageformat'] = 'Format i pavlefshëm figure.';
$messages['mispellingsfound'] = 'U pikasën gabime drejtshkrimi te mesazhi.';
$messages['parentnotwritable'] = 'S’arrihet të krijohet/lëvizet dosje te dosja mëmë e përzgjedhur. Pa të drejta hyrjeje.';
$messages['messagetoobig'] = 'Pjesa e mesazhit është shumë e madhe për ta përpunuar.';
$messages['attachmentvalidationerror'] = 'Kjo bashkëngjite është e dyshimtë, ngaqë nuk përputhet me llojin e deklaruar në mesazh. Nëse nuk e besoni dërguesin, s’duhet ta hapni në shfletues, ngaqë mund të përmbajë lëndë dashakeqe.<br/><br/><em>Pritej: $expected; u gjet: $detected</em>';
$messages['noscriptwarning'] = 'Kujdes: Ky shërbyes webmail lyp Javascript! Që të mund ta përdorni, ju lutemi, aktivizoni Javascript-in te rregullimet e shfletuesit tuaj.';
$messages['messageissent'] = 'Mesazhi qe dërguar tashmë, por s’qe ruajtur ende. Doni ta ruani tani?';
$messages['errnotfound'] = 'Kartelë Që S’gjendet';
$messages['errnotfoundexplain'] = 'Burimi i kërkuar nuk u gjet!';
$messages['errfailedrequest'] = 'Kërkesë e dështuar';
$messages['errauthorizationfailed'] = 'Mirëfilltësimi Dështoi';
$messages['errunauthorizedexplain'] = 'S’u verifikua dot se jeni i autorizuar të hyni në këtë shërbim!';
$messages['errrequestcheckfailed'] = 'Dështoi Kontrolli i Kërkesës';
$messages['errcsrfprotectionexplain'] = "Për hir të mbrojtjes tuaj, hyrja në këtë burim është e siguruar kundrejt CSRF-së.\nNëse e shihni këtë sinjalizim, ka gjasa që s’bëtë daljen para se të dilnit nga aplikacioni web.\n\nQë të vazhdohet, tani lypset ndërveprim nga qenie njerëzore.";
$messages['errcontactserveradmin'] = 'Ju lutemi, lidhuni me përgjegjësin e shërbyesit tuaj.';
$messages['clicktoresumesession'] = 'Klikoni këtu që të të rimerret sesioni juaj i mëparshëm';
$messages['errcomposesession'] = 'Gabim sesioni hartimi';
$messages['errcomposesessionexplain'] = 'S’u gjet sesioni i kërkuar i hartimit.';
$messages['clicktocompose'] = 'Klikoni këtu që të hartoni një mesazh të ri';
$messages['nosupporterror'] = 'Kjo veçori nuk mbulohet nga shfletuesi juaj.';
$messages['siginserted'] = 'Nënshkrimi u fut me sukses.';
$messages['responseinserted'] = 'Përgjigja u fut me sukses.';
$messages['noresponsesavailable'] = 'S’ka përgjigje';
$messages['listempty'] = 'Lista është e zbrazët.';
$messages['listusebutton'] = 'Përdorni butonin Krijoje që të shtoni një zë të ri.';
$messages['keypaircreatesuccess'] = 'Për $identity u krijua me sukses një dyshe e re kyçesh.';
$messages['emptyattachment'] = 'Kjo bashkëngjitje duket të jetë e zbrazët. <br>Ju lutemi, kontrolloni duke u lidhur me personin që e dërgoi.';
$messages['oauthloginfailed'] = 'Hyrja me OAuth dështoi. Ju lutemi, riprovoni.';
$messages['oauthinvalidrequest'] = 'Kërkesa për autorizim qe e pavlefshme, ose jo e plotë.';
$messages['oauthaccessdenied'] = 'Shërbyesi i autorizimit, ose përdoruesi nuk pranuan kërkesën.';
