<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail ACL plugin                 |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['sharing'] = 'Partajare';
$labels['myrights'] = 'Drepturi de acces';
$labels['username'] = 'Utilizator:';
$labels['advanced'] = 'Modul avansat';
$labels['add'] = 'Adaugă';
$labels['newuser'] = 'Adăugare intrare';
$labels['editperms'] = 'Editare permisiuni';
$labels['actions'] = 'Acțiunea drepturilor de acces...';
$labels['anyone'] = 'Toți utilizatori (oricare)';
$labels['anonymous'] = 'Vizitator';
$labels['identifier'] = 'Identificator';
$labels['acll'] = 'Caută';
$labels['aclr'] = 'Citire mesaje';
$labels['acls'] = 'Menține starea citirii';
$labels['aclw'] = 'Indicator scriere';
$labels['acli'] = 'Inserare (copiere în)';
$labels['aclp'] = 'Postează';
$labels['aclc'] = 'Creează subdirectoare';
$labels['aclk'] = 'Creează subdirectoare';
$labels['acld'] = 'Ștergere mesaje';
$labels['aclt'] = 'Ștergere mesaje';
$labels['acle'] = 'Elimină';
$labels['aclx'] = 'Ștergere dosar';
$labels['acla'] = 'Administrează';
$labels['acln'] = 'Adnotează mesaje';
$labels['aclfull'] = 'Control complet';
$labels['aclother'] = 'Altul';
$labels['aclread'] = 'Citeşte';
$labels['aclwrite'] = 'Scrie';
$labels['acldelete'] = 'Șterge';
$labels['shortacll'] = 'Caută';
$labels['shortaclr'] = 'Citeşte';
$labels['shortacls'] = 'Păstrează';
$labels['shortaclw'] = 'Scrie';
$labels['shortacli'] = 'Inserează';
$labels['shortaclp'] = 'Postează';
$labels['shortaclc'] = 'Creează';
$labels['shortaclk'] = 'Creează';
$labels['shortacld'] = 'Șterge';
$labels['shortaclt'] = 'Șterge';
$labels['shortacle'] = 'Elimină';
$labels['shortaclx'] = 'Ștergere dosar';
$labels['shortacla'] = 'Administrează';
$labels['shortacln'] = 'Adnotă';
$labels['shortaclother'] = 'Altul';
$labels['shortaclread'] = 'Citeşte';
$labels['shortaclwrite'] = 'Scrie';
$labels['shortacldelete'] = 'Șterge';
$labels['longacll'] = 'Dosarul este vizibil pe liste și se poate subscrie la acesta';
$labels['longaclr'] = 'Dosarul se poate deschide pentru citire';
$labels['longacls'] = 'Indicatorul de Văzut a fost schimbat';
$labels['longaclw'] = 'Indicatoarele și cuvintele cheie ale mesajelor se pot schimba cu excepția Văzut și Șters';
$labels['longacli'] = 'Mesajul se poate scrie sau copia într-un dosar';
$labels['longaclp'] = 'Mesajele se pot trimite către acest dosar';
$labels['longaclc'] = 'Dosarele se pot crea (sau redenumi) direct sub acest dosar';
$labels['longaclk'] = 'Dosarele se pot crea (sau redenumi) direct sub acest dosar';
$labels['longacld'] = 'Indicatorul de Șters al mesajelor se poate modifica';
$labels['longaclt'] = 'Indicatorul de Șters al mesajelor se poate modifica';
$labels['longacle'] = 'Mesajele se pot elimina';
$labels['longaclx'] = 'Dosarul se poate șterge sau redenumi';
$labels['longacla'] = 'Drepturile de acces la dosar se pot schimba';
$labels['longacln'] = 'Metadatele (adnotarile) impartite ale mesajelor pot fi schimbate';
$labels['longaclfull'] = 'Control complet include și administrare dosar';
$labels['longaclread'] = 'Dosarul se poate deschide pentru citire';
$labels['longaclwrite'] = 'Mesajul se poate marca, scrie sau copia într-un dosar';
$labels['longacldelete'] = 'Mesajele se pot șterge';
$labels['longaclother'] = 'Alte drepturi de acces';
$labels['ariasummaryacltable'] = 'Listă drepturi de acces';
$labels['arialabelaclactions'] = 'Arată acțiuni';
$labels['arialabelaclform'] = 'Drepturi de acces de la';
$messages['deleting'] = 'Șterg drepturile de access...';
$messages['saving'] = 'Salvez drepturi accesare...';
$messages['updatesuccess'] = 'Drepturile de acces au fost schimbate cu succes';
$messages['deletesuccess'] = 'Drepturile de acces au fost șterse cu succes';
$messages['createsuccess'] = 'Drepturile de acces au fost adăugate cu succes';
$messages['updateerror'] = 'Nu s-au putut actualiza drepturile de acces';
$messages['deleteerror'] = 'Nu s-au putut șterge drepturile de acces';
$messages['createerror'] = 'Nu s-au putut adăuga drepturi de acces';
$messages['deleteconfirm'] = 'Sunteți sigur că doriți să ștergeți drepturile de acces la utilizatorul (ii) selectați?';
$messages['norights'] = 'Nu au fost specificate drepturi!';
$messages['nouser'] = 'Nu a fost specificat niciun utilizator!';
