<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['scope'] = 'Berik';
$labels['messagedelete'] = 'Berjocht fuortsmite';
$labels['add'] = 'Tafoegje';
$labels['del'] = 'Fuortsmite';
$labels['sender'] = 'Stjoerder';
$labels['none'] = 'gjin';
$labels['flagread'] = 'Lêze';
$labels['flagdeleted'] = 'Ferwidere';
$labels['flagflagged'] = 'Flagge';
$labels['notifyimportance'] = 'Prioriteit:';
$labels['notifymethodmailto'] = 'E-mail';
$labels['notifymethodtel'] = 'Telefoannûmer';
$labels['notifymethodsms'] = 'SMS';
$labels['...'] = '...';
$labels['datetest'] = 'Date';
$labels['year'] = 'jier';
$labels['month'] = 'moanne';
$labels['day'] = 'dei';
$labels['hour'] = 'oerre';
$labels['minute'] = 'minút';
$labels['second'] = 'sekonde';
$labels['time'] = 'tiid (oo:mm:ss)';
$labels['iso8601'] = 'datum (ISO8601)';
$labels['std11'] = 'datum (RFC2822)';
$labels['zone'] = 'tiidsône';
$labels['advancedopts'] = 'Avansearre opsjes';
$labels['body'] = 'Ynhâld';
$labels['text'] = 'tekst';
$labels['modtype'] = 'type:';
$labels['domain'] = 'domein';
$labels['user'] = 'brûker';
$labels['vacation.subject'] = 'Ûnderwerp';
$labels['vacation.body'] = 'Ynhâld';
$labels['vacation.status'] = 'Status';
$labels['vacation.keep'] = 'Hâlde';
