<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Managesieve plugin         |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['filters'] = 'Филтери';
$labels['managefilters'] = 'Управљај филтерима долазне поште';
$labels['filtername'] = 'Назив филтера';
$labels['newfilter'] = 'Нови филтер';
$labels['filteradd'] = 'Додај филтер';
$labels['filterdel'] = 'Обриши филтер';
$labels['actions'] = 'Радње';
$labels['scope'] = 'Распон';
$labels['moveup'] = 'Помери горе';
$labels['movedown'] = 'Помери доле';
$labels['filterallof'] = 'поклопи сва ова правила';
$labels['filteranyof'] = 'поклопи било које од ових правила';
$labels['filterany'] = 'све поруке';
$labels['filtercontains'] = 'садржи';
$labels['filternotcontains'] = 'не садржи';
$labels['filteris'] = 'је једнак';
$labels['filterisnot'] = 'није једнак';
$labels['filterexists'] = 'постоји';
$labels['filternotexists'] = 'не постоји';
$labels['filtermatches'] = 'поклапа израз';
$labels['filternotmatches'] = 'не поклапа израз';
$labels['filterregex'] = 'поклапа регуларни израз';
$labels['filternotregex'] = 'не поклапа регуларни израз';
$labels['filterunder'] = 'испод';
$labels['filterover'] = 'преко';
$labels['addrule'] = 'Додај правило';
$labels['delrule'] = 'Обриши правило';
$labels['messagemoveto'] = 'Премести поруку у';
$labels['messageredirect'] = 'Преусмери поруку у';
$labels['messagecopyto'] = 'Копирај поруку у';
$labels['messagesendcopy'] = 'Пошаљи копију поруке за';
$labels['messagereply'] = 'Одговори поруком';
$labels['messagedelete'] = 'Обриши поруку';
$labels['messagediscard'] = 'Одбаци поруком';
$labels['messagekeep'] = 'Задржи поруку у примљеним';
$labels['messagesrules'] = 'За долазну пошту:';
$labels['add'] = 'Додај';
$labels['del'] = 'Обриши';
$labels['sender'] = 'Пошиљалац';
$labels['flagread'] = 'Читање';
$labels['flagdeleted'] = 'Обрисано';
$labels['flagflagged'] = 'Обележено';
$labels['notifymethodmailto'] = 'Е-пошта';
$labels['notifymethodtel'] = 'Телефон';
$labels['datetest'] = 'Датум';
$labels['advancedopts'] = 'Напредне опције';
$labels['body'] = 'Тело';
$labels['spamtestequals'] = 'је једнак';
$labels['spamtestnotequals'] = 'није једнак';
$labels['vacation.subject'] = 'Наслов';
$labels['vacation.body'] = 'Тело';
$labels['vacation.keep'] = 'Задржи';
$messages['filterunknownerror'] = 'Непозната грешка сервера.';
$messages['filterconnerror'] = 'Не могу да се повежем на сервер.';
