<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Password plugin            |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['changepasswd']  = 'Ndryshoni fjalëkalimin';
$labels['curpasswd']  = 'Fjalëkalimi i Tanishëm';
$labels['newpasswd']  = 'Fjalëkalimi i Ri:';
$labels['confpasswd']  = 'Ripohoni Fjalëkalimin e Ri:';
$messages['nopassword'] = 'Ju lutemi, futni fjalëkalimin e ri.';
$messages['nocurpassword'] = 'Ju lutemi, futni fjalëkalimin e tanishëm.';
$messages['passwordincorrect'] = 'Fjalëkalimi i tanishëm është i pasaktë.';
$messages['passwordinconsistency'] = 'Fjalëkalimet nuk përputhen, ju lutemi, riprovoni.';
$messages['crypterror'] = 'S’u ruajt dot fjalëkalimi i ri. Mungon funksioni i Fshehtëzimit.';
$messages['connecterror'] = 'S’u ruajt dot fjalëkalimi i ri. Gabim lidhjeje.';
$messages['internalerror'] = 'S’u ruajt dot fjalëkalimi i ri.';
$messages['passwordshort'] = 'Fjalëkalimi duhet të jetë të paktën $length shenja i gjatë.';
$messages['passwordweak'] = 'Fjalëkalimi duhet të përmbajë të paktën një numër dhe një shenjë pikësimi.';
$messages['passwordtooweak'] = 'Fjalëkalim shumë i dobët.';
$messages['passwordnoseq'] = 'Fjalëkalimi s’duhet të jetë një sekuencë si, fjala vjen, 123456 apo QWERTY.';
$messages['passwordnocommon'] = 'Fjalëkalimi s’duhet të jetë një fjalë apo emër i rëndomtë.';
$messages['passwordforbidden'] = 'Fjalëkalimi përmban shenja të ndaluara.';
$messages['firstloginchange'] = 'Kjo është hyrja juaj e parë. Ju lutemi, ndryshoni fjalëkalimin tuaj.';
$messages['disablednotice'] = 'Sistemi është hëpërhë nën gjendje punimesh mirëmbajtjeje dhe ndryshimi i fjalëkalimit s’është i mundur në këtë çast. Gjithçka do të duhej të ish kthyer në gjendje normale shumë shpejt. Kërkojmë ndjesë për çfarëdo sikleti.';
$messages['passwinhistory'] = 'Ky fjalëkalim është përdorur një herë më parë.';
$messages['samepasswd'] = 'Fjalëkalimi i ri duhet të jetë i ndryshëm nga i vjetri.';
$messages['passwdexpirewarning'] = 'Kujdes! Fjalëkalimi juaj do të skadojë së shpejti, ndryshojeni para $expirationdatetime.';
$messages['passwdexpired'] = 'Fjalëkalimi juaj ka skaduar, lypset ta ndryshoni tani!';
$messages['passwdconstraintviolation'] = 'Cenim kufizimi fjalëkalimi. Mundet fjalëkalim shumë i dobët.';
$messages['pwned_mustnotbedisclosed'] = 'Fjalëkalimi s’duhet të jetë <a href="$href" target="_blank">gjë e ditur rëndom</a>.';
$messages['pwned_isdisclosed'] = 'Ky fjalëkalim është rëndom i njohur';
$messages['pwned_fetcherror'] = 'S’u arrit të verifikohej fortësia e fjalëkalimit.';
