<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail client                     |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$messages['errortitle']  = '¡Ha ocurrido un error!';
$messages['loginfailed']  = 'Contraseña o nombre de usuario incorrecto';
$messages['cookiesdisabled'] = 'Tu navegador no acepta cookies.';
$messages['sessionerror'] = 'Tu sesión no es válida o ha expirado.';
$messages['cookiesmismatch'] = 'Se encontró una discordancia de cookies. Por favor, borrá las cookies de tu navegador.';
$messages['storageerror'] = 'Error de conexión con el servidor IMAP.';
$messages['servererror'] = '¡Error en el servidor!';
$messages['servererrormsg'] = 'Error en servidor: $msg';
$messages['accountlocked'] = 'Demasiados errores de inicio de sesión. Intentá de nuevo más tarde.';
$messages['connerror'] = 'Error de conexión (No se pudo conectar con el servidor)';
$messages['dberror'] = '¡Error en base de datos!';
$messages['dbconnerror'] = '¡No fue posible conectar con la base de datos!';
$messages['windowopenerror'] = '¡La ventana emergente ha sido bloqueada!';
$messages['requesttimedout'] = 'Tiempo de espera agotado';
$messages['errorreadonly'] = 'No se pudo realizar la operación. La carpeta es de sólo lectura.';
$messages['errornoperm'] = 'No se pudo realizar la operación. Permiso denegado.';
$messages['erroroverquota'] = 'No se pudo realizar la operación. Espacio en disco insuficiente.';
$messages['erroroverquotadelete'] = 'Espacio en disco insuficiente. Usá SHIFT+DEL para eliminar un mensaje.';
$messages['invalidrequest'] = '¡Petición no válida! No se guardó ningún dato.';
$messages['invalidhost'] = 'Nombre de servidor no válido.';
$messages['nomessagesfound'] = 'No se han encontrado mensajes en esta casilla.';
$messages['loggedout'] = 'Terminaste la sesión satisfactoriamente. ¡Hasta luego!';
$messages['mailboxempty'] = 'La casilla está vacía';
$messages['nomessages'] = 'No hay mensajes';
$messages['refreshing'] = 'Actualizando...';
$messages['loading'] = 'Cargando...';
$messages['uploading'] = 'Subiendo archivo...';
$messages['attaching'] = 'Adjuntando archivo...';
$messages['uploadingmany'] = 'Subiendo archivos...';
$messages['loadingdata'] = 'Cargando datos...';
$messages['checkingmail'] = 'Verificando si hay nuevos mensajes...';
$messages['sendingmessage'] = 'Enviando mensaje...';
$messages['messagesent'] = 'Mensaje enviado correctamente';
$messages['savingmessage'] = 'Guardar mensaje...';
$messages['messagesaved'] = 'Mensaje guardado en borradores';
$messages['successfullysaved'] = 'Guardado correctamente';
$messages['savingresponse'] = 'Guardando texto de respuesta...';
$messages['deleteresponseconfirm'] = '¿Realmente deseás eliminar este texto de respuesta?';
$messages['nocontactselected'] = 'Todavía no seleccionaste un contacto.';
$messages['addedsuccessfully'] = 'Contacto agregado correctamente a la libreta de direcciones.';
$messages['contactexists'] = 'Ya existe un contacto con la misma dirección de correo electrónico.';
$messages['contactnameexists'] = 'Ya existe un contacto con el mismo nombre.';
$messages['blockedimages'] = 'Para proteger tu privacidad, las imágenes externas han sido bloqueadas en este mensaje.';
$messages['blockedresources'] = 'Para proteger tu privacidad los recursos remotos han sido bloqueados.';
$messages['suspiciousemail'] = 'Este mensaje contiene direcciones de correo electrónico sospechosas que pueden ser fraudulentas.';
$messages['bccemail'] = 'El o los mensajes reenviados contienen destinatarios confidenciales (Bcc)';
$messages['bouncehint'] = 'El mensaje será enviado sin ninguna modificación, ej. usando el cuerpo original, encabezados y destinatarios.';
$messages['encryptedmessage'] = 'Lo siento, este es un mensaje cifrado y no puede ser mostrado.';
$messages['externalmessagedecryption'] = 'Este es un mensaje cifrado y se puede descifrar con una extensión de tu navegador.';
$messages['nopubkeyfor'] = 'No se encontró una clave pública para $email';
$messages['nopubkeyforsender'] = 'No se encontró una clave pública para tu identidad remitente. ¿Querés encriptar el mensaje solo para los destinatarios?';
$messages['encryptnoattachments'] = 'Los adjuntos ya subidos no pueden ser encriptados. Volvé a agregarlos en el editor de encriptación.';
$messages['searchpubkeyservers'] = '¿Deseás buscar las claves faltantes en servidores de claves públicas?';
$messages['encryptpubkeysfound'] = 'Se han encontrado las siguientes claves públicas:';
$messages['keyservererror'] = 'Error al obtener la clave del servidor de claves.';
$messages['keyimportsuccess'] = 'La clave pública $key fue importada satisfactoriamente a tu almacén de claves.';
$messages['nocontactsfound'] = 'No se encontraron contactos.';
$messages['contactnotfound'] = 'No se encontró el contacto solicitado.';
$messages['contactsearchonly'] = 'Necesitás usar un formulario de búsqueda para ver contactos de la libreta de direcciones seleccionada.';
$messages['sendingfailed'] = 'Error al enviar mensaje.';
$messages['senttooquickly'] = 'Por favor, esperá $sec segundo(s) antes de enviar este mensaje.';
$messages['errorsavingsent'] = 'Ocurrió un error al guardar el mensaje enviado.';
$messages['errorsaving'] = 'Ocurrió un error al guardar.';
$messages['errormoving'] = 'No se pudo mover el/los mensaje(s)';
$messages['errorcopying'] = 'No se pudo copiar el/los mensaje(s).';
$messages['errordeleting'] = 'No se ha podido eliminar el/los mensaje(s).';
$messages['errormarking'] = 'No se puede marcar el/los mensaje(s).';
$messages['alerttitle'] = 'Atención';
$messages['confirmationtitle'] = 'Estás seguro...';
$messages['deletecontactconfirm']  = '¿Realmente quiere eliminar los contactos seleccionados?';
$messages['deletegroupconfirm']  = 'Realmente deseas eliminar el grupo seleccionado?';
$messages['deletemessagesconfirm'] = '¿Realmente quiere eliminar los mensajes seleccionados?';
$messages['deletefolderconfirm']  = '¿Realmente quiere eliminar esta carpeta?';
$messages['movefolderconfirm']  = '¿Realmente deseás mover esta carpeta?';
$messages['purgefolderconfirm']  = '¿Realmente quiere eliminar todos los mensajes de esta carpeta?';
$messages['contactdeleting'] = 'Eliminando contacto(s)...';
$messages['groupdeleting'] = 'Eliminando grupo...';
$messages['folderdeleting'] = 'Eliminando carpeta...';
$messages['foldermoving'] = 'Moviendo carpeta...';
$messages['foldersubscribing'] = 'Suscribiendo a carpeta...';
$messages['folderunsubscribing'] = 'Quitando suscripción a carpeta...';
$messages['formincomplete'] = 'No se han llenado todos los campos del formulario';
$messages['noemailwarning'] = 'Por favor, introduzca un e-mail válido';
$messages['nonamewarning']  = 'Por favor, introduzca su nombre';
$messages['nopagesizewarning'] = 'Por favor, introduzca un tamaño de página';
$messages['nosenderwarning'] = 'Por favor, Ingresá la dirección de correo electrónico del remitente.';
$messages['recipientsadded'] = 'Destinatario(s) agregado(s) satisfactoriamente.';
$messages['norecipientwarning'] = 'Por favor, introduzca al menos un destinatario';
$messages['disclosedreciptitle'] = 'Demasiados destinatarios públicos';
$messages['nosubjectwarning']  = 'El campo "Asunto" esta vacío. ¿Desea completarlo en este momento?';
$messages['nosubjecttitle']  = 'Sin asunto';
$messages['nobodywarning'] = '¿Quiere enviar este mensaje sin texto?';
$messages['notsentwarning'] = 'El mensaje no se ha enviado y tiene cambios sin guardar. ¿Querés descartar los cambios?';
$messages['restoresavedcomposedata'] = 'Se ha encontrado un mensaje redactado anteriormente que no ha sido enviado.\n\nAsunto: $subject\nGuardado: $date\n\nDeseas recuperar este mensaje?';
$messages['nosearchname'] = 'Por favor, introduzca un nombre o la dirección de e-mail';
$messages['notuploadedwarning'] = 'Todavia no se subieron todos los archivos adjuntos. Por favor aguarde o cancele la subida.';
$messages['searchsuccessful'] = 'Se encontraron $nr mensajes';
$messages['contactsearchsuccessful'] = '$nr contactos encontrados.';
$messages['searchnomatch'] = 'La búsqueda no obtuvo resultados';
$messages['searching'] = 'Buscando...';
$messages['checking'] = 'Revisando...';
$messages['stillsearching'] = 'Búsqueda en progreso...';
$messages['nospellerrors'] = 'No se encontraron errores ortográficos';
$messages['folderdeleted'] = 'Carpeta eliminada exitosamente';
$messages['foldersubscribed'] = 'Suscripción a carpeta exitosa.';
$messages['folderunsubscribed'] = 'Suscripción a carpeta exitosamente eliminada.';
$messages['folderpurged'] = 'Carpeta vaciada exitosamente';
$messages['folderexpunged'] = 'Carpeta compactada exitosamente';
$messages['deletedsuccessfully'] = 'Eliminado exitosamente';
$messages['converting'] = 'Removiendo el formato del mensaje...';
$messages['messageopenerror'] = 'No puedo descargar el mensaje del servidor';
$messages['filelinkerror'] = 'Error al adjuntar archivo.';
$messages['fileuploaderror'] = 'Error al subir archivos';
$messages['csvfilemismatch'] = 'No es posible importar múltiples archivos CSV con campos diferentes.';
$messages['filesizeerror'] = 'El archivo excede el tamaño maximo ($size)';
$messages['filecounterror'] = 'Podés subir un máximo de $count archivos a la vez.';
$messages['msgsizeerror'] = 'Error al adjuntar un archivo. Se excedió el tamaño máximo ($size) del mensaje.';
$messages['msgsizeerrorfwd'] = 'Tamaño máximo del mensaje ($size) excedido. $num mensaje(s) no ha(n) sido ajuntado(s).';
$messages['copysuccess'] = '$nr contactos copiados exitosamente.';
$messages['movesuccess'] = '$nr contactos movidos exitosamente.';
$messages['copyerror'] = 'No se pudo copiar ningún contacto.';
$messages['moveerror'] = 'No se pudo mover ningún contacto.';
$messages['sourceisreadonly'] = 'Esta dirección es de sólo-lectura';
$messages['errorsavingcontact'] = 'No se pudo guardar la dirección de contacto';
$messages['movingmessage'] = 'Moviendo mensaje...';
$messages['copyingmessage'] = 'Copiando mensaje...';
$messages['copyingcontact'] = 'Copiando contacto(s)...';
$messages['movingcontact'] = 'Moviendo contacto(s)...';
$messages['deletingmessage'] = 'Eliminando contacto(s)...';
$messages['markingmessage'] = 'Marcando mensaje(s)...';
$messages['addingmember'] = 'Agregando contacto(s) al grupo...';
$messages['removingmember'] = 'Quitando contacto(s) del grupo...';
$messages['receiptsent'] = 'La notificación de lectura se ha enviado con éxito.';
$messages['errorsendingreceipt'] = 'No se ha podido enviar la notificación de lectura.';
$messages['deleteidentityconfirm'] = 'Realmente querés eliminar esta identidad?';
$messages['nodeletelastidentity'] = 'No se puede borrar esta identidad puesto que es la última.';
$messages['forbiddencharacter'] = 'El nombre de la carpeta contiene un carácter prohibido';
$messages['selectimportfile'] = 'Por favor, seleccione el archivo a subir';
$messages['addresswriterror'] = 'La libreta de direcciones seleccionada es de solo-lectura';
$messages['contactaddedtogroup'] = 'Contactos agregados al grupo correctamente';
$messages['contactremovedfromgroup'] = 'Contactos eliminados del grupo correctamente';
$messages['nogroupassignmentschanged'] = 'Ninguna asiganción de grupo fue modificada.';
$messages['importwait'] = 'Importando, aguarde por favor...';
$messages['importformaterror'] = 'Importación fallida! El archivo subido no es un archivo de importación de datos válido.';
$messages['importconfirm'] = '<b>Se importaron $inserted contactos correctamente. $skipped ya existentes fueron ignorados</b>:<p><em>$names</em></p>';
$messages['importmessagesuccess'] = '$nr mensajes importados exitosamente';
$messages['importmessageerror'] = 'Importación fallida! El archivo subido no es un mensaje o archivo mailbox válido';
$messages['opnotpermitted'] = 'Operación no permitida!';
$messages['nofromaddress'] = 'A la identidad seleccionada le falta la dirección de correo electrónico.';
$messages['editorwarning'] = 'Cambiar el tipo de editor puede causar la pérdida del formato. Deseas continuar?';
$messages['httpreceivedencrypterror'] = 'Ha ocurrido un error fatal de configuración. Contactá inmediatamente al administrador. <b>Tu mensaje no pudo ser enviado.</b>';
$messages['smtpconnerror'] = 'Error SMTP ($code): Conexión al servidor falló';
$messages['smtpautherror'] = 'Error SMTP ($code): Falló la autentificación';
$messages['smtpfromerror'] = 'Error SMTP ($code): No se pudo establecer el remitente "$from" ($msg)';
$messages['smtptoerror'] = 'Error SMTP ($code): No se puedo agregar el destinatario "$to" ($msg)';
$messages['smtprecipientserror'] = 'Error SMTP: No se pudo leer la lista de destinatarios';
$messages['smtputf8error'] = 'Error SMTP: El servidor no soporta Unicode en las direcciones de correo.';
$messages['smtpsizeerror'] = 'Error SMTP: El mensaje excede el límite del servidor ($limit)';
$messages['smtperror'] = 'Error SMTP: $msg';
$messages['emailformaterror'] = 'Dirección de correo electrónico no válida: $email';
$messages['toomanyrecipients'] = 'Demasiados destinatarios. Reducí la cantidad a un máximo de $max.';
$messages['maxgroupmembersreached'] = 'El número de miembros del grupo excede el máximo de $max';
$messages['internalerror'] = 'Ocurrió un error interno. Por favor, intentá nuevamente.';
$messages['contactdelerror'] = 'No se pudo eliminar el/los contactos(s).';
$messages['contactdeleted'] = 'Contacto(s) eliminado/s exitosamente.';
$messages['contactrestoreerror'] = 'No se pudo recuperar el/los contacto/s eliminado(s).';
$messages['contactrestored'] = 'Contacto(s) recuperado/s satisfactoriamente.';
$messages['groupdeleted'] = 'Grupo eliminado correctamente.';
$messages['grouprenamed'] = 'Grupo renombrado satisfactoriamente.';
$messages['groupcreated'] = 'Grupo creado satisfactoriamente.';
$messages['savedsearchdeleted'] = 'Búsqueda guardada se eliminó satisfactoriamente.';
$messages['savedsearchdeleteerror'] = 'No se pudo eliminar la búsqueda guardada.';
$messages['savedsearchcreated'] = 'Búsqueda guardada exitosamente.';
$messages['savedsearchcreateerror'] = 'No se pudo guardar la búsqueda.';
$messages['messagedeleted'] = 'Mensaje(s) eliminado/s satisfactoriamente.';
$messages['messagemoved'] = 'Mensaje(s) movidos correctamente.';
$messages['messagemovedtotrash'] = 'Mensaje(s) movido(s) a la Papelera satisfactoriamente.';
$messages['messagecopied'] = 'Mensaje(s) copiados correctamente.';
$messages['messagemarked'] = 'Mensaje(s) marcados satisfactoriamente.';
$messages['autocompletechars'] = 'Ingresá por lo menos $min caracteres para autocompletar.';
$messages['autocompletemore'] = 'Se encontraron mas coincidencias. Por favor, escribí mas caracteres.';
$messages['namecannotbeempty'] = 'El nombre no puede estar vacio.';
$messages['nametoolong'] = 'El nombre es demasiado largo.';
$messages['namedotforbidden'] = 'El nombre de la carpeta no puede comenzar con un punto.';
$messages['folderupdated'] = 'Carpeta actualizada correctamente.';
$messages['foldercreated'] = 'Carpeta creada satisfactoriamente.';
$messages['invalidimageformat'] = 'No es un formato de imágen válido.';
$messages['mispellingsfound'] = 'Errores de ortografía encontrados en el mensaje.';
$messages['parentnotwritable'] = 'No se pudo crear/mover la carpeta dentro de la carpeta superior seleccionada. No tiene permiso para acceder a ella.';
$messages['messagetoobig'] = 'El mensaje es demasiado grande para ser procesado.';
$messages['attachmentvalidationerror'] = 'Este adjunto es sospechoso porque su tipo no coinciden con el tipo declarado en el mensaje. Si no confiás en el remitente no deberías abrir el mensaje en el navegador porque podría tener contenido malicioso.<br/><br/><em>Esperado: $expected; encontrado: $detected</em>';
$messages['noscriptwarning'] = 'Advertencia: Este servicio de webmail requiere Javascript! Para usarlo, por favor, habilite Javascript en las preferencia de tu navegador.';
$messages['messageissent'] = 'El mensaje se envió pero todavía no fue guardado. ¿Querés guardarlo ahora?';
$messages['errnotfound'] = 'Archivo no encontrado';
$messages['errnotfoundexplain'] = '¡No se encontró el recurso solicitado!';
$messages['errfailedrequest'] = 'Error en la solicitud';
$messages['errauthorizationfailed'] = 'Falló la autorización';
$messages['errunauthorizedexplain'] = '¡No pudimos verificar que estuvieses autorizado a acceder a este servicio!';
$messages['errrequestcheckfailed'] = 'Verificación de la solicitud fallida';
$messages['errcsrfprotectionexplain'] = "El acceso a este recurso está protegido contra CSRF.\nSi ves esto probablemente no cerrarste la sesión antes de salir de la aplicación web.\nSe necesita interacción humana para continuar.";
$messages['errcontactserveradmin'] = 'Por favor, contactate con el administrador del servidor.';
$messages['clicktoresumesession'] = 'Hacé clic acá para continuar la sesión previa';
$messages['errcomposesession'] = 'Error al componer la sesión';
$messages['errcomposesessionexplain'] = 'No se encontró la composición de sesión solicitada.';
$messages['clicktocompose'] = 'Hacé clic aquí para componer un nuevo mensaje';
$messages['nosupporterror'] = 'Tu navegador no tiene soporte para esta función.';
$messages['siginserted'] = 'Firma insertada satisfactoriamente.';
$messages['responseinserted'] = 'Respuesta insertada satisfactoriamente.';
$messages['noresponsesavailable'] = 'No hay respuestas disponibles';
$messages['listempty'] = 'La lista está vacía.';
$messages['listusebutton'] = 'Usá el botón Crear para agregar un nuevo registro.';
$messages['keypaircreatesuccess'] = 'Un nuevo par de claves ha sido creado satisfactoriamente para $identity.';
$messages['emptyattachment'] = 'Este archivo adjunto parece estar vacío.<br>Por favor, consulte con la persona que lo envió.';
$messages['oauthloginfailed'] = 'Falló la autenticación mediante OAuth. Por favor, intentá nuevamente.';
